(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    690267,      22220]*)
(*NotebookOutlinePosition[    691573,      22261]*)
(*  CellTagsIndexPosition[    691482,      22255]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Growth Model with EKF", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(\(@\)\(ARTICLE\)\) {Singer : 
          1998, \[IndentingNewLine]AUTHOR = {Singer, \(\(H\)\(.\)\)}, \
\[IndentingNewLine]TITLE = {{Continuous\ Panel\ Models\ with\ Time\ Dependent\
\ Parameters}}, \[IndentingNewLine]JOURNAL = {Journal\ of\ Mathematical\ \
Sociology}, \[IndentingNewLine]VOLUME = {23}, \[IndentingNewLine]PAGES = \
{\(77--\) 98}, \[IndentingNewLine]YEAR = {1998}}\ \), "\[IndentingNewLine]", 
    \(\(\(=\)\(\ \)\(growth . 
        pdf\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(@\)\(INCOLLECTION\)\) {Singer : 
          2006  b, \[IndentingNewLine]AUTHOR = {Singer, \(\(H\)\(.\)\)}, \
\[IndentingNewLine]TITLE = {{Stochastic\ Differential\ Equation\ Models\ with\
\ Sampled\ Data}}, 
        BOOKTITLE = {Longitudinal\ Models\ in\ the\ Behavioral\ and\ related\ \
Sciences}, 
        SERIES = {{The\ European\ Association\ of\ Methodology\ \((EAM)\)\ \
Methodology\ and\ Statistics\ series, vol . II}}, 
        PUBLISHER = {Erlbaum\ publishers}, \[IndentingNewLine]YEAR = {2006}, \
\[IndentingNewLine]EDITOR = {van\ Montfort, K . and\ Oud, 
            H . and\ Satorra, \(\(A\)\(.\)\)}, \[IndentingNewLine]NOTE = {}, \
\[IndentingNewLine]PAGES = {}}\), "\[IndentingNewLine]", 
    \(\(\(=\)\(SDGL . pdf\)\)\)}], "Input",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["load packages", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
<<Kuba.Impl.m
<<Kalman.exakt.impl.m\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(RandomMultinomial\) is Protected."\)], "Message"],

Cell[BoxData[
    \(SetDelayed::"write" \(\(:\)\(\ \)\) 
      "Tag \!\(RandomMultinomial\) in \!\(RandomMultinomial[\(\(xij_, pij_, \
n_\)\)]\) is Protected."\)], "Message"],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(RandomNumbers\) is Protected."\)], "Message"],

Cell[BoxData[
    \(SetDelayed::"write" \(\(:\)\(\ \)\) 
      "Tag \!\(RandomNumbers\) in \!\(RandomNumbers[\(\(\(\({x1_, x2_, dx_}\)\
\), density_, n_\)\)]\) is Protected."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$Path", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({"Macintosh HD:Mathematica 4.2 Files:AddOns:JLink", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Kernel", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Autoload", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Applications", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Kernel", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Autoload", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Applications", ":", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:StandardPackages", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:StandardPackages:StartUp", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:Autoload", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:Applications", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:ExtraPackages", 
      "Macintosh HD:Mathematica 4.2 Files:SystemFiles:Graphics:Packages", 
      "Macintosh HD:Mathematica 4.2 Files:Configuration:Kernel", 
      "Macintosh HD:Mathematica 2.2.2:Hermann.Notebooks:SDE", 
      "Macintosh HD:Mathematica 2.2.2:Hermann.Notebooks:SDE:code", 
      "Macintosh HD:Mathematica \
2.2.2:Hermann.Notebooks:SDE:applications"}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["system and Jacobi matrices", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Clear[A0,A1,A,t,s]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
A0 = {{lambda11,lambda12},
\t  {lambda21,lambda22}}/100    (*scaling*)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{lambda11\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A1[t_] := {{alpha t,     0},\n\t\t   {0,      beta t}}/100; ",
  StyleBox["(*scaling*)",
    FontColor->RGBColor[1, 0, 0]]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["A[t_] = A0 + A1[t]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{lambda11\/100 + \(alpha\ t\)\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100 + \(beta\ t\)\/100}}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Matrices do not commute !",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["(A[t].A[s]-A[s].A[t]//Simplify)//MatrixForm", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0", \(-\(\(\((alpha - beta)\)\ lambda12\ \((s - 
                          t)\)\)\/10000\)\)},
            {\(\(\((alpha - beta)\)\ lambda21\ \((s - t)\)\)\/10000\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
drift//Clear
drift[{y1_,y2_},{t_},{lambda11_,lambda12_,
\t\t\t\t\t  lambda21_,lambda22_,
\t\t\t\t\t  alpha_,beta_}] = A[t].{y1,y2} \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({\((lambda11\/100 + \(alpha\ t\)\/100)\)\ y1 + \(lambda12\ y2\)\/100, \
\(lambda21\ y1\)\/100 + \((lambda22\/100 + \(beta\ t\)\/100)\)\ y2}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
drift[{Y1,Y2},{t},{lambda11,lambda12,lambda21,lambda22,
\t\t\t\t\talpha,beta}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({\((lambda11\/100 + \(alpha\ t\)\/100)\)\ Y1 + \(lambda12\ Y2\)\/100, \
\(lambda21\ Y1\)\/100 + \((lambda22\/100 + \(beta\ t\)\/100)\)\ Y2}\)], \
"Output"]
}, Open  ]],

Cell[TextData[StyleBox["time dependent diffusion ",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["\<\
diffusion//Clear
diffusion[{y1_,y2_},{t_},
\t{lambda11_,lambda12_,
     lambda21_,lambda22_,
\t\t\talpha_,beta_}] := t{{.01,0},{0,.02}}\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
diffusion[{Y1,Y2},{t},{lambda11,lambda12,lambda21,lambda22,alpha,\
beta}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.01`\ t, 0}, {0, 0.02`\ t}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[Jacobif,y1,y2,lambda11,lambda12,lambda21,lambda22,alpha,beta];\


Jacobif[{y1_,y2_},{t_},{lambda11_,lambda12_,lambda21_,lambda22_,alpha_,beta_}]\
 = 
\t\tOuter[D,drift[{y1,y2},{t},{lambda11,lambda12,
\t \t\tlambda21,lambda22,alpha,beta}],{y1,y2}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{lambda11\/100 + \(alpha\ t\)\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100 + \(beta\ t\)\/100}}\)], "Output"]
}, Open  ]],

Cell["\<\
mue[{t_},theta_] := {0,0}//N;

sigma[{t_},theta_] := {{10^16,0},{0,10^16}}//N;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["sigma[{_},_]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1.`*^16, 0.`}, {0.`, 1.`*^16}}\)], "Output"]
}, Open  ]],

Cell["\<\
h//Clear
h[{y1_,y2_},{t_},theta_] := {y1,y2};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Jacobih//Clear
Jacobih[{y1_,y2_},{t_},theta_] = IdentityMatrix[2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 0}, {0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R//Clear
R[{y1_,y2_},{t_},theta_] = .001 IdentityMatrix[2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.001`, 0}, {0, 0.001`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["simulation", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
SeedRandom[9999];
Y0 = {1,2};
n = 10;
Y0 = Shape[1,{n}]/. (1->Y0)
T = 100;
dt = 10.^-1;
Theta = {.1,-.01,.02,.3,.01,-.02}*100;
\t\t(*{lambda11_,lambda12_,lambda21_,lambda22_,alpha_,beta_}*)
k = 2;
p = 2;
q = 1;
X = Shape[1,{n}]/. 1->Shape[dt Range[0,T],{T+1,q}];
Nonlin = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 
        2}, {1, 2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["X//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Panel data",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["\<\
{Z,Y} = 

MapThread[
     NonLinStateSpace[h,{R,const},drift,diffusion,#1,#2,T,dt,Theta,Gauss,\
EulerStep]&,
\t      {Y0,X}]//Transpose;//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({1.0500000000000114`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
plot1[Z//flatten[#,{1,3}]&//Transpose//AddTimeAxis,
\t\tdicke->0.002,farbmodell->Hue]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 21}\),
      SequenceForm[ "Dimension der Daten  ", {101, 21}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.0212878 0.0379809 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07366 -18 -4.5 ]
[-0.0125 .07366 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .26357 -18 -4.5 ]
[-0.0125 .26357 0 4.5 ]
[-0.0125 .35852 -12 -4.5 ]
[-0.0125 .35852 0 4.5 ]
[-0.0125 .45347 -24 -4.5 ]
[-0.0125 .45347 0 4.5 ]
[-0.0125 .54842 -12 -4.5 ]
[-0.0125 .54842 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .10412 -5 -6 ]
[.97619 .10412 5 6 ]
[.97619 .59268 -5 -6 ]
[.97619 .59268 5 6 ]
[.97619 .08556 -5 -6 ]
[.97619 .08556 5 6 ]
[.97619 .53057 -5 -6 ]
[.97619 .53057 5 6 ]
[.97619 .10907 -5 -6 ]
[.97619 .10907 5 6 ]
[.97619 .59327 -5 -6 ]
[.97619 .59327 5 6 ]
[.97619 .10674 -5 -6 ]
[.97619 .10674 5 6 ]
[.97619 .58131 -5 -6 ]
[.97619 .58131 5 6 ]
[.97619 .09345 -5 -6 ]
[.97619 .09345 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .09592 -5 -6 ]
[.97619 .09592 5 6 ]
[.97619 .54961 -5 -6 ]
[.97619 .54961 5 6 ]
[.97619 .10354 -5 -6 ]
[.97619 .10354 5 6 ]
[.97619 .54937 -5 -6 ]
[.97619 .54937 5 6 ]
[.97619 .09403 -5 -6 ]
[.97619 .09403 5 6 ]
[.97619 .57498 -5 -6 ]
[.97619 .57498 5 6 ]
[.97619 .09156 -5 -6 ]
[.97619 .09156 5 6 ]
[.97619 .58622 -5 -6 ]
[.97619 .58622 5 6 ]
[.97619 .09089 -5 -6 ]
[.97619 .09089 5 6 ]
[.97619 .55089 -5 -6 ]
[.97619 .55089 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07366 m
.00625 .07366 L
s
[(2.5)] -0.0125 .07366 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(5)] -0.0125 .16862 1 0 Mshowa
0 .26357 m
.00625 .26357 L
s
[(7.5)] -0.0125 .26357 1 0 Mshowa
0 .35852 m
.00625 .35852 L
s
[(10)] -0.0125 .35852 1 0 Mshowa
0 .45347 m
.00625 .45347 L
s
[(12.5)] -0.0125 .45347 1 0 Mshowa
0 .54842 m
.00625 .54842 L
s
[(15)] -0.0125 .54842 1 0 Mshowa
.125 Mabswid
0 .09265 m
.00375 .09265 L
s
0 .11165 m
.00375 .11165 L
s
0 .13064 m
.00375 .13064 L
s
0 .14963 m
.00375 .14963 L
s
0 .18761 m
.00375 .18761 L
s
0 .2066 m
.00375 .2066 L
s
0 .22559 m
.00375 .22559 L
s
0 .24458 m
.00375 .24458 L
s
0 .28256 m
.00375 .28256 L
s
0 .30155 m
.00375 .30155 L
s
0 .32054 m
.00375 .32054 L
s
0 .33953 m
.00375 .33953 L
s
0 .37751 m
.00375 .37751 L
s
0 .3965 m
.00375 .3965 L
s
0 .41549 m
.00375 .41549 L
s
0 .43448 m
.00375 .43448 L
s
0 .47246 m
.00375 .47246 L
s
0 .49145 m
.00375 .49145 L
s
0 .51044 m
.00375 .51044 L
s
0 .52943 m
.00375 .52943 L
s
0 .05467 m
.00375 .05467 L
s
0 .03568 m
.00375 .03568 L
s
0 .01669 m
.00375 .01669 L
s
0 .56742 m
.00375 .56742 L
s
0 .58641 m
.00375 .58641 L
s
0 .6054 m
.00375 .6054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07366 m
1 .07366 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .26357 m
1 .26357 L
s
.99375 .35852 m
1 .35852 L
s
.99375 .45347 m
1 .45347 L
s
.99375 .54842 m
1 .54842 L
s
.125 Mabswid
.99625 .09265 m
1 .09265 L
s
.99625 .11165 m
1 .11165 L
s
.99625 .13064 m
1 .13064 L
s
.99625 .14963 m
1 .14963 L
s
.99625 .18761 m
1 .18761 L
s
.99625 .2066 m
1 .2066 L
s
.99625 .22559 m
1 .22559 L
s
.99625 .24458 m
1 .24458 L
s
.99625 .28256 m
1 .28256 L
s
.99625 .30155 m
1 .30155 L
s
.99625 .32054 m
1 .32054 L
s
.99625 .33953 m
1 .33953 L
s
.99625 .37751 m
1 .37751 L
s
.99625 .3965 m
1 .3965 L
s
.99625 .41549 m
1 .41549 L
s
.99625 .43448 m
1 .43448 L
s
.99625 .47246 m
1 .47246 L
s
.99625 .49145 m
1 .49145 L
s
.99625 .51044 m
1 .51044 L
s
.99625 .52943 m
1 .52943 L
s
.99625 .05467 m
1 .05467 L
s
.99625 .03568 m
1 .03568 L
s
.99625 .01669 m
1 .01669 L
s
.99625 .56742 m
1 .56742 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .6054 m
1 .6054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
gsave
.97619 .10412 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01614 m
.03333 .0204 L
.04286 .01773 L
.05238 .01774 L
.0619 .01751 L
.07143 .01811 L
.08095 .01932 L
.09048 .018 L
.1 .01982 L
.10952 .02109 L
.11905 .01965 L
.12857 .02005 L
.1381 .02163 L
.14762 .02043 L
.15714 .02002 L
.16667 .02359 L
.17619 .02131 L
.18571 .0232 L
.19524 .02476 L
.20476 .02291 L
.21429 .02257 L
.22381 .02357 L
.23333 .02231 L
.24286 .02532 L
.25238 .02579 L
.2619 .02439 L
.27143 .0269 L
.28095 .02575 L
.29048 .03143 L
.3 .02822 L
.30952 .0287 L
.31905 .02906 L
.32857 .02965 L
.3381 .03121 L
.34762 .03147 L
.35714 .03121 L
.36667 .03119 L
.37619 .0332 L
.38571 .03373 L
.39524 .03428 L
.40476 .03369 L
.41429 .03617 L
.42381 .03613 L
.43333 .0365 L
.44286 .037 L
.45238 .03565 L
.4619 .03751 L
.47143 .04156 L
.48095 .03863 L
.49048 .03967 L
Mistroke
.5 .04328 L
.50952 .04263 L
.51905 .03992 L
.52857 .04351 L
.5381 .04578 L
.54762 .04699 L
.55714 .04643 L
.56667 .04874 L
.57619 .04732 L
.58571 .04815 L
.59524 .05157 L
.60476 .05033 L
.61429 .05093 L
.62381 .05227 L
.63333 .05521 L
.64286 .0557 L
.65238 .05709 L
.6619 .05675 L
.67143 .06004 L
.68095 .06078 L
.69048 .06285 L
.7 .06486 L
.70952 .06816 L
.71905 .06528 L
.72857 .06768 L
.7381 .06971 L
.74762 .07008 L
.75714 .0715 L
.76667 .0742 L
.77619 .07141 L
.78571 .07402 L
.79524 .0744 L
.80476 .07321 L
.81429 .07429 L
.82381 .07805 L
.83333 .07512 L
.84286 .07969 L
.85238 .0806 L
.8619 .08297 L
.87143 .08579 L
.88095 .08725 L
.89048 .09146 L
.9 .09345 L
.90952 .09406 L
.91905 .09683 L
.92857 .09791 L
.9381 .09924 L
.94762 .09873 L
.95714 .10221 L
.96667 .10544 L
Mistroke
.97619 .10412 L
Mfstroke
1 0 .6 r
gsave
.97619 .59268 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05749 m
.03333 .05678 L
.04286 .05846 L
.05238 .06281 L
.0619 .06444 L
.07143 .0687 L
.08095 .07007 L
.09048 .07012 L
.1 .076 L
.10952 .0766 L
.11905 .08022 L
.12857 .08059 L
.1381 .08482 L
.14762 .0878 L
.15714 .09203 L
.16667 .09704 L
.17619 .09912 L
.18571 .10042 L
.19524 .1041 L
.20476 .10709 L
.21429 .11077 L
.22381 .1167 L
.23333 .12069 L
.24286 .12449 L
.25238 .1283 L
.2619 .13089 L
.27143 .13167 L
.28095 .139 L
.29048 .14477 L
.3 .14559 L
.30952 .14916 L
.31905 .15297 L
.32857 .15614 L
.3381 .16042 L
.34762 .16533 L
.35714 .17137 L
.36667 .17379 L
.37619 .17833 L
.38571 .18248 L
.39524 .18775 L
.40476 .19276 L
.41429 .19668 L
.42381 .20452 L
.43333 .20863 L
.44286 .21564 L
.45238 .2224 L
.4619 .22719 L
.47143 .23343 L
.48095 .24104 L
.49048 .24636 L
Mistroke
.5 .24921 L
.50952 .25514 L
.51905 .26156 L
.52857 .26934 L
.5381 .27708 L
.54762 .28317 L
.55714 .28901 L
.56667 .29687 L
.57619 .30271 L
.58571 .30966 L
.59524 .31336 L
.60476 .32197 L
.61429 .3281 L
.62381 .3324 L
.63333 .33743 L
.64286 .34612 L
.65238 .34984 L
.6619 .35778 L
.67143 .36782 L
.68095 .37204 L
.69048 .37663 L
.7 .38416 L
.70952 .39095 L
.71905 .39683 L
.72857 .40483 L
.7381 .41008 L
.74762 .41835 L
.75714 .4253 L
.76667 .42918 L
.77619 .43433 L
.78571 .44466 L
.79524 .45275 L
.80476 .45963 L
.81429 .47083 L
.82381 .47812 L
.83333 .48443 L
.84286 .48745 L
.85238 .49321 L
.8619 .51021 L
.87143 .51188 L
.88095 .51634 L
.89048 .52382 L
.9 .52963 L
.90952 .53826 L
.91905 .54417 L
.92857 .55164 L
.9381 .56476 L
.94762 .57299 L
.95714 .57811 L
.96667 .58425 L
Mistroke
.97619 .59268 L
Mfstroke
.8 0 1 r
gsave
.97619 .08556 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01674 m
.03333 .01684 L
.04286 .01748 L
.05238 .01792 L
.0619 .01765 L
.07143 .02027 L
.08095 .02013 L
.09048 .01875 L
.1 .0185 L
.10952 .02101 L
.11905 .01916 L
.12857 .0213 L
.1381 .02257 L
.14762 .02071 L
.15714 .02114 L
.16667 .02451 L
.17619 .02393 L
.18571 .02064 L
.19524 .02319 L
.20476 .02328 L
.21429 .02381 L
.22381 .02383 L
.23333 .025 L
.24286 .02652 L
.25238 .02531 L
.2619 .0266 L
.27143 .0271 L
.28095 .02786 L
.29048 .03102 L
.3 .02865 L
.30952 .02818 L
.31905 .03132 L
.32857 .02958 L
.3381 .02905 L
.34762 .03007 L
.35714 .0298 L
.36667 .03158 L
.37619 .03036 L
.38571 .03046 L
.39524 .03265 L
.40476 .03219 L
.41429 .03182 L
.42381 .03359 L
.43333 .0349 L
.44286 .03329 L
.45238 .03575 L
.4619 .03675 L
.47143 .03358 L
.48095 .0341 L
.49048 .03527 L
Mistroke
.5 .03602 L
.50952 .0348 L
.51905 .03665 L
.52857 .0367 L
.5381 .03928 L
.54762 .04248 L
.55714 .03988 L
.56667 .0432 L
.57619 .04641 L
.58571 .04865 L
.59524 .04636 L
.60476 .04726 L
.61429 .04812 L
.62381 .04815 L
.63333 .05095 L
.64286 .05086 L
.65238 .04975 L
.6619 .05251 L
.67143 .05233 L
.68095 .05319 L
.69048 .055 L
.7 .05507 L
.70952 .05411 L
.71905 .05578 L
.72857 .05825 L
.7381 .05985 L
.74762 .05902 L
.75714 .0598 L
.76667 .06084 L
.77619 .06118 L
.78571 .06463 L
.79524 .066 L
.80476 .06798 L
.81429 .07054 L
.82381 .07004 L
.83333 .07046 L
.84286 .07214 L
.85238 .07497 L
.8619 .07536 L
.87143 .07497 L
.88095 .07522 L
.89048 .07481 L
.9 .07793 L
.90952 .07719 L
.91905 .08115 L
.92857 .08141 L
.9381 .08523 L
.94762 .08542 L
.95714 .08637 L
.96667 .08653 L
Mistroke
.97619 .08556 L
Mfstroke
.2 0 1 r
gsave
.97619 .53057 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05434 m
.03333 .05728 L
.04286 .05986 L
.05238 .06169 L
.0619 .06308 L
.07143 .06697 L
.08095 .0717 L
.09048 .07233 L
.1 .0774 L
.10952 .07897 L
.11905 .0811 L
.12857 .08335 L
.1381 .08697 L
.14762 .08982 L
.15714 .09229 L
.16667 .09414 L
.17619 .09652 L
.18571 .10108 L
.19524 .10438 L
.20476 .10992 L
.21429 .11471 L
.22381 .11645 L
.23333 .12017 L
.24286 .12493 L
.25238 .12824 L
.2619 .13027 L
.27143 .13593 L
.28095 .14229 L
.29048 .14447 L
.3 .14544 L
.30952 .15194 L
.31905 .15698 L
.32857 .16152 L
.3381 .16437 L
.34762 .16917 L
.35714 .17654 L
.36667 .17649 L
.37619 .18132 L
.38571 .18882 L
.39524 .19494 L
.40476 .20102 L
.41429 .20404 L
.42381 .20707 L
.43333 .21358 L
.44286 .22199 L
.45238 .22619 L
.4619 .2295 L
.47143 .23483 L
.48095 .23982 L
.49048 .24498 L
Mistroke
.5 .24837 L
.50952 .25379 L
.51905 .26184 L
.52857 .27014 L
.5381 .27426 L
.54762 .27607 L
.55714 .2845 L
.56667 .2902 L
.57619 .29685 L
.58571 .30524 L
.59524 .30598 L
.60476 .31222 L
.61429 .32064 L
.62381 .32403 L
.63333 .32716 L
.64286 .32886 L
.65238 .33369 L
.6619 .34322 L
.67143 .34912 L
.68095 .35309 L
.69048 .35797 L
.7 .36331 L
.70952 .37185 L
.71905 .37697 L
.72857 .38764 L
.7381 .39545 L
.74762 .4007 L
.75714 .40842 L
.76667 .41179 L
.77619 .41536 L
.78571 .42128 L
.79524 .42642 L
.80476 .43642 L
.81429 .4371 L
.82381 .44433 L
.83333 .44726 L
.84286 .45666 L
.85238 .45851 L
.8619 .4666 L
.87143 .47392 L
.88095 .47973 L
.89048 .48585 L
.9 .49085 L
.90952 .49625 L
.91905 .49782 L
.92857 .50502 L
.9381 .50827 L
.94762 .51339 L
.95714 .51747 L
.96667 .52529 L
Mistroke
.97619 .53057 L
Mfstroke
0 .4 1 r
gsave
.97619 .10907 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01499 L
.04286 .01489 L
.05238 .01597 L
.0619 .01843 L
.07143 .01847 L
.08095 .01892 L
.09048 .02062 L
.1 .01993 L
.10952 .01917 L
.11905 .01996 L
.12857 .02188 L
.1381 .02212 L
.14762 .018 L
.15714 .02189 L
.16667 .02246 L
.17619 .01994 L
.18571 .02219 L
.19524 .02287 L
.20476 .02374 L
.21429 .02321 L
.22381 .0263 L
.23333 .02354 L
.24286 .02626 L
.25238 .02558 L
.2619 .02666 L
.27143 .02701 L
.28095 .02438 L
.29048 .02582 L
.3 .02592 L
.30952 .02678 L
.31905 .02662 L
.32857 .02756 L
.3381 .0293 L
.34762 .02809 L
.35714 .02989 L
.36667 .0309 L
.37619 .03035 L
.38571 .02982 L
.39524 .03024 L
.40476 .03408 L
.41429 .03567 L
.42381 .03215 L
.43333 .03546 L
.44286 .03561 L
.45238 .03628 L
.4619 .03882 L
.47143 .0378 L
.48095 .03523 L
.49048 .03903 L
Mistroke
.5 .03848 L
.50952 .04034 L
.51905 .04045 L
.52857 .04053 L
.5381 .04325 L
.54762 .04318 L
.55714 .04519 L
.56667 .04422 L
.57619 .04654 L
.58571 .04445 L
.59524 .04638 L
.60476 .04663 L
.61429 .04654 L
.62381 .04802 L
.63333 .0511 L
.64286 .05321 L
.65238 .05431 L
.6619 .0551 L
.67143 .05794 L
.68095 .06043 L
.69048 .0621 L
.7 .0618 L
.70952 .06161 L
.71905 .06576 L
.72857 .06644 L
.7381 .06619 L
.74762 .07119 L
.75714 .06986 L
.76667 .07029 L
.77619 .0731 L
.78571 .07285 L
.79524 .0782 L
.80476 .07684 L
.81429 .08072 L
.82381 .07897 L
.83333 .07768 L
.84286 .08176 L
.85238 .08161 L
.8619 .08673 L
.87143 .08549 L
.88095 .08654 L
.89048 .0897 L
.9 .09011 L
.90952 .09177 L
.91905 .09604 L
.92857 .09422 L
.9381 .09923 L
.94762 .10196 L
.95714 .10429 L
.96667 .1063 L
Mistroke
.97619 .10907 L
Mfstroke
0 1 1 r
gsave
.97619 .59327 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05569 m
.03333 .05473 L
.04286 .05936 L
.05238 .06282 L
.0619 .06513 L
.07143 .06827 L
.08095 .06945 L
.09048 .0744 L
.1 .07433 L
.10952 .08047 L
.11905 .08156 L
.12857 .08503 L
.1381 .08656 L
.14762 .08885 L
.15714 .09294 L
.16667 .09649 L
.17619 .09759 L
.18571 .10298 L
.19524 .10568 L
.20476 .11066 L
.21429 .11311 L
.22381 .11651 L
.23333 .12274 L
.24286 .12716 L
.25238 .13054 L
.2619 .13299 L
.27143 .13715 L
.28095 .14046 L
.29048 .14609 L
.3 .14909 L
.30952 .15509 L
.31905 .15819 L
.32857 .16421 L
.3381 .16949 L
.34762 .17338 L
.35714 .17646 L
.36667 .18349 L
.37619 .18584 L
.38571 .19314 L
.39524 .19712 L
.40476 .20323 L
.41429 .21066 L
.42381 .21367 L
.43333 .22048 L
.44286 .22364 L
.45238 .23449 L
.4619 .23643 L
.47143 .23886 L
.48095 .24417 L
.49048 .2528 L
Mistroke
.5 .25907 L
.50952 .26316 L
.51905 .26967 L
.52857 .27674 L
.5381 .28268 L
.54762 .28987 L
.55714 .29379 L
.56667 .30125 L
.57619 .30809 L
.58571 .31511 L
.59524 .31987 L
.60476 .33206 L
.61429 .33732 L
.62381 .3397 L
.63333 .34427 L
.64286 .35519 L
.65238 .35774 L
.6619 .36819 L
.67143 .37874 L
.68095 .38161 L
.69048 .39313 L
.7 .4011 L
.70952 .41179 L
.71905 .41508 L
.72857 .41831 L
.7381 .42887 L
.74762 .43921 L
.75714 .45029 L
.76667 .45693 L
.77619 .46578 L
.78571 .4664 L
.79524 .47311 L
.80476 .47997 L
.81429 .48722 L
.82381 .49565 L
.83333 .50045 L
.84286 .50566 L
.85238 .51227 L
.8619 .52 L
.87143 .52634 L
.88095 .53483 L
.89048 .54107 L
.9 .54812 L
.90952 .55285 L
.91905 .56025 L
.92857 .56396 L
.9381 .56818 L
.94762 .57342 L
.95714 .58074 L
.96667 .58755 L
Mistroke
.97619 .59327 L
Mfstroke
0 1 .4 r
gsave
.97619 .10674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01721 m
.03333 .01757 L
.04286 .01827 L
.05238 .01756 L
.0619 .01939 L
.07143 .01873 L
.08095 .0183 L
.09048 .0202 L
.1 .01846 L
.10952 .02114 L
.11905 .01753 L
.12857 .01928 L
.1381 .02247 L
.14762 .0221 L
.15714 .02197 L
.16667 .02299 L
.17619 .02272 L
.18571 .02262 L
.19524 .02395 L
.20476 .02262 L
.21429 .02285 L
.22381 .02337 L
.23333 .02416 L
.24286 .02163 L
.25238 .02336 L
.2619 .02517 L
.27143 .02765 L
.28095 .02739 L
.29048 .02746 L
.3 .03024 L
.30952 .02785 L
.31905 .02728 L
.32857 .02879 L
.3381 .0277 L
.34762 .03223 L
.35714 .02955 L
.36667 .03055 L
.37619 .02973 L
.38571 .03246 L
.39524 .02923 L
.40476 .03121 L
.41429 .03256 L
.42381 .03402 L
.43333 .03343 L
.44286 .03236 L
.45238 .03537 L
.4619 .03601 L
.47143 .03812 L
.48095 .03603 L
.49048 .03906 L
Mistroke
.5 .04053 L
.50952 .03725 L
.51905 .04128 L
.52857 .04198 L
.5381 .04487 L
.54762 .04407 L
.55714 .04654 L
.56667 .04699 L
.57619 .04544 L
.58571 .048 L
.59524 .04768 L
.60476 .04708 L
.61429 .0498 L
.62381 .05091 L
.63333 .0535 L
.64286 .05237 L
.65238 .05342 L
.6619 .05542 L
.67143 .05674 L
.68095 .05733 L
.69048 .06059 L
.7 .06077 L
.70952 .06108 L
.71905 .06363 L
.72857 .06437 L
.7381 .06408 L
.74762 .06357 L
.75714 .06882 L
.76667 .07117 L
.77619 .06905 L
.78571 .06754 L
.79524 .06997 L
.80476 .07131 L
.81429 .07059 L
.82381 .07287 L
.83333 .0769 L
.84286 .07486 L
.85238 .07824 L
.8619 .07921 L
.87143 .08034 L
.88095 .08282 L
.89048 .08651 L
.9 .08358 L
.90952 .08644 L
.91905 .08567 L
.92857 .09184 L
.9381 .0943 L
.94762 .09655 L
.95714 .10061 L
.96667 .10401 L
Mistroke
.97619 .10674 L
Mfstroke
.2 1 0 r
gsave
.97619 .58131 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05596 m
.03333 .05551 L
.04286 .05973 L
.05238 .06429 L
.0619 .06552 L
.07143 .06581 L
.08095 .06887 L
.09048 .07212 L
.1 .07845 L
.10952 .07923 L
.11905 .08014 L
.12857 .08522 L
.1381 .08529 L
.14762 .08884 L
.15714 .0924 L
.16667 .09574 L
.17619 .09958 L
.18571 .10205 L
.19524 .1103 L
.20476 .11143 L
.21429 .1124 L
.22381 .11633 L
.23333 .12209 L
.24286 .1269 L
.25238 .13022 L
.2619 .13471 L
.27143 .1376 L
.28095 .14274 L
.29048 .14515 L
.3 .14977 L
.30952 .15226 L
.31905 .15749 L
.32857 .1627 L
.3381 .16491 L
.34762 .17178 L
.35714 .17463 L
.36667 .17886 L
.37619 .1828 L
.38571 .18729 L
.39524 .19153 L
.40476 .19772 L
.41429 .20557 L
.42381 .20819 L
.43333 .21677 L
.44286 .22087 L
.45238 .22667 L
.4619 .2312 L
.47143 .23616 L
.48095 .24311 L
.49048 .24607 L
Mistroke
.5 .25411 L
.50952 .2587 L
.51905 .26306 L
.52857 .27461 L
.5381 .27837 L
.54762 .28737 L
.55714 .2911 L
.56667 .2964 L
.57619 .29881 L
.58571 .30976 L
.59524 .31368 L
.60476 .31983 L
.61429 .32402 L
.62381 .32848 L
.63333 .33183 L
.64286 .33977 L
.65238 .34478 L
.6619 .35245 L
.67143 .36014 L
.68095 .36569 L
.69048 .37576 L
.7 .37815 L
.70952 .38528 L
.71905 .39248 L
.72857 .40339 L
.7381 .40685 L
.74762 .41358 L
.75714 .42183 L
.76667 .4283 L
.77619 .43904 L
.78571 .44142 L
.79524 .44714 L
.80476 .45195 L
.81429 .46176 L
.82381 .46921 L
.83333 .48351 L
.84286 .49119 L
.85238 .49947 L
.8619 .50577 L
.87143 .50798 L
.88095 .51348 L
.89048 .51753 L
.9 .53225 L
.90952 .53622 L
.91905 .54286 L
.92857 .55563 L
.9381 .56304 L
.94762 .56672 L
.95714 .57369 L
.96667 .57937 L
Mistroke
.97619 .58131 L
Mfstroke
.8 1 0 r
gsave
.97619 .09345 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01699 m
.03333 .01813 L
.04286 .01625 L
.05238 .01831 L
.0619 .01903 L
.07143 .01775 L
.08095 .02 L
.09048 .01937 L
.1 .01856 L
.10952 .01871 L
.11905 .02177 L
.12857 .02324 L
.1381 .02032 L
.14762 .02284 L
.15714 .02079 L
.16667 .02276 L
.17619 .0211 L
.18571 .02237 L
.19524 .02481 L
.20476 .02453 L
.21429 .02254 L
.22381 .02494 L
.23333 .02651 L
.24286 .02505 L
.25238 .02576 L
.2619 .02555 L
.27143 .02697 L
.28095 .02934 L
.29048 .03102 L
.3 .03173 L
.30952 .02927 L
.31905 .03038 L
.32857 .0282 L
.3381 .03041 L
.34762 .0306 L
.35714 .03107 L
.36667 .03126 L
.37619 .03409 L
.38571 .03085 L
.39524 .03197 L
.40476 .03473 L
.41429 .03235 L
.42381 .03355 L
.43333 .03575 L
.44286 .032 L
.45238 .03731 L
.4619 .03795 L
.47143 .03726 L
.48095 .03599 L
.49048 .03962 L
Mistroke
.5 .04211 L
.50952 .03952 L
.51905 .03942 L
.52857 .03899 L
.5381 .03991 L
.54762 .03922 L
.55714 .04317 L
.56667 .04341 L
.57619 .04321 L
.58571 .048 L
.59524 .04437 L
.60476 .04551 L
.61429 .04481 L
.62381 .0442 L
.63333 .04463 L
.64286 .04635 L
.65238 .04902 L
.6619 .05063 L
.67143 .04959 L
.68095 .05297 L
.69048 .05145 L
.7 .05068 L
.70952 .0536 L
.71905 .05707 L
.72857 .05671 L
.7381 .05672 L
.74762 .05953 L
.75714 .06227 L
.76667 .06338 L
.77619 .06495 L
.78571 .06813 L
.79524 .06882 L
.80476 .06872 L
.81429 .07078 L
.82381 .07234 L
.83333 .07178 L
.84286 .07015 L
.85238 .07435 L
.8619 .07494 L
.87143 .07632 L
.88095 .08044 L
.89048 .08056 L
.9 .08286 L
.90952 .08438 L
.91905 .08676 L
.92857 .08733 L
.9381 .08909 L
.94762 .0878 L
.95714 .0875 L
.96667 .09286 L
Mistroke
.97619 .09345 L
Mfstroke
1 .6 0 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0527 m
.03333 .05829 L
.04286 .05832 L
.05238 .06426 L
.0619 .0633 L
.07143 .06724 L
.08095 .06953 L
.09048 .07268 L
.1 .0765 L
.10952 .07769 L
.11905 .07909 L
.12857 .08373 L
.1381 .08524 L
.14762 .08891 L
.15714 .09416 L
.16667 .09218 L
.17619 .0971 L
.18571 .10301 L
.19524 .10575 L
.20476 .11096 L
.21429 .11334 L
.22381 .1181 L
.23333 .12001 L
.24286 .12585 L
.25238 .13047 L
.2619 .13061 L
.27143 .13825 L
.28095 .14088 L
.29048 .14408 L
.3 .15198 L
.30952 .15548 L
.31905 .16189 L
.32857 .16779 L
.3381 .17248 L
.34762 .17576 L
.35714 .18141 L
.36667 .18671 L
.37619 .19013 L
.38571 .19616 L
.39524 .20093 L
.40476 .20579 L
.41429 .21146 L
.42381 .21865 L
.43333 .22343 L
.44286 .22654 L
.45238 .23404 L
.4619 .24168 L
.47143 .24515 L
.48095 .25222 L
.49048 .25841 L
Mistroke
.5 .26362 L
.50952 .2696 L
.51905 .27456 L
.52857 .28334 L
.5381 .28712 L
.54762 .2889 L
.55714 .29609 L
.56667 .30473 L
.57619 .30947 L
.58571 .31573 L
.59524 .32121 L
.60476 .32737 L
.61429 .33475 L
.62381 .34073 L
.63333 .34993 L
.64286 .35628 L
.65238 .36252 L
.6619 .36694 L
.67143 .3782 L
.68095 .38122 L
.69048 .3833 L
.7 .39117 L
.70952 .39535 L
.71905 .40285 L
.72857 .41319 L
.7381 .41885 L
.74762 .42575 L
.75714 .43073 L
.76667 .43763 L
.77619 .44658 L
.78571 .45205 L
.79524 .46036 L
.80476 .46784 L
.81429 .47578 L
.82381 .48325 L
.83333 .489 L
.84286 .49627 L
.85238 .5034 L
.8619 .51304 L
.87143 .52013 L
.88095 .52815 L
.89048 .53614 L
.9 .54775 L
.90952 .5551 L
.91905 .56419 L
.92857 .57004 L
.9381 .57427 L
.94762 .58277 L
.95714 .58923 L
.96667 .59662 L
Mistroke
.97619 .60332 L
Mfstroke
1 0 0 r
gsave
.97619 .09592 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01946 m
.03333 .01628 L
.04286 .01601 L
.05238 .0186 L
.0619 .01769 L
.07143 .01881 L
.08095 .01923 L
.09048 .02094 L
.1 .01911 L
.10952 .01865 L
.11905 .02141 L
.12857 .02076 L
.1381 .01832 L
.14762 .02248 L
.15714 .02127 L
.16667 .02113 L
.17619 .02098 L
.18571 .02076 L
.19524 .02284 L
.20476 .02509 L
.21429 .0234 L
.22381 .02415 L
.23333 .02261 L
.24286 .0254 L
.25238 .02497 L
.2619 .02579 L
.27143 .02548 L
.28095 .02691 L
.29048 .02581 L
.3 .02727 L
.30952 .02828 L
.31905 .02786 L
.32857 .02768 L
.3381 .02805 L
.34762 .03048 L
.35714 .03147 L
.36667 .03271 L
.37619 .03216 L
.38571 .03242 L
.39524 .03291 L
.40476 .03388 L
.41429 .03093 L
.42381 .03337 L
.43333 .03588 L
.44286 .03557 L
.45238 .0346 L
.4619 .03785 L
.47143 .03899 L
.48095 .03877 L
.49048 .03755 L
Mistroke
.5 .03784 L
.50952 .041 L
.51905 .04122 L
.52857 .03904 L
.5381 .04273 L
.54762 .04251 L
.55714 .04103 L
.56667 .04374 L
.57619 .04693 L
.58571 .0474 L
.59524 .04616 L
.60476 .04704 L
.61429 .04918 L
.62381 .05086 L
.63333 .0534 L
.64286 .05368 L
.65238 .05176 L
.6619 .05325 L
.67143 .0575 L
.68095 .05457 L
.69048 .05649 L
.7 .05764 L
.70952 .05681 L
.71905 .05852 L
.72857 .05536 L
.7381 .06028 L
.74762 .06358 L
.75714 .06108 L
.76667 .06502 L
.77619 .0664 L
.78571 .06704 L
.79524 .06743 L
.80476 .06933 L
.81429 .0694 L
.82381 .0697 L
.83333 .07121 L
.84286 .07193 L
.85238 .07385 L
.8619 .07684 L
.87143 .07794 L
.88095 .07721 L
.89048 .08046 L
.9 .08135 L
.90952 .08527 L
.91905 .08465 L
.92857 .08546 L
.9381 .08674 L
.94762 .0895 L
.95714 .09222 L
.96667 .08939 L
Mistroke
.97619 .09592 L
Mfstroke
1 0 .6 r
gsave
.97619 .54961 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05301 m
.03333 .05558 L
.04286 .0584 L
.05238 .0625 L
.0619 .06465 L
.07143 .06716 L
.08095 .07043 L
.09048 .07389 L
.1 .07724 L
.10952 .07734 L
.11905 .07925 L
.12857 .08411 L
.1381 .08679 L
.14762 .08865 L
.15714 .09424 L
.16667 .09692 L
.17619 .09964 L
.18571 .10097 L
.19524 .10596 L
.20476 .1089 L
.21429 .11241 L
.22381 .11605 L
.23333 .12026 L
.24286 .12539 L
.25238 .12851 L
.2619 .13129 L
.27143 .13756 L
.28095 .13989 L
.29048 .14312 L
.3 .14894 L
.30952 .15181 L
.31905 .15683 L
.32857 .16031 L
.3381 .16614 L
.34762 .16948 L
.35714 .17417 L
.36667 .17768 L
.37619 .18404 L
.38571 .1861 L
.39524 .18905 L
.40476 .19741 L
.41429 .20199 L
.42381 .20452 L
.43333 .20876 L
.44286 .21606 L
.45238 .21976 L
.4619 .2281 L
.47143 .22964 L
.48095 .23509 L
.49048 .23764 L
Mistroke
.5 .2436 L
.50952 .2464 L
.51905 .25457 L
.52857 .25777 L
.5381 .26531 L
.54762 .2711 L
.55714 .27999 L
.56667 .28461 L
.57619 .29073 L
.58571 .29297 L
.59524 .3003 L
.60476 .30632 L
.61429 .31391 L
.62381 .31784 L
.63333 .32175 L
.64286 .32939 L
.65238 .33167 L
.6619 .33702 L
.67143 .35037 L
.68095 .35602 L
.69048 .36294 L
.7 .36997 L
.70952 .37647 L
.71905 .38235 L
.72857 .38923 L
.7381 .39646 L
.74762 .4026 L
.75714 .40747 L
.76667 .41062 L
.77619 .41448 L
.78571 .42264 L
.79524 .43249 L
.80476 .43757 L
.81429 .44324 L
.82381 .45069 L
.83333 .45556 L
.84286 .46275 L
.85238 .46756 L
.8619 .47101 L
.87143 .47673 L
.88095 .48561 L
.89048 .49145 L
.9 .49828 L
.90952 .50447 L
.91905 .51199 L
.92857 .51804 L
.9381 .52554 L
.94762 .53169 L
.95714 .53967 L
.96667 .5438 L
Mistroke
.97619 .54961 L
Mfstroke
.8 0 1 r
gsave
.97619 .10354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01503 m
.03333 .01679 L
.04286 .01912 L
.05238 .01939 L
.0619 .01997 L
.07143 .01774 L
.08095 .01757 L
.09048 .01981 L
.1 .01906 L
.10952 .01891 L
.11905 .02037 L
.12857 .02005 L
.1381 .02005 L
.14762 .02336 L
.15714 .02148 L
.16667 .02126 L
.17619 .02053 L
.18571 .0219 L
.19524 .02245 L
.20476 .02119 L
.21429 .0241 L
.22381 .02269 L
.23333 .02314 L
.24286 .02376 L
.25238 .02469 L
.2619 .02449 L
.27143 .02452 L
.28095 .02556 L
.29048 .02832 L
.3 .02862 L
.30952 .02726 L
.31905 .02757 L
.32857 .02948 L
.3381 .03174 L
.34762 .03013 L
.35714 .0305 L
.36667 .03249 L
.37619 .03289 L
.38571 .03273 L
.39524 .03426 L
.40476 .03271 L
.41429 .03495 L
.42381 .03777 L
.43333 .03879 L
.44286 .03584 L
.45238 .03495 L
.4619 .03478 L
.47143 .03901 L
.48095 .03871 L
.49048 .03939 L
Mistroke
.5 .04177 L
.50952 .04196 L
.51905 .0426 L
.52857 .04166 L
.5381 .04352 L
.54762 .04525 L
.55714 .04654 L
.56667 .04619 L
.57619 .0457 L
.58571 .04855 L
.59524 .04786 L
.60476 .04942 L
.61429 .05031 L
.62381 .05027 L
.63333 .05048 L
.64286 .05339 L
.65238 .05453 L
.6619 .05466 L
.67143 .0563 L
.68095 .05642 L
.69048 .05894 L
.7 .0588 L
.70952 .05887 L
.71905 .05742 L
.72857 .05646 L
.7381 .05892 L
.74762 .05926 L
.75714 .06063 L
.76667 .05896 L
.77619 .06372 L
.78571 .06453 L
.79524 .06764 L
.80476 .06727 L
.81429 .07024 L
.82381 .06998 L
.83333 .06942 L
.84286 .07354 L
.85238 .07527 L
.8619 .07705 L
.87143 .07986 L
.88095 .07929 L
.89048 .08652 L
.9 .09109 L
.90952 .09209 L
.91905 .09246 L
.92857 .09397 L
.9381 .0937 L
.94762 .09664 L
.95714 .10032 L
.96667 .10147 L
Mistroke
.97619 .10354 L
Mfstroke
.2 0 1 r
gsave
.97619 .54937 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05517 m
.03333 .05633 L
.04286 .06079 L
.05238 .06012 L
.0619 .06532 L
.07143 .0678 L
.08095 .07093 L
.09048 .07211 L
.1 .07562 L
.10952 .077 L
.11905 .08039 L
.12857 .08337 L
.1381 .08719 L
.14762 .08882 L
.15714 .09505 L
.16667 .09625 L
.17619 .09788 L
.18571 .10242 L
.19524 .10378 L
.20476 .11008 L
.21429 .10911 L
.22381 .11909 L
.23333 .1179 L
.24286 .12287 L
.25238 .12613 L
.2619 .13052 L
.27143 .13464 L
.28095 .13796 L
.29048 .14212 L
.3 .14598 L
.30952 .15167 L
.31905 .15349 L
.32857 .15695 L
.3381 .16219 L
.34762 .16371 L
.35714 .16647 L
.36667 .16989 L
.37619 .17341 L
.38571 .17927 L
.39524 .18301 L
.40476 .18789 L
.41429 .19017 L
.42381 .19473 L
.43333 .19804 L
.44286 .20377 L
.45238 .2093 L
.4619 .21573 L
.47143 .21886 L
.48095 .22309 L
.49048 .23027 L
Mistroke
.5 .23614 L
.50952 .24186 L
.51905 .24481 L
.52857 .25418 L
.5381 .26107 L
.54762 .26713 L
.55714 .27265 L
.56667 .28001 L
.57619 .28911 L
.58571 .2946 L
.59524 .29779 L
.60476 .30472 L
.61429 .31226 L
.62381 .31703 L
.63333 .32368 L
.64286 .32746 L
.65238 .3365 L
.6619 .34154 L
.67143 .34369 L
.68095 .35057 L
.69048 .35713 L
.7 .36041 L
.70952 .36564 L
.71905 .37184 L
.72857 .37823 L
.7381 .38207 L
.74762 .38624 L
.75714 .39258 L
.76667 .40086 L
.77619 .40637 L
.78571 .4181 L
.79524 .42366 L
.80476 .43165 L
.81429 .44214 L
.82381 .44626 L
.83333 .45493 L
.84286 .46029 L
.85238 .46247 L
.8619 .47462 L
.87143 .48188 L
.88095 .48597 L
.89048 .49334 L
.9 .49929 L
.90952 .50666 L
.91905 .50904 L
.92857 .51909 L
.9381 .52577 L
.94762 .53242 L
.95714 .53953 L
.96667 .54301 L
Mistroke
.97619 .54937 L
Mfstroke
0 .4 1 r
gsave
.97619 .09403 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01627 m
.03333 .01809 L
.04286 .01933 L
.05238 .0175 L
.0619 .01962 L
.07143 .01927 L
.08095 .01719 L
.09048 .01823 L
.1 .01956 L
.10952 .02094 L
.11905 .02067 L
.12857 .02236 L
.1381 .01947 L
.14762 .0198 L
.15714 .02202 L
.16667 .02232 L
.17619 .02373 L
.18571 .0242 L
.19524 .02145 L
.20476 .02396 L
.21429 .02196 L
.22381 .0239 L
.23333 .0242 L
.24286 .02649 L
.25238 .02197 L
.2619 .02618 L
.27143 .0244 L
.28095 .0268 L
.29048 .02474 L
.3 .02747 L
.30952 .02721 L
.31905 .02553 L
.32857 .02754 L
.3381 .02736 L
.34762 .03055 L
.35714 .03035 L
.36667 .02984 L
.37619 .03074 L
.38571 .02988 L
.39524 .03215 L
.40476 .03164 L
.41429 .03269 L
.42381 .03475 L
.43333 .03673 L
.44286 .03623 L
.45238 .03871 L
.4619 .03714 L
.47143 .03581 L
.48095 .03742 L
.49048 .03772 L
Mistroke
.5 .03869 L
.50952 .0387 L
.51905 .04064 L
.52857 .03943 L
.5381 .04131 L
.54762 .04321 L
.55714 .04358 L
.56667 .04374 L
.57619 .04221 L
.58571 .04328 L
.59524 .04542 L
.60476 .0451 L
.61429 .04973 L
.62381 .04882 L
.63333 .05068 L
.64286 .05246 L
.65238 .05277 L
.6619 .05392 L
.67143 .05342 L
.68095 .05563 L
.69048 .05364 L
.7 .05339 L
.70952 .05762 L
.71905 .05898 L
.72857 .0589 L
.7381 .05765 L
.74762 .06151 L
.75714 .0636 L
.76667 .06071 L
.77619 .06551 L
.78571 .06132 L
.79524 .06586 L
.80476 .06659 L
.81429 .0703 L
.82381 .06974 L
.83333 .06825 L
.84286 .07 L
.85238 .07513 L
.8619 .07486 L
.87143 .07873 L
.88095 .07648 L
.89048 .07818 L
.9 .07986 L
.90952 .08138 L
.91905 .08125 L
.92857 .08486 L
.9381 .08508 L
.94762 .08888 L
.95714 .08998 L
.96667 .09458 L
Mistroke
.97619 .09403 L
Mfstroke
0 1 1 r
gsave
.97619 .57498 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05816 m
.03333 .05902 L
.04286 .06102 L
.05238 .06319 L
.0619 .06501 L
.07143 .06903 L
.08095 .06985 L
.09048 .07262 L
.1 .07429 L
.10952 .07859 L
.11905 .08039 L
.12857 .08533 L
.1381 .08949 L
.14762 .09033 L
.15714 .09456 L
.16667 .09385 L
.17619 .09763 L
.18571 .10337 L
.19524 .10632 L
.20476 .11021 L
.21429 .11493 L
.22381 .11687 L
.23333 .12447 L
.24286 .12584 L
.25238 .13063 L
.2619 .13384 L
.27143 .13869 L
.28095 .14079 L
.29048 .14582 L
.3 .14894 L
.30952 .1542 L
.31905 .16011 L
.32857 .16256 L
.3381 .16839 L
.34762 .17309 L
.35714 .17859 L
.36667 .18239 L
.37619 .18512 L
.38571 .19092 L
.39524 .19465 L
.40476 .2013 L
.41429 .20849 L
.42381 .21191 L
.43333 .21922 L
.44286 .22473 L
.45238 .23194 L
.4619 .23534 L
.47143 .24035 L
.48095 .24842 L
.49048 .24939 L
Mistroke
.5 .25592 L
.50952 .26191 L
.51905 .26452 L
.52857 .26792 L
.5381 .27728 L
.54762 .28239 L
.55714 .2881 L
.56667 .29373 L
.57619 .30011 L
.58571 .30797 L
.59524 .31118 L
.60476 .32296 L
.61429 .3287 L
.62381 .33757 L
.63333 .34292 L
.64286 .35212 L
.65238 .35837 L
.6619 .36523 L
.67143 .36807 L
.68095 .37338 L
.69048 .37944 L
.7 .38359 L
.70952 .39341 L
.71905 .4005 L
.72857 .40805 L
.7381 .41409 L
.74762 .42088 L
.75714 .42871 L
.76667 .4383 L
.77619 .44272 L
.78571 .45087 L
.79524 .45785 L
.80476 .46616 L
.81429 .4717 L
.82381 .48201 L
.83333 .48761 L
.84286 .494 L
.85238 .49813 L
.8619 .51101 L
.87143 .51956 L
.88095 .52318 L
.89048 .52565 L
.9 .53417 L
.90952 .54147 L
.91905 .54922 L
.92857 .55168 L
.9381 .55765 L
.94762 .56382 L
.95714 .56831 L
.96667 .56972 L
Mistroke
.97619 .57498 L
Mfstroke
0 1 .4 r
gsave
.97619 .09156 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01789 m
.03333 .01715 L
.04286 .01921 L
.05238 .01729 L
.0619 .01796 L
.07143 .0198 L
.08095 .01788 L
.09048 .01726 L
.1 .01926 L
.10952 .01955 L
.11905 .02026 L
.12857 .01996 L
.1381 .01939 L
.14762 .02243 L
.15714 .02087 L
.16667 .02279 L
.17619 .02314 L
.18571 .02271 L
.19524 .02235 L
.20476 .02307 L
.21429 .02384 L
.22381 .0223 L
.23333 .02375 L
.24286 .02248 L
.25238 .02511 L
.2619 .02503 L
.27143 .02548 L
.28095 .02373 L
.29048 .02586 L
.3 .02761 L
.30952 .02771 L
.31905 .02525 L
.32857 .02743 L
.3381 .02825 L
.34762 .02502 L
.35714 .02722 L
.36667 .02495 L
.37619 .02697 L
.38571 .02702 L
.39524 .028 L
.40476 .02982 L
.41429 .03096 L
.42381 .03011 L
.43333 .03149 L
.44286 .03026 L
.45238 .03232 L
.4619 .0332 L
.47143 .03452 L
.48095 .03491 L
.49048 .03514 L
Mistroke
.5 .03367 L
.50952 .03456 L
.51905 .03227 L
.52857 .03447 L
.5381 .03418 L
.54762 .03591 L
.55714 .03648 L
.56667 .03983 L
.57619 .04073 L
.58571 .04202 L
.59524 .0436 L
.60476 .04563 L
.61429 .04696 L
.62381 .04655 L
.63333 .05026 L
.64286 .04964 L
.65238 .05072 L
.6619 .05016 L
.67143 .05068 L
.68095 .0536 L
.69048 .05357 L
.7 .05599 L
.70952 .05552 L
.71905 .05678 L
.72857 .05431 L
.7381 .05397 L
.74762 .05506 L
.75714 .05784 L
.76667 .05944 L
.77619 .0628 L
.78571 .06274 L
.79524 .06233 L
.80476 .06404 L
.81429 .06784 L
.82381 .0669 L
.83333 .07026 L
.84286 .07084 L
.85238 .07369 L
.8619 .0737 L
.87143 .07543 L
.88095 .07517 L
.89048 .07414 L
.9 .0761 L
.90952 .0793 L
.91905 .08186 L
.92857 .08168 L
.9381 .07932 L
.94762 .08213 L
.95714 .08382 L
.96667 .08706 L
Mistroke
.97619 .09156 L
Mfstroke
.2 1 0 r
gsave
.97619 .58622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05521 m
.03333 .05704 L
.04286 .06157 L
.05238 .06419 L
.0619 .06194 L
.07143 .06808 L
.08095 .06928 L
.09048 .07262 L
.1 .07331 L
.10952 .07642 L
.11905 .0806 L
.12857 .08331 L
.1381 .08576 L
.14762 .09039 L
.15714 .09504 L
.16667 .09714 L
.17619 .10002 L
.18571 .10378 L
.19524 .10887 L
.20476 .11192 L
.21429 .11738 L
.22381 .11986 L
.23333 .12228 L
.24286 .12729 L
.25238 .13036 L
.2619 .13225 L
.27143 .1401 L
.28095 .14379 L
.29048 .14582 L
.3 .15364 L
.30952 .15928 L
.31905 .1631 L
.32857 .16611 L
.3381 .17161 L
.34762 .17524 L
.35714 .17981 L
.36667 .18484 L
.37619 .19044 L
.38571 .19649 L
.39524 .20063 L
.40476 .20614 L
.41429 .21248 L
.42381 .21626 L
.43333 .2228 L
.44286 .22804 L
.45238 .23381 L
.4619 .23771 L
.47143 .24392 L
.48095 .24687 L
.49048 .25457 L
Mistroke
.5 .25945 L
.50952 .26274 L
.51905 .27148 L
.52857 .27819 L
.5381 .2825 L
.54762 .28973 L
.55714 .29436 L
.56667 .30405 L
.57619 .30945 L
.58571 .31545 L
.59524 .32245 L
.60476 .32529 L
.61429 .33762 L
.62381 .34563 L
.63333 .35085 L
.64286 .35869 L
.65238 .3641 L
.6619 .37036 L
.67143 .37519 L
.68095 .38896 L
.69048 .39375 L
.7 .40084 L
.70952 .40657 L
.71905 .41592 L
.72857 .42361 L
.7381 .42691 L
.74762 .43435 L
.75714 .44115 L
.76667 .44795 L
.77619 .45303 L
.78571 .46054 L
.79524 .46526 L
.80476 .47099 L
.81429 .46982 L
.82381 .47484 L
.83333 .48096 L
.84286 .48958 L
.85238 .49793 L
.8619 .50716 L
.87143 .51083 L
.88095 .52016 L
.89048 .53081 L
.9 .53435 L
.90952 .53763 L
.91905 .54566 L
.92857 .55948 L
.9381 .56663 L
.94762 .57249 L
.95714 .57667 L
.96667 .58544 L
Mistroke
.97619 .58622 L
Mfstroke
.8 1 0 r
gsave
.97619 .09089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01635 m
.03333 .01648 L
.04286 .01722 L
.05238 .01713 L
.0619 .02008 L
.07143 .01962 L
.08095 .01713 L
.09048 .01957 L
.1 .02115 L
.10952 .02238 L
.11905 .0195 L
.12857 .01972 L
.1381 .02181 L
.14762 .0196 L
.15714 .02201 L
.16667 .02187 L
.17619 .02368 L
.18571 .02011 L
.19524 .02336 L
.20476 .02377 L
.21429 .02511 L
.22381 .02278 L
.23333 .025 L
.24286 .0259 L
.25238 .02406 L
.2619 .02577 L
.27143 .02556 L
.28095 .02763 L
.29048 .02868 L
.3 .02651 L
.30952 .02817 L
.31905 .02906 L
.32857 .03092 L
.3381 .03018 L
.34762 .02967 L
.35714 .02874 L
.36667 .03142 L
.37619 .02934 L
.38571 .03342 L
.39524 .02945 L
.40476 .03093 L
.41429 .03216 L
.42381 .03098 L
.43333 .02995 L
.44286 .03236 L
.45238 .0342 L
.4619 .03193 L
.47143 .03379 L
.48095 .03479 L
.49048 .03264 L
Mistroke
.5 .03434 L
.50952 .03709 L
.51905 .03357 L
.52857 .03793 L
.5381 .04032 L
.54762 .03872 L
.55714 .04024 L
.56667 .04313 L
.57619 .04256 L
.58571 .04284 L
.59524 .04413 L
.60476 .0457 L
.61429 .04488 L
.62381 .04614 L
.63333 .04343 L
.64286 .04279 L
.65238 .0427 L
.6619 .04305 L
.67143 .04499 L
.68095 .04897 L
.69048 .04858 L
.7 .0537 L
.70952 .05236 L
.71905 .05553 L
.72857 .05519 L
.7381 .05677 L
.74762 .05513 L
.75714 .05454 L
.76667 .05628 L
.77619 .05871 L
.78571 .06014 L
.79524 .06484 L
.80476 .06375 L
.81429 .06493 L
.82381 .06735 L
.83333 .06776 L
.84286 .0679 L
.85238 .06735 L
.8619 .07083 L
.87143 .07007 L
.88095 .07453 L
.89048 .07403 L
.9 .0748 L
.90952 .07997 L
.91905 .07922 L
.92857 .08395 L
.9381 .08737 L
.94762 .08948 L
.95714 .09148 L
.96667 .09295 L
Mistroke
.97619 .09089 L
Mfstroke
1 .6 0 r
gsave
.97619 .55089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05493 m
.03333 .05714 L
.04286 .05794 L
.05238 .06295 L
.0619 .06575 L
.07143 .06604 L
.08095 .06991 L
.09048 .07221 L
.1 .07606 L
.10952 .07689 L
.11905 .08005 L
.12857 .08473 L
.1381 .08876 L
.14762 .09098 L
.15714 .09413 L
.16667 .09874 L
.17619 .1007 L
.18571 .10322 L
.19524 .105 L
.20476 .10978 L
.21429 .11343 L
.22381 .11703 L
.23333 .12003 L
.24286 .12246 L
.25238 .12568 L
.2619 .12835 L
.27143 .13283 L
.28095 .13663 L
.29048 .13984 L
.3 .14556 L
.30952 .14807 L
.31905 .15241 L
.32857 .15701 L
.3381 .16339 L
.34762 .16735 L
.35714 .17311 L
.36667 .17557 L
.37619 .18157 L
.38571 .1871 L
.39524 .19077 L
.40476 .1949 L
.41429 .20197 L
.42381 .20341 L
.43333 .21023 L
.44286 .21619 L
.45238 .22092 L
.4619 .2278 L
.47143 .23155 L
.48095 .23732 L
.49048 .24318 L
Mistroke
.5 .24641 L
.50952 .25012 L
.51905 .25902 L
.52857 .26389 L
.5381 .26844 L
.54762 .27349 L
.55714 .28334 L
.56667 .28807 L
.57619 .29577 L
.58571 .29861 L
.59524 .30886 L
.60476 .31516 L
.61429 .32281 L
.62381 .32764 L
.63333 .33329 L
.64286 .34136 L
.65238 .34826 L
.6619 .35072 L
.67143 .35664 L
.68095 .3624 L
.69048 .36433 L
.7 .37184 L
.70952 .37548 L
.71905 .38513 L
.72857 .39115 L
.7381 .39656 L
.74762 .40276 L
.75714 .41102 L
.76667 .42009 L
.77619 .42511 L
.78571 .42892 L
.79524 .43534 L
.80476 .44333 L
.81429 .45179 L
.82381 .45996 L
.83333 .46672 L
.84286 .47629 L
.85238 .47361 L
.8619 .48221 L
.87143 .48573 L
.88095 .49144 L
.89048 .49349 L
.9 .50366 L
.90952 .50662 L
.91905 .51485 L
.92857 .51847 L
.9381 .53038 L
.94762 .53052 L
.95714 .53696 L
.96667 .54049 L
Mistroke
.97619 .55089 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@0000030?ooo`800000
:03oool3000000<0oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`0000040?ooo`800000
903oool3000000@0oooo0P0000040?ooo`8000000`3oool001l0oooo00@000000?ooo`3oool00000
:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo000O0?ooo`040000003oool0oooo000002T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3oool010000000oooo
0?ooo`00000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`007`3oool010000000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
9@3oool4000000<0oooo00@000000?ooo`3oool000009@3oool3000000<0oooo00@000000?ooo`3o
ool00000903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool000009`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000009P3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000002D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000T
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`007`3oool010000000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00000V0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000008`3oool2000000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`00803oool2000002T0oooo0`0000040?ooo`800000:@3o
ool00`000000oooo0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V0?ooo`<00000103o
ool2000002D0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000030?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`006`3ooook000000<0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`80
c03o1@00I_o]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool90<co00<00?mV
00@006Ko0<co003<o`00c?l01@00ofH20<`0o`P00?mV0P00I_oB0?ooo`8000000`3oool001/0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`@0c?l000<0c03o0<co003oool0
5P3<o`000`00ofH0c?l00<co00040<co00800?mV0P00I_l30<co00030<`0o`00ofH00?mV00800?mV
0P00I_ni0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo02H0oooo0`3<
0?l0103<o`0006Ko001Vo`3oool70<co00030<`0o`00I_l006Ko00`0c?l01000ofH30<co0003001V
o`00ofH00?mV00@00?mV0P00I_l=003oIYL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0@@3oool00`00ofH0oooo0<co00030<co00030<`0o`00ofH00?mV01<0c?l00P00
I_l50<co00800?mV1@3<o`03003oIXT0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0B03oool00`3<o`00oooo0?ooo`060?ooo`80c03o00<0oooo003oIP3oool00P3o0005
0<`0o`80c?l000<0c03o001Vo`00I_l00P00I_l20<co00<006Ko00<00?mV0<co003<o`00403<o`02
003oIP<0c?l01@00ofIa0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000I@3oool2001V
o`030?l0003<0?l0c03o01<006Ko0P3<o`000`00I_l0c?l0001Vo`020<co0080c03o0`3<o`02003o
IV`0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1c0?ooo`040?l0003oool0oooo0?oo
o`<0c?l01@3<0?l01000I_l0c03o0<`0o`3<0?l20<co00<006Ko2P3<o`080?ooo`/0c?l0DP3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`210?ooo`80o`001@3<0?l4001V
o`<0c03o0`3o00080<co0003003oIP3<o`00c?l000<0c?l01@3oool20<co0500oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0RP3oool20?l000<0oooo1`3<0?l5001Vo``0
0?mV1`3<o`190?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool20?nI00800?oo
R`3oool00`3o0000oooo0?ooo`040?ooo`D0o`002@00I_l5003oIPD0c?l000@0oooo0<co003<o`00
c?l00P00ofH60<co03T0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`030?ooo`800?oo
1@3oV@2D0?ooo`L0o`000P3<0?l00`00I_l0c03o0<`0o`020<`0o`D00?mV00@0c?l0001Vo`00I_l0
06Ko0P3<o`000`00I_l0c03o0<`0o`03003oIP@0c?l0=P3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`070?ooo`<0<ol00P3oV@0203?o00030?nI003oool0oooo09@0oooo
0P3o0002001Vo`P00?mV103oool30?l0008006Ko0P3<0?l00`00I_l00?mV003oIP02003oIP<0c?l0
0P00ofHa0?ooo`030000003oool0oooo0040oooo00060?ooo`D000000`3oool00`000000oooo0?oo
o`020?ooo`<000001@3oool00`000000oooo0?ooo`0:0?ooo`80<ol01@3oV@2K0?ooo`80o`000P3o
ool00`3o00000?mV003oIP05003oIP050?l00000ofH006Ko001Vo`3oool00P3o00000`00I_l0c03o
0<`0o`020<`0o`T0c?l0103oool30<co02<0oooo00<000000?ooo`3oool00@3oool000L0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool03`3oool203?o0080oiT00P3o09VI0?ooo`80o`000`3oool50?l0008006Ko1`00ofH30<co0004
0<`0o`3o0000o`000?l000800?mV0`00I_l40<co0003003oIP3oool0oooo00D0c?l07P3oool00`00
0000oooo0?ooo`010?ooo`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P00000B0?ooo`80<`3o0`3oV@0203?o0:80oooo1@3o0005001Vo`L0o`00103<o`000`00ofH0
c03o0<`0o`05003oIP030<`0o`00ofH0c?l000D0c?l05P3oool3000000<0oooo00090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`@0oiT0
0P3o09VX0?ooo`@006Ko0P3oool3001Vo`800?mV00<006Ko0?ooo`3oool00P00ofH30<`0o`03003o
IP00I_l006Ko00@006Ko00@00?mV0<co0000ofH00?mV0P3<o`020?ooo`@00?mV3@3oool00`000000
oooo0?ooo`010?ooo`001P3oool01@000000oooo0?ooo`3oool0000000L0oooo100000050?ooo`03
0000003oool0oooo01P0oooo0P00ool30?nI0080<ol0Z@3oool2001Vo`H0oooo1000I_l30?l00004
0<`0o`00ofH0c?l00<`0o`<0o`000P00I_l20<co0005001Vo`00ofH0c?l0003oIP3<0?l00`3oool2
003oIP/0oooo00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool20?nI00<0<ol0/P3oool7
001Vo`<0c03o0P00ofH50?l000D0c?l00P3<0?l4003oIP80c03o1@3oool00`000000oooo0?ooo`01
0?ooo`001`3oool3000000P0oooo1@0000040?ooo`030000003oool0oooo01l0oooo1@3oV@2f0?oo
o`040?l00000I_l006Ko001Vo`80c03o103oool00`00ofH0oooo0?ooo`050<co00<006Ko00<0o`00
0<co003<o`001@3oool00`000000oooo0?ooo`010?ooo`006`3oool2000002D0oooo0P3oV@03003o
ok80oooo1@3o000:0<`0o`80oooo103<o`000`00I_l00?mV0?ooo`030?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool09P3oool30?nI00800?oo^03oool01000I_l0o`000?l0003o0003001V
o`80c03o1@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo02T0oooo103oV@2m0?ooo`8006Ko1@3<0?l60?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo02/0oooo0P0co`030?nI0080o`2I^P3oool3001Vo`800?mV
00<0c03o0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`0]0?ooo`<0<ol00P3oV@0203<0okd0oooo00<006Ko0?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`006`3oool200000340oooo0P0co`030?nI0<40oooo0P0000030?ooo`006`3oool00`00
0000oooo0?ooo`0b0?ooo`<0<ol00P3oV@0203<0okh0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0=@3oool203?o00D0oiT0^`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`0g0?ooo`800?oo0`0co`020?nI0;T0oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00000m0?ooo`80<ol00`3oV@2e0?ooo`8000000`3oool001/0oooo00<00000
0?ooo`3oool0?P3oool203?o0003003oo`3oV@00oiT00;@0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0@03oool00`0co`000?oo003oo`020?nI0;80oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0@@3oool203?o00800?oo0`3oV@2_0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo04<0oooo100co`000`00ool0oiT0
0?nI002]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000B03oool00`0co`000?oo003o
o`020?nI0:X0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`180?ooo`80<ol000<00?oo
03<0o`3oV@000P3oV@2X0?ooo`030000003oool0oooo0040oooo000C0?ooo`<000001@3oool00`00
0000oooo0?ooo`1:0?ooo`80<ol00`3o09T00`3oV@00<`3o0?ooo`2U0?ooo`030000003oool0oooo
0040oooo000B0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1<0?oo
o`<0<ol000<00?oo0?nI000c0?l00P0c0?nS0?ooo`030000003oool0oooo0040oooo000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`3oV@00<ol0003oo`030?nI00@0
<`3oW`3oool00`000000oooo0?ooo`010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`800000
D03oool00`3oV@00<ol0003oo`02003oo`80oiT00P3oool303<0oiX0oooo0`0000030?ooo`004P3o
ool4000000D0oooo00<000000?ooo`3oool0D@3oool403?o0003003oo`3oV@00oiT000<0o`2I0P0c
0?nJ0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0E03oool0103oV@00<ol0003oo`00ool30?nI0080o`2I0`0c0?nG0?ooo`030000003o
ool0oooo0040oooo000B0?ooo`D00000103oool00`000000oooo0?ooo`1F0?ooo`80<ol00`00ool2
0?nI0080o`2I00<0oooo03<0o`3oool0U@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`00
0000oooo0?ooo`1H0?ooo`<0<ol00P00ool30?nI00030?ooo`0c0?l0oooo09@0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P00001L0?ooo`0303?o0000ool00?oo00800?oo0P3oV@0503<0ohl0
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`0303?o0000ool00?oo00800?oo
00<0o`2I0?nI003o09T00`3oool203<0ohh0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0G@3oool303?o00800?oo00@0o`2I0?nI003o09T0o`2I0`3oool00`0c0?l0oooo
0?ooo`2;0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0600oooo0P0c
o`000`00ool0<ol00?nI00020?nI00<0oooo00<0<`3o0?ooo`3oool0RP3oool00`000000oooo0?oo
o`010?ooo`006`3oool2000006<0oooo00<0<ol0003oo`0co`000P0co`020?nI0080oooo0`0c0?n8
0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0H`3oool01`0co`000?oo003oo`00ool0
<ol003<0o`3oV@00103oool00`0c0?l0oooo0?ooo`260?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo06@0oooo0`0co`02003oo`0303<0o`3oV@00oooo00<0oooo00<0<`3o
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1W0?oo
o`80<ol000<00?oo03?o003oV@000P3oV@020?ooo`D0<`3oPP3oool00`000000oooo0?ooo`010?oo
o`006`3oool00`000000oooo0?ooo`1X0?ooo`030?nI000co`000?oo00<0<ol000<0oiT00?l0V@3o
ool0103oool00`0c0?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000
JP3oool01`3oV@00<ol0003oo`00ool0oooo03?o003oV@000P3o09T40?ooo`0303<0o`3oool0oooo
07d0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1[0?ooo`<0<ol00P3oool30?nI0080
o`2I0P3oool203<0ogh0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
KP3oool203?o0080oooo00<0<ol00?nI003oV@000P3o09T20?ooo`0303<0o`3oool0oooo07/0oooo
00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0K`3oool0103oV@00<ol003?o
0000ool203?o0080oiT00P3o09T00`3oool0<`3o03<0o`1k0?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0700oooo0P3oV@000`0co`000?oo003oo`0203?o00<0oiT00P3o
ool303<0ogP0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001d0?ooo`<0<ol000@0oooo
03?o000co`00<`3o0P3oV@020?l0V@030?ooo`0c0?l0oooo07D0oooo0P0000030?ooo`006`3oool0
0`000000oooo0?ooo`1d0?ooo`030?nI0000ool0<ol000800?oo00<0<ol003<0o`0c0?l00P3oV@00
0`3o09T0oooo03<0o`1f0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0M@3oool20?nI
0080<ol000<00?oo03?o000co`000P0c0?l0103oV@00o`2I0?l0V@0c0?me0?ooo`030000003oool0
oooo0040oooo00080?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo07L0oooo0P3oV@000`0co`000?oo003oo`0303?o00040?nI003oool0
o`2I03<0og@0oooo00<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00@0oiT003?o000co`00<ol00P00
ool0100co`00oiT00?ooo`3o09T303<0og40oooo00<000000?ooo`3oool00@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000N`3oool20?nI00030?ooo`0c
o`000?oo00800?oo0P3oV@030?l0V@0303<0o`3oool0oooo06`0oooo0`0000030?ooo`002P3oool0
0`000000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?ooo`1l0?ooo`80oiT000D0<ol0
003oo`0co`000?oo03<0o`030?nI00030?l0V@0c0?l0oooo06h0oooo00<000000?ooo`3oool00@3o
ool000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0O`3oool303?o0007003oo`0c0?l0<`3o03<0o`3oV@00oooo03<0o`1^0?ooo`03
0000003oool0oooo0040oooo00060?ooo`D000001`3oool5000000@0oooo00<000000?ooo`3oool0
O`3oool0103oV@00oooo03?o000co`03003oo`040?nI003o09T0oooo03<0ofd0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P0000210?ooo`030?nI003oool0oooo0080<ol000<0oooo003oo`3o
V@000P3o09T203<0ofX0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`210?ooo`@0oiT0
00<0<ol00?ooo`00ool00P3oV@020?l0V@0303<0o`3oool0oooo06P0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0QP3oool203?o00800?oo0P3oV@000`3oool0<`3o03<0
o`1X0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo08L0oooo00<0oiT0
03?o000co`000P00ool00`3oV@00oooo0?ooo`0303<0ofD0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0R03oool01@0co`000?oo03?o000co`000?oo00<0oiT000<0oooo
0?l0V@0c0?l0I03oool00`000000oooo0?ooo`010?ooo`006`3oool2000008X0oooo00/0<ol0003o
o`00ool0oooo003oo`0c0?l0oooo0?nI003oool0o`2I03<0o`1R0?ooo`8000000`3oool001/0oooo
00<000000?ooo`3oool0RP3oool303?o00080?ooo`00ool0<`3o03<0o`3oV@00<`3o0?ooo`0c0?mR
0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo08d0oooo00<0<ol0003o
o`00ool00P00ool0103oV@00<`3o0?ooo`0c0?mQ0?ooo`030000003oool0oooo0040oooo000K0?oo
o`030000003oool0oooo08h0oooo00P0<ol0003oo`00ool0oooo003oo`3oV@00<`3o0?ooo`<0<`3o
GP3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2?0?ooo`<0<ol000@0
oooo003oo`3oV@00oiT00`3oool00`0c0?l0o`2I0?ooo`1K0?ooo`030000003oool0oooo0040oooo
000K0?ooo`800000T`3oool203?o0007003oo`0co`00oiT00?nI000c0?l0oooo03<0o`020?l0VET0
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2B0?ooo`04003oo`3oV@00<ol0003oo`80
<ol000<0oiT003<0o`0c0?l00`0c0?mI0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo09<0oooo00<00?oo03?o003oV@000P00ool00`3o09T0oiT00?nI000403<0o`030?l0
V@3oool0oooo05D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0U03o
ool01@00ool0<ol00?nI003oV@000?oo0080o`2I0P3oV@020?ooo`0303<0o`3o09T0o`2I05D0oooo
00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0UP3oool203?o00030?nI0000
ool00?oo0080o`2I00<0oiT00?ooo`3oool00P0c0?l00`3o09T0oooo0?ooo`1B0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`800000V@3oool02@0co`00oiT0003oo`00ool0oooo0?l0V@3oV@00
<ol00?ooo`0403<0oe40oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2I0?ooo`80<ol0
0P00ool01@3oool0o`2I0?nI000co`00oooo0080<`3o00<0o`2I03<0o`0c0?l0D03oool00`000000
oooo0?ooo`010?ooo`003@3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo09/0oooo
0P0co`000`00ool0oooo0?ooo`040?nI00040?ooo`3o09T0<`3o03<0odl0oooo00<000000?ooo`3o
ool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo09d0oooo00D0<ol0003oo`00ool0oooo0?l0V@0203?o00030?nI003oool0o`2I
0080<`3oCP3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo0P00002O0?ooo`0703?o003oV@000?oo0?ooo`3o09T0oooo03?o
00020?nI0080o`2I0`0c0?m90?ooo`<000000`3oool000h0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo09l0oooo00H0<ol00?nI0000ool0oooo
0?l0V@3oool203?o0080oiT00P3o09T303<0odT0oooo00<000000?ooo`3oool00@3oool000h0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:00
oooo0P0co`03003oo`80oooo00L0<ol00?ooo`3oV@00oiT00?l0V@0c0?l0oooo0080<`3oA`3oool0
0`000000oooo0?ooo`010?ooo`003@3oool2000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`2R0?ooo`80<ol000@0oooo003oo`00ool0<ol00`3oool00`3oV@00o`2I03<0
o`020?ooo`0303<0o`3oool0oooo04@0oooo00<000000?ooo`3oool00@3oool000h0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0Y03oool01@0co`00oooo0?ooo`00
ool0<ol000<0oooo0P3oV@0503<0od@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00002V
0?ooo`0403?o003oV@00oooo003oo`@0<ol000H0oooo0?nI003oV@00o`2I03<0o`3oool203<0od40
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2U0?ooo`0403?o003oool0oiT00?nI00<0
0?oo00H0oooo03?o003oool0oooo0?nI003o09T30?ooo`<0<`3o?`3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`0303?o0000ool0oooo0080oiT000<0oooo003o
o`3o09T00P0co`000`3oool0oiT00?l0V@050?ooo`0303<0o`3oool0oooo03`0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0Y`3oool203?o0080oooo00<0oiT00?ooo`00
ool00P3o09T0100co`00oooo0?nI003o09T50?ooo`0303<0o`3oool0oooo03/0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0Z@3oool203?o00030?ooo`3oV@00oiT00080
0?oo00<0o`2I03?o003oool00P3oV@050?ooo`80<`3o>`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool200000:`0oooo00<0<ol00?ooo`3oool00P3oV@000`00ool0<ol00?ooo`020?ooo`<0oiT0
103oool00`0c0?l0oooo0?ooo`0g0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0[03o
ool203?o00<0oooo00<00?oo03?o003oool0103oool00`3oV@00oooo0?ooo`020?ooo`80<`3o>03o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2/0?ooo`03003oo`3oool0
<ol00080oooo00<0oiT0003oo`0co`000`0co`020?ooo`030?nI003oool0oooo00<0oooo00<0<`3o
0?ooo`3oool0=@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2]0?oo
o`03003oo`3oool0<ol00080oooo00<0oiT0003oo`00ool00P3o09T0100co`00oooo0?ooo`3oV@04
0?l0V@0303<0o`3oool0oooo03D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0[P3oool2003oo`0303?o003oool0oooo0080oiT00P00ool01P3o09T0<ol00?ooo`3oool0
oiT00?ooo`80<`3o00<0o`2I03<0o`3oool0=@3oool00`000000oooo0?ooo`010?ooo`006`3oool2
00000;80oooo00@0<ol0003oo`00ool0oooo0P3oV@000`00ool0o`2I03?o00020?ooo`050?nI003o
ool0oooo03<0o`3o09T00P0c0?lc0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0/P3o
ool00`0co`000?oo0?ooo`020?ooo`030?nI0000ool0o`2I0080<ol000<0oooo0?nI003oV@000P3o
ool00`3o09T0<`3o03<0o`0c0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo0;<0oooo100co`000`3oool0oiT0003oo`020?l0V@0303?o003oool0oooo0080oiT000@0oooo
0?l0V@3oool0<`3o<P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2e
0?ooo`03003oo`3oool0<ol00080oooo0P00ool00`3oool0<ol00?l0V@020?ooo`80oiT000<0o`2I
03<0o`0c0?l0<@3oool00`000000oooo0?ooo`010?ooo`006`3oool200000;L0oooo00<00?oo0?oo
o`0co`000`3oool01000ool0<ol00?ooo`3o09T30?ooo`040?nI003o09T0o`2I03<0obl0oooo0P00
00030?ooo`006`3oool00`000000oooo0?ooo`2g0?ooo`03003oo`3oool0<ol000<0oooo0P00ool0
0`3o09T0oooo0?ooo`020?ooo`030?nI003oool0o`2I00<0<`3o;@3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`04003oo`3oool0<ol003?o0080oooo00<0oiT0
003oo`0co`000P0co`020?ooo`030?nI003oool0o`2I00<0<`3o;03oool00`000000oooo0?ooo`01
0?ooo`0000@0oooo00000000000000000P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3
000000D0oooo00<000000?ooo`3oool0^@3oool01000ool0oooo0?ooo`0co`020?ooo`050?nI0000
ool0o`2I0?l0V@0co`000P3oool00`3oV@00oooo0?l0V@020?l0V@80<`3o:P3oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0;X0oooo0P00ool01@3oool0
<ol003?o003oool0oiT000800?oo00D0o`2I03?o000co`00oooo0?nI00030?ooo`040?l0V@0c0?l0
<`3o03<0obP0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00002m0?ooo`05003oo`3oool0
oooo03?o003oool00P3oV@001@00ool0o`2I0?ooo`0co`00oooo0080oiT00P3oool0103o09T0<`3o
03<0o`0c0?lU0?ooo`<000000`3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool01000ool0oooo
0?ooo`0co`020?ooo`050?nI0000ool0o`2I0?ooo`0co`000P3oool00`3oV@00oooo0?ooo`020?l0
V@@0<`3o903oool00`000000oooo0?ooo`010?ooo`000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3oool0_P3oool00`00
ool0oooo0?ooo`0303?o00040?nI0000ool0o`2I0?ooo`80<ol000<0oooo0?nI003oV@000`3oool4
03<0ob<0oooo00<000000?ooo`3oool00@3oool000030?ooo`000000000000<0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0_`3oool4
003oo`050?ooo`0co`00oiT0003oo`3o09T00P3oool0100co`00oooo0?ooo`3oV@030?ooo`030?l0
V@0c0?l0oooo0080<`3o8@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`<00000203oool5000000@0oooo00<000000?ooo`3oool0``3oool01000ool0oooo03?o
003oV@0503?o0080oooo00H0oiT00?ooo`3oool0oooo0?l0V@0c0?l20?ooo`0303<0o`3oool0oooo
01h0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000350?ooo`04003oo`3oool0<ol00?nI
00800?oo00<0o`2I03?o003oool00P3oool01@3oV@00oooo0?nI003oV@00oooo0080<`3o00<0o`2I
03<0o`3oool07@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0<D0oooo00<00?oo0?oo
o`3oool00P3oV@000`00ool0o`2I03?o00030?ooo`040?nI003oool0oooo0?nI0080oooo00<0<`3o
0?l0V@0c0?l07P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`360?oo
o`06003oo`3oool0oooo0?ooo`3oV@000?oo0`0co`050?ooo`<0oiT0100c0?lL0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo0<L0oooo00H00?oo0?ooo`3oool0oooo0?nI
0000ool303?o00L0oooo00@0oiT00?ooo`0c0?l0oooo0`0c0?lI0?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo0<P0oooo0P00ool30?ooo`<00?oo00<0<ol00?l0V@3oool0
1@3oool00`3oV@00oooo03<0o`030?ooo`0303<0o`3oool0oooo01H0oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00003;0?ooo`03003oo`3oool0oooo0080oooo00@0oiT0003oo`0co`00o`2I
1P3oool30?nI000403<0o`3o09T0oooo03<0oaH0oooo0P0000030?ooo`006`3oool00`000000oooo
0?ooo`3;0?ooo`800?oo0`3oool00`3oV@00<ol003?o00090?ooo`040?nI000c0?l0o`2I0?ooo`@0
<`3o4`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`<00?oo
00@0oooo0?nI000co`00<ol02@3oool00`3oV@00<`3o03<0o`040?ooo`0303<0o`3oool0oooo0100
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0d03oool00`00ool0oooo
0?nI000403?o00L0oooo103oV@000`0c0?l0oooo0?ooo`0203<0oa00oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00003B0?ooo`03003oo`3oool00?oo00D0<ol02@3oool00`3oV@00<`3o0?oo
o`020?ooo`<0<`3o303oool2000000<0oooo000K0?ooo`030000003oool0oooo0=80oooo00L00?oo
0?ooo`00ool00?oo0?ooo`0co`00o`2I0080<ol0203oool20?nI00D0oooo0P0c0?l;0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0=<0oooo00T00?oo0?ooo`3oool00?oo
0?ooo`0co`00o`2I0?ooo`0co`00203oool00`0c0?l0oiT00?ooo`050?ooo`80<`3o2@3oool00`00
0000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`D00?oo00<0<ol00?l0V@0c
o`002@3oool00`3oV@00<`3o0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0e`3oool01000ool0oiT0003oo`0co`02003oo`03
0?l0V@3oool0oooo00H0oooo00<0oiT003<0o`0c0?l01P3oool203<0o`H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003I0?ooo`03003oo`3oV@00oooo00<0<ol000<0o`2I0?ooo`3oool0
1P3oool40?nI00H0oooo00<0<`3o0?ooo`3oool00P3oool2000000<0oooo000K0?ooo`030000003o
ool0oooo0=T0oooo00<00?oo0?nI003oool00P3oool203?o00X0oooo00<0<`3o0?nI003oool02P3o
ool00`000000oooo0?ooo`010?ooo`003@3oool3000000<0oooo0`0000050?ooo`030000003oool0
oooo0=X0oooo00<00?oo0?nI003oool00P3oool01000ool0<ol003?o000co`080?ooo`0403<0o`3o
V@00oiT00?nI00P0oooo00<000000?ooo`3oool00@3oool000h0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f`3oool00`00ool0oiT0
0?ooo`020?ooo`800?oo0P0co`080?ooo`<0<`3o00<0oiT00?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0g@3oool00`3oV@00oooo0?ooo`020?ooo`03003oo`0co`00oooo00X0oooo00<0
<`3o0?nI003oool01@3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo0P00003O0?ooo`030?nI0000ool0oooo0080oooo00<0<ol0
003oo`3oool02`3oool0103oV@00oooo0?ooo`3oool3000000<0oooo000>0?ooo`040000003oool0
oooo0?ooo`@000001@3oool00`000000oooo0?ooo`3O0?ooo`030?nI0000ool00?oo0080oooo00<0
<ol0003oo`00ool0403oool00`000000oooo0?ooo`010?ooo`003@3oool2000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3P0?ooo`80oiT000D00?oo0?ooo`0co`00<ol00?oo
o`02003oo`h0oooo00<000000?ooo`3oool00@3oool000h0oooo00@000000?ooo`3oool0oooo1@00
00040?ooo`030000003oool0oooo0>80oooo00<0oiT0003oo`00ool00P0co`020?ooo`03003oo`3o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0h`3oool2
0?nI00800?oo0`0co`02003oo`/0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003V0?oo
o`80oiT00P00ool00`0co`00oooo03?o0004003oo`H0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`3W0?ooo`80oiT000<0oooo03?o000co`000P0co`020?ooo`03003oo`3oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0j@3oool00`3oV@00oooo
003oo`0303?o0080oooo00<00?oo0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`3Z0?ooo`040?nI003oool00?oo003oo`@0<ol01@3oool00`000000oooo
0?ooo`010?ooo`006`3oool200000>`0oooo00@0oiT00?ooo`3oool00?oo0`0co`040?ooo`800000
0`3oool001/0oooo00<000000?ooo`3oool0k03oool20?nI00030?ooo`00ool00?oo00H0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0kP3oool0103oV@00oooo0?ooo`00
ool50?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0>l0oooo00<0oiT0
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3`0?oo
o`030?nI003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003b0?ooo`03
0?nI003oool0oooo0080oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3g0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3o
ool001/0oooon`0000030?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3o
oolJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-13.8823, -0.913064, \
0.419554, 0.105204}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalues of A[t]", "Subsection"],

Cell["\<\
r = \
MapThread[Rule[#1,#2]&,{{lambda11,lambda12,lambda21,lambda22,alpha,beta},\
Theta}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["r", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({lambda11 \[Rule] 10.`, lambda12 \[Rule] \(-1.`\), 
      lambda21 \[Rule] 2.`, lambda22 \[Rule] 30.`, alpha \[Rule] 1.`, 
      beta \[Rule] \(-2.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A[t]/.r
A[t]/.r//Eigenvalues\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{\(\(0.1`\)\(\[InvisibleSpace]\)\) + 
          0.01`\ t, \(-0.01`\)}, {0.02`, \(\(0.3`\)\(\[InvisibleSpace]\)\) - 
          0.02`\ t}}\)], "Output"],

Cell[BoxData[
    \({1\/2\ \((\(\(0.4`\)\(\[InvisibleSpace]\)\) - 
            0.030000000000000002`\ \@\(\(-7.609475708248709`\) + t\)\ \
\@\(\(-5.723857625084625`\) + t\) - 0.01`\ t)\), 
      1\/2\ \((\(\(0.4`\)\(\[InvisibleSpace]\)\) + 
            0.030000000000000002`\ \@\(\(-7.609475708248709`\) + t\)\ \
\@\(\(-5.723857625084625`\) + t\) - 0.01`\ t)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Map[{Re[#],Im[#]}&,A[t]/.r//Eigenvalues]/.t->5", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.19561552812808852`, 0.`}, {0.15438447187191148`, 0.`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[A[t]/.r//Flatten//Evaluate,{t,0,10},
\tAxes->None]
Plot[Map[{Re[#],Im[#]}&,A[t]/.r//Eigenvalues]//Evaluate,{t,0,10},
\tAxes->None]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0337023 1.89872 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0337 -6 -4.5 ]
[-0.0125 .0337 0 4.5 ]
[-0.0125 .12864 -24 -4.5 ]
[-0.0125 .12864 0 4.5 ]
[-0.0125 .22357 -18 -4.5 ]
[-0.0125 .22357 0 4.5 ]
[-0.0125 .31851 -24 -4.5 ]
[-0.0125 .31851 0 4.5 ]
[-0.0125 .41345 -18 -4.5 ]
[-0.0125 .41345 0 4.5 ]
[-0.0125 .50838 -24 -4.5 ]
[-0.0125 .50838 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0337 m
.00625 .0337 L
s
[(0)] -0.0125 .0337 1 0 Mshowa
0 .12864 m
.00625 .12864 L
s
[(0.05)] -0.0125 .12864 1 0 Mshowa
0 .22357 m
.00625 .22357 L
s
[(0.1)] -0.0125 .22357 1 0 Mshowa
0 .31851 m
.00625 .31851 L
s
[(0.15)] -0.0125 .31851 1 0 Mshowa
0 .41345 m
.00625 .41345 L
s
[(0.2)] -0.0125 .41345 1 0 Mshowa
0 .50838 m
.00625 .50838 L
s
[(0.25)] -0.0125 .50838 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .10965 m
.00375 .10965 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .20459 m
.00375 .20459 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .29952 m
.00375 .29952 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .39446 m
.00375 .39446 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .4894 m
.00375 .4894 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .58433 m
.00375 .58433 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0337 m
1 .0337 L
s
.99375 .12864 m
1 .12864 L
s
.99375 .22357 m
1 .22357 L
s
.99375 .31851 m
1 .31851 L
s
.99375 .41345 m
1 .41345 L
s
.99375 .50838 m
1 .50838 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .39446 m
1 .39446 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .4894 m
1 .4894 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .58433 m
1 .58433 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.007 w
.02381 .22357 m
.06244 .23128 L
.10458 .23968 L
.14415 .24757 L
.18221 .25515 L
.22272 .26323 L
.26171 .271 L
.30316 .27927 L
.34309 .28723 L
.3815 .29489 L
.42237 .30303 L
.46172 .31088 L
.49955 .31842 L
.53984 .32645 L
.57861 .33418 L
.61984 .3424 L
.65954 .35032 L
.69774 .35793 L
.73838 .36604 L
.77751 .37384 L
.81909 .38213 L
.85916 .39011 L
.89771 .3978 L
.93871 .40598 L
.97619 .41345 L
s
1 .6 0 r
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.57861 .01472 L
.61984 .01472 L
.65954 .01472 L
.69774 .01472 L
.73838 .01472 L
.77751 .01472 L
.81909 .01472 L
.85916 .01472 L
.89771 .01472 L
.93871 .01472 L
.97619 .01472 L
s
.8 1 0 r
.02381 .07168 m
.06244 .07168 L
.10458 .07168 L
.14415 .07168 L
.18221 .07168 L
.22272 .07168 L
.26171 .07168 L
.30316 .07168 L
.34309 .07168 L
.3815 .07168 L
.42237 .07168 L
.46172 .07168 L
.49955 .07168 L
.53984 .07168 L
.57861 .07168 L
.61984 .07168 L
.65954 .07168 L
.69774 .07168 L
.73838 .07168 L
.77751 .07168 L
.81909 .07168 L
.85916 .07168 L
.89771 .07168 L
.93871 .07168 L
.97619 .07168 L
s
.2 1 0 r
.02381 .60332 m
.06244 .58791 L
.10458 .57111 L
.14415 .55533 L
.18221 .54016 L
.22272 .52401 L
.26171 .50846 L
.30316 .49193 L
.34309 .47601 L
.3815 .4607 L
.42237 .4444 L
.46172 .42871 L
.49955 .41363 L
.53984 .39756 L
.57861 .3821 L
.61984 .36566 L
.65954 .34983 L
.69774 .3346 L
.73838 .3184 L
.77751 .30279 L
.81909 .28621 L
.85916 .27024 L
.89771 .25487 L
.93871 .23852 L
.97619 .22357 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002`0oooo1@00000]0?ooo`<00000;03oool3000002h0
oooo0`00000Z0?ooo`<00000103oool2000000<0oooo000O0?ooo`040000003oool0oooo000002`0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo
0?ooo`000000;03oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000]0?ooo`030000
003oool0oooo02/0oooo1@00000[0?ooo`050000003oool0oooo0?ooo`000000;03oool01@000000
oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`007`3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000;03oool4000002h0oooo0`00000[0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool00000:`3oool01@000000oooo
0?ooo`3oool0000002`0oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo000O0?ooo`040000003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000
000]0?ooo`800000;@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`000000
:@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool00200oooo0P00000]0?ooo`<00000
;`3oool00`000000oooo0?ooo`0/0?ooo`800000;P3oool3000002/0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0
oooo003o0?oooaX0oooo000K0?ooooh00000000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo0@000000
01/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool2000000@0oooolP3oV@040?ooo`80
0000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3o
ool100000000503oool2000000D0oooo00<000000?ooo`3oool0nP3oool1000000004`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0?X0oooo0@00000001<0oooo00@000000?oo
o`3oool00000103oool200000?T0oooo0`00000001<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3j0?ooo`400000000C0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0nP3oool1000000004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?X0oooo0@00000001@0oooo0P0000050?ooo`030000003oool0oooo0?X0oooo0@00000001/0
oooo0P00003j0?ooo`800000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo0P0000040?oooo80c?l0103oool200000000
6`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00
000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0
oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000
000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1
000000006`3oool200000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool00`000000oooo0?ooo`3j0?ooo`40000000020?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0nP3oool10000000000D0oooo
0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?X0oooo0@00000000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P00003i0?oo
o`<0000000001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?X0oooo0@00000000050?ooo`000000oooo
0?ooo`000000203oool01@000000oooo0?ooo`000000oooo00@000001@3oool00`000000oooo0?oo
o`3j0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000080?ooo`030000003oool0oooo0?X0oooo0@0000000080oooo0P00000:0?ooo`800000
0P3oool5000000@0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00
000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?oo
o`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0
nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1
000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0
oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00
000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?oo
o`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo0P00003j0?ooo`800000
000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1
00000000203oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?oo
o`3oool0nP3oool1000000001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0nP3oool1000000001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`<0o`00k@3oool203?o00<0oooo0`00000000L0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo1@3o003U0?ooo`<0<ol01`3oool1000000001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool50?l00=h0oooo0P0co`0:0?oo
o`40000000070?ooo`040000003oool0oooo000000P0oooo0P0000060?ooo`030000003oool0oooo
0100oooo1@3o003F0?ooo`<0<ol0303oool100000000203oool2000000X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`H0o`00cP3oool203?o00l0oooo0@00000001/0oooo
0P00000L0?ooo`D0o`00aP3oool303?o0100oooo0P00000001/0oooo00<000000?ooo`3oool0803o
ool50?l00;l0oooo0P0co`0D0?ooo`400000000K0?ooo`030000003oool0oooo02D0oooo1@3o002g
0?ooo`<0<ol05P3oool1000000006`3oool00`000000oooo0?ooo`0Z0?ooo`D0o`00/03oool203?o
01T0oooo0@00000001/0oooo00<000000?ooo`3oool0;`3oool50?l00:P0oooo0`0co`0K0?ooo`40
0000000K0?ooo`800000=@3oool50?l00:40oooo0P0co`0M0?ooo`800000000K0?ooo`030000003o
ool0oooo03T0oooo1@3o002I0?ooo`<0<ol0803oool1000000006`3oool00`000000oooo0?ooo`0n
0?ooo`D0o`00TP3oool203?o02<0oooo0@00000001/0oooo00<000000?ooo`3oool0@`3oool50?l0
08X0oooo0`0co`0U0?ooo`400000000K0?ooo`030000003oool0oooo04P0oooo1@3o00230?ooo`80
<ol0:03oool1000000006`3oool2000004h0oooo1@3o001k0?ooo`<0<ol0:@3oool2000000006`3o
ool00`000000oooo0?ooo`1B0?ooo`D0o`00M03oool203?o02d0oooo0@00000001/0oooo00<00000
0?ooo`3oool0E`3oool50?l006`0oooo0`0co`0_0?ooo`400000000K0?ooo`030000003oool0oooo
05`0oooo1@3o001T0?ooo`<0<ol0<P3oool1000000006`3oool200000680oooo1@3o001L0?ooo`<0
<ol0=03oool2000000006`3oool00`000000oooo0?ooo`1V0?ooo`H0o`00E03oool203?o03P0oooo
0@00000001/0oooo00<000000?ooo`3oool0K03oool50?l004d0oooo0P0co`0j0?ooo`4000000002
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool3000000D0oooo00<00000
0?ooo`3oool0L@3oool40?l004H0oooo0`0co`0l0?ooo`40000000001@3oool000000?ooo`3oool0
000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0M@3oool50?l003l0oooo0P0co`0o0?ooo`40000000001@3oool000000?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000N`3o
ool50?l003P0oooo0P0co`0o0?ooo`<0000000001@3oool000000?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07l0oooo1@3o
000`0?ooo`<0<ol0@`3oool10000000000D0oooo0000003oool0oooo000000090?ooo`040000003o
ool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`240?ooo`D0o`00:03oool303?o04H0oooo
0@00000000050?ooo`000000oooo0?ooo`000000203oool2000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`D0o`00803oool303?o04T0oooo0@0000000080oooo0P00
000:0?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`2>0?ooo`D0o`00
6@3oool203?o04`0oooo0@00000001/0oooo0P00002D0?ooo`D0o`004P3oool203?o04d0oooo0P00
000001/0oooo00<000000?ooo`3oool0V03oool60?l000T0oooo0`0co`1@0?ooo`400000000K0?oo
o`030000003oool0oooo09h0oooo1@3o00020?ooo`80<ol0D`3oool1000000006`3oool00`000000
oooo0?ooo`2S0?ooo`80<ol00P3o001C0?ooo`400000000K0?ooo`030000003oool0oooo0:00oooo
0`0co`040?ooo`D0o`00CP3oool1000000006`3oool2000009l0oooo0P0co`0<0?ooo`D0o`00B03o
ool2000000006`3oool00`000000oooo0?ooo`2K0?ooo`<0<ol04`3oool50?l004@0oooo0@000000
01/0oooo00<000000?ooo`3oool0V@3oool203?o01/0oooo1@3o000o0?ooo`400000000K0?ooo`03
0000003oool0oooo09H0oooo0`0co`0R0?ooo`D0o`00>P3oool1000000006`3oool00`000000oooo
0?ooo`2C0?ooo`<0<ol0:P3oool50?l003D0oooo0@00000001/0oooo0P00002A0?ooo`<0<ol0<P3o
ool50?l002l0oooo0P00000001/0oooo00<000000?ooo`3oool0SP3oool203?o03X0oooo1P3o000Z
0?ooo`400000000K0?ooo`030000003oool0oooo08/0oooo0`0co`120?ooo`D0o`009@3oool10000
00006`3oool00`000000oooo0?ooo`290?ooo`80<ol0BP3oool50?l00200oooo0@00000001/0oooo
0P0000270?ooo`<0<ol0D@3oool50?l001X0oooo0P00000001/0oooo00<000000?ooo`3oool0Q03o
ool203?o05T0oooo1@3o000F0?ooo`400000000K0?ooo`030000003oool0oooo0840oooo0`0co`1P
0?ooo`D0o`004@3oool100000000203oool2000000@0oooo00@000000?ooo`3oool0oooo1@000004
0?ooo`030000003oool0oooo07l0oooo0P0co`1X0?ooo`D0o`00303oool1000000001`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0O03o
ool303?o06l0oooo1@3o00070?ooo`40000000070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0103oool2000007/0oooo0P0co`1g0?ooo`80o`000`3oool3000000001`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0N03o
ool203?o0800oooo0@00000000L0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0M@3oool303?o0880oooo0@00000000L0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0L`3oool203?o08D0oooo0@00000000P0oooo0P0000090?ooo`<000001@3oool00`000000oooo
0?ooo`1a0?ooo`80<ol0Q`3oool1000000006`3oool2000006l0oooo0`0co`280?ooo`800000000K
0?ooo`030000003oool0oooo06`0oooo0P0co`2<0?ooo`400000000K0?ooo`030000003oool0oooo
06T0oooo0`0co`2>0?ooo`400000000K0?ooo`030000003oool0oooo06L0oooo0P0co`2A0?ooo`40
0000000K0?ooo`030000003oool0oooo06@0oooo0`0co`2C0?ooo`400000000K0?ooo`800000HP3o
ool303?o09D0oooo0P00000001/0oooo00<000000?ooo`3oool0GP3oool303?o09T0oooo0@000000
01/0oooo00<000000?ooo`3oool0G03oool203?o09`0oooo0@00000001/0oooo00<000000?ooo`3o
ool0FP3oool203?o09h0oooo0@00000001/0oooo00<000000?ooo`3oool0E`3oool303?o0:00oooo
0@00000001/0oooo0P00001F0?ooo`80<ol0XP3oool2000000006`3oool00`000000oooo0?ooo`1C
0?ooo`80<ol0Y@3oool1000000006`3oool00`000000oooo0?ooo`1@0?ooo`<0<ol0Y`3oool10000
00006`3oool00`000000oooo0?ooo`1=0?ooo`<0<ol0ZP3oool1000000006`3oool2000004/0oooo
0`0co`2/0?ooo`800000000K0?ooo`030000003oool0oooo04P0oooo0P0co`2`0?ooo`400000000K
0?ooo`030000003oool0oooo04D0oooo0`0co`2b0?ooo`40000000020?ooo`800000103oool01000
0000oooo0?ooo`3oool500000080oooo0`0000050?ooo`030000003oool0oooo04<0oooo0P0co`2e
0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool303?o0;L0oooo
0@00000000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo0P00000o0?ooo`80<ol0^03oool30000000000D0oooo0000003oool0oooo
0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0k0?ooo`<0<ol0_03oool10000000000D0oooo0000003oool0oooo000000070?ooo`060000
003oool0oooo0?ooo`000000oooo100000050?ooo`030000003oool0oooo03T0oooo0P0co`2o0?oo
o`40000000001@3oool000000?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool0=P3oool303?o0<40oooo0@0000000080oooo0P000009
0?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0=03oool203?o0<@0oooo0@000000
01/0oooo0P00000b0?ooo`<0<ol0a@3oool2000000006`3oool00`000000oooo0?ooo`0_0?ooo`80
<ol0b@3oool1000000006`3oool00`000000oooo0?ooo`0/0?ooo`<0<ol0b`3oool1000000006`3o
ool00`000000oooo0?ooo`0Z0?ooo`80<ol0cP3oool1000000006`3oool00`000000oooo0?ooo`0W
0?ooo`<0<ol0d03oool1000000006`3oool2000002H0oooo0P0co`3B0?ooo`800000000K0?ooo`03
0000003oool0oooo0280oooo0`0co`3E0?ooo`400000000K0?ooo`030000003oool0oooo0200oooo
0P0co`3H0?ooo`400000000K0?ooo`030000003oool0oooo01d0oooo0`0co`3J0?ooo`400000000K
0?ooo`030000003oool0oooo01/0oooo0P0co`3M0?ooo`400000000K0?ooo`8000006@3oool303?o
0=h0oooo0P00000001/0oooo00<000000?ooo`3oool05P3oool203?o0>80oooo0@00000001/0oooo
00<000000?ooo`3oool04`3oool303?o0>@0oooo0@00000001/0oooo00<000000?ooo`3oool0403o
ool303?o0>L0oooo0@00000001/0oooo0P00000>0?ooo`<0<ol0j@3oool2000000006`3oool00`00
0000oooo0?ooo`0;0?ooo`80<ol0k@3oool1000000006`3oool00`000000oooo0?ooo`090?ooo`80
<ol0k`3oool100000000203oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool01P3oool303?o0?40oooo0@00000000L0oooo00@000000?ooo`3oool00000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool203?o0?@0
oooo0@00000000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`80
0000103oool00`0co`00oooo0?ooo`3b0?ooo`<0000000070?ooo`040000003oool0oooo000000T0
oooo0P0000050?ooo`030000003oool0oooo0?X0oooo0@00000000L0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo0@00000000L0oooo
00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool100000000203oool2000000T0oooo0`0000050?ooooh00000003o0?oooaX0oooo
003o0?oooaX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-1.37678, -0.046681, \
0.0414781, 0.0020805}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.041298 1.8797 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0413 -6 -4.5 ]
[-0.0125 .0413 0 4.5 ]
[-0.0125 .13528 -24 -4.5 ]
[-0.0125 .13528 0 4.5 ]
[-0.0125 .22927 -18 -4.5 ]
[-0.0125 .22927 0 4.5 ]
[-0.0125 .32325 -24 -4.5 ]
[-0.0125 .32325 0 4.5 ]
[-0.0125 .41724 -18 -4.5 ]
[-0.0125 .41724 0 4.5 ]
[-0.0125 .51122 -24 -4.5 ]
[-0.0125 .51122 0 4.5 ]
[-0.0125 .60521 -18 -4.5 ]
[-0.0125 .60521 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0413 m
.00625 .0413 L
s
[(0)] -0.0125 .0413 1 0 Mshowa
0 .13528 m
.00625 .13528 L
s
[(0.05)] -0.0125 .13528 1 0 Mshowa
0 .22927 m
.00625 .22927 L
s
[(0.1)] -0.0125 .22927 1 0 Mshowa
0 .32325 m
.00625 .32325 L
s
[(0.15)] -0.0125 .32325 1 0 Mshowa
0 .41724 m
.00625 .41724 L
s
[(0.2)] -0.0125 .41724 1 0 Mshowa
0 .51122 m
.00625 .51122 L
s
[(0.25)] -0.0125 .51122 1 0 Mshowa
0 .60521 m
.00625 .60521 L
s
[(0.3)] -0.0125 .60521 1 0 Mshowa
.125 Mabswid
0 .06009 m
.00375 .06009 L
s
0 .07889 m
.00375 .07889 L
s
0 .09769 m
.00375 .09769 L
s
0 .11649 m
.00375 .11649 L
s
0 .15408 m
.00375 .15408 L
s
0 .17288 m
.00375 .17288 L
s
0 .19167 m
.00375 .19167 L
s
0 .21047 m
.00375 .21047 L
s
0 .24807 m
.00375 .24807 L
s
0 .26686 m
.00375 .26686 L
s
0 .28566 m
.00375 .28566 L
s
0 .30446 m
.00375 .30446 L
s
0 .34205 m
.00375 .34205 L
s
0 .36085 m
.00375 .36085 L
s
0 .37964 m
.00375 .37964 L
s
0 .39844 m
.00375 .39844 L
s
0 .43604 m
.00375 .43604 L
s
0 .45483 m
.00375 .45483 L
s
0 .47363 m
.00375 .47363 L
s
0 .49243 m
.00375 .49243 L
s
0 .53002 m
.00375 .53002 L
s
0 .54882 m
.00375 .54882 L
s
0 .56761 m
.00375 .56761 L
s
0 .58641 m
.00375 .58641 L
s
0 .0225 m
.00375 .0225 L
s
0 .0037 m
.00375 .0037 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0413 m
1 .0413 L
s
.99375 .13528 m
1 .13528 L
s
.99375 .22927 m
1 .22927 L
s
.99375 .32325 m
1 .32325 L
s
.99375 .41724 m
1 .41724 L
s
.99375 .51122 m
1 .51122 L
s
.99375 .60521 m
1 .60521 L
s
.125 Mabswid
.99625 .06009 m
1 .06009 L
s
.99625 .07889 m
1 .07889 L
s
.99625 .09769 m
1 .09769 L
s
.99625 .11649 m
1 .11649 L
s
.99625 .15408 m
1 .15408 L
s
.99625 .17288 m
1 .17288 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .21047 m
1 .21047 L
s
.99625 .24807 m
1 .24807 L
s
.99625 .26686 m
1 .26686 L
s
.99625 .28566 m
1 .28566 L
s
.99625 .30446 m
1 .30446 L
s
.99625 .34205 m
1 .34205 L
s
.99625 .36085 m
1 .36085 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39844 m
1 .39844 L
s
.99625 .43604 m
1 .43604 L
s
.99625 .45483 m
1 .45483 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .49243 m
1 .49243 L
s
.99625 .53002 m
1 .53002 L
s
.99625 .54882 m
1 .54882 L
s
.99625 .56761 m
1 .56761 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .0225 m
1 .0225 L
s
.99625 .0037 m
1 .0037 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.007 w
.02381 .60332 m
.06244 .58794 L
.10458 .57116 L
.14415 .55537 L
.18221 .54016 L
.22272 .52393 L
.26171 .50825 L
.30316 .49153 L
.34309 .47532 L
.3815 .45959 L
.42237 .44264 L
.46172 .42594 L
.49955 .4092 L
.53984 .38938 L
.55838 .37775 L
.5608 .37582 L
.56342 .37345 L
.56462 .37221 L
.56589 .37072 L
.56817 .367 L
.56943 .36339 L
.57014 .36332 L
.57078 .36326 L
.57226 .36311 L
.57365 .36298 L
.57861 .36249 L
.58957 .36141 L
.59975 .3604 L
.61984 .35842 L
.65968 .35449 L
.69801 .35071 L
.7174 .34879 L
.72769 .34778 L
.7331 .34724 L
.73879 .34668 L
.74384 .34618 L
.74522 .34605 L
.7467 .3459 L
.74741 .34583 L
.74809 .34576 L
.74936 .342 L
.75053 .33986 L
.75178 .33818 L
.75401 .33575 L
.75905 .33144 L
.77806 .31954 L
.81595 .30086 L
.85629 .28299 L
.89511 .26652 L
.93639 .2494 L
Mistroke
.97615 .23312 L
.97619 .23311 L
Mfstroke
1 .6 0 r
.02381 .0413 m
.06244 .0413 L
.10458 .0413 L
.14415 .0413 L
.18221 .0413 L
.22272 .0413 L
.26171 .0413 L
.30316 .0413 L
.34309 .0413 L
.3815 .0413 L
.42237 .0413 L
.46172 .0413 L
.49955 .0413 L
.52059 .0413 L
.53984 .0413 L
.54934 .0413 L
.55436 .0413 L
.55972 .0413 L
.56236 .0413 L
.56486 .0413 L
.56709 .0413 L
.56835 .0413 L
.56951 .03829 L
.57061 .0362 L
.57162 .03485 L
.57394 .03255 L
.57619 .03083 L
.57861 .0293 L
.58878 .02463 L
.59453 .02271 L
.59985 .02123 L
.60961 .01905 L
.61997 .01732 L
.62934 .01618 L
.63461 .01569 L
.63944 .01534 L
.6437 .01509 L
.64835 .01489 L
.6507 .01482 L
.65199 .01479 L
.6532 .01477 L
.65434 .01475 L
.65557 .01473 L
.65669 .01472 L
.65772 .01472 L
.65898 .01472 L
.66016 .01472 L
.66123 .01473 L
.6624 .01474 L
.66366 .01476 L
Mistroke
.665 .01478 L
.66742 .01484 L
.66987 .01492 L
.67218 .01501 L
.67649 .01524 L
.68166 .0156 L
.68641 .01601 L
.69713 .01727 L
.70689 .01886 L
.71599 .02082 L
.72597 .02368 L
.73157 .02575 L
.73667 .0281 L
.74673 .03601 L
.74792 .03822 L
.74917 .0413 L
.74983 .0413 L
.75055 .0413 L
.7518 .0413 L
.75469 .0413 L
.7574 .0413 L
.77656 .0413 L
.81494 .0413 L
.85556 .0413 L
.89466 .0413 L
.93621 .0413 L
.97619 .0413 L
Mfstroke
.8 1 0 r
.02381 .23116 m
.06244 .23891 L
.10458 .24738 L
.14415 .25536 L
.18221 .26306 L
.22272 .27129 L
.26171 .27927 L
.30316 .28781 L
.34309 .29614 L
.3815 .30429 L
.42237 .31318 L
.46172 .32211 L
.49955 .33138 L
.52059 .33713 L
.53984 .34324 L
.55972 .352 L
.56217 .35359 L
.56346 .35455 L
.56482 .3557 L
.56601 .35689 L
.56732 .35854 L
.56851 .36089 L
.56963 .36337 L
.57079 .36326 L
.57189 .36315 L
.57396 .36295 L
.57861 .36249 L
.5882 .36154 L
.59842 .36053 L
.6168 .35872 L
.65513 .35494 L
.69592 .35091 L
.71617 .34891 L
.72609 .34793 L
.73518 .34704 L
.74403 .34616 L
.74618 .34595 L
.74737 .34583 L
.74848 .34572 L
.7498 .3501 L
.751 .35177 L
.75335 .35408 L
.75572 .35587 L
.75824 .35746 L
.76275 .35986 L
.77293 .3642 L
.81082 .37591 L
.85116 .38598 L
.88998 .39485 L
.93126 .40387 L
Mistroke
.97102 .41231 L
.97619 .4134 L
Mfstroke
.2 1 0 r
.02381 .0413 m
.06244 .0413 L
.10458 .0413 L
.14415 .0413 L
.18221 .0413 L
.22272 .0413 L
.26171 .0413 L
.30316 .0413 L
.34309 .0413 L
.3815 .0413 L
.42237 .0413 L
.46172 .0413 L
.49955 .0413 L
.52059 .0413 L
.53984 .0413 L
.54934 .0413 L
.55436 .0413 L
.55972 .0413 L
.56236 .0413 L
.56486 .0413 L
.56709 .0413 L
.56835 .0413 L
.56951 .0443 L
.57061 .0464 L
.57162 .04775 L
.57394 .05004 L
.57619 .05177 L
.57861 .0533 L
.58878 .05797 L
.59453 .05988 L
.59985 .06137 L
.60961 .06355 L
.61997 .06528 L
.62934 .06642 L
.63461 .0669 L
.63944 .06726 L
.6437 .06751 L
.64835 .0677 L
.6507 .06777 L
.65199 .06781 L
.6532 .06783 L
.65434 .06785 L
.65557 .06786 L
.65669 .06787 L
.65772 .06788 L
.65898 .06788 L
.66016 .06788 L
.66123 .06787 L
.6624 .06786 L
.66366 .06784 L
Mistroke
.665 .06782 L
.66742 .06776 L
.66987 .06768 L
.67218 .06758 L
.67649 .06736 L
.68166 .067 L
.68641 .06659 L
.69713 .06533 L
.70689 .06373 L
.71599 .06177 L
.72597 .05891 L
.73157 .05684 L
.73667 .0545 L
.74673 .04659 L
.74792 .04437 L
.74917 .0413 L
.74983 .0413 L
.75055 .0413 L
.7518 .0413 L
.75469 .0413 L
.7574 .0413 L
.77656 .0413 L
.81494 .0413 L
.85556 .0413 L
.89466 .0413 L
.93621 .0413 L
.97619 .0413 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002`0oooo1@00000]0?ooo`<00000;03oool3000002h0
oooo0`00000Z0?ooo`<00000103oool2000000<0oooo000O0?ooo`040000003oool0oooo000002`0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo
0?ooo`000000;03oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000]0?ooo`030000
003oool0oooo02/0oooo1@00000[0?ooo`050000003oool0oooo0?ooo`000000;03oool01@000000
oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`007`3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000;03oool4000002h0oooo0`00000[0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool00000:`3oool01@000000oooo
0?ooo`3oool0000002`0oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo000O0?ooo`040000003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000
000]0?ooo`800000;@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`000000
:@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool00200oooo0P00000]0?ooo`<00000
;`3oool00`000000oooo0?ooo`0/0?ooo`800000;P3oool3000002/0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0
oooo000K0?ooooh00000000K0?ooo`800000103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000006`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`03
0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3o
ool0V`3ooolB0?nI04d0oooo0@00000001/0oooo00<000000?ooo`3oool0UP3oool50?nI0180oooo
1@3oV@180?ooo`400000000K0?ooo`800000U03oool30?nI01`0oooo103oV@130?ooo`800000000K
0?ooo`030000003oool0oooo0940oooo0P3oV@0S0?ooo`<0oiT0@@3oool100000000503oool20000
00D0oooo00<000000?ooo`3oool0S`3oool20?nI02P0oooo00<0oiT00?ooo`3oool0?P3oool10000
00004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08d0oooo0P3oV@0[0?oo
o`030?nI003oool0oooo03d0oooo0@00000001<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`2=0?ooo`030?nI003oool0oooo02X0oooo00<0oiT00?ooo`3oool0?@3oool10000
00004`3oool010000000oooo0?ooo`0000040?ooo`800000103ooon;03?o02`0oooo>`0co`030?oo
o`<00000000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0S@3oool00`0c
o`00oooo0?ooo`0Y0?ooo`80<ol0?`3oool1000000004`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo08h0oooo0P0co`0X0?ooo`0303?o003oool0oooo03l0oooo0@00000001@0
oooo0P0000050?ooo`030000003oool0oooo08l0oooo0`0co`0U0?ooo`0303?o003oool0oooo0400
oooo0@00000001/0oooo00<000000?ooo`3oool0TP3oool303?o01h0oooo100co`130?ooo`400000
000K0?ooo`800000UP3oool503?o01D0oooo100co`160?ooo`800000000K0?ooo`030000003oool0
oooo09X0oooo5@0co`1;0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0
oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool200000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool0
0`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0
oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
000000<0oooo0`0000050?ooo`030000003oool0oooo0?X0oooo0@00000000050?ooo`000000oooo
0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3j0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?X0
oooo0@00000000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo0P00003i0?ooo`<0000000001@3oool000000?ooo`3oool00000
00P0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00<000000?ooo`3oool0nP3oool1
0000000000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool00000
203oool00`000000oooo0?ooo`3j0?ooo`40000000020?ooo`8000002P3oool200000080oooo1@00
00040?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo0P00003j0?ooo`800000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00
000001/0oooo0P00003j0?ooo`800000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0
oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000
000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo0P00003j0?ooo`800000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00
000001/0oooo0P00003j0?ooo`800000000K0?ooo`030000003oool0oooo0?X0oooo0@00000000P0
oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0?X0
oooo0@00000000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?X0oooo0@00000000L0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`800000n@3oool3000000001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool30<co0>d0oooo0P3o00050?ooo`40
000000070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`D0c?l0i@3oool40?l000H0oooo0@00000000L0oooo00@000000?ooo`3oool0
0000203oool2000000H0oooo00<000000?ooo`3oool02`3oool50<co0=h0oooo0P3o000:0?ooo`40
000000080?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo
1@3<o`3F0?ooo`<0o`00303oool1000000006`3oool2000001H0oooo1P3<o`3>0?ooo`80o`003P3o
ool2000000006`3oool00`000000oooo0?ooo`0K0?ooo`D0c?l0a`3oool20?l00140oooo0@000000
01/0oooo00<000000?ooo`3oool0803oool50<co0;l0oooo0`3o000C0?ooo`400000000K0?ooo`03
0000003oool0oooo02D0oooo1@3<o`2h0?ooo`80o`005P3oool1000000006`3oool00`000000oooo
0?ooo`0Z0?ooo`D0c?l0/@3oool20?l001P0oooo0@00000001/0oooo0P00000`0?ooo`D0c?l0ZP3o
ool20?l001T0oooo0P00000001/0oooo00<000000?ooo`3oool0=03oool50<co0:80oooo0`3o000L
0?ooo`400000000K0?ooo`030000003oool0oooo03T0oooo1@3<o`2K0?ooo`80o`007`3oool10000
00006`3oool00`000000oooo0?ooo`0n0?ooo`D0c?l0T`3oool30?l00240oooo0@00000001/0oooo
00<000000?ooo`3oool0@`3oool50<co08`0oooo0P3o000T0?ooo`400000000K0?ooo`800000B@3o
ool50<co08@0oooo0`3o000U0?ooo`800000000K0?ooo`030000003oool0oooo04d0oooo1@3<o`1m
0?ooo`80o`00:@3oool1000000006`3oool00`000000oooo0?ooo`1B0?ooo`D0c?l0M@3oool30?l0
02/0oooo0@00000001/0oooo00<000000?ooo`3oool0E`3oool50<co06h0oooo0P3o000^0?ooo`40
0000000K0?ooo`800000G@3oool40<co06P0oooo0P3o000_0?ooo`800000000K0?ooo`030000003o
ool0oooo0600oooo103<o`1R0?ooo`80o`00<P3oool1000000006`3oool00`000000oooo0?ooo`1T
0?ooo`<0c?l0GP3oool00`3o0000oooo0?ooo`0b0?ooo`40000000020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0I`3oool50<co
05L0oooo0P3o000e0?ooo`40000000001@3oool000000?ooo`3oool0000000T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool5
0<co0500oooo0P3o000g0?ooo`40000000001@3oool000000?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000LP3oool40<co04X0oooo0P3o000g
0?ooo`<0000000001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo1@3<o`140?ooo`030?l0003oool0
oooo03T0oooo0@00000000050?ooo`000000oooo0?ooo`0000002@3oool010000000oooo0?ooo`3o
ool4000000D0oooo00<000000?ooo`3oool0NP3oool30<co0400oooo00<0o`000?ooo`3oool0>P3o
ool10000000000D0oooo0000003oool0oooo000000080?ooo`8000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo07d0oooo0`3<o`0l0?ooo`030?l0003oool0oooo03/0oooo0@00
00000080oooo0P00000:0?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?oo
o`200?ooo`@0c?l0=`3oool00`3o0000oooo0?ooo`0l0?ooo`400000000K0?ooo`800000Q@3oool3
0<co03<0oooo00<0o`000?ooo`3oool0?03oool2000000006`3oool00`000000oooo0?ooo`270?oo
o`<0c?l0:@3oool80<co03l0oooo0@00000001/0oooo00<000000?ooo`3oool0RP3oool00`3<o`00
oooo0?ooo`0K0?ooo`/0c?l000<0o`000?ooo`3oool0103oool20<co03h0oooo0@00000001/0oooo
00<000000?ooo`3oool0R`3oool20<co0140oooo2P3<o`000`3o0000oooo0?ooo`0@0?ooo`80c?l0
?@3oool1000000006`3oool00`000000oooo0?ooo`2<0?ooo`030<co003oool0oooo00P0oooo1`3<
o`000`3o0000oooo0?ooo`0L0?ooo`<0c?l0>P3oool1000000006`3oool2000008h0oooo2P3<o`0Y
0?ooo`<0c?l0=P3oool2000000006`3oool00`000000oooo0?ooo`2<0?ooo`030?l0003oool0oooo
03@0oooo0`3<o`0d0?ooo`400000000K0?ooo`030000003oool0oooo08`0oooo00<0o`000?ooo`3o
ool0=`3oool30<co0340oooo0@00000001/0oooo00<000000?ooo`3oool0R`3oool20?l003`0oooo
103<o`0]0?ooo`400000000K0?ooo`800000RP3oool20?l00480oooo0`3<o`0Y0?ooo`800000000K
0?ooo`030000003oool0oooo08L0oooo0P3o00170?ooo`<0c?l09`3oool1000000006`3oool00`00
0000oooo0?ooo`260?ooo`030?l0003oool0oooo04X0oooo1@3<o`0R0?ooo`400000000K0?ooo`03
0000003oool0oooo08@0oooo0P3o001B0?ooo`D0c?l07@3oool1000000006`3oool00`000000oooo
0?ooo`220?ooo`80o`00F@3oool40<co01T0oooo0@00000001/0oooo0P0000210?ooo`80o`00G`3o
ool30<co01D0oooo0P00000001/0oooo00<000000?ooo`3oool0OP3oool20?l006@0oooo0`3<o`0C
0?ooo`40000000080?ooo`800000103oool010000000oooo0?ooo`3oool5000000@0oooo00<00000
0?ooo`3oool0O03oool20?l006T0oooo1@3<o`0>0?ooo`40000000070?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1j0?ooo`80o`00L03o
ool50<co00T0oooo0@00000000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo07P0oooo0P3o001g0?ooo`@0c?l01@3oool1000000001`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0P00001f0?ooo`<0o`00P03o
ool3000000001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`1c0?ooo`80o`00Q@3oool1000000001`3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1a0?ooo`80
o`00Q`3oool100000000203oool2000000T0oooo0`0000050?ooo`030000003oool0oooo06h0oooo
0`3o00290?ooo`400000000K0?ooo`030000003oool0oooo06`0oooo0P3o002<0?ooo`400000000K
0?ooo`800000JP3oool30?l008d0oooo0P00000001/0oooo00<000000?ooo`3oool0I`3oool20?l0
0940oooo0@00000001/0oooo00<000000?ooo`3oool0I@3oool20?l009<0oooo0@00000001/0oooo
00<000000?ooo`3oool0HP3oool30?l009D0oooo0@00000001/0oooo0P00001Q0?ooo`80o`00U`3o
ool2000000006`3oool00`000000oooo0?ooo`1N0?ooo`80o`00VP3oool1000000006`3oool00`00
0000oooo0?ooo`1L0?ooo`80o`00W03oool1000000006`3oool00`000000oooo0?ooo`1J0?ooo`80
o`00WP3oool1000000006`3oool00`000000oooo0?ooo`1G0?ooo`<0o`00X03oool1000000006`3o
ool2000005H0oooo0P3o002R0?ooo`800000000K0?ooo`030000003oool0oooo05<0oooo0P3o002U
0?ooo`400000000K0?ooo`030000003oool0oooo0500oooo0`3o002W0?ooo`400000000K0?ooo`03
0000003oool0oooo04d0oooo0`3o002Z0?ooo`400000000K0?ooo`030000003oool0oooo04X0oooo
0`3o002]0?ooo`400000000K0?ooo`800000B@3oool20?l00:l0oooo0P00000001/0oooo00<00000
0?ooo`3oool0A@3oool30?l00;80oooo0@0000000080oooo0P0000040?ooo`040000003oool0oooo
0?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3oool0@`3oool20?l00;D0oooo0@000000
00050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`<0o`00]`3oool10000000000D0
oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0n0?ooo`80o`00^P3oool10000000000D0oooo0000003oool0oooo
0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000003`0oooo
0`3o002j0?ooo`<0000000001@3oool000000?ooo`3oool0000000L0oooo00H000000?ooo`3oool0
oooo0000003oool4000000D0oooo00<000000?ooo`3oool0>@3oool20?l00;l0oooo0@0000000005
0?ooo`000000oooo0?ooo`0000001`3oool01`000000oooo0?ooo`3oool000000?ooo`000000203o
ool00`000000oooo0?ooo`0f0?ooo`<0o`00`@3oool1000000000P3oool2000000T0oooo0`000002
0?ooo`D00000103oool00`000000oooo0?ooo`0d0?ooo`80o`00a03oool1000000006`3oool20000
0380oooo0`3o00350?ooo`800000000K0?ooo`030000003oool0oooo02l0oooo0P3o00390?ooo`40
0000000K0?ooo`030000003oool0oooo02`0oooo0`3o003;0?ooo`400000000K0?ooo`030000003o
ool0oooo02X0oooo0P3o003>0?ooo`400000000K0?ooo`030000003oool0oooo02L0oooo0`3o003@
0?ooo`400000000K0?ooo`8000009P3oool20?l00=80oooo0P00000001/0oooo00<000000?ooo`3o
ool08P3oool30?l00=D0oooo0@00000001/0oooo00<000000?ooo`3oool0803oool20?l00=P0oooo
0@00000001/0oooo00<000000?ooo`3oool07@3oool30?l00=X0oooo0@00000001/0oooo00<00000
0?ooo`3oool06`3oool20?l00=d0oooo0@00000001/0oooo0P00000I0?ooo`<0o`00gP3oool20000
00006`3oool00`000000oooo0?ooo`0F0?ooo`80o`00hP3oool1000000006`3oool00`000000oooo
0?ooo`0C0?ooo`<0o`00i03oool1000000006`3oool00`000000oooo0?ooo`0@0?ooo`<0o`00i`3o
ool1000000006`3oool00`000000oooo0?ooo`0=0?ooo`<0o`00jP3oool1000000006`3oool20000
00`0oooo0P3o003/0?ooo`800000000K0?ooo`030000003oool0oooo00T0oooo0P3o003_0?ooo`40
000000080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo
0?ooo`060?ooo`<0o`00l@3oool1000000001`3oool010000000oooo0?ooo`0000070?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`80o`00m03oool100000000
1`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0?l0003oool0oooo0?80oooo0`00000000L0oooo00@000000?ooo`3oool000002@3oool2000000D0
oooo00<000000?ooo`3oool0nP3oool1000000001`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool1000000001`3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`40000000080?ooo`8000002@3oool3000000D0oooooP0000000?l0oooo6P3oool00?l0oooo6P3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-1.37678, -0.0506915, \
0.0414781, 0.00210156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Missing data ", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
SeedRandom[9999];

n = 10;
Y0 = {1,2};
Y0 = Shape[1,{n}]/. (1->Y0)
T = 100;
dt = 10.^-1;

Theta = {.1,-.01,.02,.3,.01,-.02}*100;  (*scaling in f !!*)
      (*{lambda11_,lambda12_,lambda21_,lambda22_,alpha_,beta_}*)

k = 2;
p = 2;
q = 1;
X = Shape[1,{n}]/. 1->Shape[dt Range[0,T],{T+1,q}];
Nonlin = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 
        2}, {1, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["panel data",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["\<\
{Z,Y} = MapThread[NonLinStateSpace[h,{R,const},drift,diffusion,
\t                    #1,#2,T,dt,Theta,Gauss,EulerStep]&,{Y0,X}]//Transpose;//\
Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({1.0666666666666629`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Z\)\(//\)\(Dimensions\)\(\ \)\( (*\ 
        N\ x\ T1\ x\ k*) \)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
plot1[Z//flatten[#,{1,3}]&//Transpose//AddTimeAxis,dicke->0.007,\
farbmodell->Hue]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 21}\),
      SequenceForm[ "Dimension der Daten  ", {101, 21}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.0212878 0.0379809 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07366 -18 -4.5 ]
[-0.0125 .07366 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .26357 -18 -4.5 ]
[-0.0125 .26357 0 4.5 ]
[-0.0125 .35852 -12 -4.5 ]
[-0.0125 .35852 0 4.5 ]
[-0.0125 .45347 -24 -4.5 ]
[-0.0125 .45347 0 4.5 ]
[-0.0125 .54842 -12 -4.5 ]
[-0.0125 .54842 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .10412 -5 -6 ]
[.97619 .10412 5 6 ]
[.97619 .59268 -5 -6 ]
[.97619 .59268 5 6 ]
[.97619 .08556 -5 -6 ]
[.97619 .08556 5 6 ]
[.97619 .53057 -5 -6 ]
[.97619 .53057 5 6 ]
[.97619 .10907 -5 -6 ]
[.97619 .10907 5 6 ]
[.97619 .59327 -5 -6 ]
[.97619 .59327 5 6 ]
[.97619 .10674 -5 -6 ]
[.97619 .10674 5 6 ]
[.97619 .58131 -5 -6 ]
[.97619 .58131 5 6 ]
[.97619 .09345 -5 -6 ]
[.97619 .09345 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .09592 -5 -6 ]
[.97619 .09592 5 6 ]
[.97619 .54961 -5 -6 ]
[.97619 .54961 5 6 ]
[.97619 .10354 -5 -6 ]
[.97619 .10354 5 6 ]
[.97619 .54937 -5 -6 ]
[.97619 .54937 5 6 ]
[.97619 .09403 -5 -6 ]
[.97619 .09403 5 6 ]
[.97619 .57498 -5 -6 ]
[.97619 .57498 5 6 ]
[.97619 .09156 -5 -6 ]
[.97619 .09156 5 6 ]
[.97619 .58622 -5 -6 ]
[.97619 .58622 5 6 ]
[.97619 .09089 -5 -6 ]
[.97619 .09089 5 6 ]
[.97619 .55089 -5 -6 ]
[.97619 .55089 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07366 m
.00625 .07366 L
s
[(2.5)] -0.0125 .07366 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(5)] -0.0125 .16862 1 0 Mshowa
0 .26357 m
.00625 .26357 L
s
[(7.5)] -0.0125 .26357 1 0 Mshowa
0 .35852 m
.00625 .35852 L
s
[(10)] -0.0125 .35852 1 0 Mshowa
0 .45347 m
.00625 .45347 L
s
[(12.5)] -0.0125 .45347 1 0 Mshowa
0 .54842 m
.00625 .54842 L
s
[(15)] -0.0125 .54842 1 0 Mshowa
.125 Mabswid
0 .09265 m
.00375 .09265 L
s
0 .11165 m
.00375 .11165 L
s
0 .13064 m
.00375 .13064 L
s
0 .14963 m
.00375 .14963 L
s
0 .18761 m
.00375 .18761 L
s
0 .2066 m
.00375 .2066 L
s
0 .22559 m
.00375 .22559 L
s
0 .24458 m
.00375 .24458 L
s
0 .28256 m
.00375 .28256 L
s
0 .30155 m
.00375 .30155 L
s
0 .32054 m
.00375 .32054 L
s
0 .33953 m
.00375 .33953 L
s
0 .37751 m
.00375 .37751 L
s
0 .3965 m
.00375 .3965 L
s
0 .41549 m
.00375 .41549 L
s
0 .43448 m
.00375 .43448 L
s
0 .47246 m
.00375 .47246 L
s
0 .49145 m
.00375 .49145 L
s
0 .51044 m
.00375 .51044 L
s
0 .52943 m
.00375 .52943 L
s
0 .05467 m
.00375 .05467 L
s
0 .03568 m
.00375 .03568 L
s
0 .01669 m
.00375 .01669 L
s
0 .56742 m
.00375 .56742 L
s
0 .58641 m
.00375 .58641 L
s
0 .6054 m
.00375 .6054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07366 m
1 .07366 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .26357 m
1 .26357 L
s
.99375 .35852 m
1 .35852 L
s
.99375 .45347 m
1 .45347 L
s
.99375 .54842 m
1 .54842 L
s
.125 Mabswid
.99625 .09265 m
1 .09265 L
s
.99625 .11165 m
1 .11165 L
s
.99625 .13064 m
1 .13064 L
s
.99625 .14963 m
1 .14963 L
s
.99625 .18761 m
1 .18761 L
s
.99625 .2066 m
1 .2066 L
s
.99625 .22559 m
1 .22559 L
s
.99625 .24458 m
1 .24458 L
s
.99625 .28256 m
1 .28256 L
s
.99625 .30155 m
1 .30155 L
s
.99625 .32054 m
1 .32054 L
s
.99625 .33953 m
1 .33953 L
s
.99625 .37751 m
1 .37751 L
s
.99625 .3965 m
1 .3965 L
s
.99625 .41549 m
1 .41549 L
s
.99625 .43448 m
1 .43448 L
s
.99625 .47246 m
1 .47246 L
s
.99625 .49145 m
1 .49145 L
s
.99625 .51044 m
1 .51044 L
s
.99625 .52943 m
1 .52943 L
s
.99625 .05467 m
1 .05467 L
s
.99625 .03568 m
1 .03568 L
s
.99625 .01669 m
1 .01669 L
s
.99625 .56742 m
1 .56742 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .6054 m
1 .6054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
gsave
.97619 .10412 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.007 w
.02381 .01614 m
.03333 .0204 L
.04286 .01773 L
.05238 .01774 L
.0619 .01751 L
.07143 .01811 L
.08095 .01932 L
.09048 .018 L
.1 .01982 L
.10952 .02109 L
.11905 .01965 L
.12857 .02005 L
.1381 .02163 L
.14762 .02043 L
.15714 .02002 L
.16667 .02359 L
.17619 .02131 L
.18571 .0232 L
.19524 .02476 L
.20476 .02291 L
.21429 .02257 L
.22381 .02357 L
.23333 .02231 L
.24286 .02532 L
.25238 .02579 L
.2619 .02439 L
.27143 .0269 L
.28095 .02575 L
.29048 .03143 L
.3 .02822 L
.30952 .0287 L
.31905 .02906 L
.32857 .02965 L
.3381 .03121 L
.34762 .03147 L
.35714 .03121 L
.36667 .03119 L
.37619 .0332 L
.38571 .03373 L
.39524 .03428 L
.40476 .03369 L
.41429 .03617 L
.42381 .03613 L
.43333 .0365 L
.44286 .037 L
.45238 .03565 L
.4619 .03751 L
.47143 .04156 L
.48095 .03863 L
.49048 .03967 L
Mistroke
.5 .04328 L
.50952 .04263 L
.51905 .03992 L
.52857 .04351 L
.5381 .04578 L
.54762 .04699 L
.55714 .04643 L
.56667 .04874 L
.57619 .04732 L
.58571 .04815 L
.59524 .05157 L
.60476 .05033 L
.61429 .05093 L
.62381 .05227 L
.63333 .05521 L
.64286 .0557 L
.65238 .05709 L
.6619 .05675 L
.67143 .06004 L
.68095 .06078 L
.69048 .06285 L
.7 .06486 L
.70952 .06816 L
.71905 .06528 L
.72857 .06768 L
.7381 .06971 L
.74762 .07008 L
.75714 .0715 L
.76667 .0742 L
.77619 .07141 L
.78571 .07402 L
.79524 .0744 L
.80476 .07321 L
.81429 .07429 L
.82381 .07805 L
.83333 .07512 L
.84286 .07969 L
.85238 .0806 L
.8619 .08297 L
.87143 .08579 L
.88095 .08725 L
.89048 .09146 L
.9 .09345 L
.90952 .09406 L
.91905 .09683 L
.92857 .09791 L
.9381 .09924 L
.94762 .09873 L
.95714 .10221 L
.96667 .10544 L
Mistroke
.97619 .10412 L
Mfstroke
1 0 .6 r
gsave
.97619 .59268 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05749 m
.03333 .05678 L
.04286 .05846 L
.05238 .06281 L
.0619 .06444 L
.07143 .0687 L
.08095 .07007 L
.09048 .07012 L
.1 .076 L
.10952 .0766 L
.11905 .08022 L
.12857 .08059 L
.1381 .08482 L
.14762 .0878 L
.15714 .09203 L
.16667 .09704 L
.17619 .09912 L
.18571 .10042 L
.19524 .1041 L
.20476 .10709 L
.21429 .11077 L
.22381 .1167 L
.23333 .12069 L
.24286 .12449 L
.25238 .1283 L
.2619 .13089 L
.27143 .13167 L
.28095 .139 L
.29048 .14477 L
.3 .14559 L
.30952 .14916 L
.31905 .15297 L
.32857 .15614 L
.3381 .16042 L
.34762 .16533 L
.35714 .17137 L
.36667 .17379 L
.37619 .17833 L
.38571 .18248 L
.39524 .18775 L
.40476 .19276 L
.41429 .19668 L
.42381 .20452 L
.43333 .20863 L
.44286 .21564 L
.45238 .2224 L
.4619 .22719 L
.47143 .23343 L
.48095 .24104 L
.49048 .24636 L
Mistroke
.5 .24921 L
.50952 .25514 L
.51905 .26156 L
.52857 .26934 L
.5381 .27708 L
.54762 .28317 L
.55714 .28901 L
.56667 .29687 L
.57619 .30271 L
.58571 .30966 L
.59524 .31336 L
.60476 .32197 L
.61429 .3281 L
.62381 .3324 L
.63333 .33743 L
.64286 .34612 L
.65238 .34984 L
.6619 .35778 L
.67143 .36782 L
.68095 .37204 L
.69048 .37663 L
.7 .38416 L
.70952 .39095 L
.71905 .39683 L
.72857 .40483 L
.7381 .41008 L
.74762 .41835 L
.75714 .4253 L
.76667 .42918 L
.77619 .43433 L
.78571 .44466 L
.79524 .45275 L
.80476 .45963 L
.81429 .47083 L
.82381 .47812 L
.83333 .48443 L
.84286 .48745 L
.85238 .49321 L
.8619 .51021 L
.87143 .51188 L
.88095 .51634 L
.89048 .52382 L
.9 .52963 L
.90952 .53826 L
.91905 .54417 L
.92857 .55164 L
.9381 .56476 L
.94762 .57299 L
.95714 .57811 L
.96667 .58425 L
Mistroke
.97619 .59268 L
Mfstroke
.8 0 1 r
gsave
.97619 .08556 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01674 m
.03333 .01684 L
.04286 .01748 L
.05238 .01792 L
.0619 .01765 L
.07143 .02027 L
.08095 .02013 L
.09048 .01875 L
.1 .0185 L
.10952 .02101 L
.11905 .01916 L
.12857 .0213 L
.1381 .02257 L
.14762 .02071 L
.15714 .02114 L
.16667 .02451 L
.17619 .02393 L
.18571 .02064 L
.19524 .02319 L
.20476 .02328 L
.21429 .02381 L
.22381 .02383 L
.23333 .025 L
.24286 .02652 L
.25238 .02531 L
.2619 .0266 L
.27143 .0271 L
.28095 .02786 L
.29048 .03102 L
.3 .02865 L
.30952 .02818 L
.31905 .03132 L
.32857 .02958 L
.3381 .02905 L
.34762 .03007 L
.35714 .0298 L
.36667 .03158 L
.37619 .03036 L
.38571 .03046 L
.39524 .03265 L
.40476 .03219 L
.41429 .03182 L
.42381 .03359 L
.43333 .0349 L
.44286 .03329 L
.45238 .03575 L
.4619 .03675 L
.47143 .03358 L
.48095 .0341 L
.49048 .03527 L
Mistroke
.5 .03602 L
.50952 .0348 L
.51905 .03665 L
.52857 .0367 L
.5381 .03928 L
.54762 .04248 L
.55714 .03988 L
.56667 .0432 L
.57619 .04641 L
.58571 .04865 L
.59524 .04636 L
.60476 .04726 L
.61429 .04812 L
.62381 .04815 L
.63333 .05095 L
.64286 .05086 L
.65238 .04975 L
.6619 .05251 L
.67143 .05233 L
.68095 .05319 L
.69048 .055 L
.7 .05507 L
.70952 .05411 L
.71905 .05578 L
.72857 .05825 L
.7381 .05985 L
.74762 .05902 L
.75714 .0598 L
.76667 .06084 L
.77619 .06118 L
.78571 .06463 L
.79524 .066 L
.80476 .06798 L
.81429 .07054 L
.82381 .07004 L
.83333 .07046 L
.84286 .07214 L
.85238 .07497 L
.8619 .07536 L
.87143 .07497 L
.88095 .07522 L
.89048 .07481 L
.9 .07793 L
.90952 .07719 L
.91905 .08115 L
.92857 .08141 L
.9381 .08523 L
.94762 .08542 L
.95714 .08637 L
.96667 .08653 L
Mistroke
.97619 .08556 L
Mfstroke
.2 0 1 r
gsave
.97619 .53057 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05434 m
.03333 .05728 L
.04286 .05986 L
.05238 .06169 L
.0619 .06308 L
.07143 .06697 L
.08095 .0717 L
.09048 .07233 L
.1 .0774 L
.10952 .07897 L
.11905 .0811 L
.12857 .08335 L
.1381 .08697 L
.14762 .08982 L
.15714 .09229 L
.16667 .09414 L
.17619 .09652 L
.18571 .10108 L
.19524 .10438 L
.20476 .10992 L
.21429 .11471 L
.22381 .11645 L
.23333 .12017 L
.24286 .12493 L
.25238 .12824 L
.2619 .13027 L
.27143 .13593 L
.28095 .14229 L
.29048 .14447 L
.3 .14544 L
.30952 .15194 L
.31905 .15698 L
.32857 .16152 L
.3381 .16437 L
.34762 .16917 L
.35714 .17654 L
.36667 .17649 L
.37619 .18132 L
.38571 .18882 L
.39524 .19494 L
.40476 .20102 L
.41429 .20404 L
.42381 .20707 L
.43333 .21358 L
.44286 .22199 L
.45238 .22619 L
.4619 .2295 L
.47143 .23483 L
.48095 .23982 L
.49048 .24498 L
Mistroke
.5 .24837 L
.50952 .25379 L
.51905 .26184 L
.52857 .27014 L
.5381 .27426 L
.54762 .27607 L
.55714 .2845 L
.56667 .2902 L
.57619 .29685 L
.58571 .30524 L
.59524 .30598 L
.60476 .31222 L
.61429 .32064 L
.62381 .32403 L
.63333 .32716 L
.64286 .32886 L
.65238 .33369 L
.6619 .34322 L
.67143 .34912 L
.68095 .35309 L
.69048 .35797 L
.7 .36331 L
.70952 .37185 L
.71905 .37697 L
.72857 .38764 L
.7381 .39545 L
.74762 .4007 L
.75714 .40842 L
.76667 .41179 L
.77619 .41536 L
.78571 .42128 L
.79524 .42642 L
.80476 .43642 L
.81429 .4371 L
.82381 .44433 L
.83333 .44726 L
.84286 .45666 L
.85238 .45851 L
.8619 .4666 L
.87143 .47392 L
.88095 .47973 L
.89048 .48585 L
.9 .49085 L
.90952 .49625 L
.91905 .49782 L
.92857 .50502 L
.9381 .50827 L
.94762 .51339 L
.95714 .51747 L
.96667 .52529 L
Mistroke
.97619 .53057 L
Mfstroke
0 .4 1 r
gsave
.97619 .10907 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01499 L
.04286 .01489 L
.05238 .01597 L
.0619 .01843 L
.07143 .01847 L
.08095 .01892 L
.09048 .02062 L
.1 .01993 L
.10952 .01917 L
.11905 .01996 L
.12857 .02188 L
.1381 .02212 L
.14762 .018 L
.15714 .02189 L
.16667 .02246 L
.17619 .01994 L
.18571 .02219 L
.19524 .02287 L
.20476 .02374 L
.21429 .02321 L
.22381 .0263 L
.23333 .02354 L
.24286 .02626 L
.25238 .02558 L
.2619 .02666 L
.27143 .02701 L
.28095 .02438 L
.29048 .02582 L
.3 .02592 L
.30952 .02678 L
.31905 .02662 L
.32857 .02756 L
.3381 .0293 L
.34762 .02809 L
.35714 .02989 L
.36667 .0309 L
.37619 .03035 L
.38571 .02982 L
.39524 .03024 L
.40476 .03408 L
.41429 .03567 L
.42381 .03215 L
.43333 .03546 L
.44286 .03561 L
.45238 .03628 L
.4619 .03882 L
.47143 .0378 L
.48095 .03523 L
.49048 .03903 L
Mistroke
.5 .03848 L
.50952 .04034 L
.51905 .04045 L
.52857 .04053 L
.5381 .04325 L
.54762 .04318 L
.55714 .04519 L
.56667 .04422 L
.57619 .04654 L
.58571 .04445 L
.59524 .04638 L
.60476 .04663 L
.61429 .04654 L
.62381 .04802 L
.63333 .0511 L
.64286 .05321 L
.65238 .05431 L
.6619 .0551 L
.67143 .05794 L
.68095 .06043 L
.69048 .0621 L
.7 .0618 L
.70952 .06161 L
.71905 .06576 L
.72857 .06644 L
.7381 .06619 L
.74762 .07119 L
.75714 .06986 L
.76667 .07029 L
.77619 .0731 L
.78571 .07285 L
.79524 .0782 L
.80476 .07684 L
.81429 .08072 L
.82381 .07897 L
.83333 .07768 L
.84286 .08176 L
.85238 .08161 L
.8619 .08673 L
.87143 .08549 L
.88095 .08654 L
.89048 .0897 L
.9 .09011 L
.90952 .09177 L
.91905 .09604 L
.92857 .09422 L
.9381 .09923 L
.94762 .10196 L
.95714 .10429 L
.96667 .1063 L
Mistroke
.97619 .10907 L
Mfstroke
0 1 1 r
gsave
.97619 .59327 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05569 m
.03333 .05473 L
.04286 .05936 L
.05238 .06282 L
.0619 .06513 L
.07143 .06827 L
.08095 .06945 L
.09048 .0744 L
.1 .07433 L
.10952 .08047 L
.11905 .08156 L
.12857 .08503 L
.1381 .08656 L
.14762 .08885 L
.15714 .09294 L
.16667 .09649 L
.17619 .09759 L
.18571 .10298 L
.19524 .10568 L
.20476 .11066 L
.21429 .11311 L
.22381 .11651 L
.23333 .12274 L
.24286 .12716 L
.25238 .13054 L
.2619 .13299 L
.27143 .13715 L
.28095 .14046 L
.29048 .14609 L
.3 .14909 L
.30952 .15509 L
.31905 .15819 L
.32857 .16421 L
.3381 .16949 L
.34762 .17338 L
.35714 .17646 L
.36667 .18349 L
.37619 .18584 L
.38571 .19314 L
.39524 .19712 L
.40476 .20323 L
.41429 .21066 L
.42381 .21367 L
.43333 .22048 L
.44286 .22364 L
.45238 .23449 L
.4619 .23643 L
.47143 .23886 L
.48095 .24417 L
.49048 .2528 L
Mistroke
.5 .25907 L
.50952 .26316 L
.51905 .26967 L
.52857 .27674 L
.5381 .28268 L
.54762 .28987 L
.55714 .29379 L
.56667 .30125 L
.57619 .30809 L
.58571 .31511 L
.59524 .31987 L
.60476 .33206 L
.61429 .33732 L
.62381 .3397 L
.63333 .34427 L
.64286 .35519 L
.65238 .35774 L
.6619 .36819 L
.67143 .37874 L
.68095 .38161 L
.69048 .39313 L
.7 .4011 L
.70952 .41179 L
.71905 .41508 L
.72857 .41831 L
.7381 .42887 L
.74762 .43921 L
.75714 .45029 L
.76667 .45693 L
.77619 .46578 L
.78571 .4664 L
.79524 .47311 L
.80476 .47997 L
.81429 .48722 L
.82381 .49565 L
.83333 .50045 L
.84286 .50566 L
.85238 .51227 L
.8619 .52 L
.87143 .52634 L
.88095 .53483 L
.89048 .54107 L
.9 .54812 L
.90952 .55285 L
.91905 .56025 L
.92857 .56396 L
.9381 .56818 L
.94762 .57342 L
.95714 .58074 L
.96667 .58755 L
Mistroke
.97619 .59327 L
Mfstroke
0 1 .4 r
gsave
.97619 .10674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01721 m
.03333 .01757 L
.04286 .01827 L
.05238 .01756 L
.0619 .01939 L
.07143 .01873 L
.08095 .0183 L
.09048 .0202 L
.1 .01846 L
.10952 .02114 L
.11905 .01753 L
.12857 .01928 L
.1381 .02247 L
.14762 .0221 L
.15714 .02197 L
.16667 .02299 L
.17619 .02272 L
.18571 .02262 L
.19524 .02395 L
.20476 .02262 L
.21429 .02285 L
.22381 .02337 L
.23333 .02416 L
.24286 .02163 L
.25238 .02336 L
.2619 .02517 L
.27143 .02765 L
.28095 .02739 L
.29048 .02746 L
.3 .03024 L
.30952 .02785 L
.31905 .02728 L
.32857 .02879 L
.3381 .0277 L
.34762 .03223 L
.35714 .02955 L
.36667 .03055 L
.37619 .02973 L
.38571 .03246 L
.39524 .02923 L
.40476 .03121 L
.41429 .03256 L
.42381 .03402 L
.43333 .03343 L
.44286 .03236 L
.45238 .03537 L
.4619 .03601 L
.47143 .03812 L
.48095 .03603 L
.49048 .03906 L
Mistroke
.5 .04053 L
.50952 .03725 L
.51905 .04128 L
.52857 .04198 L
.5381 .04487 L
.54762 .04407 L
.55714 .04654 L
.56667 .04699 L
.57619 .04544 L
.58571 .048 L
.59524 .04768 L
.60476 .04708 L
.61429 .0498 L
.62381 .05091 L
.63333 .0535 L
.64286 .05237 L
.65238 .05342 L
.6619 .05542 L
.67143 .05674 L
.68095 .05733 L
.69048 .06059 L
.7 .06077 L
.70952 .06108 L
.71905 .06363 L
.72857 .06437 L
.7381 .06408 L
.74762 .06357 L
.75714 .06882 L
.76667 .07117 L
.77619 .06905 L
.78571 .06754 L
.79524 .06997 L
.80476 .07131 L
.81429 .07059 L
.82381 .07287 L
.83333 .0769 L
.84286 .07486 L
.85238 .07824 L
.8619 .07921 L
.87143 .08034 L
.88095 .08282 L
.89048 .08651 L
.9 .08358 L
.90952 .08644 L
.91905 .08567 L
.92857 .09184 L
.9381 .0943 L
.94762 .09655 L
.95714 .10061 L
.96667 .10401 L
Mistroke
.97619 .10674 L
Mfstroke
.2 1 0 r
gsave
.97619 .58131 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05596 m
.03333 .05551 L
.04286 .05973 L
.05238 .06429 L
.0619 .06552 L
.07143 .06581 L
.08095 .06887 L
.09048 .07212 L
.1 .07845 L
.10952 .07923 L
.11905 .08014 L
.12857 .08522 L
.1381 .08529 L
.14762 .08884 L
.15714 .0924 L
.16667 .09574 L
.17619 .09958 L
.18571 .10205 L
.19524 .1103 L
.20476 .11143 L
.21429 .1124 L
.22381 .11633 L
.23333 .12209 L
.24286 .1269 L
.25238 .13022 L
.2619 .13471 L
.27143 .1376 L
.28095 .14274 L
.29048 .14515 L
.3 .14977 L
.30952 .15226 L
.31905 .15749 L
.32857 .1627 L
.3381 .16491 L
.34762 .17178 L
.35714 .17463 L
.36667 .17886 L
.37619 .1828 L
.38571 .18729 L
.39524 .19153 L
.40476 .19772 L
.41429 .20557 L
.42381 .20819 L
.43333 .21677 L
.44286 .22087 L
.45238 .22667 L
.4619 .2312 L
.47143 .23616 L
.48095 .24311 L
.49048 .24607 L
Mistroke
.5 .25411 L
.50952 .2587 L
.51905 .26306 L
.52857 .27461 L
.5381 .27837 L
.54762 .28737 L
.55714 .2911 L
.56667 .2964 L
.57619 .29881 L
.58571 .30976 L
.59524 .31368 L
.60476 .31983 L
.61429 .32402 L
.62381 .32848 L
.63333 .33183 L
.64286 .33977 L
.65238 .34478 L
.6619 .35245 L
.67143 .36014 L
.68095 .36569 L
.69048 .37576 L
.7 .37815 L
.70952 .38528 L
.71905 .39248 L
.72857 .40339 L
.7381 .40685 L
.74762 .41358 L
.75714 .42183 L
.76667 .4283 L
.77619 .43904 L
.78571 .44142 L
.79524 .44714 L
.80476 .45195 L
.81429 .46176 L
.82381 .46921 L
.83333 .48351 L
.84286 .49119 L
.85238 .49947 L
.8619 .50577 L
.87143 .50798 L
.88095 .51348 L
.89048 .51753 L
.9 .53225 L
.90952 .53622 L
.91905 .54286 L
.92857 .55563 L
.9381 .56304 L
.94762 .56672 L
.95714 .57369 L
.96667 .57937 L
Mistroke
.97619 .58131 L
Mfstroke
.8 1 0 r
gsave
.97619 .09345 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01699 m
.03333 .01813 L
.04286 .01625 L
.05238 .01831 L
.0619 .01903 L
.07143 .01775 L
.08095 .02 L
.09048 .01937 L
.1 .01856 L
.10952 .01871 L
.11905 .02177 L
.12857 .02324 L
.1381 .02032 L
.14762 .02284 L
.15714 .02079 L
.16667 .02276 L
.17619 .0211 L
.18571 .02237 L
.19524 .02481 L
.20476 .02453 L
.21429 .02254 L
.22381 .02494 L
.23333 .02651 L
.24286 .02505 L
.25238 .02576 L
.2619 .02555 L
.27143 .02697 L
.28095 .02934 L
.29048 .03102 L
.3 .03173 L
.30952 .02927 L
.31905 .03038 L
.32857 .0282 L
.3381 .03041 L
.34762 .0306 L
.35714 .03107 L
.36667 .03126 L
.37619 .03409 L
.38571 .03085 L
.39524 .03197 L
.40476 .03473 L
.41429 .03235 L
.42381 .03355 L
.43333 .03575 L
.44286 .032 L
.45238 .03731 L
.4619 .03795 L
.47143 .03726 L
.48095 .03599 L
.49048 .03962 L
Mistroke
.5 .04211 L
.50952 .03952 L
.51905 .03942 L
.52857 .03899 L
.5381 .03991 L
.54762 .03922 L
.55714 .04317 L
.56667 .04341 L
.57619 .04321 L
.58571 .048 L
.59524 .04437 L
.60476 .04551 L
.61429 .04481 L
.62381 .0442 L
.63333 .04463 L
.64286 .04635 L
.65238 .04902 L
.6619 .05063 L
.67143 .04959 L
.68095 .05297 L
.69048 .05145 L
.7 .05068 L
.70952 .0536 L
.71905 .05707 L
.72857 .05671 L
.7381 .05672 L
.74762 .05953 L
.75714 .06227 L
.76667 .06338 L
.77619 .06495 L
.78571 .06813 L
.79524 .06882 L
.80476 .06872 L
.81429 .07078 L
.82381 .07234 L
.83333 .07178 L
.84286 .07015 L
.85238 .07435 L
.8619 .07494 L
.87143 .07632 L
.88095 .08044 L
.89048 .08056 L
.9 .08286 L
.90952 .08438 L
.91905 .08676 L
.92857 .08733 L
.9381 .08909 L
.94762 .0878 L
.95714 .0875 L
.96667 .09286 L
Mistroke
.97619 .09345 L
Mfstroke
1 .6 0 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0527 m
.03333 .05829 L
.04286 .05832 L
.05238 .06426 L
.0619 .0633 L
.07143 .06724 L
.08095 .06953 L
.09048 .07268 L
.1 .0765 L
.10952 .07769 L
.11905 .07909 L
.12857 .08373 L
.1381 .08524 L
.14762 .08891 L
.15714 .09416 L
.16667 .09218 L
.17619 .0971 L
.18571 .10301 L
.19524 .10575 L
.20476 .11096 L
.21429 .11334 L
.22381 .1181 L
.23333 .12001 L
.24286 .12585 L
.25238 .13047 L
.2619 .13061 L
.27143 .13825 L
.28095 .14088 L
.29048 .14408 L
.3 .15198 L
.30952 .15548 L
.31905 .16189 L
.32857 .16779 L
.3381 .17248 L
.34762 .17576 L
.35714 .18141 L
.36667 .18671 L
.37619 .19013 L
.38571 .19616 L
.39524 .20093 L
.40476 .20579 L
.41429 .21146 L
.42381 .21865 L
.43333 .22343 L
.44286 .22654 L
.45238 .23404 L
.4619 .24168 L
.47143 .24515 L
.48095 .25222 L
.49048 .25841 L
Mistroke
.5 .26362 L
.50952 .2696 L
.51905 .27456 L
.52857 .28334 L
.5381 .28712 L
.54762 .2889 L
.55714 .29609 L
.56667 .30473 L
.57619 .30947 L
.58571 .31573 L
.59524 .32121 L
.60476 .32737 L
.61429 .33475 L
.62381 .34073 L
.63333 .34993 L
.64286 .35628 L
.65238 .36252 L
.6619 .36694 L
.67143 .3782 L
.68095 .38122 L
.69048 .3833 L
.7 .39117 L
.70952 .39535 L
.71905 .40285 L
.72857 .41319 L
.7381 .41885 L
.74762 .42575 L
.75714 .43073 L
.76667 .43763 L
.77619 .44658 L
.78571 .45205 L
.79524 .46036 L
.80476 .46784 L
.81429 .47578 L
.82381 .48325 L
.83333 .489 L
.84286 .49627 L
.85238 .5034 L
.8619 .51304 L
.87143 .52013 L
.88095 .52815 L
.89048 .53614 L
.9 .54775 L
.90952 .5551 L
.91905 .56419 L
.92857 .57004 L
.9381 .57427 L
.94762 .58277 L
.95714 .58923 L
.96667 .59662 L
Mistroke
.97619 .60332 L
Mfstroke
1 0 0 r
gsave
.97619 .09592 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01946 m
.03333 .01628 L
.04286 .01601 L
.05238 .0186 L
.0619 .01769 L
.07143 .01881 L
.08095 .01923 L
.09048 .02094 L
.1 .01911 L
.10952 .01865 L
.11905 .02141 L
.12857 .02076 L
.1381 .01832 L
.14762 .02248 L
.15714 .02127 L
.16667 .02113 L
.17619 .02098 L
.18571 .02076 L
.19524 .02284 L
.20476 .02509 L
.21429 .0234 L
.22381 .02415 L
.23333 .02261 L
.24286 .0254 L
.25238 .02497 L
.2619 .02579 L
.27143 .02548 L
.28095 .02691 L
.29048 .02581 L
.3 .02727 L
.30952 .02828 L
.31905 .02786 L
.32857 .02768 L
.3381 .02805 L
.34762 .03048 L
.35714 .03147 L
.36667 .03271 L
.37619 .03216 L
.38571 .03242 L
.39524 .03291 L
.40476 .03388 L
.41429 .03093 L
.42381 .03337 L
.43333 .03588 L
.44286 .03557 L
.45238 .0346 L
.4619 .03785 L
.47143 .03899 L
.48095 .03877 L
.49048 .03755 L
Mistroke
.5 .03784 L
.50952 .041 L
.51905 .04122 L
.52857 .03904 L
.5381 .04273 L
.54762 .04251 L
.55714 .04103 L
.56667 .04374 L
.57619 .04693 L
.58571 .0474 L
.59524 .04616 L
.60476 .04704 L
.61429 .04918 L
.62381 .05086 L
.63333 .0534 L
.64286 .05368 L
.65238 .05176 L
.6619 .05325 L
.67143 .0575 L
.68095 .05457 L
.69048 .05649 L
.7 .05764 L
.70952 .05681 L
.71905 .05852 L
.72857 .05536 L
.7381 .06028 L
.74762 .06358 L
.75714 .06108 L
.76667 .06502 L
.77619 .0664 L
.78571 .06704 L
.79524 .06743 L
.80476 .06933 L
.81429 .0694 L
.82381 .0697 L
.83333 .07121 L
.84286 .07193 L
.85238 .07385 L
.8619 .07684 L
.87143 .07794 L
.88095 .07721 L
.89048 .08046 L
.9 .08135 L
.90952 .08527 L
.91905 .08465 L
.92857 .08546 L
.9381 .08674 L
.94762 .0895 L
.95714 .09222 L
.96667 .08939 L
Mistroke
.97619 .09592 L
Mfstroke
1 0 .6 r
gsave
.97619 .54961 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05301 m
.03333 .05558 L
.04286 .0584 L
.05238 .0625 L
.0619 .06465 L
.07143 .06716 L
.08095 .07043 L
.09048 .07389 L
.1 .07724 L
.10952 .07734 L
.11905 .07925 L
.12857 .08411 L
.1381 .08679 L
.14762 .08865 L
.15714 .09424 L
.16667 .09692 L
.17619 .09964 L
.18571 .10097 L
.19524 .10596 L
.20476 .1089 L
.21429 .11241 L
.22381 .11605 L
.23333 .12026 L
.24286 .12539 L
.25238 .12851 L
.2619 .13129 L
.27143 .13756 L
.28095 .13989 L
.29048 .14312 L
.3 .14894 L
.30952 .15181 L
.31905 .15683 L
.32857 .16031 L
.3381 .16614 L
.34762 .16948 L
.35714 .17417 L
.36667 .17768 L
.37619 .18404 L
.38571 .1861 L
.39524 .18905 L
.40476 .19741 L
.41429 .20199 L
.42381 .20452 L
.43333 .20876 L
.44286 .21606 L
.45238 .21976 L
.4619 .2281 L
.47143 .22964 L
.48095 .23509 L
.49048 .23764 L
Mistroke
.5 .2436 L
.50952 .2464 L
.51905 .25457 L
.52857 .25777 L
.5381 .26531 L
.54762 .2711 L
.55714 .27999 L
.56667 .28461 L
.57619 .29073 L
.58571 .29297 L
.59524 .3003 L
.60476 .30632 L
.61429 .31391 L
.62381 .31784 L
.63333 .32175 L
.64286 .32939 L
.65238 .33167 L
.6619 .33702 L
.67143 .35037 L
.68095 .35602 L
.69048 .36294 L
.7 .36997 L
.70952 .37647 L
.71905 .38235 L
.72857 .38923 L
.7381 .39646 L
.74762 .4026 L
.75714 .40747 L
.76667 .41062 L
.77619 .41448 L
.78571 .42264 L
.79524 .43249 L
.80476 .43757 L
.81429 .44324 L
.82381 .45069 L
.83333 .45556 L
.84286 .46275 L
.85238 .46756 L
.8619 .47101 L
.87143 .47673 L
.88095 .48561 L
.89048 .49145 L
.9 .49828 L
.90952 .50447 L
.91905 .51199 L
.92857 .51804 L
.9381 .52554 L
.94762 .53169 L
.95714 .53967 L
.96667 .5438 L
Mistroke
.97619 .54961 L
Mfstroke
.8 0 1 r
gsave
.97619 .10354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01503 m
.03333 .01679 L
.04286 .01912 L
.05238 .01939 L
.0619 .01997 L
.07143 .01774 L
.08095 .01757 L
.09048 .01981 L
.1 .01906 L
.10952 .01891 L
.11905 .02037 L
.12857 .02005 L
.1381 .02005 L
.14762 .02336 L
.15714 .02148 L
.16667 .02126 L
.17619 .02053 L
.18571 .0219 L
.19524 .02245 L
.20476 .02119 L
.21429 .0241 L
.22381 .02269 L
.23333 .02314 L
.24286 .02376 L
.25238 .02469 L
.2619 .02449 L
.27143 .02452 L
.28095 .02556 L
.29048 .02832 L
.3 .02862 L
.30952 .02726 L
.31905 .02757 L
.32857 .02948 L
.3381 .03174 L
.34762 .03013 L
.35714 .0305 L
.36667 .03249 L
.37619 .03289 L
.38571 .03273 L
.39524 .03426 L
.40476 .03271 L
.41429 .03495 L
.42381 .03777 L
.43333 .03879 L
.44286 .03584 L
.45238 .03495 L
.4619 .03478 L
.47143 .03901 L
.48095 .03871 L
.49048 .03939 L
Mistroke
.5 .04177 L
.50952 .04196 L
.51905 .0426 L
.52857 .04166 L
.5381 .04352 L
.54762 .04525 L
.55714 .04654 L
.56667 .04619 L
.57619 .0457 L
.58571 .04855 L
.59524 .04786 L
.60476 .04942 L
.61429 .05031 L
.62381 .05027 L
.63333 .05048 L
.64286 .05339 L
.65238 .05453 L
.6619 .05466 L
.67143 .0563 L
.68095 .05642 L
.69048 .05894 L
.7 .0588 L
.70952 .05887 L
.71905 .05742 L
.72857 .05646 L
.7381 .05892 L
.74762 .05926 L
.75714 .06063 L
.76667 .05896 L
.77619 .06372 L
.78571 .06453 L
.79524 .06764 L
.80476 .06727 L
.81429 .07024 L
.82381 .06998 L
.83333 .06942 L
.84286 .07354 L
.85238 .07527 L
.8619 .07705 L
.87143 .07986 L
.88095 .07929 L
.89048 .08652 L
.9 .09109 L
.90952 .09209 L
.91905 .09246 L
.92857 .09397 L
.9381 .0937 L
.94762 .09664 L
.95714 .10032 L
.96667 .10147 L
Mistroke
.97619 .10354 L
Mfstroke
.2 0 1 r
gsave
.97619 .54937 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05517 m
.03333 .05633 L
.04286 .06079 L
.05238 .06012 L
.0619 .06532 L
.07143 .0678 L
.08095 .07093 L
.09048 .07211 L
.1 .07562 L
.10952 .077 L
.11905 .08039 L
.12857 .08337 L
.1381 .08719 L
.14762 .08882 L
.15714 .09505 L
.16667 .09625 L
.17619 .09788 L
.18571 .10242 L
.19524 .10378 L
.20476 .11008 L
.21429 .10911 L
.22381 .11909 L
.23333 .1179 L
.24286 .12287 L
.25238 .12613 L
.2619 .13052 L
.27143 .13464 L
.28095 .13796 L
.29048 .14212 L
.3 .14598 L
.30952 .15167 L
.31905 .15349 L
.32857 .15695 L
.3381 .16219 L
.34762 .16371 L
.35714 .16647 L
.36667 .16989 L
.37619 .17341 L
.38571 .17927 L
.39524 .18301 L
.40476 .18789 L
.41429 .19017 L
.42381 .19473 L
.43333 .19804 L
.44286 .20377 L
.45238 .2093 L
.4619 .21573 L
.47143 .21886 L
.48095 .22309 L
.49048 .23027 L
Mistroke
.5 .23614 L
.50952 .24186 L
.51905 .24481 L
.52857 .25418 L
.5381 .26107 L
.54762 .26713 L
.55714 .27265 L
.56667 .28001 L
.57619 .28911 L
.58571 .2946 L
.59524 .29779 L
.60476 .30472 L
.61429 .31226 L
.62381 .31703 L
.63333 .32368 L
.64286 .32746 L
.65238 .3365 L
.6619 .34154 L
.67143 .34369 L
.68095 .35057 L
.69048 .35713 L
.7 .36041 L
.70952 .36564 L
.71905 .37184 L
.72857 .37823 L
.7381 .38207 L
.74762 .38624 L
.75714 .39258 L
.76667 .40086 L
.77619 .40637 L
.78571 .4181 L
.79524 .42366 L
.80476 .43165 L
.81429 .44214 L
.82381 .44626 L
.83333 .45493 L
.84286 .46029 L
.85238 .46247 L
.8619 .47462 L
.87143 .48188 L
.88095 .48597 L
.89048 .49334 L
.9 .49929 L
.90952 .50666 L
.91905 .50904 L
.92857 .51909 L
.9381 .52577 L
.94762 .53242 L
.95714 .53953 L
.96667 .54301 L
Mistroke
.97619 .54937 L
Mfstroke
0 .4 1 r
gsave
.97619 .09403 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01627 m
.03333 .01809 L
.04286 .01933 L
.05238 .0175 L
.0619 .01962 L
.07143 .01927 L
.08095 .01719 L
.09048 .01823 L
.1 .01956 L
.10952 .02094 L
.11905 .02067 L
.12857 .02236 L
.1381 .01947 L
.14762 .0198 L
.15714 .02202 L
.16667 .02232 L
.17619 .02373 L
.18571 .0242 L
.19524 .02145 L
.20476 .02396 L
.21429 .02196 L
.22381 .0239 L
.23333 .0242 L
.24286 .02649 L
.25238 .02197 L
.2619 .02618 L
.27143 .0244 L
.28095 .0268 L
.29048 .02474 L
.3 .02747 L
.30952 .02721 L
.31905 .02553 L
.32857 .02754 L
.3381 .02736 L
.34762 .03055 L
.35714 .03035 L
.36667 .02984 L
.37619 .03074 L
.38571 .02988 L
.39524 .03215 L
.40476 .03164 L
.41429 .03269 L
.42381 .03475 L
.43333 .03673 L
.44286 .03623 L
.45238 .03871 L
.4619 .03714 L
.47143 .03581 L
.48095 .03742 L
.49048 .03772 L
Mistroke
.5 .03869 L
.50952 .0387 L
.51905 .04064 L
.52857 .03943 L
.5381 .04131 L
.54762 .04321 L
.55714 .04358 L
.56667 .04374 L
.57619 .04221 L
.58571 .04328 L
.59524 .04542 L
.60476 .0451 L
.61429 .04973 L
.62381 .04882 L
.63333 .05068 L
.64286 .05246 L
.65238 .05277 L
.6619 .05392 L
.67143 .05342 L
.68095 .05563 L
.69048 .05364 L
.7 .05339 L
.70952 .05762 L
.71905 .05898 L
.72857 .0589 L
.7381 .05765 L
.74762 .06151 L
.75714 .0636 L
.76667 .06071 L
.77619 .06551 L
.78571 .06132 L
.79524 .06586 L
.80476 .06659 L
.81429 .0703 L
.82381 .06974 L
.83333 .06825 L
.84286 .07 L
.85238 .07513 L
.8619 .07486 L
.87143 .07873 L
.88095 .07648 L
.89048 .07818 L
.9 .07986 L
.90952 .08138 L
.91905 .08125 L
.92857 .08486 L
.9381 .08508 L
.94762 .08888 L
.95714 .08998 L
.96667 .09458 L
Mistroke
.97619 .09403 L
Mfstroke
0 1 1 r
gsave
.97619 .57498 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05816 m
.03333 .05902 L
.04286 .06102 L
.05238 .06319 L
.0619 .06501 L
.07143 .06903 L
.08095 .06985 L
.09048 .07262 L
.1 .07429 L
.10952 .07859 L
.11905 .08039 L
.12857 .08533 L
.1381 .08949 L
.14762 .09033 L
.15714 .09456 L
.16667 .09385 L
.17619 .09763 L
.18571 .10337 L
.19524 .10632 L
.20476 .11021 L
.21429 .11493 L
.22381 .11687 L
.23333 .12447 L
.24286 .12584 L
.25238 .13063 L
.2619 .13384 L
.27143 .13869 L
.28095 .14079 L
.29048 .14582 L
.3 .14894 L
.30952 .1542 L
.31905 .16011 L
.32857 .16256 L
.3381 .16839 L
.34762 .17309 L
.35714 .17859 L
.36667 .18239 L
.37619 .18512 L
.38571 .19092 L
.39524 .19465 L
.40476 .2013 L
.41429 .20849 L
.42381 .21191 L
.43333 .21922 L
.44286 .22473 L
.45238 .23194 L
.4619 .23534 L
.47143 .24035 L
.48095 .24842 L
.49048 .24939 L
Mistroke
.5 .25592 L
.50952 .26191 L
.51905 .26452 L
.52857 .26792 L
.5381 .27728 L
.54762 .28239 L
.55714 .2881 L
.56667 .29373 L
.57619 .30011 L
.58571 .30797 L
.59524 .31118 L
.60476 .32296 L
.61429 .3287 L
.62381 .33757 L
.63333 .34292 L
.64286 .35212 L
.65238 .35837 L
.6619 .36523 L
.67143 .36807 L
.68095 .37338 L
.69048 .37944 L
.7 .38359 L
.70952 .39341 L
.71905 .4005 L
.72857 .40805 L
.7381 .41409 L
.74762 .42088 L
.75714 .42871 L
.76667 .4383 L
.77619 .44272 L
.78571 .45087 L
.79524 .45785 L
.80476 .46616 L
.81429 .4717 L
.82381 .48201 L
.83333 .48761 L
.84286 .494 L
.85238 .49813 L
.8619 .51101 L
.87143 .51956 L
.88095 .52318 L
.89048 .52565 L
.9 .53417 L
.90952 .54147 L
.91905 .54922 L
.92857 .55168 L
.9381 .55765 L
.94762 .56382 L
.95714 .56831 L
.96667 .56972 L
Mistroke
.97619 .57498 L
Mfstroke
0 1 .4 r
gsave
.97619 .09156 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01789 m
.03333 .01715 L
.04286 .01921 L
.05238 .01729 L
.0619 .01796 L
.07143 .0198 L
.08095 .01788 L
.09048 .01726 L
.1 .01926 L
.10952 .01955 L
.11905 .02026 L
.12857 .01996 L
.1381 .01939 L
.14762 .02243 L
.15714 .02087 L
.16667 .02279 L
.17619 .02314 L
.18571 .02271 L
.19524 .02235 L
.20476 .02307 L
.21429 .02384 L
.22381 .0223 L
.23333 .02375 L
.24286 .02248 L
.25238 .02511 L
.2619 .02503 L
.27143 .02548 L
.28095 .02373 L
.29048 .02586 L
.3 .02761 L
.30952 .02771 L
.31905 .02525 L
.32857 .02743 L
.3381 .02825 L
.34762 .02502 L
.35714 .02722 L
.36667 .02495 L
.37619 .02697 L
.38571 .02702 L
.39524 .028 L
.40476 .02982 L
.41429 .03096 L
.42381 .03011 L
.43333 .03149 L
.44286 .03026 L
.45238 .03232 L
.4619 .0332 L
.47143 .03452 L
.48095 .03491 L
.49048 .03514 L
Mistroke
.5 .03367 L
.50952 .03456 L
.51905 .03227 L
.52857 .03447 L
.5381 .03418 L
.54762 .03591 L
.55714 .03648 L
.56667 .03983 L
.57619 .04073 L
.58571 .04202 L
.59524 .0436 L
.60476 .04563 L
.61429 .04696 L
.62381 .04655 L
.63333 .05026 L
.64286 .04964 L
.65238 .05072 L
.6619 .05016 L
.67143 .05068 L
.68095 .0536 L
.69048 .05357 L
.7 .05599 L
.70952 .05552 L
.71905 .05678 L
.72857 .05431 L
.7381 .05397 L
.74762 .05506 L
.75714 .05784 L
.76667 .05944 L
.77619 .0628 L
.78571 .06274 L
.79524 .06233 L
.80476 .06404 L
.81429 .06784 L
.82381 .0669 L
.83333 .07026 L
.84286 .07084 L
.85238 .07369 L
.8619 .0737 L
.87143 .07543 L
.88095 .07517 L
.89048 .07414 L
.9 .0761 L
.90952 .0793 L
.91905 .08186 L
.92857 .08168 L
.9381 .07932 L
.94762 .08213 L
.95714 .08382 L
.96667 .08706 L
Mistroke
.97619 .09156 L
Mfstroke
.2 1 0 r
gsave
.97619 .58622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05521 m
.03333 .05704 L
.04286 .06157 L
.05238 .06419 L
.0619 .06194 L
.07143 .06808 L
.08095 .06928 L
.09048 .07262 L
.1 .07331 L
.10952 .07642 L
.11905 .0806 L
.12857 .08331 L
.1381 .08576 L
.14762 .09039 L
.15714 .09504 L
.16667 .09714 L
.17619 .10002 L
.18571 .10378 L
.19524 .10887 L
.20476 .11192 L
.21429 .11738 L
.22381 .11986 L
.23333 .12228 L
.24286 .12729 L
.25238 .13036 L
.2619 .13225 L
.27143 .1401 L
.28095 .14379 L
.29048 .14582 L
.3 .15364 L
.30952 .15928 L
.31905 .1631 L
.32857 .16611 L
.3381 .17161 L
.34762 .17524 L
.35714 .17981 L
.36667 .18484 L
.37619 .19044 L
.38571 .19649 L
.39524 .20063 L
.40476 .20614 L
.41429 .21248 L
.42381 .21626 L
.43333 .2228 L
.44286 .22804 L
.45238 .23381 L
.4619 .23771 L
.47143 .24392 L
.48095 .24687 L
.49048 .25457 L
Mistroke
.5 .25945 L
.50952 .26274 L
.51905 .27148 L
.52857 .27819 L
.5381 .2825 L
.54762 .28973 L
.55714 .29436 L
.56667 .30405 L
.57619 .30945 L
.58571 .31545 L
.59524 .32245 L
.60476 .32529 L
.61429 .33762 L
.62381 .34563 L
.63333 .35085 L
.64286 .35869 L
.65238 .3641 L
.6619 .37036 L
.67143 .37519 L
.68095 .38896 L
.69048 .39375 L
.7 .40084 L
.70952 .40657 L
.71905 .41592 L
.72857 .42361 L
.7381 .42691 L
.74762 .43435 L
.75714 .44115 L
.76667 .44795 L
.77619 .45303 L
.78571 .46054 L
.79524 .46526 L
.80476 .47099 L
.81429 .46982 L
.82381 .47484 L
.83333 .48096 L
.84286 .48958 L
.85238 .49793 L
.8619 .50716 L
.87143 .51083 L
.88095 .52016 L
.89048 .53081 L
.9 .53435 L
.90952 .53763 L
.91905 .54566 L
.92857 .55948 L
.9381 .56663 L
.94762 .57249 L
.95714 .57667 L
.96667 .58544 L
Mistroke
.97619 .58622 L
Mfstroke
.8 1 0 r
gsave
.97619 .09089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01635 m
.03333 .01648 L
.04286 .01722 L
.05238 .01713 L
.0619 .02008 L
.07143 .01962 L
.08095 .01713 L
.09048 .01957 L
.1 .02115 L
.10952 .02238 L
.11905 .0195 L
.12857 .01972 L
.1381 .02181 L
.14762 .0196 L
.15714 .02201 L
.16667 .02187 L
.17619 .02368 L
.18571 .02011 L
.19524 .02336 L
.20476 .02377 L
.21429 .02511 L
.22381 .02278 L
.23333 .025 L
.24286 .0259 L
.25238 .02406 L
.2619 .02577 L
.27143 .02556 L
.28095 .02763 L
.29048 .02868 L
.3 .02651 L
.30952 .02817 L
.31905 .02906 L
.32857 .03092 L
.3381 .03018 L
.34762 .02967 L
.35714 .02874 L
.36667 .03142 L
.37619 .02934 L
.38571 .03342 L
.39524 .02945 L
.40476 .03093 L
.41429 .03216 L
.42381 .03098 L
.43333 .02995 L
.44286 .03236 L
.45238 .0342 L
.4619 .03193 L
.47143 .03379 L
.48095 .03479 L
.49048 .03264 L
Mistroke
.5 .03434 L
.50952 .03709 L
.51905 .03357 L
.52857 .03793 L
.5381 .04032 L
.54762 .03872 L
.55714 .04024 L
.56667 .04313 L
.57619 .04256 L
.58571 .04284 L
.59524 .04413 L
.60476 .0457 L
.61429 .04488 L
.62381 .04614 L
.63333 .04343 L
.64286 .04279 L
.65238 .0427 L
.6619 .04305 L
.67143 .04499 L
.68095 .04897 L
.69048 .04858 L
.7 .0537 L
.70952 .05236 L
.71905 .05553 L
.72857 .05519 L
.7381 .05677 L
.74762 .05513 L
.75714 .05454 L
.76667 .05628 L
.77619 .05871 L
.78571 .06014 L
.79524 .06484 L
.80476 .06375 L
.81429 .06493 L
.82381 .06735 L
.83333 .06776 L
.84286 .0679 L
.85238 .06735 L
.8619 .07083 L
.87143 .07007 L
.88095 .07453 L
.89048 .07403 L
.9 .0748 L
.90952 .07997 L
.91905 .07922 L
.92857 .08395 L
.9381 .08737 L
.94762 .08948 L
.95714 .09148 L
.96667 .09295 L
Mistroke
.97619 .09089 L
Mfstroke
1 .6 0 r
gsave
.97619 .55089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05493 m
.03333 .05714 L
.04286 .05794 L
.05238 .06295 L
.0619 .06575 L
.07143 .06604 L
.08095 .06991 L
.09048 .07221 L
.1 .07606 L
.10952 .07689 L
.11905 .08005 L
.12857 .08473 L
.1381 .08876 L
.14762 .09098 L
.15714 .09413 L
.16667 .09874 L
.17619 .1007 L
.18571 .10322 L
.19524 .105 L
.20476 .10978 L
.21429 .11343 L
.22381 .11703 L
.23333 .12003 L
.24286 .12246 L
.25238 .12568 L
.2619 .12835 L
.27143 .13283 L
.28095 .13663 L
.29048 .13984 L
.3 .14556 L
.30952 .14807 L
.31905 .15241 L
.32857 .15701 L
.3381 .16339 L
.34762 .16735 L
.35714 .17311 L
.36667 .17557 L
.37619 .18157 L
.38571 .1871 L
.39524 .19077 L
.40476 .1949 L
.41429 .20197 L
.42381 .20341 L
.43333 .21023 L
.44286 .21619 L
.45238 .22092 L
.4619 .2278 L
.47143 .23155 L
.48095 .23732 L
.49048 .24318 L
Mistroke
.5 .24641 L
.50952 .25012 L
.51905 .25902 L
.52857 .26389 L
.5381 .26844 L
.54762 .27349 L
.55714 .28334 L
.56667 .28807 L
.57619 .29577 L
.58571 .29861 L
.59524 .30886 L
.60476 .31516 L
.61429 .32281 L
.62381 .32764 L
.63333 .33329 L
.64286 .34136 L
.65238 .34826 L
.6619 .35072 L
.67143 .35664 L
.68095 .3624 L
.69048 .36433 L
.7 .37184 L
.70952 .37548 L
.71905 .38513 L
.72857 .39115 L
.7381 .39656 L
.74762 .40276 L
.75714 .41102 L
.76667 .42009 L
.77619 .42511 L
.78571 .42892 L
.79524 .43534 L
.80476 .44333 L
.81429 .45179 L
.82381 .45996 L
.83333 .46672 L
.84286 .47629 L
.85238 .47361 L
.8619 .48221 L
.87143 .48573 L
.88095 .49144 L
.89048 .49349 L
.9 .50366 L
.90952 .50662 L
.91905 .51485 L
.92857 .51847 L
.9381 .53038 L
.94762 .53052 L
.95714 .53696 L
.96667 .54049 L
Mistroke
.97619 .55089 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@0000030?ooo`800000
:03oool3000000<0oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`0000040?ooo`800000
903oool3000000@0oooo0P0000040?ooo`8000000`3oool001l0oooo00@000000?ooo`3oool00000
:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo000O0?ooo`040000003oool0oooo000002T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3oool010000000oooo
0?ooo`00000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`007`3oool010000000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
9@3oool4000000<0oooo00@000000?ooo`3oool000009@3oool3000000<0oooo00@000000?ooo`3o
ool00000903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool000009`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000009P3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000002D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000T
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`007`3oool010000000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00000V0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000008`3oool2000000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`00803oool2000002T0oooo0`0000040?ooo`800000:@3o
ool00`000000oooo0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V0?ooo`<00000103o
ool2000002D0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000030?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`006`3ooook000000<0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`80
c03o1@00I_o]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool90<co00<00?mV
00@006Ko0<co003<o`00c?l01@00ofH20<`0o`P00?mV0P00I_oB0?ooo`8000000`3oool001/0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`@0c?l000<0c03o0<co003oool0
5P3<o`000`00ofH0c?l00<co00040<co00800?mV0P00I_l30<co00030<`0o`00ofH00?mV00800?mV
0P00I_ni0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo02H0oooo0`3<
0?l0103<o`0006Ko001Vo`3oool70<co00030<`0o`00I_l006Ko00`0c?l01000ofH30<co0003001V
o`00ofH00?mV00@00?mV0P00I_l=003oIYL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0@@3oool00`00ofH0oooo0<co00030<co00030<`0o`00ofH00?mV01<0c?l00P00
I_l50<co00800?mV1@3<o`03003oIXT0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0B03oool00`3<o`00oooo0?ooo`060?ooo`80c03o00<0oooo003oIP3oool00P3o0005
0<`0o`80c?l000<0c03o001Vo`00I_l00P00I_l20<co00<006Ko00<00?mV0<co003<o`00403<o`02
003oIP<0c?l01@00ofIa0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000I@3oool2001V
o`030?l0003<0?l0c03o01<006Ko0P3<o`000`00I_l0c?l0001Vo`020<co0080c03o0`3<o`02003o
IV`0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1c0?ooo`040?l0003oool0oooo0?oo
o`<0c?l01@3<0?l01000I_l0c03o0<`0o`3<0?l20<co00<006Ko2P3<o`080?ooo`/0c?l0DP3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`210?ooo`80o`001@3<0?l4001V
o`<0c03o0`3o00080<co0003003oIP3<o`00c?l000<0c?l01@3oool20<co0500oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0RP3oool20?l000<0oooo1`3<0?l5001Vo``0
0?mV1`3<o`190?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool20?nI00800?oo
R`3oool00`3o0000oooo0?ooo`040?ooo`D0o`002@00I_l5003oIPD0c?l000@0oooo0<co003<o`00
c?l00P00ofH60<co03T0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`030?ooo`800?oo
1@3oV@2D0?ooo`L0o`000P3<0?l00`00I_l0c03o0<`0o`020<`0o`D00?mV00@0c?l0001Vo`00I_l0
06Ko0P3<o`000`00I_l0c03o0<`0o`03003oIP@0c?l0=P3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`070?ooo`<0<ol00P3oV@0203?o00030?nI003oool0oooo09@0oooo
0P3o0002001Vo`P00?mV103oool30?l0008006Ko0P3<0?l00`00I_l00?mV003oIP02003oIP<0c?l0
0P00ofHa0?ooo`030000003oool0oooo0040oooo00060?ooo`D000000`3oool00`000000oooo0?oo
o`020?ooo`<000001@3oool00`000000oooo0?ooo`0:0?ooo`80<ol01@3oV@2K0?ooo`80o`000P3o
ool00`3o00000?mV003oIP05003oIP050?l00000ofH006Ko001Vo`3oool00P3o00000`00I_l0c03o
0<`0o`020<`0o`T0c?l0103oool30<co02<0oooo00<000000?ooo`3oool00@3oool000L0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool03`3oool203?o0080oiT00P3o09VI0?ooo`80o`000`3oool50?l0008006Ko1`00ofH30<co0004
0<`0o`3o0000o`000?l000800?mV0`00I_l40<co0003003oIP3oool0oooo00D0c?l07P3oool00`00
0000oooo0?ooo`010?ooo`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P00000B0?ooo`80<`3o0`3oV@0203?o0:80oooo1@3o0005001Vo`L0o`00103<o`000`00ofH0
c03o0<`0o`05003oIP030<`0o`00ofH0c?l000D0c?l05P3oool3000000<0oooo00090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`@0oiT0
0P3o09VX0?ooo`@006Ko0P3oool3001Vo`800?mV00<006Ko0?ooo`3oool00P00ofH30<`0o`03003o
IP00I_l006Ko00@006Ko00@00?mV0<co0000ofH00?mV0P3<o`020?ooo`@00?mV3@3oool00`000000
oooo0?ooo`010?ooo`001P3oool01@000000oooo0?ooo`3oool0000000L0oooo100000050?ooo`03
0000003oool0oooo01P0oooo0P00ool30?nI0080<ol0Z@3oool2001Vo`H0oooo1000I_l30?l00004
0<`0o`00ofH0c?l00<`0o`<0o`000P00I_l20<co0005001Vo`00ofH0c?l0003oIP3<0?l00`3oool2
003oIP/0oooo00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool20?nI00<0<ol0/P3oool7
001Vo`<0c03o0P00ofH50?l000D0c?l00P3<0?l4003oIP80c03o1@3oool00`000000oooo0?ooo`01
0?ooo`001`3oool3000000P0oooo1@0000040?ooo`030000003oool0oooo01l0oooo1@3oV@2f0?oo
o`040?l00000I_l006Ko001Vo`80c03o103oool00`00ofH0oooo0?ooo`050<co00<006Ko00<0o`00
0<co003<o`001@3oool00`000000oooo0?ooo`010?ooo`006`3oool2000002D0oooo0P3oV@03003o
ok80oooo1@3o000:0<`0o`80oooo103<o`000`00I_l00?mV0?ooo`030?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool09P3oool30?nI00800?oo^03oool01000I_l0o`000?l0003o0003001V
o`80c03o1@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo02T0oooo103oV@2m0?ooo`8006Ko1@3<0?l60?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo02/0oooo0P0co`030?nI0080o`2I^P3oool3001Vo`800?mV
00<0c03o0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`0]0?ooo`<0<ol00P3oV@0203<0okd0oooo00<006Ko0?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`006`3oool200000340oooo0P0co`030?nI0<40oooo0P0000030?ooo`006`3oool00`00
0000oooo0?ooo`0b0?ooo`<0<ol00P3oV@0203<0okh0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0=@3oool203?o00D0oiT0^`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`0g0?ooo`800?oo0`0co`020?nI0;T0oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00000m0?ooo`80<ol00`3oV@2e0?ooo`8000000`3oool001/0oooo00<00000
0?ooo`3oool0?P3oool203?o0003003oo`3oV@00oiT00;@0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0@03oool00`0co`000?oo003oo`020?nI0;80oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0@@3oool203?o00800?oo0`3oV@2_0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo04<0oooo100co`000`00ool0oiT0
0?nI002]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000B03oool00`0co`000?oo003o
o`020?nI0:X0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`180?ooo`80<ol000<00?oo
03<0o`3oV@000P3oV@2X0?ooo`030000003oool0oooo0040oooo000C0?ooo`<000001@3oool00`00
0000oooo0?ooo`1:0?ooo`80<ol00`3o09T00`3oV@00<`3o0?ooo`2U0?ooo`030000003oool0oooo
0040oooo000B0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1<0?oo
o`<0<ol000<00?oo0?nI000c0?l00P0c0?nS0?ooo`030000003oool0oooo0040oooo000F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`3oV@00<ol0003oo`030?nI00@0
<`3oW`3oool00`000000oooo0?ooo`010?ooo`005P3oool00`000000oooo0?ooo`020?ooo`800000
D03oool00`3oV@00<ol0003oo`02003oo`80oiT00P3oool303<0oiX0oooo0`0000030?ooo`004P3o
ool4000000D0oooo00<000000?ooo`3oool0D@3oool403?o0003003oo`3oV@00oiT000<0o`2I0P0c
0?nJ0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0E03oool0103oV@00<ol0003oo`00ool30?nI0080o`2I0`0c0?nG0?ooo`030000003o
ool0oooo0040oooo000B0?ooo`D00000103oool00`000000oooo0?ooo`1F0?ooo`80<ol00`00ool2
0?nI0080o`2I00<0oooo03<0o`3oool0U@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`00
0000oooo0?ooo`1H0?ooo`<0<ol00P00ool30?nI00030?ooo`0c0?l0oooo09@0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P00001L0?ooo`0303?o0000ool00?oo00800?oo0P3oV@0503<0ohl0
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`0303?o0000ool00?oo00800?oo
00<0o`2I0?nI003o09T00`3oool203<0ohh0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0G@3oool303?o00800?oo00@0o`2I0?nI003o09T0o`2I0`3oool00`0c0?l0oooo
0?ooo`2;0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0600oooo0P0c
o`000`00ool0<ol00?nI00020?nI00<0oooo00<0<`3o0?ooo`3oool0RP3oool00`000000oooo0?oo
o`010?ooo`006`3oool2000006<0oooo00<0<ol0003oo`0co`000P0co`020?nI0080oooo0`0c0?n8
0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0H`3oool01`0co`000?oo003oo`00ool0
<ol003<0o`3oV@00103oool00`0c0?l0oooo0?ooo`260?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo06@0oooo0`0co`02003oo`0303<0o`3oV@00oooo00<0oooo00<0<`3o
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1W0?oo
o`80<ol000<00?oo03?o003oV@000P3oV@020?ooo`D0<`3oPP3oool00`000000oooo0?ooo`010?oo
o`006`3oool00`000000oooo0?ooo`1X0?ooo`030?nI000co`000?oo00<0<ol000<0oiT00?l0V@3o
ool0103oool00`0c0?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000
JP3oool01`3oV@00<ol0003oo`00ool0oooo03?o003oV@000P3o09T40?ooo`0303<0o`3oool0oooo
07d0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1[0?ooo`<0<ol00P3oool30?nI0080
o`2I0P3oool203<0ogh0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
KP3oool203?o0080oooo00<0<ol00?nI003oV@000P3o09T20?ooo`0303<0o`3oool0oooo07/0oooo
00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0K`3oool0103oV@00<ol003?o
0000ool203?o0080oiT00P3o09T00`3oool0<`3o03<0o`1k0?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0700oooo0P3oV@000`0co`000?oo003oo`0203?o00<0oiT00P3o
ool303<0ogP0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001d0?ooo`<0<ol000@0oooo
03?o000co`00<`3o0P3oV@020?l0V@030?ooo`0c0?l0oooo07D0oooo0P0000030?ooo`006`3oool0
0`000000oooo0?ooo`1d0?ooo`030?nI0000ool0<ol000800?oo00<0<ol003<0o`0c0?l00P3oV@00
0`3o09T0oooo03<0o`1f0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0M@3oool20?nI
0080<ol000<00?oo03?o000co`000P0c0?l0103oV@00o`2I0?l0V@0c0?me0?ooo`030000003oool0
oooo0040oooo00080?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo07L0oooo0P3oV@000`0co`000?oo003oo`0303?o00040?nI003oool0
o`2I03<0og@0oooo00<000000?ooo`3oool00@3oool000T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00@0oiT003?o000co`00<ol00P00
ool0100co`00oiT00?ooo`3o09T303<0og40oooo00<000000?ooo`3oool00@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000N`3oool20?nI00030?ooo`0c
o`000?oo00800?oo0P3oV@030?l0V@0303<0o`3oool0oooo06`0oooo0`0000030?ooo`002P3oool0
0`000000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?ooo`1l0?ooo`80oiT000D0<ol0
003oo`0co`000?oo03<0o`030?nI00030?l0V@0c0?l0oooo06h0oooo00<000000?ooo`3oool00@3o
ool000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0O`3oool303?o0007003oo`0c0?l0<`3o03<0o`3oV@00oooo03<0o`1^0?ooo`03
0000003oool0oooo0040oooo00060?ooo`D000001`3oool5000000@0oooo00<000000?ooo`3oool0
O`3oool0103oV@00oooo03?o000co`03003oo`040?nI003o09T0oooo03<0ofd0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P0000210?ooo`030?nI003oool0oooo0080<ol000<0oooo003oo`3o
V@000P3o09T203<0ofX0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`210?ooo`@0oiT0
00<0<ol00?ooo`00ool00P3oV@020?l0V@0303<0o`3oool0oooo06P0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0QP3oool203?o00800?oo0P3oV@000`3oool0<`3o03<0
o`1X0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo08L0oooo00<0oiT0
03?o000co`000P00ool00`3oV@00oooo0?ooo`0303<0ofD0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0R03oool01@0co`000?oo03?o000co`000?oo00<0oiT000<0oooo
0?l0V@0c0?l0I03oool00`000000oooo0?ooo`010?ooo`006`3oool2000008X0oooo00/0<ol0003o
o`00ool0oooo003oo`0c0?l0oooo0?nI003oool0o`2I03<0o`1R0?ooo`8000000`3oool001/0oooo
00<000000?ooo`3oool0RP3oool303?o00080?ooo`00ool0<`3o03<0o`3oV@00<`3o0?ooo`0c0?mR
0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo08d0oooo00<0<ol0003o
o`00ool00P00ool0103oV@00<`3o0?ooo`0c0?mQ0?ooo`030000003oool0oooo0040oooo000K0?oo
o`030000003oool0oooo08h0oooo00P0<ol0003oo`00ool0oooo003oo`3oV@00<`3o0?ooo`<0<`3o
GP3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2?0?ooo`<0<ol000@0
oooo003oo`3oV@00oiT00`3oool00`0c0?l0o`2I0?ooo`1K0?ooo`030000003oool0oooo0040oooo
000K0?ooo`800000T`3oool203?o0007003oo`0co`00oiT00?nI000c0?l0oooo03<0o`020?l0VET0
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2B0?ooo`04003oo`3oV@00<ol0003oo`80
<ol000<0oiT003<0o`0c0?l00`0c0?mI0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo09<0oooo00<00?oo03?o003oV@000P00ool00`3o09T0oiT00?nI000403<0o`030?l0
V@3oool0oooo05D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0U03o
ool01@00ool0<ol00?nI003oV@000?oo0080o`2I0P3oV@020?ooo`0303<0o`3o09T0o`2I05D0oooo
00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0UP3oool203?o00030?nI0000
ool00?oo0080o`2I00<0oiT00?ooo`3oool00P0c0?l00`3o09T0oooo0?ooo`1B0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`800000V@3oool02@0co`00oiT0003oo`00ool0oooo0?l0V@3oV@00
<ol00?ooo`0403<0oe40oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2I0?ooo`80<ol0
0P00ool01@3oool0o`2I0?nI000co`00oooo0080<`3o00<0o`2I03<0o`0c0?l0D03oool00`000000
oooo0?ooo`010?ooo`003@3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo09/0oooo
0P0co`000`00ool0oooo0?ooo`040?nI00040?ooo`3o09T0<`3o03<0odl0oooo00<000000?ooo`3o
ool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo09d0oooo00D0<ol0003oo`00ool0oooo0?l0V@0203?o00030?nI003oool0o`2I
0080<`3oCP3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo0P00002O0?ooo`0703?o003oV@000?oo0?ooo`3o09T0oooo03?o
00020?nI0080o`2I0`0c0?m90?ooo`<000000`3oool000h0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo09l0oooo00H0<ol00?nI0000ool0oooo
0?l0V@3oool203?o0080oiT00P3o09T303<0odT0oooo00<000000?ooo`3oool00@3oool000h0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0:00
oooo0P0co`03003oo`80oooo00L0<ol00?ooo`3oV@00oiT00?l0V@0c0?l0oooo0080<`3oA`3oool0
0`000000oooo0?ooo`010?ooo`003@3oool2000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`2R0?ooo`80<ol000@0oooo003oo`00ool0<ol00`3oool00`3oV@00o`2I03<0
o`020?ooo`0303<0o`3oool0oooo04@0oooo00<000000?ooo`3oool00@3oool000h0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0Y03oool01@0co`00oooo0?ooo`00
ool0<ol000<0oooo0P3oV@0503<0od@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00002V
0?ooo`0403?o003oV@00oooo003oo`@0<ol000H0oooo0?nI003oV@00o`2I03<0o`3oool203<0od40
oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2U0?ooo`0403?o003oool0oiT00?nI00<0
0?oo00H0oooo03?o003oool0oooo0?nI003o09T30?ooo`<0<`3o?`3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`2V0?ooo`0303?o0000ool0oooo0080oiT000<0oooo003o
o`3o09T00P0co`000`3oool0oiT00?l0V@050?ooo`0303<0o`3oool0oooo03`0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0Y`3oool203?o0080oooo00<0oiT00?ooo`00
ool00P3o09T0100co`00oooo0?nI003o09T50?ooo`0303<0o`3oool0oooo03/0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0Z@3oool203?o00030?ooo`3oV@00oiT00080
0?oo00<0o`2I03?o003oool00P3oV@050?ooo`80<`3o>`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool200000:`0oooo00<0<ol00?ooo`3oool00P3oV@000`00ool0<ol00?ooo`020?ooo`<0oiT0
103oool00`0c0?l0oooo0?ooo`0g0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0[03o
ool203?o00<0oooo00<00?oo03?o003oool0103oool00`3oV@00oooo0?ooo`020?ooo`80<`3o>03o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2/0?ooo`03003oo`3oool0
<ol00080oooo00<0oiT0003oo`0co`000`0co`020?ooo`030?nI003oool0oooo00<0oooo00<0<`3o
0?ooo`3oool0=@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2]0?oo
o`03003oo`3oool0<ol00080oooo00<0oiT0003oo`00ool00P3o09T0100co`00oooo0?ooo`3oV@04
0?l0V@0303<0o`3oool0oooo03D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0[P3oool2003oo`0303?o003oool0oooo0080oiT00P00ool01P3o09T0<ol00?ooo`3oool0
oiT00?ooo`80<`3o00<0o`2I03<0o`3oool0=@3oool00`000000oooo0?ooo`010?ooo`006`3oool2
00000;80oooo00@0<ol0003oo`00ool0oooo0P3oV@000`00ool0o`2I03?o00020?ooo`050?nI003o
ool0oooo03<0o`3o09T00P0c0?lc0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0/P3o
ool00`0co`000?oo0?ooo`020?ooo`030?nI0000ool0o`2I0080<ol000<0oooo0?nI003oV@000P3o
ool00`3o09T0<`3o03<0o`0c0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo0;<0oooo100co`000`3oool0oiT0003oo`020?l0V@0303?o003oool0oooo0080oiT000@0oooo
0?l0V@3oool0<`3o<P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2e
0?ooo`03003oo`3oool0<ol00080oooo0P00ool00`3oool0<ol00?l0V@020?ooo`80oiT000<0o`2I
03<0o`0c0?l0<@3oool00`000000oooo0?ooo`010?ooo`006`3oool200000;L0oooo00<00?oo0?oo
o`0co`000`3oool01000ool0<ol00?ooo`3o09T30?ooo`040?nI003o09T0o`2I03<0obl0oooo0P00
00030?ooo`006`3oool00`000000oooo0?ooo`2g0?ooo`03003oo`3oool0<ol000<0oooo0P00ool0
0`3o09T0oooo0?ooo`020?ooo`030?nI003oool0o`2I00<0<`3o;@3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`04003oo`3oool0<ol003?o0080oooo00<0oiT0
003oo`0co`000P0co`020?ooo`030?nI003oool0o`2I00<0<`3o;03oool00`000000oooo0?ooo`01
0?ooo`0000@0oooo00000000000000000P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3
000000D0oooo00<000000?ooo`3oool0^@3oool01000ool0oooo0?ooo`0co`020?ooo`050?nI0000
ool0o`2I0?l0V@0co`000P3oool00`3oV@00oooo0?l0V@020?l0V@80<`3o:P3oool00`000000oooo
0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0;X0oooo0P00ool01@3oool0
<ol003?o003oool0oiT000800?oo00D0o`2I03?o000co`00oooo0?nI00030?ooo`040?l0V@0c0?l0
<`3o03<0obP0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00002m0?ooo`05003oo`3oool0
oooo03?o003oool00P3oV@001@00ool0o`2I0?ooo`0co`00oooo0080oiT00P3oool0103o09T0<`3o
03<0o`0c0?lU0?ooo`<000000`3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool01000ool0oooo
0?ooo`0co`020?ooo`050?nI0000ool0o`2I0?ooo`0co`000P3oool00`3oV@00oooo0?ooo`020?l0
V@@0<`3o903oool00`000000oooo0?ooo`010?ooo`000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3oool0_P3oool00`00
ool0oooo0?ooo`0303?o00040?nI0000ool0o`2I0?ooo`80<ol000<0oooo0?nI003oV@000`3oool4
03<0ob<0oooo00<000000?ooo`3oool00@3oool000030?ooo`000000000000<0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0_`3oool4
003oo`050?ooo`0co`00oiT0003oo`3o09T00P3oool0100co`00oooo0?ooo`3oV@030?ooo`030?l0
V@0c0?l0oooo0080<`3o8@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`<00000203oool5000000@0oooo00<000000?ooo`3oool0``3oool01000ool0oooo03?o
003oV@0503?o0080oooo00H0oiT00?ooo`3oool0oooo0?l0V@0c0?l20?ooo`0303<0o`3oool0oooo
01h0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000350?ooo`04003oo`3oool0<ol00?nI
00800?oo00<0o`2I03?o003oool00P3oool01@3oV@00oooo0?nI003oV@00oooo0080<`3o00<0o`2I
03<0o`3oool07@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0<D0oooo00<00?oo0?oo
o`3oool00P3oV@000`00ool0o`2I03?o00030?ooo`040?nI003oool0oooo0?nI0080oooo00<0<`3o
0?l0V@0c0?l07P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`360?oo
o`06003oo`3oool0oooo0?ooo`3oV@000?oo0`0co`050?ooo`<0oiT0100c0?lL0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo0<L0oooo00H00?oo0?ooo`3oool0oooo0?nI
0000ool303?o00L0oooo00@0oiT00?ooo`0c0?l0oooo0`0c0?lI0?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo0<P0oooo0P00ool30?ooo`<00?oo00<0<ol00?l0V@3oool0
1@3oool00`3oV@00oooo03<0o`030?ooo`0303<0o`3oool0oooo01H0oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00003;0?ooo`03003oo`3oool0oooo0080oooo00@0oiT0003oo`0co`00o`2I
1P3oool30?nI000403<0o`3o09T0oooo03<0oaH0oooo0P0000030?ooo`006`3oool00`000000oooo
0?ooo`3;0?ooo`800?oo0`3oool00`3oV@00<ol003?o00090?ooo`040?nI000c0?l0o`2I0?ooo`@0
<`3o4`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`<00?oo
00@0oooo0?nI000co`00<ol02@3oool00`3oV@00<`3o03<0o`040?ooo`0303<0o`3oool0oooo0100
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0d03oool00`00ool0oooo
0?nI000403?o00L0oooo103oV@000`0c0?l0oooo0?ooo`0203<0oa00oooo00<000000?ooo`3oool0
0@3oool001/0oooo0P00003B0?ooo`03003oo`3oool00?oo00D0<ol02@3oool00`3oV@00<`3o0?oo
o`020?ooo`<0<`3o303oool2000000<0oooo000K0?ooo`030000003oool0oooo0=80oooo00L00?oo
0?ooo`00ool00?oo0?ooo`0co`00o`2I0080<ol0203oool20?nI00D0oooo0P0c0?l;0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0=<0oooo00T00?oo0?ooo`3oool00?oo
0?ooo`0co`00o`2I0?ooo`0co`00203oool00`0c0?l0oiT00?ooo`050?ooo`80<`3o2@3oool00`00
0000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`D00?oo00<0<ol00?l0V@0c
o`002@3oool00`3oV@00<`3o0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0e`3oool01000ool0oiT0003oo`0co`02003oo`03
0?l0V@3oool0oooo00H0oooo00<0oiT003<0o`0c0?l01P3oool203<0o`H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003I0?ooo`03003oo`3oV@00oooo00<0<ol000<0o`2I0?ooo`3oool0
1P3oool40?nI00H0oooo00<0<`3o0?ooo`3oool00P3oool2000000<0oooo000K0?ooo`030000003o
ool0oooo0=T0oooo00<00?oo0?nI003oool00P3oool203?o00X0oooo00<0<`3o0?nI003oool02P3o
ool00`000000oooo0?ooo`010?ooo`003@3oool3000000<0oooo0`0000050?ooo`030000003oool0
oooo0=X0oooo00<00?oo0?nI003oool00P3oool01000ool0<ol003?o000co`080?ooo`0403<0o`3o
V@00oiT00?nI00P0oooo00<000000?ooo`3oool00@3oool000h0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f`3oool00`00ool0oiT0
0?ooo`020?ooo`800?oo0P0co`080?ooo`<0<`3o00<0oiT00?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0g@3oool00`3oV@00oooo0?ooo`020?ooo`03003oo`0co`00oooo00X0oooo00<0
<`3o0?nI003oool01@3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo0P00003O0?ooo`030?nI0000ool0oooo0080oooo00<0<ol0
003oo`3oool02`3oool0103oV@00oooo0?ooo`3oool3000000<0oooo000>0?ooo`040000003oool0
oooo0?ooo`@000001@3oool00`000000oooo0?ooo`3O0?ooo`030?nI0000ool00?oo0080oooo00<0
<ol0003oo`00ool0403oool00`000000oooo0?ooo`010?ooo`003@3oool2000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3P0?ooo`80oiT000D00?oo0?ooo`0co`00<ol00?oo
o`02003oo`h0oooo00<000000?ooo`3oool00@3oool000h0oooo00@000000?ooo`3oool0oooo1@00
00040?ooo`030000003oool0oooo0>80oooo00<0oiT0003oo`00ool00P0co`020?ooo`03003oo`3o
ool0oooo00/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0h`3oool2
0?nI00800?oo0`0co`02003oo`/0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003V0?oo
o`80oiT00P00ool00`0co`00oooo03?o0004003oo`H0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`3W0?ooo`80oiT000<0oooo03?o000co`000P0co`020?ooo`03003oo`3oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0j@3oool00`3oV@00oooo
003oo`0303?o0080oooo00<00?oo0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`3Z0?ooo`040?nI003oool00?oo003oo`@0<ol01@3oool00`000000oooo
0?ooo`010?ooo`006`3oool200000>`0oooo00@0oiT00?ooo`3oool00?oo0`0co`040?ooo`800000
0`3oool001/0oooo00<000000?ooo`3oool0k03oool20?nI00030?ooo`00ool00?oo00H0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0kP3oool0103oV@00oooo0?ooo`00
ool50?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0>l0oooo00<0oiT0
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3`0?oo
o`030?nI003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003b0?ooo`03
0?nI003oool0oooo0080oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`3g0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3o
ool001/0oooon`0000030?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3o
oolJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-13.8823, -0.913064, \
0.419554, 0.105204}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["missing data",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["\<\
miss = -9;
ZM = Shape[miss,{n,T+1,p}];
tau = {0,10,20,30,50,60,70,80,85,90,95,100}+1;
Do[ ZM[[nn,tau[[i]] ]] = Z[[nn,tau[[i]] ]],{nn,1,n},{i,Length[tau]}];\
\>", \
"Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ZM//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? drift\)], "Input"],

Cell["Global`drift", "Print",
  CellTags->"Info3374837877-7494599"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(drift[{y1_, y2_}, {t_}, {lambda11_, lambda12_, lambda21_, 
                        lambda22_, alpha_, 
                        beta_}] = {\((lambda11\/100 + \(alpha\ t\)\/100)\)\ \
y1 + \(lambda12\ y2\)\/100, \(lambda21\ y1\)\/100 + \((lambda22\/100 + \(beta\
\ t\)\/100)\)\ y2}\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "drift"],
      Editable->False]], "Print",
  CellTags->"Info3374837877-7494599"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ML estimation;  n= 10", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
FISHER=True;
system={drift,Jacobif,diffusion,h,Jacobih,R,mue,sigma,dt};
THETA0=Theta;
F0=IdentityMatrix[Theta//Length];
MAXSTEP=1;
miss\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
asymptotic standard deviation using F \[TildeTilde] - Hessian \
(Greene, ch. 4)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ZM // Dimensions\), "\[IndentingNewLine]", 
    \(X // Dimensions\[IndentingNewLine] (*{ZM, X} // 
          Transpose\  = \ {{ZM1, X1},  ... , {ZMN, 
            XN}}*) \), "\[IndentingNewLine]", 
    \(\(({ZM, X} // Transpose)\) // Dimensions\)}], "Input"],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"],

Cell[BoxData[
    \({10, 101, 1}\)], "Output"],

Cell[BoxData[
    \({10, 2, 101}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\({THETA, COV, LIKI, psii, scoreii, k, ReturnCode}\), "=", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"BFGS", "[", 
            RowBox[{\({ZM, X} // Transpose\), ",", \({THETA0, F0}\), ",", 
              RowBox[{"{", 
                RowBox[{"system", ",", 
                  RowBox[{"{", 
                    RowBox[{"Lik", ",", "EKF", ",", "Score", ",", 
                      StyleBox["Hesse",
                        FontColor->RGBColor[1, 0, 0]]}], "}"}]}], "}"}], 
              ",", \({{miss, 1}, 
                KMAX = 30, {EPS1 = 10^\(-4\), EPS2 = 10^\(-4\)}, OPTION = 1, 
                PRINT = {1, 1, 1, 1, 1, 1, 1, 1}}\)}], "]"}]}], 
        ";"}]}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Tiefe von data = "\[InvisibleSpace]5\),
      SequenceForm[ "Tiefe von data = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \("L\[ADoubleDot]nge der Paneldaten"\)], "Print"],

Cell[BoxData[
    \({101, 101, 101, 101, 101, 101, 101, 101, 101, 101}\)], "Print"],

Cell[BoxData[
    \("***********************LSDE1**********************************"\)], \
"Print"],

Cell[BoxData[
    \("***********************MODUL:    BFGS (skeleton)**************"\)], \
"Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \("Technical Output"\)], "Print"],

Cell[BoxData[
    \(EKF\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"KMAX\"\>", "\<\"EPS1\"\>", "\<\"EPS2\"\>", "\<\"K\
\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"T\"\>", "\<\"OPTION\"\>"},
          {"1", "30", \(1\/10000\), \(1\/10000\), "2", "1", "10", "100", "1"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"KMAX", "EPS1", "EPS2", "K",
           "Q", "n", "T", "OPTION"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"MAXSTEP\"\>", "\<\"MINSTEP\"\>", "\<\"BOUND\"\>", \
"\<\"STEPREDUCE\"\>", "\<\"FMAX\"\>"},
          {"1", "1", "1.`*^-10", "1.`*^-6", "4", "1000"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"MAXSTEP", "MINSTEP", 
          "BOUND", "STEPREDUCE", "FMAX"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"RESAMPLING\"\>", "\<\"FDIGITS\"\>", \
"\<\"TYP\"\>", "\<\"YMAX\"\>", "\<\"ANALGRAD\"\>", "\<\"FACTOR\"\>", \
"\<\"CSEED\"\>"},
          {"1", "True", "16", "1", "1000.`", "False", "1.`", \(-999\)}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"RESAMPLING", "FDIGITS", 
          "TYP", "YMAX", "ANALGRAD", "FACTOR", "CSEED"}}, TableDirections -> {
          Column, Row}, TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("    SCALING"\)], "Print"],

Cell[BoxData[
    \(Transpose::"nmtx" \(\(:\)\(\ \)\) 
      "The first two levels of the one-dimensional list \!\({}\) cannot be \
transposed."\)], "Message"],

Cell[BoxData[
    TagBox[\(Transpose[{}]\),
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCALING"}}, TableDepth -> 
          0]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("STARTWERT THETA0 = "\[InvisibleSpace]{10.`, \
\(-1.`\), 2.`, 30.`, 1.`, \(-2.`\)}\),
      SequenceForm[ 
      "STARTWERT THETA0 = ", {10.0, -1.0, 2.0, 30.0, 1.0, -2.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("EIGENWERTE DER HESSE-MATRIX: "\[InvisibleSpace]{1, 
          1, 1, 1, 1, 1}\),
      SequenceForm[ "EIGENWERTE DER HESSE-MATRIX: ", {1, 1, 1, 1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("{MINI,COND,BOUND} = "\[InvisibleSpace]{1, 1, 
          1.`*^-6}\),
      SequenceForm[ "{MINI,COND,BOUND} = ", {1, 1, 9.9999999999999995*^-07}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-7, 1.4901161193847656`*^-8, 
          2.9802322387695312`*^-8, 4.470348358154297`*^-7, 
          1.4901161193847656`*^-8, 2.9802322387695312`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-07, 1.4901161193847656*^-08, 
        2.9802322387695312*^-08, 4.4703483581542969*^-07, 
        1.4901161193847656*^-08, 2.9802322387695312*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{5.407956886291505`, 30.13719940185547`, 1.225024700164795`, 
        6.030935827891032`, 43.37734317779541`, 33.404881954193115`}, 
      65.03115471383268`}\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]1\),
      SequenceForm[ "BFGS: Iteration = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    28.220225411509650\"\>",
            28.220225411509652,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832680\"\>",
            65.031154713832677,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 28.220225411509652, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832677, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.021759470402980\"\>",
            67.021759470402984,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832680\"\>",
            65.031154713832677,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 2, "  LIKNEU  ", 
        PaddedForm[ 67.021759470402984, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832677, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.021759470402980\"\>",
            67.021759470402984,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 67.021759470402984, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832680\"\>",
            65.031154713832677,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 65.031154713832677, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.990604756570306\"\>",
            1.9906047565703062,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.9906047565703062, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 10.0080\"\>",
                10.007792024145136,
                AutoDelete->True], 
              InterpretationBox["\<\" 10.0000\"\>",
                10.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0078\"\>",
                0.0077920241451356976,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.4080\"\>",
                5.4079568862915046,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-0.9566\"\>",
                -0.9565769864028888,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.0000\"\>",
                -1.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0434\"\>",
                0.043423013597111156,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.1370\"\>",
                30.137199401855469,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 2.0018\"\>",
                2.0017650699224818,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.0000\"\>",
                2.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0018\"\>",
                0.0017650699224818439,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2250\"\>",
                1.2250247001647949,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.0090\"\>",
                30.008689639835666,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.0000\"\>",
                30.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0087\"\>",
                0.0086896398356674683,
                AutoDelete->True], 
              InterpretationBox["\<\" 6.0309\"\>",
                6.0309358278910317,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 1.0625\"\>",
                1.0625,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0000\"\>",
                1.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0625\"\>",
                0.0625,
                AutoDelete->True], 
              InterpretationBox["\<\" 43.3770\"\>",
                43.37734317779541,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-1.9519\"\>",
                -1.9518687644473853,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0000\"\>",
                -2.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0481\"\>",
                0.048131235552614574,
                AutoDelete->True], 
              InterpretationBox["\<\" 33.4050\"\>",
                33.404881954193115,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False]},
              {
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False]},
              {
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False]},
              {
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False]},
              {
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False]},
              {
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 0\"\>",
                  0,
                  Editable->False], 
                InterpretationBox["\<\" 1\"\>",
                  1,
                  Editable->False]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4912772214628959`*^-7, 1.4901161193847656`*^-8, 
          2.9828623979128626`*^-8, 4.471643215393374`*^-7, 
          1.5832483768463135`*^-8, 2.908511108826675`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4912772214628959*^-07, 1.4901161193847656*^-08, 
        2.9828623979128626*^-08, 4.4716432153933742*^-07, 
        1.5832483768463135*^-08, 2.908511108826675*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.5208672622516786`*^-6\),
      SequenceForm[ "NOISE  ", 1.5208672622516786*^-06],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.1339278708708435`\
\[InvisibleSpace]"  "\[InvisibleSpace]121.24496907168596`\),
      SequenceForm[ 
      "*BFGSUP ", 0.13392787087084351, "  ", 121.24496907168596],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]3.6288311933247233`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 3.6288311933247233, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]2\),
      SequenceForm[ "BFGS: Iteration = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    43.189348706395180\"\>",
            43.18934870639518,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.021759470402980\"\>",
            67.021759470402984,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 43.18934870639518, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.021759470402984, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.722518221055690\"\>",
            67.722518221055694,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.021759470402980\"\>",
            67.021759470402984,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 2, "  LIKNEU  ", 
        PaddedForm[ 67.722518221055694, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.021759470402984, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.722518221055690\"\>",
            67.722518221055694,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 67.722518221055694, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.021759470402980\"\>",
            67.021759470402984,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 67.021759470402984, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.700758750652710\"\>",
            0.70075875065271021,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.70075875065271021, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 10.0130\"\>",
                10.013489134065983,
                AutoDelete->True], 
              InterpretationBox["\<\" 10.0080\"\>",
                10.007792024145136,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0057\"\>",
                0.0056971099208474882,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1138\"\>",
                -0.11381750590412661,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-0.9168\"\>",
                -0.91682991906059264,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9566\"\>",
                -0.9565769864028888,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0397\"\>",
                0.039747067342296195,
                AutoDelete->True], 
              InterpretationBox["\<\" 6.4711\"\>",
                6.4711389541625977,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 2.0009\"\>",
                2.0009324303430893,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.0018\"\>",
                2.0017650699224818,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0008\"\>",
                -0.00083263957939233981,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9119\"\>",
                -1.9118835767915516,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.0060\"\>",
                30.006062576146224,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.0090\"\>",
                30.008689639835666,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0026\"\>",
                -0.0026270636894432562,
                AutoDelete->True], 
              InterpretationBox["\<\"-8.1047\"\>",
                -8.1046741566099563,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 1.1250\"\>",
                1.125,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0625\"\>",
                1.0625,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0625\"\>",
                0.062499999999999993,
                AutoDelete->True], 
              InterpretationBox["\<\" 14.0140\"\>",
                14.014236450195312,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-1.9819\"\>",
                -1.98194894459754,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9519\"\>",
                -1.9518687644473853,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0301\"\>",
                -0.030080180150154581,
                AutoDelete->True], 
              InterpretationBox["\<\"-58.6860\"\>",
                -58.686331086704826,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 5.076\"\>",
                  5.0760983042029135,
                  AutoDelete->True], 
                InterpretationBox["\<\" 17.46\"\>",
                  17.460489280270632,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.318\"\>",
                  2.3181372634386923,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.45\"\>",
                  10.445349572418024,
                  AutoDelete->True], 
                InterpretationBox["\<\" 21.66\"\>",
                  21.655543163798935,
                  AutoDelete->True], 
                InterpretationBox["\<\" 68.06\"\>",
                  68.057775013830565,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 17.46\"\>",
                  17.460489280270632,
                  AutoDelete->True], 
                InterpretationBox["\<\" 75.78\"\>",
                  75.782031201541784,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9332794408130312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.757703780992841,
                  AutoDelete->True], 
                InterpretationBox["\<\" 92.74\"\>",
                  92.738639315620375,
                  AutoDelete->True], 
                InterpretationBox["\<\" 291.6\"\>",
                  291.63384952548125,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 2.318\"\>",
                  2.3181372634386923,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9332794408130312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.317\"\>",
                  2.317498434220536,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.937\"\>",
                  5.9367850110039706,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.32\"\>",
                  12.322636784810967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 38.68\"\>",
                  38.679009098171697,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 10.45\"\>",
                  10.445349572418024,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.757703780992841,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.937\"\>",
                  5.9367850110039706,
                  AutoDelete->True], 
                InterpretationBox["\<\" 27.75\"\>",
                  27.751705226856298,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.52\"\>",
                  55.522980148848859,
                  AutoDelete->True], 
                InterpretationBox["\<\" 174.3\"\>",
                  174.2919679714287,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 21.66\"\>",
                  21.655543163798935,
                  AutoDelete->True], 
                InterpretationBox["\<\" 92.74\"\>",
                  92.738639315620375,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.32\"\>",
                  12.322636784810967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.52\"\>",
                  55.522980148848859,
                  AutoDelete->True], 
                InterpretationBox["\<\" 116.\"\>",
                  115.99793059611332,
                  AutoDelete->True], 
                InterpretationBox["\<\" 361.8\"\>",
                  361.78749908609041,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 68.06\"\>",
                  68.057775013830565,
                  AutoDelete->True], 
                InterpretationBox["\<\" 291.6\"\>",
                  291.63384952548125,
                  AutoDelete->True], 
                InterpretationBox["\<\" 38.68\"\>",
                  38.679009098171697,
                  AutoDelete->True], 
                InterpretationBox["\<\" 174.3\"\>",
                  174.2919679714287,
                  AutoDelete->True], 
                InterpretationBox["\<\" 361.8\"\>",
                  361.78749908609041,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1137.\"\>",
                  1136.5334734698897,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.492126156995592`*^-7, 1.4901161193847656`*^-8, 
          2.981621668253972`*^-8, 4.4712517523983455`*^-7, 
          1.6763806343078613`*^-8, 2.953334070142418`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.492126156995592*^-07, 1.4901161193847656*^-08, 
        2.9816216682539721*^-08, 4.4712517523983455*^-07, 
        1.6763806343078613*^-08, 2.9533340701424182*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.1176439657215923`*^-6\),
      SequenceForm[ "NOISE  ", 1.1176439657215923*^-06],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.22524057276957554`\
\[InvisibleSpace]"  "\[InvisibleSpace]233.18212946375473`\),
      SequenceForm[ 
      "*BFGSUP ", 0.22524057276957554, "  ", 233.18212946375473],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.7999703739256904`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.79997037392569037, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]3\),
      SequenceForm[ "BFGS: Iteration = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.337901941444890\"\>",
            68.337901941444898,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.722518221055690\"\>",
            67.722518221055694,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 68.337901941444898, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.722518221055694, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.337901941444890\"\>",
            68.337901941444898,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 68.337901941444898, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.722518221055690\"\>",
            67.722518221055694,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 67.722518221055694, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.615383720389204\"\>",
            0.61538372038920386,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.61538372038920386, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 9.8069\"\>",
                9.8069172155843916,
                AutoDelete->True], 
              InterpretationBox["\<\" 10.0130\"\>",
                10.013489134065983,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2066\"\>",
                -0.20657191848159093,
                AutoDelete->True], 
              InterpretationBox["\<\"-5.4103\"\>",
                -5.4103027924782001,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-1.1668\"\>",
                -1.1668299190605926,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9168\"\>",
                -0.91682991906059264,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2500\"\>",
                -0.25,
                AutoDelete->True], 
              InterpretationBox["\<\"-16.3170\"\>",
                -16.317485809326172,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 2.0087\"\>",
                2.0086788351749112,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.0009\"\>",
                2.0009324303430893,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0077\"\>",
                0.007746404831822094,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0222\"\>",
                0.022159735628548644,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.0870\"\>",
                30.086930559951917,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.0060\"\>",
                30.006062576146224,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0809\"\>",
                0.08086798380569192,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5929\"\>",
                0.59292897249612164,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 1.3596\"\>",
                1.3596216593428558,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1250\"\>",
                1.125,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2346\"\>",
                0.23462165934285589,
                AutoDelete->True], 
              InterpretationBox["\<\"-14.3640\"\>",
                -14.363837348090277,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-1.9945\"\>",
                -1.9945338334198872,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9819\"\>",
                -1.98194894459754,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0126\"\>",
                -0.012584888822347125,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9828\"\>",
                -1.9827919457192673,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 11.39\"\>",
                  11.394710708618391,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.65\"\>",
                  44.647310157165265,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.01075\"\>",
                  0.010746334972214555,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.06879\"\>",
                  0.068789833397804756,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.51\"\>",
                  55.510915469533778,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.408\"\>",
                  0.40803711964667855,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 44.65\"\>",
                  44.647310157165265,
                  AutoDelete->True], 
                InterpretationBox["\<\" 192.7\"\>",
                  192.73323200902558,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.0122\"\>",
                  0.01220429744639695,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1399\"\>",
                  0.13994501053463893,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.4\"\>",
                  238.35551059710508,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7699\"\>",
                  0.76988328775240689,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.01075\"\>",
                  0.010746334972214555,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.0122\"\>",
                  0.01220429744639695,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.158\"\>",
                  3.1581783965686223,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.718\"\>",
                  9.7178883717061364,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.02609\"\>",
                  -0.026091806077364055,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.32\"\>",
                  63.324080411246797,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.06879\"\>",
                  0.068789833397804756,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1399\"\>",
                  0.13994501053463893,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.718\"\>",
                  9.7178883717061364,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.757748192579427,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.01407\"\>",
                  -0.01407085453598711,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.13808798014713,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.51\"\>",
                  55.510915469533778,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.4\"\>",
                  238.35551059710505,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.02609\"\>",
                  -0.026091806077364055,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.01407\"\>",
                  -0.014070854535994215,
                  AutoDelete->True], 
                InterpretationBox["\<\" 297.3\"\>",
                  297.2888193045398,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.242\"\>",
                  -0.24200597425658543,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.408\"\>",
                  0.40803711964667855,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7699\"\>",
                  0.76988328775240689,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.32\"\>",
                  63.324080411246804,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.13808798014719,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.242\"\>",
                  -0.24200597425658543,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1859.\"\>",
                  1859.0160255215301,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4613445424414264`*^-7, 1.7387120709726105`*^-8, 
          2.99316471096115`*^-8, 4.4833020210194463`*^-7, 
          2.025994150851452`*^-8, 2.972087015837263`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4613445424414264*^-07, 1.7387120709726105*^-08, 
        2.9931647109611499*^-08, 4.4833020210194463*^-07, 
        2.0259941508514521*^-08, 2.9720870158372629*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]4.834525701575032`*^-7\),
      SequenceForm[ "NOISE  ", 4.8345257015750325*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.3888569379207623`\
\[InvisibleSpace]"  "\[InvisibleSpace]5.798509681925723`\),
      SequenceForm[ 
      "*BFGSUP ", 0.38885693792076231, "  ", 5.7985096819257231],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.3916321434397414`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.3916321434397414, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]4\),
      SequenceForm[ "BFGS: Iteration = ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.404502172892610\"\>",
            69.404502172892606,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 69.404502172892606, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.337901941444890\"\>",
            68.337901941444898,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 68.337901941444898, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.066600231447708\"\>",
            1.0666002314477083,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.0666002314477083, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 9.1448\"\>",
                9.1447972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\" 9.8069\"\>",
                9.8069172155843916,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.6621\"\>",
                -0.6621199738156428,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.7290\"\>",
                -2.7290246697476697,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-0.8291\"\>",
                -0.82909515287163482,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.1668\"\>",
                -1.1668299190605926,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3377\"\>",
                0.33773476618895787,
                AutoDelete->True], 
              InterpretationBox["\<\"-10.3050\"\>",
                -10.304541486243146,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 1.7499\"\>",
                1.7499452800353639,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.0087\"\>",
                2.0086788351749112,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2587\"\>",
                -0.25873355513954738,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4489\"\>",
                -0.4489067842948975,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.1390\"\>",
                30.139464090120299,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.0870\"\>",
                30.086930559951917,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0525\"\>",
                0.052533530168381082,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.5874\"\>",
                -0.58737620421505909,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 1.1574\"\>",
                1.1574431112692398,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.3596\"\>",
                1.3596216593428558,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2022\"\>",
                -0.2021785480736159,
                AutoDelete->True], 
              InterpretationBox["\<\"-16.1260\"\>",
                -16.126466971824168,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-1.9949\"\>",
                -1.9948573484209371,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9945\"\>",
                -1.9945338334198872,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0003\"\>",
                -0.00032351500104979309,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.8336\"\>",
                -1.8335692656607869,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.79\"\>",
                  12.791931572162721,
                  AutoDelete->True], 
                InterpretationBox["\<\" 46.7\"\>",
                  46.69912137767168,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.4747\"\>",
                  -0.47467594755115017,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.009\"\>",
                  -1.0085850664440215,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.96\"\>",
                  49.960600294574263,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.05114\"\>",
                  0.051140886461585433,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 46.7\"\>",
                  46.69912137767168,
                  AutoDelete->True], 
                InterpretationBox["\<\" 194.1\"\>",
                  194.07259950377934,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.072\"\>",
                  -1.0719575670631176,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.158\"\>",
                  -2.1576100042315249,
                  AutoDelete->True], 
                InterpretationBox["\<\" 223.\"\>",
                  223.03714970762968,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.4269\"\>",
                  -0.42685128022350982,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.4747\"\>",
                  -0.47467594755115017,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.072\"\>",
                  -1.0719575670631176,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.244\"\>",
                  3.2444437177962011,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9334660135676174,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.312\"\>",
                  0.3119882180935119,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.3\"\>",
                  63.298845215597233,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-1.009\"\>",
                  -1.0085850664440212,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.158\"\>",
                  -2.1576100042315249,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9334660135676174,
                  AutoDelete->True], 
                InterpretationBox["\<\" 45.28\"\>",
                  45.28267752701295,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.202\"\>",
                  1.2017896151672824,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.12576335603671,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.96\"\>",
                  49.960600294574263,
                  AutoDelete->True], 
                InterpretationBox["\<\" 223.\"\>",
                  223.03714970762965,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.312\"\>",
                  0.3119882180935119,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.202\"\>",
                  1.2017896151672753,
                  AutoDelete->True], 
                InterpretationBox["\<\" 288.6\"\>",
                  288.64050988069573,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.705\"\>",
                  -1.7048724332964527,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.05114\"\>",
                  0.051140886461585378,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.4269\"\>",
                  -0.42685128022351004,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.3\"\>",
                  63.29884521559724,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.12576335603677,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.705\"\>",
                  -1.7048724332964527,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1859.\"\>",
                  1858.8368680989829,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.3626809778464957`*^-7, 1.4901161193847656`*^-8, 
          2.6076216698219834`*^-8, 4.4911301270306556`*^-7, 
          1.724724637373149`*^-8, 2.97256909075519`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.3626809778464957*^-07, 1.4901161193847656*^-08, 
        2.6076216698219834*^-08, 4.4911301270306556*^-07, 
        1.7247246373731491*^-08, 2.9725690907551901*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]2.588401632614179`*^-7\),
      SequenceForm[ "NOISE  ", 2.5884016326141789*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.8236939929380115`\
\[InvisibleSpace]"  "\[InvisibleSpace]0.5977111246245793`\),
      SequenceForm[ 
      "*BFGSUP ", 0.82369399293801149, "  ", 0.59771112462457932],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.15984363994110137`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.15984363994110137, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]5\),
      SequenceForm[ "BFGS: Iteration = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.533065245439070\"\>",
            69.533065245439062,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.404502172892610\"\>",
            69.404502172892606,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 69.533065245439062, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 69.404502172892606, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.533065245439070\"\>",
            69.533065245439062,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 69.533065245439062, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.404502172892610\"\>",
            69.404502172892606,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 69.404502172892606, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.128563072546456\"\>",
            0.12856307254645571,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.12856307254645571, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 8.8948\"\>",
                8.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\" 9.1448\"\>",
                9.1447972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2500\"\>",
                -0.24999999999999994,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2807\"\>",
                -0.28074719087847305,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-0.7027\"\>",
                -0.70272928026170733,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.8291\"\>",
                -0.82909515287163482,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1264\"\>",
                0.12636587260992752,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2440\"\>",
                1.2440023422241211,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 1.6847\"\>",
                1.6846932234861967,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.7499\"\>",
                1.7499452800353639,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0653\"\>",
                -0.065252056549167131,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1114\"\>",
                -0.11135830989387613,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.2670\"\>",
                30.267296923700179,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.1390\"\>",
                30.139464090120299,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1278\"\>",
                0.12783283357988154,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3681\"\>",
                0.36808445639389448,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 1.0975\"\>",
                1.0975379585978724,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1574\"\>",
                1.1574431112692398,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0599\"\>",
                -0.059905152671367479,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.9653\"\>",
                0.96527790119808077,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0124\"\>",
                -2.012361103782716,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9949\"\>",
                -1.9948573484209371,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0175\"\>",
                -0.017503755361778915,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0484\"\>",
                0.048449163544641065,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.28\"\>",
                  13.277706123881059,
                  AutoDelete->True], 
                InterpretationBox["\<\" 53.18\"\>",
                  53.179835596417789,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.5262\"\>",
                  -0.52620764046774449,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.03988\"\>",
                  -0.039882552599517673,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.12\"\>",
                  58.12336718135623,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8556\"\>",
                  0.85561819119767768,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 53.18\"\>",
                  53.179835596417789,
                  AutoDelete->True], 
                InterpretationBox["\<\" 240.5\"\>",
                  240.4606279108126,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6259\"\>",
                  -0.62591843929971791,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.313\"\>",
                  3.3134454805530429,
                  AutoDelete->True], 
                InterpretationBox["\<\" 286.3\"\>",
                  286.29664179076821,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.183\"\>",
                  6.1825772543601794,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.5262\"\>",
                  -0.52620764046774438,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6259\"\>",
                  -0.62591843929971791,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.218\"\>",
                  3.217845432460372,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.04\"\>",
                  10.041516321871068,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7371\"\>",
                  0.73712126952538637,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.330138283664894,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.03988\"\>",
                  -0.039882552599517451,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.313\"\>",
                  3.3134454805530429,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.04\"\>",
                  10.041516321871068,
                  AutoDelete->True], 
                InterpretationBox["\<\" 45.83\"\>",
                  45.828415156135343,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.991\"\>",
                  8.9914151507561471,
                  AutoDelete->True], 
                InterpretationBox["\<\" 286.\"\>",
                  285.96319355681135,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 58.12\"\>",
                  58.12336718135623,
                  AutoDelete->True], 
                InterpretationBox["\<\" 286.3\"\>",
                  286.29664179076815,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7371\"\>",
                  0.73712126952538548,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.991\"\>",
                  8.99141515075614,
                  AutoDelete->True], 
                InterpretationBox["\<\" 373.8\"\>",
                  373.82186625583046,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.117\"\>",
                  7.117158027549122,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.8556\"\>",
                  0.85561819119767768,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.183\"\>",
                  6.1825772543601802,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.330138283664901,
                  AutoDelete->True], 
                InterpretationBox["\<\" 286.\"\>",
                  285.9631935568114,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.117\"\>",
                  7.117158027549122,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.7448961525931,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.3254280748618766`*^-7, 1.4901161193847656`*^-8, 
          2.510388528535063`*^-8, 4.5101787036210566`*^-7, 
          1.6354590037433392`*^-8, 2.9986517187695444`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.3254280748618766*^-07, 1.4901161193847656*^-08, 
        2.5103885285350631*^-08, 4.5101787036210566*^-07, 
        1.6354590037433392*^-08, 2.9986517187695444*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.97775086580779`*^-8\),
      SequenceForm[ "NOISE  ", 5.9777508658077906*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]5.292878979544825`\
\[InvisibleSpace]"  "\[InvisibleSpace]18.805009614435857`\),
      SequenceForm[ "*BFGSUP ", 5.2928789795448248, "  ", 18.805009614435857],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.4481257410250421`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.4481257410250421, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]6\),
      SequenceForm[ "BFGS: Iteration = ", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.096291944916570\"\>",
            70.096291944916572,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.096291944916572, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.533065245439070\"\>",
            69.533065245439062,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 69.533065245439062, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.563226699477511\"\>",
            0.56322669947751081,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.56322669947751081, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 7.8948\"\>",
                7.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\" 8.8948\"\>",
                8.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.0000\"\>",
                -1.0,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1536\"\>",
                -0.15357272695468543,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\"-0.2828\"\>",
                -0.28279614498223427,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.7027\"\>",
                -0.70272928026170733,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.4199\"\>",
                0.41993313527947307,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.0452\"\>",
                2.0452356338500977,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 1.2736\"\>",
                1.2735660969701037,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.6847\"\>",
                1.6846932234861967,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4111\"\>",
                -0.41112712651609284,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.6581\"\>",
                -0.65814491467924863,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.3720\"\>",
                30.372136350589198,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.2670\"\>",
                30.267296923700179,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1048\"\>",
                0.10483942688901766,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.0295\"\>",
                -1.0294793244142042,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.9338\"\>",
                0.93381924887754952,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0975\"\>",
                1.0975379585978724,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1637\"\>",
                -0.16371870972032287,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.7676\"\>",
                2.7675983565696511,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0147\"\>",
                -2.0146968822925766,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0124\"\>",
                -2.012361103782716,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0023\"\>",
                -0.002335778509860633,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.4737\"\>",
                0.47373801130157195,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.28\"\>",
                  13.279049933267451,
                  AutoDelete->True], 
                InterpretationBox["\<\" 54.09\"\>",
                  54.092519377376362,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.9277\"\>",
                  -0.9276817273622664,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.8701\"\>",
                  -0.87013735762283984,
                  AutoDelete->True], 
                InterpretationBox["\<\" 59.63\"\>",
                  59.626249136581968,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.156\"\>",
                  1.1564291054707203,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 54.09\"\>",
                  54.092519377376362,
                  AutoDelete->True], 
                InterpretationBox["\<\" 242.2\"\>",
                  242.20415639123061,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.797\"\>",
                  -2.7966554178980054,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.103\"\>",
                  -3.1028920622588045,
                  AutoDelete->True], 
                InterpretationBox["\<\" 292.7\"\>",
                  292.65627998464862,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.922\"\>",
                  7.9217240355851217,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.9277\"\>",
                  -0.9276817273622664,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.797\"\>",
                  -2.7966554178980054,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.787\"\>",
                  4.7870303808448531,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.13\"\>",
                  14.129989869373603,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.364\"\>",
                  -4.3640181795848818,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.11\"\>",
                  62.105087963534316,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.8701\"\>",
                  -0.87013735762283961,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.103\"\>",
                  -3.1028920622588045,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.13\"\>",
                  14.129989869373603,
                  AutoDelete->True], 
                InterpretationBox["\<\" 56.02\"\>",
                  56.0215458736089,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.72\"\>",
                  -4.7204241905745015,
                  AutoDelete->True], 
                InterpretationBox["\<\" 282.8\"\>",
                  282.79820973206222,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 59.63\"\>",
                  59.626249136581968,
                  AutoDelete->True], 
                InterpretationBox["\<\" 292.7\"\>",
                  292.65627998464856,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.364\"\>",
                  -4.3640181795848827,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.72\"\>",
                  -4.7204241905745086,
                  AutoDelete->True], 
                InterpretationBox["\<\" 390.\"\>",
                  390.01895789499224,
                  AutoDelete->True], 
                InterpretationBox["\<\" 11.12\"\>",
                  11.124190544572921,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.156\"\>",
                  1.1564291054707203,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.922\"\>",
                  7.9217240355851226,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.11\"\>",
                  62.105087963534324,
                  AutoDelete->True], 
                InterpretationBox["\<\" 282.8\"\>",
                  282.79820973206228,
                  AutoDelete->True], 
                InterpretationBox["\<\" 11.12\"\>",
                  11.124190544572919,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1861.\"\>",
                  1860.6997130170446,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: "\[InvisibleSpace]{1.1764164629234`*^-7, 
          1.4901161193847656`*^-8, 1.897761370197093`*^-8, 
          4.5258009956164953`*^-7, 1.4901161193847656`*^-8, 
          3.0021322999784`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.1764164629234*^-07, 1.4901161193847656*^-08, 
        1.897761370197093*^-08, 4.5258009956164953*^-07, 
        1.4901161193847656*^-08, 3.0021322999784002*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.4396167407452337`*^-7\),
      SequenceForm[ "NOISE  ", 1.4396167407452337*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]3.1700978194913225`\
\[InvisibleSpace]"  "\[InvisibleSpace]5.566406268584245`\),
      SequenceForm[ "*BFGSUP ", 3.1700978194913225, "  ", 5.5664062685842453],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.09834337678699115`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.098343376786991149, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]7\),
      SequenceForm[ "BFGS: Iteration = ", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.516070761046150\"\>",
            70.516070761046151,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.516070761046151, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.096291944916570\"\>",
            70.096291944916572,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.096291944916572, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.419778816129579\"\>",
            0.41977881612957901,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.41977881612957901, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 6.8948\"\>",
                6.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\" 7.8948\"\>",
                7.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.0000\"\>",
                -0.99999999999999989,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5739\"\>",
                0.57388871140331854,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.1159\"\>",
                0.11588066525288843,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2828\"\>",
                -0.28279614498223427,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3987\"\>",
                0.39867681023512269,
                AutoDelete->True], 
              InterpretationBox["\<\" 4.7579\"\>",
                4.7579498291015625,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 0.8169\"\>",
                0.81693247181849404,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2736\"\>",
                1.2735660969701037,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4566\"\>",
                -0.45663362515160966,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.3245\"\>",
                -0.32447281118697141,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.5280\"\>",
                30.528304094627906,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.3720\"\>",
                30.372136350589198,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1562\"\>",
                0.15616774403870792,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2058\"\>",
                -0.20581064102533148,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.8028\"\>",
                0.80282576226805724,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.9338\"\>",
                0.93381924887754952,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1310\"\>",
                -0.13099348660949225,
                AutoDelete->True], 
              InterpretationBox["\<\" 6.8935\"\>",
                6.8935060501098633,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0231\"\>",
                -2.0230555105446348,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0147\"\>",
                -2.0146968822925766,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0084\"\>",
                -0.008358628252058414,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.8282\"\>",
                0.82815242302739123,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 14.95\"\>",
                  14.948512789254982,
                  AutoDelete->True], 
                InterpretationBox["\<\" 60.46\"\>",
                  60.456958579317913,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.1931\"\>",
                  -0.19313424222572384,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.9747\"\>",
                  0.97468835415027544,
                  AutoDelete->True], 
                InterpretationBox["\<\" 69.29\"\>",
                  69.288038805296836,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.999\"\>",
                  1.9989039993744102,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 60.46\"\>",
                  60.456958579317913,
                  AutoDelete->True], 
                InterpretationBox["\<\" 264.1\"\>",
                  264.0862395687015,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5381\"\>",
                  0.53812453800775728,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.708\"\>",
                  4.7082007009034754,
                  AutoDelete->True], 
                InterpretationBox["\<\" 326.2\"\>",
                  326.18046968741442,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.63\"\>",
                  10.634577306641155,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.1931\"\>",
                  -0.19313424222572384,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5381\"\>",
                  0.53812453800775728,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.99\"\>",
                  4.9902349448205428,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.77\"\>",
                  14.767011585758212,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.63\"\>",
                  0.62995604166878039,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.58776558001481,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.9747\"\>",
                  0.97468835415027544,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.708\"\>",
                  4.7082007009034736,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.77\"\>",
                  14.767011585758212,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.81\"\>",
                  57.805845255082382,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.038\"\>",
                  7.0377606540937983,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.89222761550769,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 69.29\"\>",
                  69.288038805296836,
                  AutoDelete->True], 
                InterpretationBox["\<\" 326.2\"\>",
                  326.18046968741436,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.63\"\>",
                  0.6299560416687795,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.038\"\>",
                  7.0377606540937911,
                  AutoDelete->True], 
                InterpretationBox["\<\" 441.3\"\>",
                  441.33591385115744,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.31\"\>",
                  15.30650197480691,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.999\"\>",
                  1.9989039993744102,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.63\"\>",
                  10.634577306641155,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.587765580014818,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.89222761550775,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.31\"\>",
                  15.306501974806908,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1861.\"\>",
                  1861.02032131276,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.0274048509849235`*^-7, 1.4901161193847656`*^-8, 
          1.4901161193847656`*^-8, 4.5490718028884986`*^-7, 
          1.4901161193847656`*^-8, 3.014587626672737`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.0274048509849235*^-07, 1.4901161193847656*^-08, 
        1.4901161193847656*^-08, 4.5490718028884986*^-07, 
        1.4901161193847656*^-08, 3.0145876266727371*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.9336034995376394`*^-7\),
      SequenceForm[ "NOISE  ", 1.9336034995376394*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.570722748052135`\
\[InvisibleSpace]"  "\[InvisibleSpace]3.5952814314821993`\),
      SequenceForm[ "*BFGSUP ", 4.5707227480521349, "  ", 3.5952814314821993],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.08625959036404267`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.086259590364042668, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]8\),
      SequenceForm[ "BFGS: Iteration = ", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.775646916609270\"\>",
            70.775646916609276,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.775646916609276, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.516070761046150\"\>",
            70.516070761046151,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.516070761046151, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.259576155563124\"\>",
            0.25957615556312419,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.25957615556312419, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8948\"\>",
                5.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\" 6.8948\"\>",
                6.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.0000\"\>",
                -0.99999999999999978,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6333\"\>",
                0.63328022228225589,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5024\"\>",
                0.50237805283116577,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1159\"\>",
                0.11588066525288843,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3865\"\>",
                0.38649738757827734,
                AutoDelete->True], 
              InterpretationBox["\<\" 4.1377\"\>",
                4.1376867294311523,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\" 0.2498\"\>",
                0.24981701997194417,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.8169\"\>",
                0.81693247181849404,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.5671\"\>",
                -0.56711545184654988,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1908\"\>",
                -0.19079971313476562,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.7370\"\>",
                30.737232754643326,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.5280\"\>",
                30.528304094627906,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2089\"\>",
                0.20892866001541927,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0603\"\>",
                0.060316894257261652,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.6898\"\>",
                0.68978862930524654,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.8028\"\>",
                0.80282576226805724,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1130\"\>",
                -0.11303713296281069,
                AutoDelete->True], 
              InterpretationBox["\<\" 6.0827\"\>",
                6.0826873779296875,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0356\"\>",
                -2.0355937256893877,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0231\"\>",
                -2.0230555105446348,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0125\"\>",
                -0.012538215144752967,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6894\"\>",
                0.68944848497370081,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 14.64\"\>",
                  14.637401507786445,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.58\"\>",
                  57.575577048360103,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.02817\"\>",
                  0.028168743194675161,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.164\"\>",
                  1.1642860201110841,
                  AutoDelete->True], 
                InterpretationBox["\<\" 65.14\"\>",
                  65.137225251113961,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.489\"\>",
                  1.4890350364012708,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 57.58\"\>",
                  57.575577048360103,
                  AutoDelete->True], 
                InterpretationBox["\<\" 243.4\"\>",
                  243.35196749072091,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.693\"\>",
                  1.6930684850961351,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.927\"\>",
                  4.9266656320589606,
                  AutoDelete->True], 
                InterpretationBox["\<\" 295.9\"\>",
                  295.89079603735951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.113\"\>",
                  7.1127992104651261,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.02817\"\>",
                  0.028168743194675161,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.693\"\>",
                  1.6930684850961351,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.967\"\>",
                  4.9673002034393061,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.86\"\>",
                  14.863259669888629,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.357\"\>",
                  2.356955136002477,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.77\"\>",
                  62.770007677294089,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.164\"\>",
                  1.1642860201110841,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.927\"\>",
                  4.9266656320589588,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.86\"\>",
                  14.863259669888629,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.09\"\>",
                  58.087475425893082,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.461\"\>",
                  7.4611331675210222,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.89285714851036,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 65.14\"\>",
                  65.137225251113961,
                  AutoDelete->True], 
                InterpretationBox["\<\" 295.9\"\>",
                  295.89079603735945,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.357\"\>",
                  2.3569551360024761,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.461\"\>",
                  7.4611331675210151,
                  AutoDelete->True], 
                InterpretationBox["\<\" 397.1\"\>",
                  397.1254869076692,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.15\"\>",
                  10.148319963205022,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.489\"\>",
                  1.4890350364012708,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.113\"\>",
                  7.1127992104651261,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.77\"\>",
                  62.770007677294096,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.89285714851042,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.15\"\>",
                  10.148319963205019,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1860.4268231077963,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.783932390464469`*^-8, 1.4901161193847656`*^-8, 
          1.4901161193847656`*^-8, 4.5802045992975423`*^-7, 
          1.4901161193847656`*^-8, 3.0332710231682475`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7839323904644691*^-08, 1.4901161193847656*^-08, 
        1.4901161193847656*^-08, 4.5802045992975423*^-07, 
        1.4901161193847656*^-08, 3.0332710231682475*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.303385204209917`*^-7\),
      SequenceForm[ "NOISE  ", 1.303385204209917*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]3.815375877458653`\
\[InvisibleSpace]"  "\[InvisibleSpace]3.5169610597815137`\),
      SequenceForm[ "*BFGSUP ", 3.8153758774586528, "  ", 3.5169610597815137],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.05947457526699041`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.059474575266990411, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]9\),
      SequenceForm[ "BFGS: Iteration = ", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.833717359659530\"\>",
            70.833717359659531,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.833717359659531, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.775646916609270\"\>",
            70.775646916609276,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.775646916609276, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.058070443050255\"\>",
            0.058070443050254994,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.058070443050254994, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.4814\"\>",
                5.4813996544259886,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8948\"\>",
                5.8947972417687495,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4134\"\>",
                -0.41339758734276116,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3486\"\>",
                0.34856757568463742,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.6566\"\>",
                0.65656327980800633,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5024\"\>",
                0.50237805283116577,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1542\"\>",
                0.15418522697684051,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.7781\"\>",
                1.7780742645263672,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-0.1526\"\>",
                -0.15259537987718558,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2498\"\>",
                0.24981701997194417,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4024\"\>",
                -0.40241239984912974,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1160\"\>",
                -0.11600780487060547,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 30.8930\"\>",
                30.892589701399256,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.7370\"\>",
                30.737232754643326,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1554\"\>",
                0.15535694675592826,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1369\"\>",
                0.13694634039480766,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.6512\"\>",
                0.65123991421462391,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6898\"\>",
                0.68978862930524654,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0385\"\>",
                -0.038548715090622673,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.6642\"\>",
                2.6641826629638672,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0456\"\>",
                -2.045578056665061,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0356\"\>",
                -2.0355937256893877,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0100\"\>",
                -0.0099843309756731929,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2778\"\>",
                0.27777747500897654,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 14.2\"\>",
                  14.198956427984843,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.25\"\>",
                  55.253355699418435,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1722\"\>",
                  0.17220371755188982,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.01\"\>",
                  1.009827394544843,
                  AutoDelete->True], 
                InterpretationBox["\<\" 61.67\"\>",
                  61.668769221972312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.122\"\>",
                  1.1221842277149594,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.25\"\>",
                  55.253355699418442,
                  AutoDelete->True], 
                InterpretationBox["\<\" 232.7\"\>",
                  232.674958238469,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.492\"\>",
                  2.4916539900142314,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.771\"\>",
                  3.7714712474708039,
                  AutoDelete->True], 
                InterpretationBox["\<\" 279.7\"\>",
                  279.74210029237463,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.5\"\>",
                  5.5002501167167797,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1722\"\>",
                  0.17220371755188982,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.492\"\>",
                  2.4916539900142318,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.921\"\>",
                  4.9207685033388158,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.91\"\>",
                  14.906583460952058,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.545\"\>",
                  3.5452820450917364,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.9\"\>",
                  62.897794963388378,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.01\"\>",
                  1.009827394544843,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.771\"\>",
                  3.7714712474708021,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.91\"\>",
                  14.906583460952058,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.1\"\>",
                  58.103096497004536,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.778\"\>",
                  5.7776202784299082,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.69496314261488,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 61.67\"\>",
                  61.668769221972312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 279.7\"\>",
                  279.74210029237457,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.545\"\>",
                  3.5452820450917355,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.778\"\>",
                  5.7776202784299011,
                  AutoDelete->True], 
                InterpretationBox["\<\" 372.7\"\>",
                  372.72985698031641,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.699\"\>",
                  7.6987714632309325,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.122\"\>",
                  1.1221842277149594,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.5\"\>",
                  5.5002501167167797,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.9\"\>",
                  62.897794963388385,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.69496314261494,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.699\"\>",
                  7.698771463230929,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1860.1871823340059,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.16792198185025`*^-8, 1.4901161193847656`*^-8, 
          1.4901161193847656`*^-8, 4.6033545883594835`*^-7, 
          1.4901161193847656`*^-8, 3.048148835696371`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.1679219818502495*^-08, 1.4901161193847656*^-08, 
        1.4901161193847656*^-08, 4.6033545883594835*^-07, 
        1.4901161193847656*^-08, 3.0481488356963709*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]4.120775543015043`*^-8\),
      SequenceForm[ "NOISE  ", 4.1207755430150428*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]14.498256510124842`\
\[InvisibleSpace]"  "\[InvisibleSpace]10.806127021335584`\),
      SequenceForm[ "*BFGSUP ", 14.498256510124842, "  ", 10.806127021335584],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.0393053414624484`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.0393053414624484, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]10\),
      SequenceForm[ "BFGS: Iteration = ", 10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.863705932376700\"\>",
            70.863705932376703,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.863705932376703, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.833717359659530\"\>",
            70.833717359659531,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.833717359659531, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.029988572717173\"\>",
            0.029988572717172701,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.029988572717172701, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.4099\"\>",
                5.4099198479793493,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.4814\"\>",
                5.4813996544259886,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0715\"\>",
                -0.071479806446639121,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0750\"\>",
                0.075037439678520196,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.6803\"\>",
                0.68028173066113351,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6566\"\>",
                0.65656327980800633,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0237\"\>",
                0.023718450853127186,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0162\"\>",
                0.0162353515625,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-0.4493\"\>",
                -0.44926872067363854,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1526\"\>",
                -0.15259537987718558,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2967\"\>",
                -0.29667334079645297,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1012\"\>",
                -0.10122299194335938,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.0090\"\>",
                31.009129038828945,
                AutoDelete->True], 
              InterpretationBox["\<\" 30.8930\"\>",
                30.892589701399256,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1165\"\>",
                0.11653933742968758,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0901\"\>",
                0.090123342678191554,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.6488\"\>",
                0.64881394296553652,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6512\"\>",
                0.65123991421462391,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0024\"\>",
                -0.0024259712490874372,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0714\"\>",
                0.071391105651855469,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0533\"\>",
                -2.053300049901861,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0456\"\>",
                -2.045578056665061,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0077\"\>",
                -0.0077219932367999502,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0101\"\>",
                -0.010084645301590334,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.97\"\>",
                  13.970760182997664,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.54\"\>",
                  55.542887041476547,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5505\"\>",
                  0.55053403211576835,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.6797\"\>",
                  0.67968277284165091,
                  AutoDelete->True], 
                InterpretationBox["\<\" 61.92\"\>",
                  61.915943905416654,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.217\"\>",
                  1.2174671071205552,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.54\"\>",
                  55.542887041476554,
                  AutoDelete->True], 
                InterpretationBox["\<\" 243.5\"\>",
                  243.51456321721227,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.343\"\>",
                  4.342981894377929,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.336\"\>",
                  2.3361986403633286,
                  AutoDelete->True], 
                InterpretationBox["\<\" 294.8\"\>",
                  294.78144884726328,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.516\"\>",
                  7.5160396408377288,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.5505\"\>",
                  0.55053403211576835,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.343\"\>",
                  4.3429818943779299,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.779\"\>",
                  4.7785108744453844,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.07\"\>",
                  15.068222021462725,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.329\"\>",
                  6.3293130418991854,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.18\"\>",
                  63.184311038082882,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.6797\"\>",
                  0.67968277284165091,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.336\"\>",
                  2.3361986403633268,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.07\"\>",
                  15.068222021462725,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.93\"\>",
                  57.932221025168836,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.595\"\>",
                  3.595125420558646,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.5\"\>",
                  283.47930722119412,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 61.92\"\>",
                  61.915943905416654,
                  AutoDelete->True], 
                InterpretationBox["\<\" 294.8\"\>",
                  294.78144884726322,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.329\"\>",
                  6.3293130418991854,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.595\"\>",
                  3.5951254205586389,
                  AutoDelete->True], 
                InterpretationBox["\<\" 393.5\"\>",
                  393.4948962940764,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.52\"\>",
                  10.522710492398133,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.217\"\>",
                  1.2174671071205552,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.516\"\>",
                  7.5160396408377297,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.18\"\>",
                  63.184311038082889,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.5\"\>",
                  283.47930722119418,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.52\"\>",
                  10.522710492398133,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1861.\"\>",
                  1860.554770285222,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.061408770053609`*^-8, 1.4901161193847656`*^-8, 
          1.4901161193847656`*^-8, 4.6207203028841235`*^-7, 
          1.4901161193847656`*^-8, 3.059655502292307`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.0614087700536092*^-08, 1.4901161193847656*^-08, 
        1.4901161193847656*^-08, 4.6207203028841235*^-07, 
        1.4901161193847656*^-08, 3.0596555022923067*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.607128297109739`*^-8\),
      SequenceForm[ "NOISE  ", 1.6071282971097389*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]91.32617826947055`\
\[InvisibleSpace]"  "\[InvisibleSpace]28.2014462683518`\),
      SequenceForm[ "*BFGSUP ", 91.326178269470546, "  ", 28.201446268351798],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.01930019595573613`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.019300195955736128, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]11\),
      SequenceForm[ "BFGS: Iteration = ", 11],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.938482236250540\"\>",
            70.938482236250536,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.938482236250536, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.863705932376700\"\>",
            70.863705932376703,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.863705932376703, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.074776303873833\"\>",
            0.074776303873832717,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.074776303873832717, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.4445\"\>",
                5.4445229771911583,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.4099\"\>",
                5.4099198479793493,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0346\"\>",
                0.0346031292118089,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0520\"\>",
                -0.052046885870437556,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.6586\"\>",
                0.65857790767927449,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6803\"\>",
                0.68028173066113351,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0217\"\>",
                -0.021703822981858981,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.6888\"\>",
                -0.68880271911621094,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-1.4096\"\>",
                -1.4096127898130599,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.4493\"\>",
                -0.44926872067363854,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9603\"\>",
                -0.96034406913942127,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0967\"\>",
                -0.096703529357910156,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.3860\"\>",
                31.385511646552317,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.0090\"\>",
                31.009129038828945,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.3764\"\>",
                0.37638260772337223,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0441\"\>",
                0.044105831187065861,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.6645\"\>",
                0.66454482703695916,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6488\"\>",
                0.64881394296553652,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0157\"\>",
                0.015730884071422674,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9773\"\>",
                -0.97730255126953125,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0783\"\>",
                -2.0782746795556362,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0533\"\>",
                -2.053300049901861,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0250\"\>",
                -0.02497462965377507,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1199\"\>",
                -0.11993175310425724,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 15.29\"\>",
                  15.28692529600505,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.69\"\>",
                  63.6912908908999,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7123\"\>",
                  0.71228506517365653,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.023\"\>",
                  1.0230519963818181,
                  AutoDelete->True], 
                InterpretationBox["\<\" 73.94\"\>",
                  73.936139071428713,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.514\"\>",
                  2.5137072223857913,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 63.69\"\>",
                  63.691290890899907,
                  AutoDelete->True], 
                InterpretationBox["\<\" 288.9\"\>",
                  288.90342593740979,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.098\"\>",
                  4.0983267816725402,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.258\"\>",
                  5.2579301649345593,
                  AutoDelete->True], 
                InterpretationBox["\<\" 362.3\"\>",
                  362.2725024603169,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.59\"\>",
                  14.593540089836452,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.7123\"\>",
                  0.71228506517365653,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.098\"\>",
                  4.0983267816725402,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.491\"\>",
                  4.4914215889766771,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.31\"\>",
                  15.306497739827732,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.1\"\>",
                  6.1002652530944248,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.11\"\>",
                  63.110184187471717,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.023\"\>",
                  1.0230519963818181,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.258\"\>",
                  5.2579301649345584,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.31\"\>",
                  15.306497739827732,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.9\"\>",
                  57.896556114729883,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.821\"\>",
                  7.820920760951811,
                  AutoDelete->True], 
                InterpretationBox["\<\" 284.\"\>",
                  283.96658227757968,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 73.94\"\>",
                  73.936139071428713,
                  AutoDelete->True], 
                InterpretationBox["\<\" 362.3\"\>",
                  362.27250246031684,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.1\"\>",
                  6.1002652530944248,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.821\"\>",
                  7.8209207609518039,
                  AutoDelete->True], 
                InterpretationBox["\<\" 493.8\"\>",
                  493.78789268516221,
                  AutoDelete->True], 
                InterpretationBox["\<\" 21.06\"\>",
                  21.063421488130622,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 2.514\"\>",
                  2.5137072223857913,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.59\"\>",
                  14.593540089836454,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.11\"\>",
                  63.110184187471724,
                  AutoDelete->True], 
                InterpretationBox["\<\" 284.\"\>",
                  283.96658227757973,
                  AutoDelete->True], 
                InterpretationBox["\<\" 21.06\"\>",
                  21.063421488130622,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1862.\"\>",
                  1861.6538792148265,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.11297145067328`*^-8, 1.4901161193847656`*^-8, 
          2.10048674019137`*^-8, 4.6768056819665904`*^-7, 
          1.4901161193847656`*^-8, 3.096870600515062`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.1129714506732796*^-08, 1.4901161193847656*^-08, 
        2.1004867401913701*^-08, 4.6768056819665904*^-07, 
        1.4901161193847656*^-08, 3.0968706005150619*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.1843997539435804`*^-8\),
      SequenceForm[ "NOISE  ", 5.1843997539435804*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]14.093937831955715`\
\[InvisibleSpace]"  "\[InvisibleSpace]9.071165798268582`\),
      SequenceForm[ "*BFGSUP ", 14.093937831955715, "  ", 9.0711657982685825],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.03526843470499713`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.035268434704997131, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]12\),
      SequenceForm[ "BFGS: Iteration = ", 12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.975720354251880\"\>",
            70.975720354251877,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.975720354251877, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.938482236250540\"\>",
            70.938482236250536,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.938482236250536, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.037238118001341\"\>",
            0.037238118001340581,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.037238118001340581, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.6430\"\>",
                5.6430398389733032,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.4445\"\>",
                5.4445229771911583,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1985\"\>",
                0.19851686178214506,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2600\"\>",
                -0.25997775570637582,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5811\"\>",
                0.58108892792379052,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6586\"\>",
                0.65857790767927449,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0775\"\>",
                -0.077488979755484022,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.6997\"\>",
                -1.6996746063232422,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.0477\"\>",
                -2.0476626375595055,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.4096\"\>",
                -1.4096127898130599,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.6380\"\>",
                -0.63804984774644558,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0692\"\>",
                -0.069227359071347888,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6330\"\>",
                31.633466546513088,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.3860\"\>",
                31.385511646552317,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2480\"\>",
                0.24795489996076955,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0600\"\>",
                -0.059983207109243035,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.6878\"\>",
                0.68784462019180714,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6645\"\>",
                0.66454482703695916,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0233\"\>",
                0.023299793154848009,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.5019\"\>",
                -2.5018892288208008,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0946\"\>",
                -2.0946391899735639,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0783\"\>",
                -2.0782746795556362,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0164\"\>",
                -0.016364510417927882,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2741\"\>",
                -0.27407859091316822,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 15.87\"\>",
                  15.871707489719855,
                  AutoDelete->True], 
                InterpretationBox["\<\" 66.33\"\>",
                  66.328514788109644,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5861\"\>",
                  0.58610812515911892,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.349\"\>",
                  1.3489151697794524,
                  AutoDelete->True], 
                InterpretationBox["\<\" 77.94\"\>",
                  77.942629174366729,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.909\"\>",
                  2.9088216214335141,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 66.33\"\>",
                  66.328514788109644,
                  AutoDelete->True], 
                InterpretationBox["\<\" 299.\"\>",
                  299.00167782068024,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.103\"\>",
                  3.1026420204234855,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.016\"\>",
                  7.0164879042652641,
                  AutoDelete->True], 
                InterpretationBox["\<\" 377.9\"\>",
                  377.88711674977634,
                  AutoDelete->True], 
                InterpretationBox["\<\" 16.04\"\>",
                  16.040332787845255,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.5861\"\>",
                  0.58610812515911892,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.103\"\>",
                  3.1026420204234855,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.417\"\>",
                  4.417232000026984,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.3\"\>",
                  15.304879768132308,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.653\"\>",
                  4.6525697374267976,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.95\"\>",
                  62.945285437126557,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.349\"\>",
                  1.3489151697794524,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.016\"\>",
                  7.0164879042652633,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.3\"\>",
                  15.304879768132308,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.03\"\>",
                  58.031610917636563,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.45\"\>",
                  10.448536925224678,
                  AutoDelete->True], 
                InterpretationBox["\<\" 284.2\"\>",
                  284.24070310707714,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 77.94\"\>",
                  77.942629174366729,
                  AutoDelete->True], 
                InterpretationBox["\<\" 377.9\"\>",
                  377.88711674977628,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.653\"\>",
                  4.6525697374267967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.45\"\>",
                  10.448536925224671,
                  AutoDelete->True], 
                InterpretationBox["\<\" 517.9\"\>",
                  517.88328758621606,
                  AutoDelete->True], 
                InterpretationBox["\<\" 23.31\"\>",
                  23.312413062664277,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 2.909\"\>",
                  2.9088216214335141,
                  AutoDelete->True], 
                InterpretationBox["\<\" 16.04\"\>",
                  16.040332787845255,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.95\"\>",
                  62.945285437126564,
                  AutoDelete->True], 
                InterpretationBox["\<\" 284.2\"\>",
                  284.24070310707719,
                  AutoDelete->True], 
                InterpretationBox["\<\" 23.31\"\>",
                  23.312413062664277,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1862.\"\>",
                  1861.8582925105943,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.408784626384531`*^-8, 1.4901161193847656`*^-8, 
          3.051255103289344`*^-8, 4.7137538412977886`*^-7, 
          1.4901161193847656`*^-8, 3.121255621274656`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.4087846263845312*^-08, 1.4901161193847656*^-08, 
        3.0512551032893442*^-08, 4.7137538412977886*^-07, 
        1.4901161193847656*^-08, 3.1212556212746559*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]6.567591981365695`*^-8\),
      SequenceForm[ "NOISE  ", 6.5675919813656947*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]27.25523932001748`\
\[InvisibleSpace]"  "\[InvisibleSpace]17.990426476939`\),
      SequenceForm[ "*BFGSUP ", 27.255239320017481, "  ", 17.990426476939],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.03127474483183579`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.031274744831835788, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]13\),
      SequenceForm[ "BFGS: Iteration = ", 13],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.986836840383800\"\>",
            70.986836840383802,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.986836840383802, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.975720354251880\"\>",
            70.975720354251877,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.975720354251877, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.011116486131925\"\>",
            0.011116486131925285,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.011116486131925285, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8180\"\>",
                5.8180065398798959,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.6430\"\>",
                5.6430398389733032,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1750\"\>",
                0.1749667009065923,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2158\"\>",
                -0.21579335905899188,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5170\"\>",
                0.51695870954903966,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5811\"\>",
                0.58108892792379052,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0641\"\>",
                -0.064130218374750886,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.2857\"\>",
                -1.2856817245483398,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.2536\"\>",
                -2.2535663552949159,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0477\"\>",
                -2.0476626375595055,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2059\"\>",
                -0.20590371773541025,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0323\"\>",
                -0.03234084722578015,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.7120\"\>",
                31.711602480898147,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.6330\"\>",
                31.633466546513088,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0781\"\>",
                0.07813593438505885,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0702\"\>",
                -0.070170859715014092,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7024\"\>",
                0.702417317815487,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6878\"\>",
                0.68784462019180714,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0146\"\>",
                0.014572697623679897,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.9055\"\>",
                -1.9055471420288086,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0997\"\>",
                -2.0996974532450756,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0946\"\>",
                -2.0946391899735639,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0051\"\>",
                -0.0050582632715117605,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1998\"\>",
                -0.19984534763717932,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 14.71\"\>",
                  14.70897208506597,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.88\"\>",
                  58.877502038943277,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3067\"\>",
                  0.30674491778965651,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.056\"\>",
                  1.056098525126002,
                  AutoDelete->True], 
                InterpretationBox["\<\" 66.96\"\>",
                  66.959165010704638,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.716\"\>",
                  1.7163215625651671,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 58.88\"\>",
                  58.877502038943277,
                  AutoDelete->True], 
                InterpretationBox["\<\" 251.7\"\>",
                  251.70052525942364,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.402\"\>",
                  1.4020247991277894,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.067\"\>",
                  5.0673770085318992,
                  AutoDelete->True], 
                InterpretationBox["\<\" 308.1\"\>",
                  308.11348162432893,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.497\"\>",
                  8.4972019299756969,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.3067\"\>",
                  0.30674491778965646,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.402\"\>",
                  1.4020247991277892,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.368\"\>",
                  4.3680980708485988,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.22\"\>",
                  15.219932735923093,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.136\"\>",
                  2.1361754909886388,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.68\"\>",
                  62.678570259838082,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.056\"\>",
                  1.056098525126002,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.067\"\>",
                  5.0673770085318983,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.22\"\>",
                  15.219932735923093,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.97\"\>",
                  57.969710404616208,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.583\"\>",
                  7.5831050562047508,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.924326349713,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 66.96\"\>",
                  66.959165010704638,
                  AutoDelete->True], 
                InterpretationBox["\<\" 308.1\"\>",
                  308.11348162432887,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.136\"\>",
                  2.1361754909886379,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.583\"\>",
                  7.5831050562047428,
                  AutoDelete->True], 
                InterpretationBox["\<\" 415.\"\>",
                  414.96573181258464,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.18\"\>",
                  12.182666856551696,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 1.716\"\>",
                  1.7163215625651671,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.497\"\>",
                  8.4972019299756969,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.68\"\>",
                  62.678570259838089,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.9\"\>",
                  283.92432634971306,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.18\"\>",
                  12.182666856551696,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1861.\"\>",
                  1860.6570603570976,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.669505327761018`*^-8, 1.4901161193847656`*^-8, 
          3.35807555212813`*^-8, 4.7253970028308253`*^-7, 
          1.4901161193847656`*^-8, 3.1287930209116274`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.6695053277610181*^-08, 1.4901161193847656*^-08, 
        3.35807555212813*^-08, 4.7253970028308253*^-07, 
        1.4901161193847656*^-08, 3.1287930209116274*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]3.6513938539428636`*^-8\),
      SequenceForm[ "NOISE  ", 3.6513938539428636*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]62.54046325201597`\
\[InvisibleSpace]"  "\[InvisibleSpace]52.32166750756679`\),
      SequenceForm[ "*BFGSUP ", 62.540463252015968, "  ", 52.321667507566787],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.011804754445089658`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.011804754445089658, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]14\),
      SequenceForm[ "BFGS: Iteration = ", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987587255991990\"\>",
            70.987587255991983,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987587255991983, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.986836840383800\"\>",
            70.986836840383802,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.986836840383802, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.000750415608181\"\>",
            0.00075041560818078779,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.00075041560818078779, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8510\"\>",
                5.8509959424772111,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8180\"\>",
                5.8180065398798959,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0330\"\>",
                0.032989402597314865,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0671\"\>",
                -0.067072340867137328,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5059\"\>",
                0.50590625019055457,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5170\"\>",
                0.51695870954903966,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0111\"\>",
                -0.011052459358485143,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.3669\"\>",
                -0.36688423156738281,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.2159\"\>",
                -2.2159433614079811,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.2536\"\>",
                -2.2535663552949159,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0376\"\>",
                0.037622993886934693,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0052\"\>",
                -0.0051721607698530956,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6960\"\>",
                31.696065484709397,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.7120\"\>",
                31.711602480898147,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0155\"\>",
                -0.015536996188751824,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0264\"\>",
                -0.026425097193973193,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7036\"\>",
                0.70361197677300369,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7024\"\>",
                0.702417317815487,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0012\"\>",
                0.0011946589575166408,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.5449\"\>",
                -0.54486179351806641,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0986\"\>",
                -2.0986201922367806,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0997\"\>",
                -2.0996974532450756,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0011\"\>",
                0.0010772610082948738,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0533\"\>",
                -0.053346690168028364,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.66\"\>",
                  13.655787120754059,
                  AutoDelete->True], 
                InterpretationBox["\<\" 52.91\"\>",
                  52.907106288503499,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1943\"\>",
                  0.19429330006219986,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.6707\"\>",
                  0.67070551486542573,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.1\"\>",
                  58.100109291423514,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8225\"\>",
                  0.82252994866354578,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 52.91\"\>",
                  52.907106288503499,
                  AutoDelete->True], 
                InterpretationBox["\<\" 218.\"\>",
                  218.00994696715594,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7877\"\>",
                  0.78765559579274025,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.861\"\>",
                  2.8607725423956727,
                  AutoDelete->True], 
                InterpretationBox["\<\" 258.1\"\>",
                  258.11693846943973,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.472\"\>",
                  3.4719118084839149,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1943\"\>",
                  0.19429330006219975,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7877\"\>",
                  0.78765559579274047,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.36\"\>",
                  4.359536710939774,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.18\"\>",
                  15.175524998479416,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.224\"\>",
                  1.2237455632956169,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.589328596748686,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.6707\"\>",
                  0.67070551486542551,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.861\"\>",
                  2.8607725423956718,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.18\"\>",
                  15.175524998479416,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.83\"\>",
                  57.831764321122876,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.31\"\>",
                  4.3096439998196674,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.6\"\>",
                  283.59140565508932,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 58.1\"\>",
                  58.100109291423507,
                  AutoDelete->True], 
                InterpretationBox["\<\" 258.1\"\>",
                  258.11693846943967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.224\"\>",
                  1.2237455632956156,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.31\"\>",
                  4.3096439998196594,
                  AutoDelete->True], 
                InterpretationBox["\<\" 340.8\"\>",
                  340.77146127493916,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.725\"\>",
                  4.7245320539517408,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.8225\"\>",
                  0.82252994866354556,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.472\"\>",
                  3.4719118084839167,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.589328596748693,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.6\"\>",
                  283.59140565508937,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.725\"\>",
                  4.724532053951739,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.9096635297324,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.718663368340151`*^-8, 1.4901161193847656`*^-8, 
          3.302012922477694`*^-8, 4.7230818099840577`*^-7, 
          1.4901161193847656`*^-8, 3.1271877769183824`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7186633683401512*^-08, 1.4901161193847656*^-08, 
        3.302012922477694*^-08, 4.7230818099840577*^-07, 
        1.4901161193847656*^-08, 3.1271877769183824*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]9.018208402267192`*^-9\),
      SequenceForm[ "NOISE  ", 9.0182084022671916*^-09],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]834.2291912074841`\
\[InvisibleSpace]"  "\[InvisibleSpace]740.8072857875171`\),
      SequenceForm[ "*BFGSUP ", 834.22919120748406, "  ", 740.80728578751712],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.0019006290976903953`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.0019006290976903953, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]15\),
      SequenceForm[ "BFGS: Iteration = ", 15],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606617747740\"\>",
            70.987606617747744,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987606617747744, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987587255991990\"\>",
            70.987587255991983,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.987587255991983, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.000019361755761\"\>",
            1.9361755761337918*^-05,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.9361755761337918*^-05, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8505\"\>",
                5.8505167449568001,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8510\"\>",
                5.8509959424772111,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0005\"\>",
                -0.00047919752041134775,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0084\"\>",
                -0.0084171474151944307,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5064\"\>",
                0.50636019503905771,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5059\"\>",
                0.50590625019055457,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0005\"\>",
                0.00045394484850313187,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0407\"\>",
                -0.040669441223144531,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.1981\"\>",
                -2.1980712085588161,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.2159\"\>",
                -2.2159433614079811,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0179\"\>",
                0.017872152849165202,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0002\"\>",
                -0.00022120989514883319,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6890\"\>",
                31.688950678016116,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.6960\"\>",
                31.696065484709397,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0071\"\>",
                -0.0071148066932793692,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0043\"\>",
                -0.0042567136283417246,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7031\"\>",
                0.70314829111458632,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7036\"\>",
                0.70361197677300369,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0005\"\>",
                -0.00046368565841739128,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0603\"\>",
                -0.060339927673339844,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981402122687154,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0986\"\>",
                -2.0986201922367806,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0005\"\>",
                0.00047997996806540269,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0059\"\>",
                -0.0059239391837840475,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.19\"\>",
                  13.193226762357945,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.64\"\>",
                  50.639781649241094,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1796\"\>",
                  0.17955994440341388,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4424\"\>",
                  0.4424443380927312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 54.74\"\>",
                  54.735754687929585,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4923\"\>",
                  0.49234084716895721,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.64\"\>",
                  50.639781649241094,
                  AutoDelete->True], 
                InterpretationBox["\<\" 207.1\"\>",
                  207.06970212780402,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7293\"\>",
                  0.72925275067097806,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.712\"\>",
                  1.7115392177178301,
                  AutoDelete->True], 
                InterpretationBox["\<\" 241.9\"\>",
                  241.8854361751967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.878\"\>",
                  1.8783154843316581,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1796\"\>",
                  0.1795599444034138,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7293\"\>",
                  0.7292527506709785,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.36\"\>",
                  4.3601677468980871,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.165835745880916,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.137\"\>",
                  1.137252726598827,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.58\"\>",
                  62.580793547167012,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4424\"\>",
                  0.4424443380927312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.712\"\>",
                  1.711539217717831,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.165835745880916,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.72\"\>",
                  57.72444042412527,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.604\"\>",
                  2.60399282415655,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.42410918865761,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 54.74\"\>",
                  54.735754687929585,
                  AutoDelete->True], 
                InterpretationBox["\<\" 241.9\"\>",
                  241.88543617519665,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.137\"\>",
                  1.1372527265988257,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.604\"\>",
                  2.603992824156542,
                  AutoDelete->True], 
                InterpretationBox["\<\" 316.7\"\>",
                  316.68960697692313,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.36\"\>",
                  2.3601870668853167,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4923\"\>",
                  0.49234084716895743,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.878\"\>",
                  1.8783154843316616,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.58\"\>",
                  62.580793547167019,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.42410918865767,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.36\"\>",
                  2.3601870668853149,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6775352488335,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.717949308390617`*^-8, 1.4901161193847656`*^-8, 
          3.275381339429045`*^-8, 4.7220216211700613`*^-7, 
          1.4901161193847656`*^-8, 3.1264725510309866`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7179493083906175*^-08, 1.4901161193847656*^-08, 
        3.2753813394290449*^-08, 4.7220216211700613*^-07, 
        1.4901161193847656*^-08, 3.1264725510309866*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]9.080167728825472`*^-10\),
      SequenceForm[ "NOISE  ", 9.0801677288254723*^-10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]28481.98311650618`\
\[InvisibleSpace]"  "\[InvisibleSpace]26998.294024154235`\),
      SequenceForm[ "*BFGSUP ", 28481.983116506181, "  ", 26998.294024154235],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.00012700860638750668`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.00012700860638750668, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]16\),
      SequenceForm[ "BFGS: Iteration = ", 16],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606727895050\"\>",
            70.987606727895042,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987606727895042, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606617747740\"\>",
            70.987606617747744,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.987606617747744, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     1.101472975051365"\[Times]10\^"-7"\),
            1.1014729750513652*^-07,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.1014729750513652*^-07, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8499\"\>",
                5.8498792661909969,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8505\"\>",
                5.8505167449568001,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0006\"\>",
                -0.00063747876580308243,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0002\"\>",
                -0.00022527546928389645,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5066\"\>",
                0.50661761358627078,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5064\"\>",
                0.50636019503905771,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0003\"\>",
                0.000257418547213096,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0004\"\>",
                -0.00039958953857421875,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.1967\"\>",
                -2.1966672655721697,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.1981\"\>",
                -2.1980712085588161,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0014\"\>",
                0.0014039429866463922,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -1.3449929962904875*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6880\"\>",
                31.688391458000456,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.6890\"\>",
                31.688950678016116,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0006\"\>",
                -0.00055922001566025849,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0003\"\>",
                -0.00028451674146343602,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7031\"\>",
                0.70305850749057741,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7031\"\>",
                0.70314829111458632,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0001\"\>",
                -8.9783624008916131*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0006\"\>",
                -0.00059604644775390625,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981022847860191,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981402122687154,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                3.792748269625122*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0001\"\>",
                -0.0001195422230355313,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.19\"\>",
                  13.191775397115141,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.79\"\>",
                  50.793499562153556,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1778\"\>",
                  0.17776501348633489,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4019\"\>",
                  0.40190802746451781,
                  AutoDelete->True], 
                InterpretationBox["\<\" 54.96\"\>",
                  54.963077028059942,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5004\"\>",
                  0.50042013944919272,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.79\"\>",
                  50.793499562153556,
                  AutoDelete->True], 
                InterpretationBox["\<\" 208.6\"\>",
                  208.60255061624724,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7247\"\>",
                  0.72465651953355581,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.594\"\>",
                  1.5936158448514681,
                  AutoDelete->True], 
                InterpretationBox["\<\" 244.2\"\>",
                  244.1560166095428,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.031\"\>",
                  2.0312390183278337,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1778\"\>",
                  0.17776501348633478,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7247\"\>",
                  0.72465651953355625,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.36\"\>",
                  4.3600760194046826,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.16\"\>",
                  15.163918559239617,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.13\"\>",
                  1.1304145805640586,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.58\"\>",
                  62.579761096066683,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4019\"\>",
                  0.4019080274645177,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.594\"\>",
                  1.5936158448514699,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.16\"\>",
                  15.163918559239617,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.68\"\>",
                  57.684640485495649,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.429\"\>",
                  2.4286730222195949,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.39999287949718,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 54.96\"\>",
                  54.963077028059942,
                  AutoDelete->True], 
                InterpretationBox["\<\" 244.2\"\>",
                  244.15601660954275,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.13\"\>",
                  1.1304145805640573,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.429\"\>",
                  2.4286730222195869,
                  AutoDelete->True], 
                InterpretationBox["\<\" 320.1\"\>",
                  320.05296781634632,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.587\"\>",
                  2.5865476269083523,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.5004\"\>",
                  0.50042013944919295,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.031\"\>",
                  2.0312390183278382,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.58\"\>",
                  62.57976109606669,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.39999287949723,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.587\"\>",
                  2.5865476269083523,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6896697984689,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.716999391005929`*^-8, 1.4901161193847656`*^-8, 
          3.273289301353946`*^-8, 4.7219382908940995`*^-7, 
          1.4901161193847656`*^-8, 3.126416034677653`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7169993910059286*^-08, 1.4901161193847656*^-08, 
        3.2732893013539459*^-08, 4.7219382908940995*^-07, 
        1.4901161193847656*^-08, 3.1264160346776532*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]9.464429240324534`*^-12\),
      SequenceForm[ "NOISE  ", 9.4644292403245345*^-12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.669810468548878`*^6\
\[InvisibleSpace]"  "\[InvisibleSpace]4.348726727938828`*^6\),
      SequenceForm[ "*BFGSUP ", 4669810.4685488781, "  ", 4348726.7279388281],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.000012252152405931522`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 1.2252152405931522*^-05, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("ReturnCode = 1"\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]17\),
      SequenceForm[ "BFGS: Iteration = ", 17],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606728402310\"\>",
            70.987606728402312,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987606728402312, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606727895050\"\>",
            70.987606727895042,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.987606727895042, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     5.072706699138507"\[Times]10\^"-10"\),
            5.0727066991385072*^-10,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 5.0727066991385072*^-10, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8498\"\>",
                5.8497758864207245,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8499\"\>",
                5.8498792661909969,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0001\"\>",
                -0.0001033797702720669,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -1.0270550758343139*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5067\"\>",
                0.5066594966998007,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5066\"\>",
                0.50661761358627078,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                4.1883113529937938*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                3.910064697265625*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.1966\"\>",
                -2.1966373735561255,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.1967\"\>",
                -2.1966672655721697,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                2.9892016044006917*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6880\"\>",
                31.688378372192794,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.6880\"\>",
                31.688391458000456,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -1.3085807663811921*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -2.7446990413358817*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7030\"\>",
                0.70304438205876474,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7031\"\>",
                0.70305850749057741,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -1.412543181262086*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                2.86102294921875*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981012977535691,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981022847860191,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.19\"\>",
                  13.186953568742419,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.84\"\>",
                  50.842496174209977,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1685\"\>",
                  0.16850307388796262,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3813\"\>",
                  0.38128425538138905,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.01\"\>",
                  55.006328728117722,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4988\"\>",
                  0.49876973291597909,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.84\"\>",
                  50.842496174209977,
                  AutoDelete->True], 
                InterpretationBox["\<\" 208.8\"\>",
                  208.80688231805536,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7093\"\>",
                  0.70927141298439311,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.626\"\>",
                  1.6258425769646856,
                  AutoDelete->True], 
                InterpretationBox["\<\" 244.4\"\>",
                  244.39993497795268,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.059\"\>",
                  2.0590922809013392,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1685\"\>",
                  0.16850307388796251,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7093\"\>",
                  0.70927141298439356,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.359\"\>",
                  4.3593603131845189,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.15\"\>",
                  15.151957437335161,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.107\"\>",
                  1.1069244524710993,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.57\"\>",
                  62.574862726443193,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.3813\"\>",
                  0.38128425538138888,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.626\"\>",
                  1.6258425769646874,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.15\"\>",
                  15.151957437335161,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.64\"\>",
                  57.641215786818847,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.441\"\>",
                  2.4410730969123291,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.39013488956942,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.01\"\>",
                  55.006328728117722,
                  AutoDelete->True], 
                InterpretationBox["\<\" 244.4\"\>",
                  244.39993497795263,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.107\"\>",
                  1.1069244524710979,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.441\"\>",
                  2.4410730969123207,
                  AutoDelete->True], 
                InterpretationBox["\<\" 320.3\"\>",
                  320.33013092264702,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.612\"\>",
                  2.612137976082777,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4988\"\>",
                  0.49876973291597937,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.059\"\>",
                  2.0590922809013437,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.57\"\>",
                  62.5748627264432,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.39013488956948,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.612\"\>",
                  2.612137976082777,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6892798179192,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.716845343143828`*^-8, 1.4901161193847656`*^-8, 
          3.2732447587789976`*^-8, 4.721936340956806`*^-7, 
          1.4901161193847656`*^-8, 3.126414563884689`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7168453431438275*^-08, 1.4901161193847656*^-08, 
        3.2732447587789976*^-08, 4.7219363409568063*^-07, 
        1.4901161193847656*^-08, 3.1264145638846891*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.1084466677857563`*^-12\),
      SequenceForm[ "NOISE  ", 1.1084466677857563*^-12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]3.6015121774413353`*^8\
\[InvisibleSpace]"  "\[InvisibleSpace]4.229283410908528`*^8\),
      SequenceForm[ "*BFGSUP ", 360151217.74413353, "  ", 422928341.0908528],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]2.727178660511322`*^-6\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 2.727178660511322*^-06, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("ReturnCode = 1"\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]18\),
      SequenceForm[ "BFGS: Iteration = ", 18],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606728873970\"\>",
            70.98760672887397,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.98760672887397, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606728402310\"\>",
            70.987606728402312,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ 70.987606728402312, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     4.716582679975545"\[Times]10\^"-10"\),
            4.716582679975545*^-10,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 4.716582679975545*^-10, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 5.8498\"\>",
                5.8497812471583002,
                AutoDelete->True], 
              InterpretationBox["\<\" 5.8498\"\>",
                5.8497758864207245,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 0.5067\"\>",
                0.50665700776263523,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5067\"\>",
                0.5066594966998007,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False], 
              InterpretationBox["\<\"-0.0000\"\>",
                -3.528594970703125*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 3.0000\"\>",
                3,
                Editable->False], 
              InterpretationBox["\<\"-2.1967\"\>",
                -2.1966889813922363,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.1966\"\>",
                -2.1966373735561255,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0001\"\>",
                -5.1607836110634425*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]},
            {
              InterpretationBox["\<\" 4.0000\"\>",
                4,
                Editable->False], 
              InterpretationBox["\<\" 31.6880\"\>",
                31.688397979566499,
                AutoDelete->True], 
              InterpretationBox["\<\" 31.6880\"\>",
                31.688378372192794,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                1.9607373704469229*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]},
            {
              InterpretationBox["\<\" 5.0000\"\>",
                5,
                Editable->False], 
              InterpretationBox["\<\" 0.7030\"\>",
                0.70304531285833805,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7030\"\>",
                0.70304438205876474,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False], 
              InterpretationBox["\<\"-0.0000\"\>",
                -3.528594970703125*^-05,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 6.0000\"\>",
                6,
                Editable->False], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981025534803392,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.0981\"\>",
                -2.0981012977535691,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False], 
              InterpretationBox["\<\" 0.0000\"\>",
                0,
                Editable->False]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.15\"\>",
                  13.146973726446356,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.92\"\>",
                  50.916256126328157,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1309\"\>",
                  0.1309406599013706,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2896\"\>",
                  0.28962341589193835,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.05\"\>",
                  55.048071378116951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4732\"\>",
                  0.47315467608145306,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.92\"\>",
                  50.916256126328157,
                  AutoDelete->True], 
                InterpretationBox["\<\" 210.2\"\>",
                  210.15313226211066,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7858\"\>",
                  0.78580331472702081,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.508\"\>",
                  1.5080831881628407,
                  AutoDelete->True], 
                InterpretationBox["\<\" 245.6\"\>",
                  245.63861983583266,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.256\"\>",
                  2.2560324279252701,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1309\"\>",
                  0.13094065990137049,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7858\"\>",
                  0.78580331472702125,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.324\"\>",
                  4.3241044376716067,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.06\"\>",
                  15.06443942464549,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.153\"\>",
                  1.1525620462147261,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.551526776844518,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2896\"\>",
                  0.28962341589193819,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.508\"\>",
                  1.5080831881628427,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.06\"\>",
                  15.06443942464549,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.49\"\>",
                  57.486582873093596,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.2821562489657419,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.3\"\>",
                  283.3024407251454,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.05\"\>",
                  55.048071378116951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 245.6\"\>",
                  245.6386198358326,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.153\"\>",
                  1.1525620462147248,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.2821562489657334,
                  AutoDelete->True], 
                InterpretationBox["\<\" 321.5\"\>",
                  321.45434214356141,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.772\"\>",
                  2.7717382981848822,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4732\"\>",
                  0.47315467608145334,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.256\"\>",
                  2.2560324279252746,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.551526776844526,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.3\"\>",
                  283.30244072514546,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.772\"\>",
                  2.7717382981848822,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6879828071487,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{8.716853331265301`*^-8, 1.4901161193847656`*^-8, 
          3.273321660447473`*^-8, 4.721939262683168`*^-7, 
          1.4901161193847656`*^-8, 3.126416435063391`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {8.7168533312653008*^-08, 1.4901161193847656*^-08, 
        3.2733216604474728*^-08, 4.7219392626831679*^-07, 
        1.4901161193847656*^-08, 3.1264164350633908*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.0089706847793423`*^-12\),
      SequenceForm[ "NOISE  ", 1.0089706847793423*^-12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]4.5676883968851666`*^-7\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 4.5676883968851666*^-07, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("ReturnCode = 1"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 2"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 3"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS:  ENDE DER ITERATION  "\[InvisibleSpace]18\
\[InvisibleSpace]"  "\[InvisibleSpace]30\),
      SequenceForm[ "BFGS:  ENDE DER ITERATION  ", 18, "  ", 30],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1.1411914279848794`*^-6\)},
            {\(-0.00002002716064453125`\)},
            {\(-9.116975964361721`*^-6\)},
            {\(-7.523844507863762`*^-7\)},
            {\(-0.0000324249267578125`\)},
            {\(-9.999909168469588`*^-6\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.15\"\>",
                  13.146973726446356,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.92\"\>",
                  50.916256126328157,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1309\"\>",
                  0.1309406599013706,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2896\"\>",
                  0.28962341589193835,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.05\"\>",
                  55.048071378116951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4732\"\>",
                  0.47315467608145306,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.92\"\>",
                  50.916256126328157,
                  AutoDelete->True], 
                InterpretationBox["\<\" 210.2\"\>",
                  210.15313226211066,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7858\"\>",
                  0.78580331472702081,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.508\"\>",
                  1.5080831881628407,
                  AutoDelete->True], 
                InterpretationBox["\<\" 245.6\"\>",
                  245.63861983583266,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.256\"\>",
                  2.2560324279252701,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1309\"\>",
                  0.13094065990137049,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7858\"\>",
                  0.78580331472702125,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.324\"\>",
                  4.3241044376716067,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.06\"\>",
                  15.06443942464549,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.153\"\>",
                  1.1525620462147261,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.551526776844518,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2896\"\>",
                  0.28962341589193819,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.508\"\>",
                  1.5080831881628427,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.06\"\>",
                  15.06443942464549,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.49\"\>",
                  57.486582873093596,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.2821562489657419,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.3\"\>",
                  283.3024407251454,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.05\"\>",
                  55.048071378116951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 245.6\"\>",
                  245.6386198358326,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.153\"\>",
                  1.1525620462147248,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.2821562489657334,
                  AutoDelete->True], 
                InterpretationBox["\<\" 321.5\"\>",
                  321.45434214356141,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.772\"\>",
                  2.7717382981848822,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4732\"\>",
                  0.47315467608145334,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.256\"\>",
                  2.2560324279252746,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.551526776844526,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.3\"\>",
                  283.30244072514546,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.772\"\>",
                  2.7717382981848822,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6879828071487,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Likelihood\"\>", "\<\"THETA\"\>", "\<\"\"\>", "\<\
\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {"1", "65.03115471383268`", "10.`", \(-1.`\), "2.`", "30.`", 
            "1.`", \(-2.`\)},
          {"2", "67.02175947040298`", 
            "10.007792024145136`", \(-0.9565769864028888`\), 
            "2.001765069922482`", "30.008689639835666`", 
            "1.0625`", \(-1.9518687644473853`\)},
          {"3", "67.7225182210557`", 
            "10.013489134065983`", \(-0.9168299190605926`\), 
            "2.0009324303430893`", "30.006062576146224`", 
            "1.125`", \(-1.98194894459754`\)},
          {"4", "68.3379019414449`", 
            "9.806917215584392`", \(-1.1668299190605926`\), 
            "2.008678835174911`", "30.086930559951917`", 
            "1.3596216593428558`", \(-1.9945338334198872`\)},
          {"5", "69.4045021728926`", 
            "9.14479724176875`", \(-0.8290951528716348`\), 
            "1.7499452800353639`", "30.1394640901203`", 
            "1.1574431112692398`", \(-1.994857348420937`\)},
          {"6", "69.53306524543906`", 
            "8.89479724176875`", \(-0.7027292802617073`\), 
            "1.6846932234861967`", "30.26729692370018`", 
            "1.0975379585978724`", \(-2.012361103782716`\)},
          {"7", "70.09629194491657`", 
            "7.8947972417687495`", \(-0.28279614498223427`\), 
            "1.2735660969701037`", "30.372136350589198`", 
            "0.9338192488775495`", \(-2.0146968822925766`\)},
          {"8", "70.51607076104615`", "6.8947972417687495`", 
            "0.11588066525288843`", "0.816932471818494`", 
            "30.528304094627906`", 
            "0.8028257622680572`", \(-2.023055510544635`\)},
          {"9", "70.77564691660928`", "5.8947972417687495`", 
            "0.5023780528311658`", "0.24981701997194417`", 
            "30.737232754643326`", 
            "0.6897886293052465`", \(-2.0355937256893877`\)},
          {"10", "70.83371735965953`", "5.481399654425989`", 
            "0.6565632798080063`", \(-0.15259537987718558`\), 
            "30.892589701399256`", 
            "0.6512399142146239`", \(-2.045578056665061`\)},
          {"11", "70.8637059323767`", "5.409919847979349`", 
            "0.6802817306611335`", \(-0.44926872067363854`\), 
            "31.009129038828945`", 
            "0.6488139429655365`", \(-2.053300049901861`\)},
          {"12", "70.93848223625054`", "5.444522977191158`", 
            "0.6585779076792745`", \(-1.40961278981306`\), 
            "31.385511646552317`", 
            "0.6645448270369592`", \(-2.078274679555636`\)},
          {"13", "70.97572035425188`", "5.643039838973303`", 
            "0.5810889279237905`", \(-2.0476626375595055`\), 
            "31.633466546513088`", 
            "0.6878446201918071`", \(-2.094639189973564`\)},
          {"14", "70.9868368403838`", "5.818006539879896`", 
            "0.5169587095490397`", \(-2.253566355294916`\), 
            "31.711602480898147`", 
            "0.702417317815487`", \(-2.0996974532450756`\)},
          {"15", "70.98758725599198`", "5.850995942477211`", 
            "0.5059062501905546`", \(-2.215943361407981`\), 
            "31.696065484709397`", 
            "0.7036119767730037`", \(-2.0986201922367806`\)},
          {"16", "70.98760661774774`", "5.8505167449568`", 
            "0.5063601950390577`", \(-2.198071208558816`\), 
            "31.688950678016116`", 
            "0.7031482911145863`", \(-2.0981402122687154`\)},
          {"17", "70.98760672789504`", "5.849879266190997`", 
            "0.5066176135862708`", \(-2.1966672655721697`\), 
            "31.688391458000456`", 
            "0.7030585074905774`", \(-2.098102284786019`\)},
          {"18", "70.98760672840231`", "5.8497758864207245`", 
            "0.5066594966998007`", \(-2.1966373735561255`\), 
            "31.688378372192794`", 
            "0.7030443820587647`", \(-2.098101297753569`\)},
          {"19", "70.98760672887397`", "5.8497812471583`", 
            "0.5066570077626352`", \(-2.1966889813922363`\), 
            "31.6883979795665`", 
            "0.703045312858338`", \(-2.0981025534803392`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"Likelihood", "THETA"}}]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("INK: "\[InvisibleSpace]{0.00003542308389863181`, 
          6.055454452393343`*^-6, 0.000013301950072895014`, 
          0.00019188765063457816`, 6.055454452393343`*^-6, 
          0.000012704964449050362`}\),
      SequenceForm[ 
      "INK: ", {3.5423083898631812*^-05, 6.0554544523933429*^-06, 
        1.3301950072895014*^-05, 0.00019188765063457816, 
        6.0554544523933429*^-06, 1.2704964449050362*^-05}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Observed Fisher Information = -Hesse-Matrix"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[GridBox[{
              {"\<\"\"\>", "\<\"THETA\"\>", "\<\"SCORE\"\>"},
              {"1", "5.8497812471583`", \(-1.1411914279848794`*^-6\)},
              {"2", "0.5066570077626352`", \(-0.00002002716064453125`\)},
              {"3", \(-2.1966889813922363`\), \(-9.116975964361721`*^-6\)},
              {"4", "31.6883979795665`", \(-7.523844507863762`*^-7\)},
              {"5", "0.703045312858338`", \(-0.0000324249267578125`\)},
              {"6", \(-2.0981025534803392`\), \(-9.999909168469588`*^-6\)}
              },
            RowSpacings->0,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
              TableDirections -> {Column, Row}, TableSpacing -> {0, 1}]]], 
        "\[InvisibleSpace]", "\<\"   Likelihood = \"\>", "\[InvisibleSpace]", 
        "70.98760672887397`"}],
      SequenceForm[ 
        TableForm[ {{5.8497812471583002, -1.1411914279848794*^-06}, {
          0.50665700776263523, -2.002716064453125*^-05}, \
{-2.1966889813922363, -9.1169759643617209*^-06}, {
          31.688397979566499, -7.5238445078637619*^-07}, {
          0.70304531285833805, -3.24249267578125*^-05}, {-2.0981025534803392, \
-9.9999091684695883*^-06}}, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 1}], 
        "   Likelihood = ", 70.98760672887397],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("WALD-TEST:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"CHI \"\>", "\<\"U \"\>", "\<\"PROB \"\>", \
"\<\"ALPHA \"\>"},
          {"1", "28132.625628632053`", "6", "0", "0.05`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"CHI ", "U ", "PROB ", 
          "ALPHA "}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("NULLHYPOTHESE THETA = 0 ABLEHNEN"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("BONFERRONI-KONFIDENZINTERVALLE:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("QUANTIL Z(1-ALPHA/2U) = \
"\[InvisibleSpace]2.6382572734767504`\),
      SequenceForm[ "QUANTIL Z(1-ALPHA/2U) = ", 2.6382572734767504],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA\"\>", "\<\"GRENZE\"\>", "\<\"STD\"\>"},
          {"1", "5.8497812471583`", "5.88030460615548`", 
            "2.2288594312890084`"},
          {"2", "0.5066570077626352`", "2.4141494775451875`", 
            "0.9150546088948222`"},
          {"3", \(-2.1966889813922363`\), "10.2737961886728`", 
            "3.894160092709146`"},
          {"4", "31.6883979795665`", "4.026939195604075`", 
            "1.5263633445032792`"},
          {"5", "0.703045312858338`", "0.9120854734570436`", 
            "0.3457151365132326`"},
          {"6", \(-2.0981025534803392`\), "0.2864469065060386`", 
            "0.10857428856002087`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "GRENZE", "STD"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Korrelation der ML-Sch\[ADoubleDot]tzer"\)], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.0000000000000002`", \(-0.9727346405082805`\), 
              "0.016982377162691194`", \(-0.015655764696934252`\), 
              "0.8653997380600275`", "0.013216696128076449`"},
            {\(-0.9727346405082832`\), 
              "0.9999999999999999`", \(-0.015479995907503622`\), 
              "0.01411626858760603`", \(-0.9514349533353781`\), \
\(-0.011631755749194847`\)},
            {"0.016982377162639836`", \(-0.01547999590748369`\), 
              "1.`", \(-0.9847843220830195`\), "0.012582777084772633`", 
              "0.9033599812586023`"},
            {\(-0.01565576469688399`\), 
              "0.014116268587586722`", \(-0.9847843220830175`\), 
              "1.0000000000000002`", \(-0.011358326828952664`\), \
\(-0.9542384970836602`\)},
            {"0.8653997380600319`", \(-0.9514349533353803`\), 
              "0.012582777084752665`", \(-0.01135832682893271`\), 
              "0.9999999999999998`", "0.009101703606888192`"},
            {"0.013216696128031283`", \(-0.011631755749178154`\), 
              "0.9033599812586174`", \(-0.9542384970836768`\), 
              "0.009101703606907551`", "1.0000000000000002`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE"\)], \
"Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4.967814364445963`", \(-1.983919628471163`\), 
              "0.14739914460178496`", \(-0.053261683891307234`\), 
              "0.6668341511507669`", "0.00319839852711152`"},
            {\(-1.9839196284711684`\), 
              "0.8373249372596558`", \(-0.055160939713533315`\), 
              "0.019716274397507835`", \(-0.30098476252596845`\), \
\(-0.001155631254830877`\)},
            {"0.14739914460133918`", \(-0.055160939713462295`\), 
              "15.164482827648504`", \(-5.85346270612575`\), 
              "0.016939816413897378`", "0.38194571454327114`"},
            {\(-0.053261683891136245`\), 
              "0.019716274397480867`", \(-5.853462706125739`\), 
              "2.3297850594432363`", \(-0.005993640410012909`\), \
\(-0.1581400434060978`\)},
            {"0.6668341511507704`", \(-0.3009847625259692`\), 
              "0.016939816413870493`", \(-0.005993640410002381`\), 
              "0.11951895561436304`", "0.0003416394986261569`"},
            {"0.0031983985271005905`", \(-0.0011556312548292186`\), 
              "0.3819457145432775`", \(-0.15814004340610058`\), 
              "0.00034163949862688357`", "0.01178837613631468`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({0.0005253163441637628`, 0.0019943337807850335`, 0.06264984486170112`, 
      0.0632430386458859`, 5.856995691697612`, 
      17.445306295220036`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"12.836368244604486`", "49.2762907307746`", 
              "0.0033476611867601044`", "0.00844319643188081`", 
              "52.4748164972015`", \(-0.16808820535247293`\)},
            {"49.2762907307746`", "201.76541705923609`", 
              "0.04617903301094585`", "0.10911911121076981`", 
              "233.1781112528443`", \(-0.3803262927233557`\)},
            {"0.0033476611867601044`", "0.04617903301094585`", 
              "4.2774668999710315`", "14.980425458311409`", 
              "0.06430661903529995`", "62.37209105567134`"},
            {"0.00844319643188081`", "0.10911911121076981`", 
              "14.980425458311409`", "57.264154184446355`", 
              "0.16769469283468552`", "282.8284650547967`"},
            {"52.4748164972015`", "233.1781112528443`", 
              "0.06430661903529995`", "0.16769469283468552`", 
              "302.8052767428027`", "0.01186787970251365`"},
            {\(-0.16808820535247293`\), \(-0.3803262927233557`\), 
              "62.37209105567134`", "282.8284650547967`", 
              "0.01186787970251365`", "1858.088564762913`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({1903.614861996867`, 501.420579461061`, 15.96173146489811`, 
      15.812016965207162`, 0.17073599719691046`, 
      0.05732200874420859`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("KOMPENSIERTE LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("U =  "\[InvisibleSpace]6\[InvisibleSpace]"  Nue = "\
\[InvisibleSpace]1010\),
      SequenceForm[ "U =  ", 6, "  Nue = ", 1010],
      Editable->False]], "Print"],

Cell[BoxData[
    \("AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"LIK\"\>", "\<\"AIC\"\>", "\<\"SIC/RISS\"\>", \
"\<\"A/D\"\>"},
          {"\<\"Kompensator\"\>", "0", "6", "20.753116829505913`", 
            "40.65638303022816`"},
          {"\<\"komp. Lik.\"\>", "70.98760672887397`", "64.98760672887397`", 
            "50.23448989936806`", "30.331223698645807`"}
          },
        RowSpacings->0,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"Kompensator", "komp. Lik."}, {"LIK", 
          "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}]]]], "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtering and smoothing (true parameter values)", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
ZM//Dimensions
X//Dimensions
Theta\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"],

Cell[BoxData[
    \({10, 101, 1}\)], "Output"],

Cell[BoxData[
    \({10.`, \(-1.`\), 2.`, 30.`, 1.`, \(-2.`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["first panel unit n=1: ZM[[1]]",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[TextData[{
  "{YG,PG,YF,PF,lik}=\n\tEKG[{ZM[[",
  StyleBox["n=1",
    FontColor->RGBColor[1, 0, 0]],
  "]],X[[n]]},Theta,system,{miss,2,nonlin=1}];"
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["YG//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["z=Quantile[NormalDistribution[0,1],.995]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(2.5758293035489004`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
stdF=Map[VecDiag,PF]//Sqrt;
hpdF=YF~ii~(YF+z stdF)~ii~(YF-z stdF);

stdG=Map[VecDiag,PG]//Sqrt;
hpdG=YG~ii~(YG+z stdG)~ii~(YG-z stdG);\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(stdG\)\" is similar to \
existing symbol \"\!\(stdF\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(hpdG\)\" is similar to \
existing symbol \"\!\(hpdF\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["stdF//AddTimeAxis//plot1", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 3}\),
      SequenceForm[ "Dimension der Daten  ", {101, 3}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.083354 4.45366 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00572 -24 -4.5 ]
[-0.0125 .00572 0 4.5 ]
[-0.0125 .09479 -24 -4.5 ]
[-0.0125 .09479 0 4.5 ]
[-0.0125 .18387 -24 -4.5 ]
[-0.0125 .18387 0 4.5 ]
[-0.0125 .27294 -24 -4.5 ]
[-0.0125 .27294 0 4.5 ]
[-0.0125 .36201 -18 -4.5 ]
[-0.0125 .36201 0 4.5 ]
[-0.0125 .45108 -24 -4.5 ]
[-0.0125 .45108 0 4.5 ]
[-0.0125 .54016 -24 -4.5 ]
[-0.0125 .54016 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .04738 -5 -6 ]
[.97619 .04738 5 6 ]
[.97619 .05423 -5 -6 ]
[.97619 .05423 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00572 m
.00625 .00572 L
s
[(0.02)] -0.0125 .00572 1 0 Mshowa
0 .09479 m
.00625 .09479 L
s
[(0.04)] -0.0125 .09479 1 0 Mshowa
0 .18387 m
.00625 .18387 L
s
[(0.06)] -0.0125 .18387 1 0 Mshowa
0 .27294 m
.00625 .27294 L
s
[(0.08)] -0.0125 .27294 1 0 Mshowa
0 .36201 m
.00625 .36201 L
s
[(0.1)] -0.0125 .36201 1 0 Mshowa
0 .45108 m
.00625 .45108 L
s
[(0.12)] -0.0125 .45108 1 0 Mshowa
0 .54016 m
.00625 .54016 L
s
[(0.14)] -0.0125 .54016 1 0 Mshowa
.125 Mabswid
0 .02799 m
.00375 .02799 L
s
0 .05026 m
.00375 .05026 L
s
0 .07252 m
.00375 .07252 L
s
0 .11706 m
.00375 .11706 L
s
0 .13933 m
.00375 .13933 L
s
0 .1616 m
.00375 .1616 L
s
0 .20613 m
.00375 .20613 L
s
0 .2284 m
.00375 .2284 L
s
0 .25067 m
.00375 .25067 L
s
0 .29521 m
.00375 .29521 L
s
0 .31748 m
.00375 .31748 L
s
0 .33974 m
.00375 .33974 L
s
0 .38428 m
.00375 .38428 L
s
0 .40655 m
.00375 .40655 L
s
0 .42882 m
.00375 .42882 L
s
0 .47335 m
.00375 .47335 L
s
0 .49562 m
.00375 .49562 L
s
0 .51789 m
.00375 .51789 L
s
0 .56243 m
.00375 .56243 L
s
0 .58469 m
.00375 .58469 L
s
0 .60696 m
.00375 .60696 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00572 m
1 .00572 L
s
.99375 .09479 m
1 .09479 L
s
.99375 .18387 m
1 .18387 L
s
.99375 .27294 m
1 .27294 L
s
.99375 .36201 m
1 .36201 L
s
.99375 .45108 m
1 .45108 L
s
.99375 .54016 m
1 .54016 L
s
.125 Mabswid
.99625 .02799 m
1 .02799 L
s
.99625 .05026 m
1 .05026 L
s
.99625 .07252 m
1 .07252 L
s
.99625 .11706 m
1 .11706 L
s
.99625 .13933 m
1 .13933 L
s
.99625 .1616 m
1 .1616 L
s
.99625 .20613 m
1 .20613 L
s
.99625 .2284 m
1 .2284 L
s
.99625 .25067 m
1 .25067 L
s
.99625 .29521 m
1 .29521 L
s
.99625 .31748 m
1 .31748 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .38428 m
1 .38428 L
s
.99625 .40655 m
1 .40655 L
s
.99625 .42882 m
1 .42882 L
s
.99625 .47335 m
1 .47335 L
s
.99625 .49562 m
1 .49562 L
s
.99625 .51789 m
1 .51789 L
s
.99625 .56243 m
1 .56243 L
s
.99625 .58469 m
1 .58469 L
s
.99625 .60696 m
1 .60696 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 1 r
gsave
.97619 .04738 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .05748 m
.03333 .0589 L
.04286 .06035 L
.05238 .06185 L
.0619 .06341 L
.07143 .06506 L
.08095 .06679 L
.09048 .06863 L
.1 .07058 L
.10952 .07266 L
.11905 .02185 L
.12857 .02395 L
.1381 .02626 L
.14762 .02879 L
.15714 .03155 L
.16667 .03454 L
.17619 .03779 L
.18571 .04128 L
.19524 .04502 L
.20476 .04902 L
.21429 .01472 L
.22381 .01986 L
.23333 .02528 L
.24286 .03094 L
.25238 .03686 L
.2619 .04302 L
.27143 .04943 L
.28095 .05607 L
.29048 .06294 L
.3 .07005 L
.30952 .02258 L
.31905 .03208 L
.32857 .04159 L
.3381 .05113 L
.34762 .06074 L
.35714 .07043 L
.36667 .08023 L
.37619 .09015 L
.38571 .10021 L
.39524 .1104 L
.40476 .12075 L
.41429 .13127 L
.42381 .14195 L
.43333 .15281 L
.44286 .16386 L
.45238 .1751 L
.4619 .18653 L
.47143 .19817 L
.48095 .21003 L
.49048 .2221 L
Mistroke
.5 .0454 L
.50952 .06536 L
.51905 .08408 L
.52857 .10197 L
.5381 .1193 L
.54762 .13625 L
.55714 .15295 L
.56667 .16949 L
.57619 .18593 L
.58571 .20234 L
.59524 .04429 L
.60476 .07182 L
.61429 .09656 L
.62381 .11959 L
.63333 .14148 L
.64286 .16261 L
.65238 .18319 L
.6619 .2034 L
.67143 .22337 L
.68095 .24318 L
.69048 .0471 L
.7 .08246 L
.70952 .11317 L
.71905 .14123 L
.72857 .16758 L
.7381 .19278 L
.74762 .21718 L
.75714 .24102 L
.76667 .26447 L
.77619 .28766 L
.78571 .04927 L
.79524 .09316 L
.80476 .13009 L
.81429 .16329 L
.82381 .19416 L
.83333 .04465 L
.84286 .09441 L
.85238 .13515 L
.8619 .17133 L
.87143 .20474 L
.88095 .04553 L
.89048 .10003 L
.9 .14399 L
.90952 .18277 L
.91905 .21847 L
.92857 .04651 L
.9381 .10583 L
.94762 .153 L
.95714 .19439 L
.96667 .23239 L
Mistroke
.97619 .04738 L
Mfstroke
0 .98 .604 r
gsave
.97619 .05423 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05748 m
.03333 .06177 L
.04286 .06619 L
.05238 .07079 L
.0619 .07562 L
.07143 .08073 L
.08095 .08616 L
.09048 .09196 L
.1 .09815 L
.10952 .10478 L
.11905 .03086 L
.12857 .03753 L
.1381 .04485 L
.14762 .05282 L
.15714 .06144 L
.16667 .07071 L
.17619 .08062 L
.18571 .09116 L
.19524 .10232 L
.20476 .11409 L
.21429 .03358 L
.22381 .04954 L
.23333 .0656 L
.24286 .08185 L
.25238 .09836 L
.2619 .11518 L
.27143 .13233 L
.28095 .14985 L
.29048 .16776 L
.3 .18606 L
.30952 .04318 L
.31905 .07193 L
.32857 .09857 L
.3381 .12405 L
.34762 .14886 L
.35714 .1733 L
.36667 .19757 L
.37619 .2218 L
.38571 .24609 L
.39524 .27052 L
.40476 .29513 L
.41429 .31997 L
.42381 .34507 L
.43333 .37047 L
.44286 .39617 L
.45238 .42221 L
.4619 .44859 L
.47143 .47532 L
.48095 .50242 L
.49048 .5299 L
Mistroke
.5 .0542 L
.50952 .11647 L
.51905 .16684 L
.52857 .21156 L
.5381 .25301 L
.54762 .29235 L
.55714 .33027 L
.56667 .3672 L
.57619 .40342 L
.58571 .43916 L
.59524 .0532 L
.60476 .13668 L
.61429 .19988 L
.62381 .25449 L
.63333 .30423 L
.64286 .35086 L
.65238 .39535 L
.6619 .43832 L
.67143 .48015 L
.68095 .52114 L
.69048 .05424 L
.7 .15965 L
.70952 .23537 L
.71905 .2995 L
.72857 .35722 L
.7381 .41082 L
.74762 .46158 L
.75714 .51026 L
.76667 .55739 L
.77619 .60332 L
.78571 .05494 L
.79524 .18341 L
.80476 .27152 L
.81429 .345 L
.82381 .41048 L
.83333 .05314 L
.84286 .19449 L
.85238 .28899 L
.8619 .36719 L
.87143 .43655 L
.88095 .05355 L
.89048 .20689 L
.9 .30746 L
.90952 .39021 L
.91905 .46331 L
.92857 .05391 L
.9381 .2194 L
.94762 .32601 L
.95714 .41325 L
.96667 .49005 L
Mistroke
.97619 .05423 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@00
00030?ooo`800000:03oool3000000<0oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`00
00040?ooo`800000903oool3000000@0oooo0P0000040?ooo`8000000`3oool001l0oooo00@00000
0?ooo`3oool00000:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo000O0?ooo`040000003oool0oooo
000002T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3o
ool010000000oooo0?ooo`00000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000009@3oool4000000<0oooo00@000000?ooo`3oool000009@3oool3000000<0oooo
00@000000?ooo`3oool00000903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool000009`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000009P3oool00`000000oooo
000000030?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000903oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000008`3oool2000000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`00803oool2000002T0oooo0`000004
0?ooo`800000:@3oool00`000000oooo0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V
0?ooo`<00000103oool2000002D0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000003
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`000P3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool200000080oooo1@00003o0?ooo`<0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oooo/0
00000`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`3oool3000000<0oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?L0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo0?ooo`000000203o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0a0?ooo`<0003o``3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0340oooo10000?o20?ooo`030000003oool0oooo0040oooo00020?oo
o`8000002P3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo01T0oooo10000?lD0?oo
o`H0003o4P3oool20000oj`0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3o
ool06@3oool90000o`h0oooo0`000?l00`3oool0003o0000o`020000oa40oooo0P000?n/0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`8000006P3oool20000o`030?ooo`000?l0003o00H0003o
303oool20000o`@0oooo0`000?l@0?ooo`<0003oZP3oool2000000<0oooo000K0?ooo`030000003o
ool0oooo01T0oooo1000nYX40?ooo`P0003o1`3oool00`000?l00?ZJ003jVP040?ooo`D0003o3@3o
ool50000ojT0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0603oool0
0`000?l00?ZJ003jVP03003jVPD0oooo20000?l50?ooo`030000o`00nYX00?ZJ00D0oooo1@000?l;
0?ooo`L0003oZ03oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0H0?oo
o`040000o`00nYX00?ZJ0?ooo`<00?ZJ2@3oool50000o`<0oooo00@0003o003jVP00nYX00?ZJ1`3o
ool30000o`X0oooo0P000?l30?ooo`<0003oY`3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`0H0?ooo`030000o`00nYX00?ZJ0080oooo1000nYX90?ooo`L0003o1000nYX7
0?ooo`D0003o1`3oool00`000?l00?ZJ003jVP030?ooo`80003o:@3oool20000oaH0oooo0P000?li
0?ooo`80003o2P3oool20000o`X0oooo0P000?lA0?ooo`030000003oool0oooo0040oooo000K0?oo
o`8000006@3oool00`000?l00?ZJ003jVP030?ooo`@00?ZJ2P3oool50000o`D00?ZJ1`3oool50000
o`H0oooo00<0003o003jVP00nYX00`3oool30000obP0oooo0P000?lF0?ooo`80003o5@3oool20000
oaH0oooo0P000?l:0?ooo`80003o2P3oool20000o`X0oooo0P000?l:0?ooo`80003o103oool20000
00<0oooo000K0?ooo`030000003oool0oooo01P0oooo0`00nYX50?ooo`<00?ZJ303oool20000o`80
0?ZJ00<0oooo003jVP00nYX02P3oool30000o`D0oooo00<0003o003jVP00nYX0103oool40000obH0
oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ5@3oool2003jVQH0oooo0P000?l:0?ooo`80
0?ZJ2P3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`<00?ZJ4`3oool2003jVPL0oooo0`00nYX<0?ooo`<00?ZJ
00@0oooo003jVP00nYX00?ZJ2P3oool30000o`@0oooo00@0003o003jVP00nYX00?ZJ103oool40000
obD0oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ00<0003o0?ooo`3oool04P3oool2003j
VP030000o`3oool0oooo01<0oooo0P00nYX:0?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003j
VPX0oooo0P00nYX:0?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`D00?ZJ1@000?l<0?ooo`800?ZJ203oool3003jVP/0oooo0P00nYX30?ooo`80
0?ZJ2`3oool30000o`80oooo0P000?l3003jVPH0oooo0`000?lT0?ooo`800?ZJ00<0003o0?ooo`3o
ool04`3oool2003jVP030000o`3oool0oooo0180oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`80
0?ZJ00<0003o0?ooo`3oool01`3oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0
oooo0?ooo`070?ooo`800?ZJ2P3oool2003jVPD0oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool0103oool5003jVPP0003o1P3oool00`000?l00?ZJ003jVP090?ooo`<00?ZJ
2P3oool2003jVP<0oooo0`00nYX;0?ooo`H0003o0`00nYX70?ooo`<0003o8`3oool2003jVP80003o
503oool2003jVP030000o`3oool0oooo0180oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ
00<0003o0?ooo`3oool01`3oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo
0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVPD0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool01P3oool4003jVP030?ooo`000?l0003o00/0003o0P00
nYX:0?ooo`<00?ZJ2@3oool2003jVP@0oooo0P00nYX<0?ooo`D0003o1000nYX70?ooo`<0003o8P3o
ool2003jVP80003o503oool2003jVP80003o4`3oool2003jVP80003o503oool2003jVP030000o`3o
ool0oooo00L0oooo0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3o
ool2003jVP030000o`3oool0oooo00L0oooo0P00nYX50?ooo`030000003oool0oooo0040oooo000K
0?ooo`8000002@3oool4003jVP@0oooo20000?l2003jVP/0oooo0`00nYX80?ooo`800?ZJ103oool3
003jVPh0oooo0P000?l4003jVPP0oooo0P000?lR0?ooo`<00?ZJ0P000?lB0?ooo`030000o`00nYX0
0?ZJ0080003o4`3oool3003jVP030000o`3oool0oooo0180oooo0P00nYX20000o`P0oooo0P00nYX2
0000o`P0oooo0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2
003jVP@0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`090?ooo`H00?ZJ203oool00`00
0?l00?ZJ003jVP0<0?ooo`<00?ZJ1`3oool2003jVPD0oooo0P00nYX@0?ooo`@00?ZJ203oool30000
ob00oooo00@0003o003jVP00nYX00?ZJ0`000?lA0?ooo`050000o`00nYX00?ZJ003jVP000?l04`3o
ool3003jVP030000o`3oool0oooo0180oooo0P00nYX20000o`P0oooo0P00nYX20000o`P0oooo0P00
nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVPD0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool02`3oool6003jVPL0oooo0P00nYX=
0?ooo`<00?ZJ1P3oool2003jVPD0oooo0`00nYX?0?ooo`D00?ZJ203oool40000oah0oooo00D0003o
003jVP00nYX00?ZJ0?ooo`020000oa40oooo00@0003o003jVP00nYX00?ZJ0P000?lB0?ooo`<00?ZJ
0P000?lC0?ooo`<00?ZJ00<0003o0?ooo`3oool01P3oool3003jVP030000o`3oool0oooo00H0oooo
0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVPD0oooo
00<000000?ooo`3oool00@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`<00000103oool00`000000oooo0?ooo`0>0?ooo`@00?ZJ1P3oool2003jVPh0oooo0P00
nYX60?ooo`800?ZJ1P3oool2003jVPh0oooo0`00nYX00`3oool00?ZJ003jVP090?ooo`@0003o7@3o
ool01@000?l00?ZJ003jVP00nYX0oooo00<0003o403oool010000?l00?ZJ003jVP00nYX20000oa80
oooo0`00nYX20000oa<0oooo0`00nYX00`000?l0oooo0?ooo`050?ooo`050000o`00nYX00?ZJ003j
VP000?l0203oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo0?ooo`070?oo
o`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@
0?ooo`<00?ZJ103oool3003jVPh0oooo0`00nYX50?ooo`800?ZJ1P3oool3003jVPd0oooo0P00nYX2
0?ooo`<00?ZJ2P3oool30000oa`0oooo00@0003o003jVP00nYX00?ZJ0P3oool20000oa00oooo00@0
003o003jVP00nYX00?ZJ0P000?lB0?ooo`<00?ZJ0P000?lC0?ooo`<00?ZJ0P000?l60?ooo`040000
o`00nYX00?ZJ003jVP80003o1P3oool00`000?l00?ZJ003jVP020000o`P0oooo0P00nYX00`000?l0
oooo0?ooo`070?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`050000003oool0oooo0000003oool01@0000040?ooo`030000003oool0oooo
0140oooo1@00nYX00`3oool00?ZJ003jVP0@0?ooo`<00?ZJ103oool2003jVPL0oooo0`00nYX<0?oo
o`800?ZJ0`3oool2003jVP/0oooo0P000?lL0?ooo`040000o`00nYX00?ZJ003jVP80oooo0`000?l?
0?ooo`040000o`00nYX00?ZJ003jVP<0003o4@3oool3003jVP<0003o4P3oool3003jVP80003o1P3o
ool010000?l00?ZJ003jVP00nYX20000o`H0oooo00<0003o003jVP00nYX00P000?l70?ooo`030000
o`00nYX00?ZJ0080003o203oool2003jVPD0oooo00<000000?ooo`3oool00@3oool000050?ooo`00
0000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?oo
o`3oool00`3oool2000001<0oooo1`00nYXA0?ooo`<00?ZJ0P3oool3003jVPP0oooo0`00nYX;0?oo
o`800?ZJ0`3oool3003jVPX0oooo0`000?lK0?ooo`040000o`00nYX00?ZJ003jVP<0oooo0P000?l?
0?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?lA0?ooo`<00?ZJ00<0oooo0000o`000?l04P3o
ool3003jVP80003o1P3oool010000?l00?ZJ003jVP00nYX20000o`H0oooo00D0003o003jVP00nYX0
0?ZJ0000o`070?ooo`050000o`00nYX00?ZJ003jVP000?l01`3oool00`000?l00?ZJ003jVP030?oo
o`<000000`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool05@3oool4003jVQ80oooo0`00nYX0
0`3oool00?ZJ003jVP0:0?ooo`800?ZJ2`3oool2003jVP@0oooo0P00nYX;0?ooo`@0003o6@3oool0
10000?l00?ZJ003jVP00nYX30?ooo`<0003o3P3oool01@000?l00?ZJ003jVP00nYX0oooo0080003o
403oool01@000?l00?ZJ003jVP00nYX0oooo0080003o4P3oool3003jVP80003o1P3oool010000?l0
0?ZJ003jVP00nYX20000o`H0oooo00D0003o003jVP00nYX00?ZJ0000o`070?ooo`050000o`00nYX0
0?ZJ003jVP000?l01`3oool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo0040oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool2000000D0oooo
00<000000?ooo`3oool05P3oool3003jVQ<0oooo1@00nYX:0?ooo`<00?ZJ2P3oool2003jVP@0oooo
0P00nYX<0?ooo`@0003o603oool00`000?l00?ZJ003jVP02003jVP<0oooo0P000?l>0?ooo`050000
o`00nYX00?ZJ003jVP3oool00`000?l?0?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?lB0?oo
o`<00?ZJ0`000?l50?ooo`040000o`00nYX00?ZJ003jVP80003o1P3oool01@000?l00?ZJ003jVP00
nYX0003o00L0oooo00D0003o003jVP00nYX00?ZJ0000o`070?ooo`030000o`00nYX00?ZJ00D0oooo
00<000000?ooo`3oool00@3oool00080oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01L0oooo0P00nYXD0?ooo`@00?ZJ2`3oool2003jVPX0oooo0P00
nYX40?ooo`<00?ZJ3@3oool30000oaL0oooo00<0003o003jVP00nYX00P00nYX30?ooo`<0003o3@3o
ool010000?l00?ZJ003jVP00nYX20?ooo`80003o3`3oool00`000?l00?ZJ003jVP02003jVP<0003o
4@3oool3003jVP030?ooo`000?l0003o00D0oooo00@0003o003jVP00nYX00?ZJ0`000?l50?ooo`05
0000o`00nYX00?ZJ003jVP000?l01`3oool01@000?l00?ZJ003jVP00nYX0003o00L0oooo00<0003o
003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0^0?oo
o`<00?ZJ2`3oool2003jVPX0oooo0P00nYX50?ooo`800?ZJ3P3oool20000oaL0oooo00<0003o003j
VP00nYX00P00nYX40?ooo`80003o3@3oool010000?l00?ZJ003jVP00nYX20?ooo`<0003o3P3oool0
0`000?l00?ZJ003jVP02003jVP030?ooo`000?l0003o0100oooo00D0003o003jVP00nYX00?ZJ0?oo
o`020000o`D0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000o`D0oooo00@0003o003jVP00nYX0
0?ZJ0P000?l60?ooo`050000o`00nYX00?ZJ003jVP000?l01`3oool00`000?l00?ZJ003jVP050?oo
o`030000003oool0oooo0040oooo000K0?ooo`800000<03oool2003jVP/0oooo0`00nYX90?ooo`80
0?ZJ1@3oool2003jVPh0oooo0`000?lF0?ooo`030000o`00nYX00?ZJ00800?ZJ103oool20000o`d0
oooo00@0003o003jVP00nYX00?ZJ0`3oool20000o`h0oooo00<0003o003jVP00nYX00P00nYX00`3o
ool0003o0000o`0@0?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?l50?ooo`050000o`00nYX0
0?ZJ003jVP3oool00P000?l50?ooo`040000o`00nYX00?ZJ003jVP80003o1P3oool010000?l00?ZJ
003jVP00nYX20000o`H0oooo00<0003o003jVP00nYX0103oool2000000<0oooo000K0?ooo`030000
003oool0oooo03d0oooo0P00nYX90?ooo`800?ZJ1@3oool3003jVPh0oooo0`000?lE0?ooo`030000
o`00nYX00?ZJ00800?ZJ103oool30000o``0oooo1@00nYX20?ooo`<0003o3@3oool00`000?l00?ZJ
003jVP02003jVP040?ooo`000?l0003o0000o`l0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000
o`D0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000o`D0oooo00@0003o003jVP00nYX00?ZJ0P00
0?l60?ooo`040000o`00nYX00?ZJ003jVP80003o1P3oool00`000?l00?ZJ003jVP050?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo03d0oooo0`00nYX80?ooo`800?ZJ1P3o
ool2003jVPl0oooo0P000?lE0?ooo`030000o`00nYX00?ZJ00800?ZJ1@3oool20000o`/0oooo00@0
003o003jVP00nYX0oooo0P00nYX30?ooo`80003o3@3oool00`000?l00?ZJ003jVP02003jVP80oooo
0P000?l?0?ooo`030000o`00nYX00?ZJ00800?ZJ0`000?l40?ooo`030000o`00nYX00?ZJ00800?ZJ
0P000?l50?ooo`040000o`00nYX00?ZJ003jVP<0003o1@3oool010000?l00?ZJ003jVP00nYX20000
o`H0oooo00<0003o003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`0n0?ooo`<00?ZJ1`3oool2003jVPH0oooo0P00nYX?0?ooo`<0003o503oool00`000?l0
0?ZJ003jVP03003jVP@0oooo0`000?l:0?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ0`3oool30000
o``0oooo00<0003o003jVP00nYX00P00nYX20?ooo`<0003o3P3oool00`000?l00?ZJ003jVP02003j
VP030?ooo`000?l0003o00@0oooo00<0003o003jVP00nYX00P00nYX30000o`@0oooo00D0003o003j
VP00nYX00?ZJ0?ooo`020000o`D0oooo00@0003o003jVP00nYX00?ZJ0P000?l60?ooo`030000o`00
nYX00?ZJ00D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0?`3oool3
003jVPH0oooo0P00nYX60?ooo`<00?ZJ3`3oool40000oa80oooo00@0003o003jVP00nYX0oooo0P00
nYX50?ooo`<0003o2@3oool010000?l00?ZJ003jVP3oool2003jVP@0oooo0P000?l<0?ooo`030000
o`00nYX00?ZJ00800?ZJ0`3oool20000o`h0oooo00<0003o003jVP00nYX00P00nYX00`3oool0003o
0000o`040?ooo`030000o`00nYX00?ZJ00800?ZJ00<0oooo0000o`000?l0103oool01@000?l00?ZJ
003jVP00nYX0oooo0080003o1@3oool010000?l00?ZJ003jVP00nYX30000o`D0oooo00<0003o003j
VP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`100?ooo`80
0?ZJ1P3oool2003jVPL0oooo0P00nYX@0?ooo`@0003o403oool01@000?l00?ZJ003jVP00nYX0oooo
00800?ZJ1P3oool30000o`P0oooo00@0003o003jVP00nYX0oooo0P00nYX40?ooo`80003o303oool0
0`000?l00?ZJ003jVP02003jVP<0oooo0P000?l>0?ooo`030000o`00nYX00?ZJ00800?ZJ00<0oooo
0000o`000?l0103oool00`000?l00?ZJ003jVP02003jVP030?ooo`000?l0003o00@0oooo00D0003o
003jVP00nYX00?ZJ0?ooo`020000o`D0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000o`D0oooo
00<0003o003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3oool200000440oooo0`00
nYX50?ooo`800?ZJ1`3oool3003jVQ40oooo0`000?l?0?ooo`030000o`00nYX00?ZJ0080oooo0P00
nYX70?ooo`80003o203oool010000?l00?ZJ003jVP3oool2003jVP@0oooo0`000?l;0?ooo`030000
o`00nYX00?ZJ00800?ZJ0`3oool30000o`d0oooo00<0003o003jVP00nYX00P00nYX0103oool0003o
0000o`000?l30?ooo`030000o`00nYX00?ZJ00800?ZJ00<0oooo0000o`000?l0103oool01@000?l0
0?ZJ003jVP00nYX0oooo00<0003o103oool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool0
0`000?l00?ZJ003jVP040?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0@@3oool2003j
VPD0oooo0P00nYX80?ooo`800?ZJ4P3oool20000o`l0oooo00<0003o003jVP00nYX00P3oool3003j
VPH0oooo0`000?l70?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ1@3oool20000o`/0oooo00<0003o
003jVP00nYX00`00nYX30?ooo`80003o3@3oool00`000?l00?ZJ003jVP02003jVP80oooo0P000?l3
0?ooo`D00?ZJ00<0oooo0000o`000?l0103oool010000?l00?ZJ003jVP00nYX20?ooo`80003o103o
ool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool00`000?l00?ZJ003jVP050?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0440oooo0`00nYX40?ooo`800?ZJ203o
ool3003jVQ40oooo0`000?l>0?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX70?ooo`80003o1`3o
ool010000?l00?ZJ003jVP3oool2003jVPD0oooo0`000?l:0?ooo`040000o`00nYX00?ZJ0?ooo`80
0?ZJ0`3oool20000o`d0oooo00<0003o003jVP00nYX00P00nYX20?ooo`80003o0`3oool2003jVP04
0?ooo`00nYX00?ZJ0?ooo`<0003o0`3oool010000?l00?ZJ003jVP00nYX20?ooo`80003o103oool0
1@000?l00?ZJ003jVP00nYX0oooo00<0003o103oool00`000?l00?ZJ003jVP050?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo0480oooo0P00nYX30?ooo`<00?ZJ2@3oool2
003jVQ80oooo0`000?l=0?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX70?ooo`<0003o1P3oool0
10000?l00?ZJ003jVP3oool2003jVPH0oooo0`000?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ
0`3oool30000o``0oooo00<0003o003jVP00nYX00P00nYX20?ooo`80003o0`3oool2003jVP030?oo
o`00nYX00?ZJ0080oooo0P000?l30?ooo`@00?ZJ0P3oool20000o`@0oooo00@0003o003jVP00nYX0
0?ZJ0P3oool20000o`@0oooo00<0003o003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`120?ooo`<00?ZJ0P3oool2003jVPX0oooo0`00nYXB0?ooo`80003o
3@3oool00`000?l00?ZJ003jVP030?ooo`800?ZJ203oool20000o`H0oooo00@0003o003jVP00nYX0
oooo0`00nYX60?ooo`80003o2@3oool010000?l00?ZJ003jVP3oool2003jVP@0oooo0P000?l<0?oo
o`030000o`00nYX00?ZJ00800?ZJ0P3oool20000o`<0oooo0P00nYX00`3oool00?ZJ003jVP020?oo
o`80003o0`3oool4003jVP80oooo0`000?l30?ooo`040000o`00nYX00?ZJ003jVP80oooo0P000?l4
0?ooo`030000o`00nYX00?ZJ00D0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000140?oo
o`800?ZJ0P3oool2003jVP/0oooo0P00nYXB0?ooo`<0003o303oool00`000?l00?ZJ003jVP030?oo
o`800?ZJ203oool30000o`D0oooo00<0003o003jVP00nYX00P3oool2003jVPH0oooo0`000?l80?oo
o`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o``0oooo00<0003o003jVP00nYX00P00nYX2
0?ooo`<0003o00D0oooo0000o`00nYX00?ZJ0?ooo`02003jVP80oooo0P000?l30?ooo`@00?ZJ0`3o
ool20000o`<0oooo1000nYX20?ooo`80003o103oool00`000?l00?ZJ003jVP040?ooo`8000000`3o
ool001/0oooo00<000000?ooo`3oool0@`3oool2003jVP80oooo0P00nYX;0?ooo`800?ZJ4`3oool3
0000o`/0oooo00<0003o003jVP00nYX00`3oool3003jVPP0oooo0P000?l50?ooo`030000o`00nYX0
0?ZJ0080oooo0P00nYX70?ooo`80003o203oool010000?l00?ZJ003jVP3oool2003jVP@0oooo0`00
0?l;0?ooo`030000o`00nYX00?ZJ00800?ZJ0`3oool20000o`050?ooo`000?l00?ZJ003jVP3oool0
0P00nYX20?ooo`80003o0`3oool4003jVP<0oooo0P000?l30?ooo`@00?ZJ0P3oool30000o`<0oooo
0`00nYX50?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo04<0oooo0`00
nYX00`3oool00?ZJ003jVP0;0?ooo`<00?ZJ4`3oool30000o`X0oooo00<0003o003jVP00nYX0103o
ool2003jVPP0oooo0`000?l40?ooo`030000o`00nYX00?ZJ0080oooo0P00nYX70?ooo`<0003o1`3o
ool010000?l00?ZJ003jVP3oool2003jVPD0oooo0P000?l;0?ooo`030000o`00nYX00?ZJ00<00?ZJ
0P3oool20000o`050?ooo`000?l00?ZJ003jVP3oool00P00nYX20?ooo`<0003o00<0oooo0000o`00
nYX00`00nYX30?ooo`80003o0`3oool4003jVP<0oooo0P000?l30?ooo`800?ZJ1P3oool00`000000
oooo0?ooo`010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo
0`0000050?ooo`030000003oool0oooo04@0oooo0P00nYX00`3oool00?ZJ003jVP0<0?ooo`800?ZJ
503oool30000o`T0oooo00<0003o003jVP00nYX0103oool2003jVPT0oooo0P000?l40?ooo`030000
o`00nYX00?ZJ0080oooo0P00nYX80?ooo`80003o1`3oool3003jVP030?ooo`00nYX00?ZJ00D0oooo
0P000?l;0?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ0P3oool40000o`800?ZJ00@0oooo003jVP00
nYX00?ZJ0P3oool20000o`030?ooo`000?l00?ZJ00@00?ZJ0P3oool20000o`<0oooo1000nYX30?oo
o`80003o0`3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo0?oo
o`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`140?ooo`D00?ZJ303oool2003jVQD0oooo0`000?l80?ooo`030000o`00
nYX00?ZJ00@0oooo0P00nYX90?ooo`<0003o0P3oool20000o`800?ZJ0P3oool2003jVPP0oooo0P00
0?l70?ooo`800?ZJ0P3oool2003jVPD0oooo0`000?l:0?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ
0`3oool30000o`800?ZJ0P3oool2003jVP80oooo0P000?l01@3oool0003o003jVP00nYX0oooo0080
0?ZJ0P3oool30000o`030?ooo`000?l00?ZJ00<00?ZJ0`3oool20000o`<0oooo0P00nYX60?ooo`03
0000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool4
003jVP`0oooo0`00nYXE0?ooo`<0003o1`3oool00`000?l00?ZJ003jVP040?ooo`800?ZJ2P3oool3
0000o`030?ooo`000?l0003o00800?ZJ0P3oool2003jVPP0oooo0`000?l60?ooo`800?ZJ0P3oool2
003jVPH0oooo0P000?l:0?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ0`3oool30000o`800?ZJ0P3o
ool2003jVP80oooo10000?l2003jVP030?ooo`00nYX00?ZJ00<0oooo0P000?l00`3oool0003o003j
VP04003jVP80oooo0P000?l30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`050000003oool0oooo0000003oool0100000050?ooo`800000
A`3oool3003jVPd0oooo0P00nYXF0?ooo`<0003o1P3oool00`000?l00?ZJ003jVP040?ooo`<00?ZJ
2P3oool50000o`800?ZJ0P3oool2003jVPT0oooo0P000?l60?ooo`800?ZJ0P3oool3003jVPD0oooo
0P000?l:0?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o`800?ZJ0P3oool2003jVP<0
oooo0`000?l2003jVP030?ooo`00nYX00?ZJ00<0oooo0P000?l01@3oool0003o003jVP00nYX0oooo
00800?ZJ0P3oool30000o`80oooo0P00nYX40?ooo`<000000`3oool000050?ooo`000000oooo0?oo
o`000000203oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0A`3o
ool2003jVPd0oooo0P00nYXG0?ooo`<0003o1@3oool00`000?l00?ZJ003jVP050?ooo`800?ZJ2`3o
ool40000o`800?ZJ0P3oool3003jVPP0oooo0P000?l60?ooo`800?ZJ0`3oool2003jVPD0oooo0`00
0?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o`800?ZJ0P3oool2003jVP<0oooo
0`000?l2003jVP030?ooo`00nYX00?ZJ00<0oooo0P000?l01@3oool0003o003jVP00nYX0oooo0080
0?ZJ0`3oool20000o`040?ooo`000?l00?ZJ003jVPH0oooo00<000000?ooo`3oool00@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0EP3oool3003jVQL0oooo0`000?l40?ooo`030000o`00nYX0
0?ZJ00D0oooo0P00nYX;0?ooo`@0003o0P00nYX30?ooo`800?ZJ203oool30000o`D0oooo0P00nYX3
0?ooo`800?ZJ1P3oool20000o`T0oooo00@0003o003jVP00nYX0oooo0P00nYX40?ooo`80003o0P00
nYX20?ooo`800?ZJ0`3oool30000o`800?ZJ00<0oooo003jVP00nYX00`3oool40000o`800?ZJ00<0
oooo003jVP00nYX00`3oool20000o`040?ooo`000?l00?ZJ003jVPH0oooo00<000000?ooo`3oool0
0@3oool00080oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0E`3o
ool2003jVQP0oooo0`000?l20?ooo`80003o0P00nYX50?ooo`800?ZJ303oool30000o`800?ZJ0`3o
ool2003jVPT0oooo0P000?l50?ooo`800?ZJ0`3oool2003jVPH0oooo0P000?l90?ooo`<00?ZJ00<0
oooo003jVP00nYX01@3oool00`000?l00?ZJ003jVP020?ooo`800?ZJ103oool20000o`800?ZJ00<0
oooo003jVP00nYX0103oool30000o`800?ZJ00<0oooo003jVP00nYX00`3oool20000o`040?ooo`00
0?l00?ZJ003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0E`3o
ool2003jVQT0oooo0P000?l20?ooo`80003o0P00nYX50?ooo`800?ZJ303oool30000o`800?ZJ0`3o
ool2003jVPT0oooo0P000?l40?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX60?ooo`<0003o203o
ool2003jVP80oooo0P00nYX60?ooo`800?ZJ0P3oool2003jVP@0oooo0P000?l2003jVP030?ooo`00
nYX00?ZJ00@0oooo0`000?l2003jVP030?ooo`00nYX00?ZJ00<0oooo0P000?l0103oool0003o003j
VP00nYX60?ooo`030000003oool0oooo0040oooo000K0?ooo`800000F03oool3003jVQP0oooo0`00
0?l00`3oool0003o0000o`02003jVPD0oooo0`00nYX<0?ooo`80003o0P00nYX30?ooo`800?ZJ2@3o
ool30000o`<0oooo00<0003o003jVP00nYX00`3oool2003jVPL0oooo0P000?l80?ooo`800?ZJ0P3o
ool2003jVPH0oooo0P00nYX20?ooo`800?ZJ103oool20000o`800?ZJ00<0oooo003jVP00nYX0103o
ool30000o`800?ZJ00<0oooo003jVP00nYX00`3oool40000o`800?ZJ1@3oool2000000<0oooo000K
0?ooo`030000003oool0oooo05P0oooo0P00nYXI0?ooo`D0003o0P00nYX60?ooo`800?ZJ3P3oool2
003jVP<0oooo0P00nYX:0?ooo`80003o0`3oool00`000?l00?ZJ003jVP030?ooo`800?ZJ1`3oool3
0000o`L0oooo0P00nYX20?ooo`<00?ZJ1@3oool2003jVP80oooo0P00nYX50?ooo`040000o`00nYX0
0?ZJ0?ooo`800?ZJ1@3oool20000o`800?ZJ00<0oooo003jVP00nYX0103oool30000o`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1H0?ooo`<00?ZJ6@3oool4
0000o`800?ZJ1P3oool2003jVPh0oooo0P00nYX30?ooo`<00?ZJ2@3oool30000o`80oooo00<0003o
003jVP00nYX00`3oool2003jVPP0oooo0P000?l70?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX2
0?ooo`800?ZJ1P3oool2003jVP030?ooo`00nYX00?ZJ00D0oooo0P000?l2003jVP030?ooo`00nYX0
0?ZJ00@0oooo0`000?l2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0F@3oool2003jVQT0oooo10000?l2003jVPH0oooo0P00nYX>0?ooo`800?ZJ103oool2003j
VPX0oooo0`000?l0103oool0003o003jVP00nYX30?ooo`800?ZJ203oool30000o`H0oooo0P00nYX3
0?ooo`800?ZJ1@3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01@3oool2
0000o`800?ZJ00<0oooo003jVP00nYX0103oool30000o`800?ZJ1P3oool00`000000oooo0?ooo`01
0?ooo`006`3oool00`000000oooo0?ooo`1I0?ooo`<00?ZJ6@3oool30000o`800?ZJ1P3oool2003j
VPh0oooo0P00nYX40?ooo`800?ZJ2`3oool20000o`040?ooo`000?l00?ZJ003jVP<0oooo0`00nYX8
0?ooo`80003o1P3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool3003jVPD0oooo0P00nYX0
0`3oool00?ZJ003jVP060?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ1@3oool20000o`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1J0?ooo`800?ZJ6P3oool2
0000o`800?ZJ1P3oool3003jVPd0oooo0P00nYX40?ooo`800?ZJ2`3oool40000o`800?ZJ103oool2
003jVPP0oooo0`000?l50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2
003jVP030?ooo`00nYX00?ZJ00L0oooo0P00nYX00`3oool00?ZJ003jVP050?ooo`80003o0P00nYX6
0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000F`3oool3003jVQ/0oooo0P00nYX70?oo
o`800?ZJ3@3oool2003jVP@0oooo0`00nYX;0?ooo`<0003o0P00nYX40?ooo`800?ZJ2@3oool20000
o`D0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ00@0oooo003j
VP00nYX00?ZJ1P3oool2003jVP030?ooo`00nYX00?ZJ00D0oooo0P000?l2003jVPD0oooo0P000003
0?ooo`006`3oool00`000000oooo0?ooo`1K0?ooo`800?ZJ6`3oool2003jVPL0oooo0P00nYX=0?oo
o`800?ZJ1@3oool2003jVP/0oooo0`000?l2003jVP@0oooo0P00nYX90?ooo`80003o103oool00`00
0?l00?ZJ003jVP030?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool2003j
VPH0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`030000o`00nYX00?ZJ00H0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0F`3oool2003jVQ/0oooo0P00nYX70?ooo`80
0?ZJ3@3oool2003jVPD0oooo0P00nYX<0?ooo`80003o0P00nYX40?ooo`800?ZJ2@3oool30000o`<0
oooo00<0003o003jVP00nYX00`3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP80
oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool00`000?l00?ZJ003jVP060?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo05/0oooo0`00nYXJ0?ooo`800?ZJ
1`3oool2003jVPd0oooo0P00nYX50?ooo`800?ZJ303oool20000o`800?ZJ103oool2003jVPX0oooo
0P000?l30?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo
0P00nYX20?ooo`800?ZJ1P3oool2003jVP040?ooo`00nYX00?ZJ003jVPH0oooo0P00nYX60?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo05`0oooo0P00nYXJ0?ooo`800?ZJ
1`3oool3003jVP`0oooo0P00nYX50?ooo`800?ZJ303oool20000o`800?ZJ103oool2003jVPX0oooo
0P000?l30?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo
0P00nYX20?ooo`800?ZJ1P3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ1P3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`800?ZJ6P3oool2003jVPP0oooo0P00
nYX;0?ooo`<00?ZJ1@3oool3003jVP`0oooo00<0003o003jVP00nYX0103oool2003jVPX0oooo0`00
0?l20?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00
nYX20?ooo`800?ZJ1P3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ1P3oool00`000000oooo0?oo
o`010?ooo`006`3oool2000005d0oooo0`00nYXI0?ooo`800?ZJ203oool2003jVP/0oooo0P00nYX7
0?ooo`800?ZJ3@3oool2003jVP@0oooo0`00nYX:0?ooo`80003o0P3oool00`000?l00?ZJ003jVP03
0?ooo`<00?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX2
0?ooo`800?ZJ1P3oool2003jVPD0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1M0?oo
o`800?ZJ6@3oool2003jVPP0oooo0P00nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00nYX50?oo
o`800?ZJ2P3oool30000o`040?ooo`000?l00?ZJ003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3oool2
003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ1P3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1M0?ooo`<00?ZJ603oool2003j
VPP0oooo0P00nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00nYX50?ooo`800?ZJ2`3oool20000
o`040?ooo`000?l00?ZJ003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX2
0?ooo`<00?ZJ1@3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ1P3oool00`000000oooo0?ooo`01
0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000050?oo
o`030000003oool0oooo05h0oooo0P00nYXH0?ooo`800?ZJ203oool3003jVPX0oooo0P00nYX70?oo
o`800?ZJ3@3oool2003jVPD0oooo0P00nYX;0?ooo`@0003o0P00nYX40?ooo`800?ZJ103oool2003j
VP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003j
VPH0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo0?ooo`000000203oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1N0?ooo`<00?ZJ5`3oool2003jVPT0oooo0P00nYX:0?ooo`800?ZJ1`3oool3003jVP`0oooo0P00
nYX50?ooo`800?ZJ303oool30000o`800?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`<00?ZJ103o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000003o
ool0oooo0040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001P0?ooo`800?ZJ5`3oool2003jVPT0
oooo0P00nYX:0?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX50?ooo`<00?ZJ2`3oool30000o`80
0?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`80
0?ZJ0P3oool2003jVPH0oooo0P00nYX40?ooo`<000000`3oool000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`1O0?oo
o`800?ZJ5`3oool2003jVPT0oooo0`00nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX60?oo
o`800?ZJ303oool20000o`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003j
VP<0oooo0P00nYX50?ooo`800?ZJ0P3oool3003jVPD0oooo0P00nYX60?ooo`030000003oool0oooo
0040oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G`3oool3003jVQH0oooo0P00
nYX:0?ooo`800?ZJ2@3oool2003jVPP0oooo0P00nYX<0?ooo`800?ZJ1P3oool2003jVP`0oooo0P00
0?l2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`800?ZJ1@3o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0600oooo0P00nYXF0?ooo`800?ZJ2P3oool2003jVPT0
oooo0P00nYX80?ooo`800?ZJ303oool2003jVPH0oooo0P00nYX<0?ooo`80003o0P00nYX40?ooo`80
0?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX30?ooo`80
0?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool00080oooo0P00000:0?ooo`800000
0`3oool3000000D0oooo00<000000?ooo`3oool0H03oool2003jVQH0oooo0P00nYX:0?ooo`<00?ZJ
203oool2003jVPP0oooo0P00nYX<0?ooo`800?ZJ1P3oool2003jVPd0oooo00<0003o003jVP00nYX0
103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ
0`3oool2003jVPD0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo0600oooo0`00nYXD0?ooo`<00?ZJ2`3oool2003jVPP0oooo0P00nYX80?ooo`800?ZJ303o
ool2003jVPH0oooo0`00nYX<0?ooo`030000o`00nYX00?ZJ00@0oooo0`00nYX30?ooo`800?ZJ103o
ool2003jVP@0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`006`3oool200000680oooo0P00nYXD0?ooo`800?ZJ303oool2
003jVPP0oooo0P00nYX80?ooo`<00?ZJ2`3oool2003jVPL0oooo0P00nYX=0?ooo`800?ZJ1@3oool2
003jVP<0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0`00nYX40?ooo`800?ZJ0`3oool2
003jVPD0oooo0P00nYX50?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0H@3oool2003j
VQ@0oooo0P00nYX<0?ooo`800?ZJ203oool2003jVPT0oooo0P00nYX;0?ooo`800?ZJ1`3oool2003j
VPd0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003j
VP@0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0H@3oool3003jVQ<0oooo0P00nYX<0?ooo`<00?ZJ1`3oool2003jVPT0
oooo0P00nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0
oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVPH0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0HP3oool2003jVQ<0oooo
0P00nYX=0?ooo`800?ZJ1`3oool2003jVPT0oooo0P00nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo
0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo
0P00nYX30?ooo`800?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0HP3oool2003jVQ<0oooo0P00nYX=0?ooo`800?ZJ1`3oool2003jVPT0oooo0P00
nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0`00
nYX30?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`<00?ZJ103oool2003jVPH0oooo00<0
00000?ooo`3oool00@3oool001/0oooo0P00001S0?ooo`<00?ZJ4P3oool2003jVPd0oooo0P00nYX7
0?ooo`800?ZJ2@3oool3003jVPX0oooo0P00nYX70?ooo`<00?ZJ303oool2003jVPD0oooo0P00nYX3
0?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX4
0?ooo`800?ZJ1@3oool2000000<0oooo000K0?ooo`030000003oool0oooo06<0oooo0P00nYXB0?oo
o`800?ZJ3@3oool2003jVPL0oooo0P00nYX:0?ooo`800?ZJ2P3oool2003jVPP0oooo0P00nYX<0?oo
o`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00nYX40?oo
o`800?ZJ103oool2003jVP@0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo06<0oooo0P00nYXB0?ooo`800?ZJ3@3oool3003jVPH0oooo0P00nYX:0?ooo`80
0?ZJ2P3oool2003jVPP0oooo0P00nYX<0?ooo`800?ZJ1@3oool2003jVP80oooo0`00nYX50?ooo`80
0?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX60?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06<0oooo0`00nYXA0?ooo`800?ZJ
3P3oool2003jVPH0oooo0P00nYX:0?ooo`800?ZJ2P3oool2003jVPP0oooo0P00nYX<0?ooo`800?ZJ
1@3oool3003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX30?ooo`800?ZJ103oool2003jVP@0oooo
0P00nYX40?ooo`800?ZJ103oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0I03oool2003jVQ40oooo0P00nYX>0?ooo`800?ZJ1P3oool2003jVPX0oooo0`00
nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3o
ool2003jVP<0oooo0P00nYX40?ooo`<00?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1T0?ooo`<00?ZJ403oool2
003jVPh0oooo0P00nYX60?ooo`800?ZJ2`3oool2003jVPT0oooo0P00nYX80?ooo`800?ZJ303oool2
003jVPH0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX3
0?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo000K0?oo
o`800000IP3oool2003jVQ00oooo0P00nYX>0?ooo`<00?ZJ1@3oool2003jVP/0oooo0P00nYX90?oo
o`800?ZJ203oool2003jVP`0oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2003j
VP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ1@3oool20000
00<0oooo000K0?ooo`030000003oool0oooo06D0oooo0`00nYX?0?ooo`800?ZJ3`3oool2003jVPD0
oooo0P00nYX;0?ooo`800?ZJ2@3oool2003jVPP0oooo0`00nYX;0?ooo`800?ZJ1P3oool2003jVP03
0?ooo`00nYX00?ZJ00H0oooo0P00nYX20?ooo`<00?ZJ1@3oool2003jVP<0oooo0P00nYX40?ooo`80
0?ZJ103oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
IP3oool2003jVPl0oooo0P00nYX?0?ooo`800?ZJ1@3oool2003jVP/0oooo0`00nYX80?ooo`800?ZJ
2@3oool2003jVP/0oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2003jVP80oooo
0P00nYX60?ooo`800?ZJ0`3oool2003jVP@0oooo0`00nYX30?ooo`800?ZJ1P3oool00`000000oooo
0?ooo`010?ooo`00203oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<0
00000?ooo`3oool0IP3oool2003jVPl0oooo0P00nYX?0?ooo`800?ZJ1@3oool2003jVP`0oooo0P00
nYX80?ooo`800?ZJ2@3oool2003jVP/0oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3o
ool3003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00
nYX60?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`<00?ZJ3P3oool2003jVPl0oooo0P00
nYX50?ooo`800?ZJ303oool2003jVPP0oooo0P00nYX90?ooo`800?ZJ2`3oool2003jVPH0oooo0P00
nYX00`3oool00?ZJ003jVP070?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2003jVP<0oooo0P00
nYX50?ooo`800?ZJ0`3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool000L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000J03oool2003jVPh0oooo0P00
nYX?0?ooo`<00?ZJ103oool2003jVP`0oooo0P00nYX80?ooo`800?ZJ2@3oool2003jVP/0oooo0P00
nYX60?ooo`D00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX30?ooo`800?ZJ1@3o
ool2003jVP<0oooo0P00nYX40?ooo`<000000`3oool000L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06L0oooo0P00nYX>0?ooo`800?ZJ403o
ool2003jVP@0oooo0P00nYX<0?ooo`800?ZJ203oool2003jVPT0oooo0P00nYX;0?ooo`800?ZJ1`3o
ool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0P3oool3003jVPD0oooo0P00
nYX30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I`3oool3003jVPd0oooo0P00
nYX@0?ooo`800?ZJ103oool2003jVP`0oooo0`00nYX70?ooo`800?ZJ2@3oool2003jVP/0oooo0P00
nYX70?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX20?ooo`800?ZJ1P3o
ool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0
oooo000000P0oooo0P0000060?ooo`030000003oool0oooo06P0oooo0P00nYX=0?ooo`800?ZJ403o
ool2003jVP@0oooo0P00nYX=0?ooo`800?ZJ1`3oool2003jVPT0oooo0`00nYX:0?ooo`800?ZJ1`3o
ool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`<00?ZJ00<0oooo003jVP00nYX01P3o
ool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo00080?ooo`8000002P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo0P00nYX=0?ooo`800?ZJ403oool3
003jVP<0oooo0P00nYX=0?ooo`800?ZJ1`3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ1`3oool4
003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP070?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2
003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo
06P0oooo0`00nYX<0?ooo`800?ZJ4@3oool2003jVP80oooo0`00nYX=0?ooo`800?ZJ1`3oool2003j
VPX0oooo0P00nYX:0?ooo`800?ZJ1`3oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP070?oo
o`800?ZJ00<0oooo003jVP00nYX01P3oool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo
0040oooo000K0?ooo`800000JP3oool2003jVP`0oooo0P00nYXA0?ooo`800?ZJ0P3oool2003jVPh0
oooo0P00nYX70?ooo`800?ZJ2P3oool2003jVPX0oooo0P00nYX80?ooo`<00?ZJ1`3oool5003jVPL0
oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0P3oool3003jVPD0oooo0P0000030?ooo`00
6`3oool00`000000oooo0?ooo`1Y0?ooo`800?ZJ303oool2003jVQ40oooo0`00nYX00`3oool00?ZJ
003jVP0>0?ooo`<00?ZJ1P3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ203oool3003jVPP0oooo
1000nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2003jVP80oooo0P00nYX70?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06T0oooo0`00nYX;0?ooo`800?ZJ4P3o
ool2003jVP030?ooo`00nYX00?ZJ00l0oooo0P00nYX60?ooo`800?ZJ2P3oool2003jVPX0oooo0P00
nYX80?ooo`<00?ZJ203oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`<00?ZJ00<0
oooo003jVP00nYX01`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1Z
0?ooo`800?ZJ2`3oool2003jVQ80oooo0P00nYX00`3oool00?ZJ003jVP0?0?ooo`800?ZJ1P3oool2
003jVPX0oooo0P00nYX:0?ooo`800?ZJ203oool3003jVPP0oooo1000nYX70?ooo`800?ZJ00<0oooo
003jVP00nYX01`3oool2003jVP030?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0JP3oool2003jVP/0oooo0P00nYXB0?ooo`D00?ZJ3`3oool2003j
VPH0oooo0P00nYX:0?ooo`<00?ZJ2@3oool2003jVPP0oooo0`00nYX80?ooo`@00?ZJ1`3oool2003j
VP030?ooo`00nYX00?ZJ00L0oooo0P00nYX00`3oool00?ZJ003jVP070?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo06X0oooo0`00nYX:0?ooo`800?ZJ4`3oool4003jVPl0
oooo0P00nYX60?ooo`800?ZJ2`3oool2003jVPT0oooo0P00nYX80?ooo`<00?ZJ203oool4003jVPL0
oooo1@00nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool2000006`0oooo0P00nYX:0?ooo`800?ZJ4`3oool4003jVPl0oooo0`00nYX40?ooo`<00?ZJ
2`3oool2003jVPT0oooo0P00nYX90?ooo`800?ZJ2@3oool3003jVPP0oooo1000nYX70?ooo`800?ZJ
00<0oooo003jVP00nYX01P3oool2000000<0oooo000K0?ooo`030000003oool0oooo06/0oooo0`00
nYX90?ooo`800?ZJ4`3oool4003jVQ00oooo0P00nYX40?ooo`800?ZJ303oool2003jVPT0oooo0P00
nYX90?ooo`800?ZJ2@3oool3003jVPP0oooo1000nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01`3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`800?ZJ2@3oool2
003jVQ<0oooo1000nYX@0?ooo`800?ZJ103oool2003jVP`0oooo0P00nYX90?ooo`800?ZJ2@3oool2
003jVPT0oooo0`00nYX80?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00L0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0K03oool3003jVPP0oooo0P00nYXD0?oo
o`<00?ZJ403oool2003jVP@0oooo0P00nYX<0?ooo`800?ZJ2@3oool2003jVQ@0oooo0`00nYX80?oo
o`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0K@3oool2003jVPP0oooo0P00nYXD0?ooo`<00?ZJ403oool2003jVP@0
oooo0P00nYX<0?ooo`<00?ZJ203oool2003jVQ@0oooo0`00nYX80?ooo`@00?ZJ1`3oool2003jVP03
0?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001^0?ooo`800?ZJ
203oool2003jVQ@0oooo0`00nYX@0?ooo`<00?ZJ0`3oool2003jVPd0oooo0P00nYX80?ooo`800?ZJ
503oool3003jVPP0oooo1000nYX70?ooo`D00?ZJ1P3oool2000000<0oooo000K0?ooo`030000003o
ool0oooo06d0oooo0`00nYX70?ooo`800?ZJ503oool3003jVQ40oooo0P00nYX30?ooo`800?ZJ3@3o
ool2003jVPP0oooo0P00nYXE0?ooo`800?ZJ2@3oool3003jVPP0oooo1000nYX70?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo06h0oooo0P00nYX70?ooo`800?ZJ503oool3
003jVQ40oooo0P00nYX30?ooo`800?ZJ3@3oool2003jVPP0oooo0P00nYXE0?ooo`800?ZJ2@3oool3
003jVPP0oooo1000nYX70?ooo`030000003oool0oooo0040oooo00020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0KP3oool2003j
VPL0oooo0P00nYXE0?ooo`800?ZJ4@3oool2003jVP<0oooo0P00nYX=0?ooo`<00?ZJ1`3oool2003j
VQD0oooo0P00nYX90?ooo`<00?ZJ203oool4003jVPL0oooo00<000000?ooo`3oool00@3oool00005
0?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0KP3oool3003jVPH0oooo0P00nYXE0?ooo`800?ZJ4@3oool2
003jVP<0oooo0P00nYX>0?ooo`800?ZJ1`3oool2003jVR00oooo0`00nYX80?ooo`@00?ZJ1`3oool0
0`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1_0?ooo`800?ZJ1P3oool2
003jVRP0oooo0`00nYX20?ooo`800?ZJ3P3oool2003jVPL0oooo0P00nYXP0?ooo`<00?ZJ203oool4
003jVPL0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo0?ooo`0000002@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00001`0?ooo`800?ZJ1@3oool3
003jVRT0oooo0P00nYX20?ooo`800?ZJ3P3oool2003jVPL0oooo0P00nYXP0?ooo`<00?ZJ203oool4
003jVPD0oooo0`0000030?ooo`0000D0oooo0000003oool0oooo000000090?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo0`00
nYX40?ooo`800?ZJ:P3oool2003jVP80oooo0P00nYX>0?ooo`<00?ZJ1P3oool2003jVR00oooo0`00
nYX90?ooo`<00?ZJ1`3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000
00080?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
L03oool2003jVP@0oooo0P00nYXZ0?ooo`<00?ZJ00<0oooo003jVP00nYX03`3oool2003jVPH0oooo
0P00nYXQ0?ooo`800?ZJ2@3oool3003jVPL0oooo00<000000?ooo`3oool00@3oool00080oooo0P00
000:0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0700oooo0`00
nYX30?ooo`800?ZJ:`3oool2003jVP030?ooo`00nYX00?ZJ00l0oooo0P00nYX60?ooo`800?ZJ8@3o
ool2003jVPT0oooo0`00nYX70?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo0740oooo0P00nYX30?ooo`800?ZJ:`3oool2003jVP030?ooo`00nYX00?ZJ00l0oooo0P00nYX6
0?ooo`800?ZJ8@3oool2003jVPT0oooo0`00nYX70?ooo`030000003oool0oooo0040oooo000K0?oo
o`800000LP3oool2003jVP<0oooo0P00nYX[0?ooo`800?ZJ00<0oooo003jVP00nYX03`3oool2003j
VPD0oooo0`00nYX/0?ooo`<00?ZJ1P3oool2000000<0oooo000K0?ooo`030000003oool0oooo0740
oooo0`00nYX20?ooo`800?ZJ:`3oool5003jVPl0oooo0`00nYX40?ooo`800?ZJ;@3oool3003jVPL0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0LP3oool2003jVP80oooo
0P00nYX/0?ooo`@00?ZJ403oool2003jVP@0oooo0P00nYX]0?ooo`<00?ZJ1`3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`800?ZJ0P3oool2003jVR`0oooo1000
nYX@0?ooo`800?ZJ103oool2003jVRh0oooo0P00nYX70?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo0780oooo0`00nYX00`3oool00?ZJ003jVP0/0?ooo`@00?ZJ403oool2
003jVP@0oooo0P00nYX^0?ooo`800?ZJ1`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`00
0000oooo0?ooo`1c0?ooo`800?ZJ00<0oooo003jVP00nYX0;03oool4003jVQ00oooo0P00nYX40?oo
o`800?ZJ;P3oool2003jVPL0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001d0?ooo`80
0?ZJ00<0oooo003jVP00nYX0;@3oool3003jVQ00oooo0P00nYX40?ooo`800?ZJ=P3oool2000000<0
oooo000K0?ooo`030000003oool0oooo07<0oooo1@00nYX]0?ooo`<00?ZJ403oool3003jVP<0oooo
0P00nYXg0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo07@0oooo1000
nYX]0?ooo`<00?ZJ4@3oool2003jVP<0oooo0P00nYXg0?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo07@0oooo1000nYX]0?ooo`<00?ZJ4@3oool2003jVP<0oooo0P00nYXg
0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo07@0oooo1000nYX]0?oo
o`<00?ZJ4@3oool2003jVP<0oooo0P00nYXg0?ooo`030000003oool0oooo0040oooo000K0?ooo`80
0000MP3oool3003jVRh0oooo0P00nYXA0?ooo`800?ZJ0`3oool2003jVSH0oooo0P0000030?ooo`00
6`3oool00`000000oooo0?ooo`1e0?ooo`<00?ZJ;P3oool2003jVQ40oooo0`00nYX20?ooo`800?ZJ
=`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1e0?ooo`<00?ZJ;P3o
ool2003jVQ80oooo0P00nYX20?ooo`800?ZJ=`3oool00`000000oooo0?ooo`010?ooo`000P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`030000003oool0
oooo07H0oooo0P00nYY20?ooo`800?ZJ0P3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool0
00050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0MP3oool2003jVT80oooo0P00nYX20?ooo`800?ZJ=`3oool0
0`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`040000003oool0
oooo0?ooo`D00000103oool00`000000oooo0?ooo`2j0?ooo`<00?ZJ00<0oooo003jVP00nYX0=`3o
ool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`800000_03oool2003jVP030?oo
o`00nYX00?ZJ03D0oooo0`0000030?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2k0?ooo`800?ZJ
00<0oooo003jVP00nYX0=`3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool0^`3oool2003jVP030?oo
o`00nYX00?ZJ03L0oooo00<000000?ooo`3oool00@3oool00080oooo0P00000:0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2k0?ooo`D00?ZJ=`3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2l0?ooo`@00?ZJ=`3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2l0?ooo`@00?ZJ=`3oool00`00
0000oooo0?ooo`010?ooo`006`3oool200000;d0oooo1000nYXf0?ooo`8000000`3oool001/0oooo
00<000000?ooo`3oool0_03oool4003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0_03oool4003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0_@3oool3003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0_@3oool3003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00002n0?ooo`<0
0?ZJ=P3oool2000000<0oooo000K0?ooo`030000003oool0oooo0;d0oooo0`00nYXg0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0;d0oooo0`00nYXg0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`030000003oool0oooo0;d0oooo0`00nYXg0?ooo`030000003oool0
oooo0040oooo000K0?ooo`030000003oool0oooo0;h0oooo0P00nYXg0?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo0;h0oooo0P00nYXg0?ooo`030000003oool0oooo0040
oooo000K0?ooo`800000_`3oool2003jVSH0oooo0P0000030?ooo`006`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo000K0?oooo/000000`3oool00?l0oooo6P3oool00?l0
oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-13.8823, 0.00510927, \
0.419554, 0.000897185}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["time = AddTimeAxis[#,{0,10,dt}]&", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(AddTimeAxis[#1, {0, 10, dt}] &\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZM // Dimensions\)], "Input"],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
m1={PointSize[ps=.02],Map[Point[#]&,{(tau-1)dt,ZM[[n,tau,1]]}//\
Transpose]};
m2={PointSize[ps    ],Map[Point[#]&,{(tau-1)dt,ZM[[n,tau,2]]}//Transpose]};\
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
DisplayTogetherArray[

{{plot1[Column[hpdF,{1,3,5}]//time,color->{1,2,2},Epilog->m1,PlotLabel->\"\
filtered, 1st component\"],
  plot1[Column[hpdG,{1,3,5}]//time,color->{1,2,2},Epilog->m1,PlotLabel->\"\
smoothed, 1st component\"]},
 {plot1[Column[hpdF,{2,4,6}]//time,color->{1,2,2},Epilog->m2,PlotLabel->\"\
filtered, 2nd component\"],
  plot1[Column[hpdG,{2,4,6}]//time,color->{1,2,2},Epilog->m2,PlotLabel->\"\
smoothed, 2nd component\"]}}
]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.5 0.309017 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.0676368 0.0413296 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01502 -6 -4.5 ]
[-0.0125 .01502 0 4.5 ]
[-0.0125 .09768 -6 -4.5 ]
[-0.0125 .09768 0 4.5 ]
[-0.0125 .18034 -6 -4.5 ]
[-0.0125 .18034 0 4.5 ]
[-0.0125 .263 -6 -4.5 ]
[-0.0125 .263 0 4.5 ]
[-0.0125 .34566 -12 -4.5 ]
[-0.0125 .34566 0 4.5 ]
[-0.0125 .42832 -12 -4.5 ]
[-0.0125 .42832 0 4.5 ]
[-0.0125 .51098 -12 -4.5 ]
[-0.0125 .51098 0 4.5 ]
[-0.0125 .59364 -12 -4.5 ]
[-0.0125 .59364 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .60003 -5 -6 ]
[.97619 .60003 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .59674 -5 -6 ]
[.97619 .59674 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01502 m
.00625 .01502 L
s
[(2)] -0.0125 .01502 1 0 Mshowa
0 .09768 m
.00625 .09768 L
s
[(4)] -0.0125 .09768 1 0 Mshowa
0 .18034 m
.00625 .18034 L
s
[(6)] -0.0125 .18034 1 0 Mshowa
0 .263 m
.00625 .263 L
s
[(8)] -0.0125 .263 1 0 Mshowa
0 .34566 m
.00625 .34566 L
s
[(10)] -0.0125 .34566 1 0 Mshowa
0 .42832 m
.00625 .42832 L
s
[(12)] -0.0125 .42832 1 0 Mshowa
0 .51098 m
.00625 .51098 L
s
[(14)] -0.0125 .51098 1 0 Mshowa
0 .59364 m
.00625 .59364 L
s
[(16)] -0.0125 .59364 1 0 Mshowa
.125 Mabswid
0 .03569 m
.00375 .03569 L
s
0 .05635 m
.00375 .05635 L
s
0 .07702 m
.00375 .07702 L
s
0 .11835 m
.00375 .11835 L
s
0 .13901 m
.00375 .13901 L
s
0 .15968 m
.00375 .15968 L
s
0 .20101 m
.00375 .20101 L
s
0 .22167 m
.00375 .22167 L
s
0 .24234 m
.00375 .24234 L
s
0 .28366 m
.00375 .28366 L
s
0 .30433 m
.00375 .30433 L
s
0 .32499 m
.00375 .32499 L
s
0 .36632 m
.00375 .36632 L
s
0 .38699 m
.00375 .38699 L
s
0 .40765 m
.00375 .40765 L
s
0 .44898 m
.00375 .44898 L
s
0 .46965 m
.00375 .46965 L
s
0 .49031 m
.00375 .49031 L
s
0 .53164 m
.00375 .53164 L
s
0 .55231 m
.00375 .55231 L
s
0 .57297 m
.00375 .57297 L
s
0 .6143 m
.00375 .6143 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01502 m
1 .01502 L
s
.99375 .09768 m
1 .09768 L
s
.99375 .18034 m
1 .18034 L
s
.99375 .263 m
1 .263 L
s
.99375 .34566 m
1 .34566 L
s
.99375 .42832 m
1 .42832 L
s
.99375 .51098 m
1 .51098 L
s
.99375 .59364 m
1 .59364 L
s
.125 Mabswid
.99625 .03569 m
1 .03569 L
s
.99625 .05635 m
1 .05635 L
s
.99625 .07702 m
1 .07702 L
s
.99625 .11835 m
1 .11835 L
s
.99625 .13901 m
1 .13901 L
s
.99625 .15968 m
1 .15968 L
s
.99625 .20101 m
1 .20101 L
s
.99625 .22167 m
1 .22167 L
s
.99625 .24234 m
1 .24234 L
s
.99625 .28366 m
1 .28366 L
s
.99625 .30433 m
1 .30433 L
s
.99625 .32499 m
1 .32499 L
s
.99625 .36632 m
1 .36632 L
s
.99625 .38699 m
1 .38699 L
s
.99625 .40765 m
1 .40765 L
s
.99625 .44898 m
1 .44898 L
s
.99625 .46965 m
1 .46965 L
s
.99625 .49031 m
1 .49031 L
s
.99625 .53164 m
1 .53164 L
s
.99625 .55231 m
1 .55231 L
s
.99625 .57297 m
1 .57297 L
s
.99625 .6143 m
1 .6143 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
129.000 13.000 moveto
(nd) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .60003 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .01808 m
.03333 .02078 L
.04286 .02353 L
.05238 .02636 L
.0619 .02925 L
.07143 .0322 L
.08095 .03523 L
.09048 .03832 L
.1 .04148 L
.10952 .04471 L
.11905 .0446 L
.12857 .04788 L
.1381 .05123 L
.14762 .05465 L
.15714 .05814 L
.16667 .0617 L
.17619 .06533 L
.18571 .06904 L
.19524 .07282 L
.20476 .07667 L
.21429 .07747 L
.22381 .08139 L
.23333 .08539 L
.24286 .08946 L
.25238 .0936 L
.2619 .09781 L
.27143 .1021 L
.28095 .10647 L
.29048 .11091 L
.3 .11542 L
.30952 .11826 L
.31905 .12288 L
.32857 .12758 L
.3381 .13235 L
.34762 .1372 L
.35714 .14212 L
.36667 .14711 L
.37619 .15218 L
.38571 .15732 L
.39524 .16254 L
.40476 .16782 L
.41429 .17318 L
.42381 .17861 L
.43333 .18411 L
.44286 .18968 L
.45238 .19532 L
.4619 .20102 L
.47143 .2068 L
.48095 .21264 L
.49048 .21855 L
Mistroke
.5 .22661 L
.50952 .23269 L
.51905 .23884 L
.52857 .24505 L
.5381 .25132 L
.54762 .25766 L
.55714 .26404 L
.56667 .27049 L
.57619 .27699 L
.58571 .28354 L
.59524 .29614 L
.60476 .3029 L
.61429 .30972 L
.62381 .31658 L
.63333 .32349 L
.64286 .33045 L
.65238 .33744 L
.6619 .34448 L
.67143 .35155 L
.68095 .35866 L
.69048 .36539 L
.7 .37256 L
.70952 .37975 L
.71905 .38698 L
.72857 .39422 L
.7381 .40149 L
.74762 .40878 L
.75714 .41608 L
.76667 .4234 L
.77619 .43072 L
.78571 .43935 L
.79524 .44671 L
.80476 .45407 L
.81429 .46143 L
.82381 .46878 L
.83333 .48227 L
.84286 .48968 L
.85238 .49708 L
.8619 .50446 L
.87143 .51182 L
.88095 .51749 L
.89048 .52479 L
.9 .53206 L
.90952 .53931 L
.91905 .54651 L
.92857 .5557 L
.9381 .56286 L
.94762 .56997 L
.95714 .57703 L
.96667 .58404 L
Mistroke
.97619 .60003 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02145 m
.03333 .02424 L
.04286 .02711 L
.05238 .03004 L
.0619 .03305 L
.07143 .03612 L
.08095 .03928 L
.09048 .04251 L
.1 .04582 L
.10952 .04921 L
.11905 .04733 L
.12857 .05077 L
.1381 .05429 L
.14762 .0579 L
.15714 .0616 L
.16667 .06538 L
.17619 .06925 L
.18571 .07321 L
.19524 .07726 L
.20476 .08139 L
.21429 .08027 L
.22381 .08457 L
.23333 .08895 L
.24286 .0934 L
.25238 .09794 L
.2619 .10256 L
.27143 .10726 L
.28095 .11204 L
.29048 .11691 L
.3 .12186 L
.30952 .12128 L
.31905 .12659 L
.32857 .13193 L
.3381 .13731 L
.34762 .14275 L
.35714 .14825 L
.36667 .15383 L
.37619 .15948 L
.38571 .1652 L
.39524 .171 L
.40476 .17687 L
.41429 .18282 L
.42381 .18885 L
.43333 .19496 L
.44286 .20114 L
.45238 .2074 L
.4619 .21374 L
.47143 .22015 L
.48095 .22664 L
.49048 .2332 L
Mistroke
.5 .2299 L
.50952 .23747 L
.51905 .24482 L
.52857 .2521 L
.5381 .25937 L
.54762 .26664 L
.55714 .27393 L
.56667 .28126 L
.57619 .28863 L
.58571 .29603 L
.59524 .2994 L
.60476 .30816 L
.61429 .31649 L
.62381 .32466 L
.63333 .33276 L
.64286 .34083 L
.65238 .34889 L
.6619 .35695 L
.67143 .36502 L
.68095 .37311 L
.69048 .36868 L
.7 .37836 L
.70952 .38737 L
.71905 .39613 L
.72857 .40476 L
.7381 .4133 L
.74762 .4218 L
.75714 .43027 L
.76667 .43871 L
.77619 .44714 L
.78571 .44266 L
.79524 .45308 L
.80476 .46255 L
.81429 .47167 L
.82381 .48059 L
.83333 .48554 L
.84286 .49633 L
.85238 .50598 L
.8619 .51523 L
.87143 .52425 L
.88095 .52076 L
.89048 .53173 L
.9 .54141 L
.90952 .55063 L
.91905 .55958 L
.92857 .55898 L
.9381 .57009 L
.94762 .57975 L
.95714 .5889 L
.96667 .59775 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .59674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01731 L
.04286 .01996 L
.05238 .02267 L
.0619 .02545 L
.07143 .02828 L
.08095 .03117 L
.09048 .03413 L
.1 .03714 L
.10952 .04022 L
.11905 .04187 L
.12857 .04499 L
.1381 .04816 L
.14762 .05139 L
.15714 .05467 L
.16667 .05801 L
.17619 .06141 L
.18571 .06487 L
.19524 .06838 L
.20476 .07195 L
.21429 .07468 L
.22381 .07822 L
.23333 .08183 L
.24286 .08551 L
.25238 .08925 L
.2619 .09307 L
.27143 .09695 L
.28095 .10089 L
.29048 .10491 L
.3 .10898 L
.30952 .11523 L
.31905 .11917 L
.32857 .12323 L
.3381 .12739 L
.34762 .13165 L
.35714 .13599 L
.36667 .1404 L
.37619 .14489 L
.38571 .14945 L
.39524 .15408 L
.40476 .15878 L
.41429 .16354 L
.42381 .16837 L
.43333 .17326 L
.44286 .17822 L
.45238 .18323 L
.4619 .18831 L
.47143 .19344 L
.48095 .19864 L
.49048 .20389 L
Mistroke
.5 .22332 L
.50952 .22792 L
.51905 .23286 L
.52857 .238 L
.5381 .24328 L
.54762 .24867 L
.55714 .25416 L
.56667 .25972 L
.57619 .26535 L
.58571 .27105 L
.59524 .29287 L
.60476 .29764 L
.61429 .30295 L
.62381 .30851 L
.63333 .31423 L
.64286 .32007 L
.65238 .326 L
.6619 .33201 L
.67143 .33808 L
.68095 .34421 L
.69048 .3621 L
.7 .36675 L
.70952 .37213 L
.71905 .37783 L
.72857 .38369 L
.7381 .38968 L
.74762 .39575 L
.75714 .40189 L
.76667 .40808 L
.77619 .41431 L
.78571 .43604 L
.79524 .44033 L
.80476 .44559 L
.81429 .45119 L
.82381 .45698 L
.83333 .47901 L
.84286 .48304 L
.85238 .48818 L
.8619 .49369 L
.87143 .4994 L
.88095 .51422 L
.89048 .51785 L
.9 .52272 L
.90952 .52799 L
.91905 .53345 L
.92857 .55242 L
.9381 .55562 L
.94762 .56018 L
.95714 .56516 L
.96667 .57034 L
Mistroke
.97619 .59674 L
Mfstroke
0 g
.02 w
.02381 .01808 Mdot
.11905 .04283 Mdot
.21429 .07607 Mdot
.30952 .11784 Mdot
.5 .22671 Mdot
.59524 .29652 Mdot
.69048 .36537 Mdot
.78571 .4394 Mdot
.83333 .48267 Mdot
.88095 .51739 Mdot
.92857 .55581 Mdot
.97619 .60046 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0147151 0.97619 0.309017 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.065717 0.0412114 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01671 -6 -4.5 ]
[-0.0125 .01671 0 4.5 ]
[-0.0125 .09913 -6 -4.5 ]
[-0.0125 .09913 0 4.5 ]
[-0.0125 .18155 -6 -4.5 ]
[-0.0125 .18155 0 4.5 ]
[-0.0125 .26397 -6 -4.5 ]
[-0.0125 .26397 0 4.5 ]
[-0.0125 .3464 -12 -4.5 ]
[-0.0125 .3464 0 4.5 ]
[-0.0125 .42882 -12 -4.5 ]
[-0.0125 .42882 0 4.5 ]
[-0.0125 .51124 -12 -4.5 ]
[-0.0125 .51124 0 4.5 ]
[-0.0125 .59366 -12 -4.5 ]
[-0.0125 .59366 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .60004 -5 -6 ]
[.97619 .60004 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .59676 -5 -6 ]
[.97619 .59676 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01671 m
.00625 .01671 L
s
[(2)] -0.0125 .01671 1 0 Mshowa
0 .09913 m
.00625 .09913 L
s
[(4)] -0.0125 .09913 1 0 Mshowa
0 .18155 m
.00625 .18155 L
s
[(6)] -0.0125 .18155 1 0 Mshowa
0 .26397 m
.00625 .26397 L
s
[(8)] -0.0125 .26397 1 0 Mshowa
0 .3464 m
.00625 .3464 L
s
[(10)] -0.0125 .3464 1 0 Mshowa
0 .42882 m
.00625 .42882 L
s
[(12)] -0.0125 .42882 1 0 Mshowa
0 .51124 m
.00625 .51124 L
s
[(14)] -0.0125 .51124 1 0 Mshowa
0 .59366 m
.00625 .59366 L
s
[(16)] -0.0125 .59366 1 0 Mshowa
.125 Mabswid
0 .03731 m
.00375 .03731 L
s
0 .05792 m
.00375 .05792 L
s
0 .07852 m
.00375 .07852 L
s
0 .11973 m
.00375 .11973 L
s
0 .14034 m
.00375 .14034 L
s
0 .16095 m
.00375 .16095 L
s
0 .20216 m
.00375 .20216 L
s
0 .22276 m
.00375 .22276 L
s
0 .24337 m
.00375 .24337 L
s
0 .28458 m
.00375 .28458 L
s
0 .30519 m
.00375 .30519 L
s
0 .32579 m
.00375 .32579 L
s
0 .367 m
.00375 .367 L
s
0 .38761 m
.00375 .38761 L
s
0 .40821 m
.00375 .40821 L
s
0 .44943 m
.00375 .44943 L
s
0 .47003 m
.00375 .47003 L
s
0 .49064 m
.00375 .49064 L
s
0 .53185 m
.00375 .53185 L
s
0 .55245 m
.00375 .55245 L
s
0 .57306 m
.00375 .57306 L
s
0 .61427 m
.00375 .61427 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01671 m
1 .01671 L
s
.99375 .09913 m
1 .09913 L
s
.99375 .18155 m
1 .18155 L
s
.99375 .26397 m
1 .26397 L
s
.99375 .3464 m
1 .3464 L
s
.99375 .42882 m
1 .42882 L
s
.99375 .51124 m
1 .51124 L
s
.99375 .59366 m
1 .59366 L
s
.125 Mabswid
.99625 .03731 m
1 .03731 L
s
.99625 .05792 m
1 .05792 L
s
.99625 .07852 m
1 .07852 L
s
.99625 .11973 m
1 .11973 L
s
.99625 .14034 m
1 .14034 L
s
.99625 .16095 m
1 .16095 L
s
.99625 .20216 m
1 .20216 L
s
.99625 .22276 m
1 .22276 L
s
.99625 .24337 m
1 .24337 L
s
.99625 .28458 m
1 .28458 L
s
.99625 .30519 m
1 .30519 L
s
.99625 .32579 m
1 .32579 L
s
.99625 .367 m
1 .367 L
s
.99625 .38761 m
1 .38761 L
s
.99625 .40821 m
1 .40821 L
s
.99625 .44943 m
1 .44943 L
s
.99625 .47003 m
1 .47003 L
s
.99625 .49064 m
1 .49064 L
s
.99625 .53185 m
1 .53185 L
s
.99625 .55245 m
1 .55245 L
s
.99625 .57306 m
1 .57306 L
s
.99625 .61427 m
1 .61427 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
129.000 13.000 moveto
(nd) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .60004 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .01644 m
.03333 .01903 L
.04286 .02167 L
.05238 .02438 L
.0619 .02714 L
.07143 .02996 L
.08095 .03283 L
.09048 .03576 L
.1 .03874 L
.10952 .04177 L
.11905 .04485 L
.12857 .048 L
.1381 .0512 L
.14762 .05445 L
.15714 .05775 L
.16667 .06111 L
.17619 .06451 L
.18571 .06797 L
.19524 .07147 L
.20476 .07503 L
.21429 .07863 L
.22381 .08245 L
.23333 .08633 L
.24286 .09028 L
.25238 .0943 L
.2619 .09838 L
.27143 .10253 L
.28095 .10674 L
.29048 .11102 L
.3 .11537 L
.30952 .11978 L
.31905 .12446 L
.32857 .12921 L
.3381 .13405 L
.34762 .13896 L
.35714 .14396 L
.36667 .14903 L
.37619 .15418 L
.38571 .15941 L
.39524 .16472 L
.40476 .1701 L
.41429 .17556 L
.42381 .1811 L
.43333 .18672 L
.44286 .19241 L
.45238 .19818 L
.4619 .20402 L
.47143 .20994 L
.48095 .21593 L
.49048 .22199 L
Mistroke
.5 .22812 L
.50952 .23465 L
.51905 .24127 L
.52857 .24796 L
.5381 .25474 L
.54762 .26159 L
.55714 .26852 L
.56667 .27553 L
.57619 .28261 L
.58571 .28977 L
.59524 .29699 L
.60476 .30371 L
.61429 .31048 L
.62381 .31729 L
.63333 .32415 L
.64286 .33105 L
.65238 .33799 L
.6619 .34497 L
.67143 .35199 L
.68095 .35905 L
.69048 .36614 L
.7 .37343 L
.70952 .38076 L
.71905 .38811 L
.72857 .3955 L
.7381 .40291 L
.74762 .41034 L
.75714 .41779 L
.76667 .42525 L
.77619 .43273 L
.78571 .44023 L
.79524 .44864 L
.80476 .45708 L
.81429 .46555 L
.82381 .47403 L
.83333 .48253 L
.84286 .48963 L
.85238 .49672 L
.8619 .50379 L
.87143 .51084 L
.88095 .51786 L
.89048 .52558 L
.9 .53329 L
.90952 .54097 L
.91905 .54863 L
.92857 .55627 L
.9381 .56506 L
.94762 .57383 L
.95714 .58259 L
.96667 .59132 L
Mistroke
.97619 .60004 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01816 m
.03333 .0208 L
.04286 .0235 L
.05238 .02626 L
.0619 .02907 L
.07143 .03194 L
.08095 .03486 L
.09048 .03782 L
.1 .04084 L
.10952 .04389 L
.11905 .04698 L
.12857 .05021 L
.1381 .05349 L
.14762 .05682 L
.15714 .0602 L
.16667 .06362 L
.17619 .06707 L
.18571 .07055 L
.19524 .07405 L
.20476 .07757 L
.21429 .08108 L
.22381 .08514 L
.23333 .08924 L
.24286 .09337 L
.25238 .09754 L
.2619 .10172 L
.27143 .10593 L
.28095 .11015 L
.29048 .11435 L
.3 .11854 L
.30952 .12266 L
.31905 .12791 L
.32857 .13317 L
.3381 .13844 L
.34762 .14375 L
.35714 .1491 L
.36667 .15449 L
.37619 .15991 L
.38571 .16538 L
.39524 .17088 L
.40476 .17642 L
.41429 .18199 L
.42381 .18758 L
.43333 .19319 L
.44286 .19881 L
.45238 .20442 L
.4619 .21001 L
.47143 .21555 L
.48095 .22101 L
.49048 .22631 L
Mistroke
.5 .23126 L
.50952 .23899 L
.51905 .24641 L
.52857 .25366 L
.5381 .2608 L
.54762 .26783 L
.55714 .27475 L
.56667 .28154 L
.57619 .28814 L
.58571 .29445 L
.59524 .30015 L
.60476 .30854 L
.61429 .31635 L
.62381 .32387 L
.63333 .33117 L
.64286 .33828 L
.65238 .34519 L
.6619 .35189 L
.67143 .3583 L
.68095 .36428 L
.69048 .36934 L
.7 .3788 L
.70952 .38741 L
.71905 .39561 L
.72857 .40351 L
.7381 .41115 L
.74762 .41853 L
.75714 .42562 L
.76667 .43233 L
.77619 .4385 L
.78571 .44341 L
.79524 .45417 L
.80476 .46353 L
.81429 .47205 L
.82381 .47969 L
.83333 .48568 L
.84286 .49541 L
.85238 .5035 L
.8619 .51064 L
.87143 .51677 L
.88095 .52104 L
.89048 .53164 L
.9 .54042 L
.90952 .54817 L
.91905 .55484 L
.92857 .55946 L
.9381 .57139 L
.94762 .58132 L
.95714 .59014 L
.96667 .59783 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .59676 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01725 L
.04286 .01984 L
.05238 .02249 L
.0619 .02521 L
.07143 .02798 L
.08095 .0308 L
.09048 .03369 L
.1 .03664 L
.10952 .03965 L
.11905 .04272 L
.12857 .04578 L
.1381 .0489 L
.14762 .05208 L
.15714 .05531 L
.16667 .0586 L
.17619 .06196 L
.18571 .06539 L
.19524 .06889 L
.20476 .07248 L
.21429 .07617 L
.22381 .07975 L
.23333 .08342 L
.24286 .08719 L
.25238 .09106 L
.2619 .09504 L
.27143 .09913 L
.28095 .10334 L
.29048 .10769 L
.3 .1122 L
.30952 .1169 L
.31905 .121 L
.32857 .12526 L
.3381 .12966 L
.34762 .13418 L
.35714 .13882 L
.36667 .14357 L
.37619 .14845 L
.38571 .15344 L
.39524 .15855 L
.40476 .16378 L
.41429 .16914 L
.42381 .17463 L
.43333 .18025 L
.44286 .18602 L
.45238 .19194 L
.4619 .19803 L
.47143 .20432 L
.48095 .21084 L
.49048 .21767 L
Mistroke
.5 .22498 L
.50952 .23032 L
.51905 .23613 L
.52857 .24227 L
.5381 .24868 L
.54762 .25536 L
.55714 .2623 L
.56667 .26953 L
.57619 .27708 L
.58571 .28508 L
.59524 .29384 L
.60476 .29888 L
.61429 .3046 L
.62381 .31071 L
.63333 .31712 L
.64286 .32382 L
.65238 .33079 L
.6619 .33806 L
.67143 .34569 L
.68095 .35382 L
.69048 .36294 L
.7 .36806 L
.70952 .3741 L
.71905 .38062 L
.72857 .38749 L
.7381 .39466 L
.74762 .40214 L
.75714 .40995 L
.76667 .41817 L
.77619 .42697 L
.78571 .43704 L
.79524 .44311 L
.80476 .45064 L
.81429 .45904 L
.82381 .46837 L
.83333 .47937 L
.84286 .48385 L
.85238 .48994 L
.8619 .49694 L
.87143 .50491 L
.88095 .51469 L
.89048 .51953 L
.9 .52615 L
.90952 .53377 L
.91905 .54243 L
.92857 .55308 L
.9381 .55872 L
.94762 .56634 L
.95714 .57503 L
.96667 .58482 L
Mistroke
.97619 .59676 L
Mfstroke
0 g
.02 w
.02381 .01976 Mdot
.11905 .04443 Mdot
.21429 .07757 Mdot
.30952 .11922 Mdot
.5 .22779 Mdot
.59524 .2974 Mdot
.69048 .36605 Mdot
.78571 .43987 Mdot
.83333 .48302 Mdot
.88095 .51764 Mdot
.92857 .55594 Mdot
.97619 .60047 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.309017 0.5 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.190323 0.226837 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03651 -6 -4.5 ]
[-0.0125 .03651 0 4.5 ]
[-0.0125 .14993 -18 -4.5 ]
[-0.0125 .14993 0 4.5 ]
[-0.0125 .26335 -6 -4.5 ]
[-0.0125 .26335 0 4.5 ]
[-0.0125 .37677 -18 -4.5 ]
[-0.0125 .37677 0 4.5 ]
[-0.0125 .49019 -6 -4.5 ]
[-0.0125 .49019 0 4.5 ]
[-0.0125 .60361 -18 -4.5 ]
[-0.0125 .60361 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .56067 -5 -6 ]
[.97619 .56067 5 6 ]
[.97619 .57782 -5 -6 ]
[.97619 .57782 5 6 ]
[.97619 .54352 -5 -6 ]
[.97619 .54352 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03651 m
.00625 .03651 L
s
[(1)] -0.0125 .03651 1 0 Mshowa
0 .14993 m
.00625 .14993 L
s
[(1.5)] -0.0125 .14993 1 0 Mshowa
0 .26335 m
.00625 .26335 L
s
[(2)] -0.0125 .26335 1 0 Mshowa
0 .37677 m
.00625 .37677 L
s
[(2.5)] -0.0125 .37677 1 0 Mshowa
0 .49019 m
.00625 .49019 L
s
[(3)] -0.0125 .49019 1 0 Mshowa
0 .60361 m
.00625 .60361 L
s
[(3.5)] -0.0125 .60361 1 0 Mshowa
.125 Mabswid
0 .0592 m
.00375 .0592 L
s
0 .08188 m
.00375 .08188 L
s
0 .10457 m
.00375 .10457 L
s
0 .12725 m
.00375 .12725 L
s
0 .17262 m
.00375 .17262 L
s
0 .1953 m
.00375 .1953 L
s
0 .21798 m
.00375 .21798 L
s
0 .24067 m
.00375 .24067 L
s
0 .28603 m
.00375 .28603 L
s
0 .30872 m
.00375 .30872 L
s
0 .3314 m
.00375 .3314 L
s
0 .35409 m
.00375 .35409 L
s
0 .39945 m
.00375 .39945 L
s
0 .42214 m
.00375 .42214 L
s
0 .44482 m
.00375 .44482 L
s
0 .4675 m
.00375 .4675 L
s
0 .51287 m
.00375 .51287 L
s
0 .53556 m
.00375 .53556 L
s
0 .55824 m
.00375 .55824 L
s
0 .58092 m
.00375 .58092 L
s
0 .01383 m
.00375 .01383 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03651 m
1 .03651 L
s
.99375 .14993 m
1 .14993 L
s
.99375 .26335 m
1 .26335 L
s
.99375 .37677 m
1 .37677 L
s
.99375 .49019 m
1 .49019 L
s
.99375 .60361 m
1 .60361 L
s
.125 Mabswid
.99625 .0592 m
1 .0592 L
s
.99625 .08188 m
1 .08188 L
s
.99625 .10457 m
1 .10457 L
s
.99625 .12725 m
1 .12725 L
s
.99625 .17262 m
1 .17262 L
s
.99625 .1953 m
1 .1953 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .24067 m
1 .24067 L
s
.99625 .28603 m
1 .28603 L
s
.99625 .30872 m
1 .30872 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35409 m
1 .35409 L
s
.99625 .39945 m
1 .39945 L
s
.99625 .42214 m
1 .42214 L
s
.99625 .44482 m
1 .44482 L
s
.99625 .4675 m
1 .4675 L
s
.99625 .51287 m
1 .51287 L
s
.99625 .53556 m
1 .53556 L
s
.99625 .55824 m
1 .55824 L
s
.99625 .58092 m
1 .58092 L
s
.99625 .01383 m
1 .01383 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
129.000 13.000 moveto
(st) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .56067 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .03319 m
.03333 .03496 L
.04286 .03675 L
.05238 .03857 L
.0619 .04041 L
.07143 .04228 L
.08095 .04418 L
.09048 .0461 L
.1 .04805 L
.10952 .05003 L
.11905 .05318 L
.12857 .05524 L
.1381 .05734 L
.14762 .05946 L
.15714 .06161 L
.16667 .0638 L
.17619 .06601 L
.18571 .06826 L
.19524 .07054 L
.20476 .07285 L
.21429 .07344 L
.22381 .07581 L
.23333 .07822 L
.24286 .08066 L
.25238 .08313 L
.2619 .08564 L
.27143 .08819 L
.28095 .09077 L
.29048 .09339 L
.3 .09604 L
.30952 .10412 L
.31905 .10693 L
.32857 .10979 L
.3381 .11268 L
.34762 .11562 L
.35714 .1186 L
.36667 .12163 L
.37619 .1247 L
.38571 .12782 L
.39524 .13098 L
.40476 .13419 L
.41429 .13745 L
.42381 .14076 L
.43333 .14412 L
.44286 .14753 L
.45238 .15099 L
.4619 .15451 L
.47143 .15808 L
.48095 .1617 L
.49048 .16538 L
Mistroke
.5 .19099 L
.50952 .1951 L
.51905 .19929 L
.52857 .20355 L
.5381 .20787 L
.54762 .21227 L
.55714 .21674 L
.56667 .22129 L
.57619 .22591 L
.58571 .23062 L
.59524 .24312 L
.60476 .24808 L
.61429 .25313 L
.62381 .25826 L
.63333 .26349 L
.64286 .26881 L
.65238 .27423 L
.6619 .27974 L
.67143 .28536 L
.68095 .29108 L
.69048 .31 L
.7 .31616 L
.70952 .32244 L
.71905 .32884 L
.72857 .33536 L
.7381 .34201 L
.74762 .34879 L
.75714 .3557 L
.76667 .36275 L
.77619 .36995 L
.78571 .37873 L
.79524 .38624 L
.80476 .3939 L
.81429 .40172 L
.82381 .4097 L
.83333 .39108 L
.84286 .39887 L
.85238 .40682 L
.8619 .41495 L
.87143 .42324 L
.88095 .45364 L
.89048 .46273 L
.9 .47202 L
.90952 .48151 L
.91905 .49122 L
.92857 .51849 L
.9381 .52898 L
.94762 .5397 L
.95714 .55067 L
.96667 .5619 L
Mistroke
.97619 .56067 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57782 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05167 m
.03333 .05362 L
.04286 .0556 L
.05238 .05762 L
.0619 .05967 L
.07143 .06175 L
.08095 .06387 L
.09048 .06604 L
.1 .06824 L
.10952 .07049 L
.11905 .06698 L
.12857 .06932 L
.1381 .07172 L
.14762 .07417 L
.15714 .07669 L
.16667 .07927 L
.17619 .08191 L
.18571 .08461 L
.19524 .08738 L
.20476 .09022 L
.21429 .08631 L
.22381 .08935 L
.23333 .09247 L
.24286 .09565 L
.25238 .0989 L
.2619 .10222 L
.27143 .10561 L
.28095 .10906 L
.29048 .11258 L
.3 .11617 L
.30952 .11802 L
.31905 .12208 L
.32857 .12618 L
.3381 .13033 L
.34762 .13453 L
.35714 .13878 L
.36667 .14309 L
.37619 .14746 L
.38571 .1519 L
.39524 .1564 L
.40476 .16097 L
.41429 .16561 L
.42381 .17032 L
.43333 .1751 L
.44286 .17996 L
.45238 .1849 L
.4619 .18991 L
.47143 .19501 L
.48095 .20019 L
.49048 .20546 L
Mistroke
.5 .20788 L
.50952 .21462 L
.51905 .22126 L
.52857 .22786 L
.5381 .23446 L
.54762 .24108 L
.55714 .24774 L
.56667 .25446 L
.57619 .26124 L
.58571 .2681 L
.59524 .25987 L
.60476 .26844 L
.61429 .27673 L
.62381 .28489 L
.63333 .29299 L
.64286 .30108 L
.65238 .3092 L
.6619 .31736 L
.67143 .3256 L
.68095 .33392 L
.69048 .32711 L
.7 .33791 L
.70952 .34822 L
.71905 .3583 L
.72857 .36828 L
.7381 .37823 L
.74762 .38822 L
.75714 .39826 L
.76667 .40839 L
.77619 .41862 L
.78571 .39613 L
.79524 .4094 L
.80476 .4219 L
.81429 .43408 L
.82381 .44611 L
.83333 .40787 L
.84286 .42219 L
.85238 .43549 L
.8619 .44836 L
.87143 .46104 L
.88095 .47054 L
.89048 .48678 L
.9 .50184 L
.90952 .51643 L
.91905 .53082 L
.92857 .53553 L
.9381 .5538 L
.94762 .57071 L
.95714 .58711 L
.96667 .60332 L
Mistroke
.97619 .57782 L
Mfstroke
gsave
.97619 .54352 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .0163 L
.04286 .0179 L
.05238 .01952 L
.0619 .02116 L
.07143 .02281 L
.08095 .02448 L
.09048 .02616 L
.1 .02785 L
.10952 .02956 L
.11905 .03937 L
.12857 .04116 L
.1381 .04296 L
.14762 .04475 L
.15714 .04654 L
.16667 .04833 L
.17619 .05012 L
.18571 .05191 L
.19524 .0537 L
.20476 .05548 L
.21429 .06057 L
.22381 .06227 L
.23333 .06397 L
.24286 .06566 L
.25238 .06736 L
.2619 .06906 L
.27143 .07077 L
.28095 .07248 L
.29048 .07419 L
.3 .07592 L
.30952 .09022 L
.31905 .09179 L
.32857 .0934 L
.3381 .09504 L
.34762 .09672 L
.35714 .09843 L
.36667 .10017 L
.37619 .10194 L
.38571 .10374 L
.39524 .10556 L
.40476 .10741 L
.41429 .10929 L
.42381 .1112 L
.43333 .11313 L
.44286 .1151 L
.45238 .11708 L
.4619 .1191 L
.47143 .12114 L
.48095 .12321 L
.49048 .12531 L
Mistroke
.5 .17409 L
.50952 .17559 L
.51905 .17733 L
.52857 .17923 L
.5381 .18129 L
.54762 .18346 L
.55714 .18574 L
.56667 .18812 L
.57619 .19059 L
.58571 .19314 L
.59524 .22638 L
.60476 .22772 L
.61429 .22952 L
.62381 .23164 L
.63333 .23399 L
.64286 .23654 L
.65238 .23926 L
.6619 .24212 L
.67143 .24512 L
.68095 .24824 L
.69048 .29288 L
.7 .2944 L
.70952 .29665 L
.71905 .29937 L
.72857 .30244 L
.7381 .30578 L
.74762 .30936 L
.75714 .31315 L
.76667 .31712 L
.77619 .32127 L
.78571 .36133 L
.79524 .36308 L
.80476 .3659 L
.81429 .36936 L
.82381 .3733 L
.83333 .37429 L
.84286 .37555 L
.85238 .37816 L
.8619 .38153 L
.87143 .38545 L
.88095 .43673 L
.89048 .43867 L
.9 .44219 L
.90952 .4466 L
.91905 .45162 L
.92857 .50146 L
.9381 .50416 L
.94762 .50869 L
.95714 .51423 L
.96667 .52047 L
Mistroke
.97619 .54352 L
Mfstroke
0 g
.02 w
.02381 .03319 Mdot
.11905 .05417 Mdot
.21429 .07161 Mdot
.30952 .10825 Mdot
.5 .19529 Mdot
.59524 .24481 Mdot
.69048 .31216 Mdot
.78571 .37892 Mdot
.83333 .38545 Mdot
.88095 .45789 Mdot
.92857 .52155 Mdot
.97619 .55864 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.309017 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.215791 0.241887 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0261 -6 -4.5 ]
[-0.0125 .0261 0 4.5 ]
[-0.0125 .14704 -18 -4.5 ]
[-0.0125 .14704 0 4.5 ]
[-0.0125 .26798 -6 -4.5 ]
[-0.0125 .26798 0 4.5 ]
[-0.0125 .38893 -18 -4.5 ]
[-0.0125 .38893 0 4.5 ]
[-0.0125 .50987 -6 -4.5 ]
[-0.0125 .50987 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .58503 -5 -6 ]
[.97619 .58503 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .56674 -5 -6 ]
[.97619 .56674 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0261 m
.00625 .0261 L
s
[(1)] -0.0125 .0261 1 0 Mshowa
0 .14704 m
.00625 .14704 L
s
[(1.5)] -0.0125 .14704 1 0 Mshowa
0 .26798 m
.00625 .26798 L
s
[(2)] -0.0125 .26798 1 0 Mshowa
0 .38893 m
.00625 .38893 L
s
[(2.5)] -0.0125 .38893 1 0 Mshowa
0 .50987 m
.00625 .50987 L
s
[(3)] -0.0125 .50987 1 0 Mshowa
.125 Mabswid
0 .05029 m
.00375 .05029 L
s
0 .07447 m
.00375 .07447 L
s
0 .09866 m
.00375 .09866 L
s
0 .12285 m
.00375 .12285 L
s
0 .17123 m
.00375 .17123 L
s
0 .19542 m
.00375 .19542 L
s
0 .21961 m
.00375 .21961 L
s
0 .2438 m
.00375 .2438 L
s
0 .29217 m
.00375 .29217 L
s
0 .31636 m
.00375 .31636 L
s
0 .34055 m
.00375 .34055 L
s
0 .36474 m
.00375 .36474 L
s
0 .41312 m
.00375 .41312 L
s
0 .43731 m
.00375 .43731 L
s
0 .46149 m
.00375 .46149 L
s
0 .48568 m
.00375 .48568 L
s
0 .00191 m
.00375 .00191 L
s
0 .53406 m
.00375 .53406 L
s
0 .55825 m
.00375 .55825 L
s
0 .58244 m
.00375 .58244 L
s
0 .60663 m
.00375 .60663 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0261 m
1 .0261 L
s
.99375 .14704 m
1 .14704 L
s
.99375 .26798 m
1 .26798 L
s
.99375 .38893 m
1 .38893 L
s
.99375 .50987 m
1 .50987 L
s
.125 Mabswid
.99625 .05029 m
1 .05029 L
s
.99625 .07447 m
1 .07447 L
s
.99625 .09866 m
1 .09866 L
s
.99625 .12285 m
1 .12285 L
s
.99625 .17123 m
1 .17123 L
s
.99625 .19542 m
1 .19542 L
s
.99625 .21961 m
1 .21961 L
s
.99625 .2438 m
1 .2438 L
s
.99625 .29217 m
1 .29217 L
s
.99625 .31636 m
1 .31636 L
s
.99625 .34055 m
1 .34055 L
s
.99625 .36474 m
1 .36474 L
s
.99625 .41312 m
1 .41312 L
s
.99625 .43731 m
1 .43731 L
s
.99625 .46149 m
1 .46149 L
s
.99625 .48568 m
1 .48568 L
s
.99625 .00191 m
1 .00191 L
s
.99625 .53406 m
1 .53406 L
s
.99625 .55825 m
1 .55825 L
s
.99625 .58244 m
1 .58244 L
s
.99625 .60663 m
1 .60663 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
129.000 13.000 moveto
(st) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .58503 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .02454 m
.03333 .02647 L
.04286 .02842 L
.05238 .0304 L
.0619 .03241 L
.07143 .03445 L
.08095 .03652 L
.09048 .03863 L
.1 .04077 L
.10952 .04294 L
.11905 .04515 L
.12857 .0474 L
.1381 .04969 L
.14762 .05201 L
.15714 .05438 L
.16667 .05678 L
.17619 .05923 L
.18571 .06172 L
.19524 .06425 L
.20476 .06683 L
.21429 .06945 L
.22381 .07236 L
.23333 .07534 L
.24286 .0784 L
.25238 .08152 L
.2619 .08473 L
.27143 .08801 L
.28095 .09138 L
.29048 .09483 L
.3 .09836 L
.30952 .10198 L
.31905 .10563 L
.32857 .10936 L
.3381 .11319 L
.34762 .1171 L
.35714 .1211 L
.36667 .12519 L
.37619 .12937 L
.38571 .13365 L
.39524 .13803 L
.40476 .1425 L
.41429 .14708 L
.42381 .15176 L
.43333 .15654 L
.44286 .16142 L
.45238 .16642 L
.4619 .17152 L
.47143 .17674 L
.48095 .18207 L
.49048 .18751 L
Mistroke
.5 .19308 L
.50952 .19817 L
.51905 .20337 L
.52857 .20866 L
.5381 .21405 L
.54762 .21954 L
.55714 .22513 L
.56667 .23083 L
.57619 .23664 L
.58571 .24255 L
.59524 .24858 L
.60476 .25485 L
.61429 .26125 L
.62381 .26778 L
.63333 .27444 L
.64286 .28123 L
.65238 .28815 L
.6619 .29522 L
.67143 .30243 L
.68095 .30979 L
.69048 .3173 L
.7 .32362 L
.70952 .33005 L
.71905 .33661 L
.72857 .34329 L
.7381 .35009 L
.74762 .35703 L
.75714 .3641 L
.76667 .3713 L
.77619 .37865 L
.78571 .38614 L
.79524 .39053 L
.80476 .39499 L
.81429 .39951 L
.82381 .4041 L
.83333 .40877 L
.84286 .42117 L
.85238 .43384 L
.8619 .4468 L
.87143 .46004 L
.88095 .47358 L
.89048 .48592 L
.9 .49853 L
.90952 .51142 L
.91905 .52458 L
.92857 .53804 L
.9381 .54704 L
.94762 .55623 L
.95714 .56562 L
.96667 .57522 L
Mistroke
.97619 .58503 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03437 m
.03333 .03639 L
.04286 .03844 L
.05238 .04052 L
.0619 .04263 L
.07143 .04476 L
.08095 .04692 L
.09048 .0491 L
.1 .05131 L
.10952 .05354 L
.11905 .05578 L
.12857 .05815 L
.1381 .06056 L
.14762 .06301 L
.15714 .06549 L
.16667 .068 L
.17619 .07054 L
.18571 .07311 L
.19524 .07569 L
.20476 .07829 L
.21429 .08089 L
.22381 .08418 L
.23333 .08753 L
.24286 .09093 L
.25238 .09438 L
.2619 .09786 L
.27143 .10137 L
.28095 .1049 L
.29048 .10844 L
.3 .11198 L
.30952 .11549 L
.31905 .12011 L
.32857 .12477 L
.3381 .12946 L
.34762 .13418 L
.35714 .13894 L
.36667 .14372 L
.37619 .14854 L
.38571 .15338 L
.39524 .15823 L
.40476 .1631 L
.41429 .16798 L
.42381 .17284 L
.43333 .17769 L
.44286 .18251 L
.45238 .18728 L
.4619 .19197 L
.47143 .19656 L
.48095 .20099 L
.49048 .2052 L
Mistroke
.5 .20908 L
.50952 .21592 L
.51905 .22246 L
.52857 .22877 L
.5381 .23484 L
.54762 .24069 L
.55714 .24629 L
.56667 .2516 L
.57619 .25656 L
.58571 .26106 L
.59524 .26489 L
.60476 .27381 L
.61429 .28217 L
.62381 .29012 L
.63333 .29772 L
.64286 .30498 L
.65238 .31189 L
.6619 .3184 L
.67143 .32444 L
.68095 .32982 L
.69048 .33421 L
.7 .3441 L
.70952 .35307 L
.71905 .3614 L
.72857 .3692 L
.7381 .3765 L
.74762 .38331 L
.75714 .38957 L
.76667 .39513 L
.77619 .39975 L
.78571 .40282 L
.79524 .41079 L
.80476 .4169 L
.81429 .42148 L
.82381 .42444 L
.83333 .42511 L
.84286 .44183 L
.85238 .45649 L
.8619 .4696 L
.87143 .48108 L
.88095 .49015 L
.89048 .50733 L
.9 .52213 L
.90952 .53518 L
.91905 .54639 L
.92857 .55486 L
.9381 .5693 L
.94762 .581 L
.95714 .59073 L
.96667 .59845 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .56674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01654 L
.04286 .01839 L
.05238 .02027 L
.0619 .02219 L
.07143 .02414 L
.08095 .02613 L
.09048 .02816 L
.1 .03023 L
.10952 .03235 L
.11905 .03453 L
.12857 .03665 L
.1381 .03881 L
.14762 .04102 L
.15714 .04326 L
.16667 .04556 L
.17619 .04791 L
.18571 .05033 L
.19524 .05281 L
.20476 .05537 L
.21429 .05802 L
.22381 .06054 L
.23333 .06316 L
.24286 .06586 L
.25238 .06867 L
.2619 .0716 L
.27143 .07466 L
.28095 .07785 L
.29048 .08121 L
.3 .08474 L
.30952 .08847 L
.31905 .09114 L
.32857 .09396 L
.3381 .09691 L
.34762 .10001 L
.35714 .10325 L
.36667 .10665 L
.37619 .1102 L
.38571 .11393 L
.39524 .11782 L
.40476 .1219 L
.41429 .12618 L
.42381 .13067 L
.43333 .13538 L
.44286 .14034 L
.45238 .14556 L
.4619 .15107 L
.47143 .15692 L
.48095 .16315 L
.49048 .16983 L
Mistroke
.5 .17707 L
.50952 .18043 L
.51905 .18427 L
.52857 .18855 L
.5381 .19325 L
.54762 .19839 L
.55714 .20398 L
.56667 .21007 L
.57619 .21672 L
.58571 .22405 L
.59524 .23227 L
.60476 .23589 L
.61429 .24033 L
.62381 .24543 L
.63333 .25115 L
.64286 .25748 L
.65238 .26442 L
.6619 .27204 L
.67143 .28043 L
.68095 .28976 L
.69048 .30038 L
.7 .30314 L
.70952 .30704 L
.71905 .31182 L
.72857 .31738 L
.7381 .32368 L
.74762 .33074 L
.75714 .33863 L
.76667 .34747 L
.77619 .35755 L
.78571 .36946 L
.79524 .37028 L
.80476 .37308 L
.81429 .37754 L
.82381 .38376 L
.83333 .39242 L
.84286 .40051 L
.85238 .4112 L
.8619 .424 L
.87143 .43901 L
.88095 .45701 L
.89048 .46451 L
.9 .47493 L
.90952 .48765 L
.91905 .50278 L
.92857 .52123 L
.9381 .52477 L
.94762 .53145 L
.95714 .54051 L
.96667 .55199 L
Mistroke
.97619 .56674 L
Mfstroke
0 g
.02 w
.02381 .02255 Mdot
.11905 .04492 Mdot
.21429 .06352 Mdot
.30952 .10259 Mdot
.5 .19541 Mdot
.59524 .24821 Mdot
.69048 .32003 Mdot
.78571 .39122 Mdot
.83333 .39818 Mdot
.88095 .47543 Mdot
.92857 .54332 Mdot
.97619 .58286 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{689.938, 426.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:a0001ZR000`400?l00000o`00003oo`3ooooo
0?oook<0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo
003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0
oooo/`3oool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool0
03@0oooo0P00000b0?ooo`D00000<`3oool300000380oooo0`00000b0?ooo`<00000<03oool30000
00@0oooo0P00000f0?ooo`800000<P3oool5000003<0oooo0`00000a0?ooo`<00000<`3oool30000
0300oooo0`0000040?ooo`8000008`3oool003<0oooo00@000000?ooo`3oool00000<P3oool01000
0000oooo0?ooo`00000d0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo0000
000`0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000003@0oooo00@000000?ooo`3oool00000<P3oool010000000oooo0?ooo`00000d
0?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`050000003o
ool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000280
oooo000c0?ooo`040000003oool0oooo000003<0oooo00<000000?ooo`3oool0<@3oool500000340
oooo00D000000?ooo`3oool0oooo0000000`0?ooo`050000003oool0oooo0?ooo`000000<03oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000
<`3oool00`000000oooo0?ooo`0a0?ooo`D00000<03oool01@000000oooo0?ooo`3oool000000340
oooo00D000000?ooo`3oool0oooo0000000`0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000008P3oool003<0oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0`
0?ooo`040000003oool0oooo00000380oooo1000000b0?ooo`<00000<@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000=03oool00`000000
oooo0?ooo`0`0?ooo`040000003oool0oooo00000340oooo1000000c0?ooo`<00000<@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000280oooo000c0?ooo`040000003oool0oooo
00000340oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool000000380oooo00<0
00000?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000d0?ooo`040000003oool0oooo00000340oooo00D000000?oo
o`3oool0oooo0000000b0?ooo`030000003oool000000340oooo00<000000?ooo`3oool0<`3oool0
1@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000R0?ooo`00<`3oool010000000oooo0?ooo`00000a0?ooo`050000003oool0oooo0?ooo`00
0000<`3oool2000003<0oooo00<000000?ooo`3oool0<@3oool01@000000oooo0?ooo`3oool00000
02l0oooo0P0000040?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000<@3o
ool01@000000oooo0?ooo`3oool0000003<0oooo0P00000b0?ooo`030000003oool0oooo0380oooo
00D000000?ooo`3oool0oooo0000000_0?ooo`800000103oool010000000oooo0?ooo`00000R0?oo
o`00=03oool2000003<0oooo0`00000e0?ooo`030000003oool0oooo0380oooo0P00000b0?ooo`<0
0000<@3oool00`000000oooo0?ooo`030?ooo`800000=P3oool2000003<0oooo0`00000e0?ooo`03
0000003oool0oooo0340oooo0P00000c0?ooo`<00000<@3oool00`000000oooo0?ooo`030?ooo`80
00008`3oool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool0
0?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo000_0?ooool000007000000/0?ooool00000
7@00000O0?ooo`00;`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`009@3oool5000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`D00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01d0oooo000V0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool00P3oool300000?l0oooo4`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo01d0oooo000W
0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`D00000o`3oool@0?ooo`<000009@3oool0
0`000000oooo0?ooo`040?ooo`<000000`3oool300000003003jVP3oool0oooo0?l0oooo3P3oool3
000001l0oooo000X0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo1@000005
003jV_l0oooo3@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool5000000D00?ZJo`3oool=0?ooo`030000003oool0oooo01d0oooo000U0?oo
o`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`3oool5000000P00?ZJo`3o
ool:0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo1@000008003jV_l0oooo2P3oool00`000000oooo0?ooo`0M0?ooo`009@3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool3000000`00?ZJ
o`3oool70?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo1@00000;003jV_l0oooo1`3oool00`000000oooo0?ooo`0M0?ooo`00
9P3oool3000000H0oooo00<000000?ooo`3oool01@3oool>003jV_l0oooo1@3oool00`000000oooo
0?ooo`0R0?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`<000001@3oool<003jV_l0oooo
0P3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`l00?ZJoP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo3000nY[n0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`8000003P3oool>003jVP80oooo0`00003f0?ooo`800000;03oool2
00000180oooo2`00nY[k0?ooo`8000007`3oool002l0oooo00<000000?ooo`3oool0403oool6003j
VP80003o1000nYX500000?H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0C0?oo
o`/00?ZJ0`00003g0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0180
oooo1`00nYX00`000?l00?ZJ003jVP05000000<00?ZJl`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01T0oooo1000nYX500000?H0oooo00<000000?ooo`3oool07@3oool002l0oooo
00<000000?ooo`3oool05@3oool6003jVP030000o`000000000000<000001@00nY[a0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool06`3oool2003jVPD000000P00nY[d0?ooo`030000
003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo01P0oooo1@00nYX3000000T00?ZJkP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo1@000008003jV^h0oooo00<0
00000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool06P3oool3003jVP<0oooo3000nY[[
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3oool3000000/00?ZJk03oool0
0`000000oooo0?ooo`0M0?ooo`00;`3oool2000002@0oooo2`00nY[X0?ooo`800000;03oool20000
02@0oooo3000nY[X0?ooo`8000007`3oool002l0oooo00<000000?ooo`3oool09@3oool<003jV^H0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0V0?ooo``00?ZJiP3oool00`000000
oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`0X0?ooo``00?ZJh`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo2`00nY[T0?ooo`030000003oool0oooo01d0oooo
000_0?ooo`030000003oool0oooo02/0oooo2`00nY[Q0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:`3oool<003jV^40oooo00<000000?ooo`3oool07@3oool002l0oooo00<00000
0?ooo`3oool0;@3oool;003jVP<00000g03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02h0oooo2`00nYX300000=`0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?oo
o`3oool0<03oool4003jVP030000o`00nYX00?ZJ00D00000f`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0340oooo1`00nYX500000=/0oooo00<000000?ooo`3oool07@3oool002l0
oooo0P00000c0?ooo`@00?ZJ00<0003o0000000000000`000002003jV]P0oooo0P00000/0?ooo`80
0000=03oool5003jVPD000000P00nY[H0?ooo`8000007`3oool002l0oooo00<000000?ooo`3oool0
<`3oool4003jVPD000001@00nY[F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
=P3oool2003jVPD000001@00nY[F0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003o
ool0oooo03D0oooo0`00nYX3000000T00?ZJd`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo03T0oooo0`000009003jV]<0oooo00<000000?ooo`3oool07@3oool002L0oooo0`000005
0?ooo`030000003oool0oooo03/0oooo3000nY[@0?ooo`030000003oool0oooo02<0oooo0`000004
0?ooo`030000003oool0oooo03`0oooo2P00nY[B0?ooo`030000003oool0oooo01d0oooo000X0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?@3oool<003jV/h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo2@00nY[A0?oo
o`030000003oool0oooo01d0oooo000U0?ooo`D000001@3oool200000440oooo3000nY[90?ooo`<0
00008`3oool5000000@0oooo00<000000?ooo`3oool0@@3oool9003jV/h0oooo00<000000?ooo`3o
ool07@3oool002D0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`130?ooo`@0
0?ZJ00<0003o003jVP00nYX01@00nY[80?ooo`030000003oool0oooo0240oooo00@000000?ooo`3o
ool000001@3oool3000004@0oooo2@00nY[90?ooo`<000007`3oool002H0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`150?ooo`@00?ZJ0P000?l5003jV/L0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo000000050?ooo`030000003oool0oooo04H0oooo2@00nY[90?ooo`03
0000003oool0oooo01d0oooo000W0?ooo`8000001P3oool00`000000oooo0?ooo`160?ooo`H00?ZJ
0P000?l3003jV/H0oooo00<000000?ooo`3oool08`3oool2000000D0oooo00<000000?ooo`3oool0
B03oool:003jV/H0oooo00<000000?ooo`3oool07@3oool002P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`180?ooo`H00?ZJ00<0003o003jVP00nYX00P00nYX300000<40oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04T0oooo2`00
nY[40?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo04/0oooo1000nYX0
0`000?l00?ZJ003jVP0500000<00oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1<
0?ooo`L00?ZJ0`0000320?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000CP3oool4003j
VP030000o`000000000000<0000000<00?ZJ0?ooo`3oool0_03oool2000002`0oooo00<000000?oo
o`3oool0CP3oool4003jVPD00000`@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000
oooo0?ooo`1>0?ooo`@00?ZJ1@000002003jV[h0oooo00<000000?ooo`3oool0:P3oool200000580
oooo00<00?ZJ0000000000000`000003003jV[d0oooo0P00000O0?ooo`00;`3oool00`000000oooo
0?ooo`1@0?ooo`<00?ZJ0`000006003jV[/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`1B0?ooo`D000001P00nYZk0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003o
ool0oooo05D0oooo2P00nYZh0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0D`3o
ool3000000T00?ZJ^@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`1F
0?ooo`/00?ZJ]P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05H0oooo2P00nYZh
0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo05P0oooo1000nYX20000
o`H00?ZJ/`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05T0oooo1000nYX00`00
0?l00?ZJ003jVP02003jV[H0oooo00<000000?ooo`3oool07@3oool002l0oooo0P00001K0?ooo`D0
0?ZJ00<0003o003jVP00nYX01000nYZ`0?ooo`800000;03oool2000005`0oooo2P00nYZb0?ooo`80
00007`3oool002l0oooo00<000000?ooo`3oool0F`3oool5003jVP<0003o1000nYZ`0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0G03oool;003jV[40oooo00<000000?ooo`3oool0
7@3oool002l0oooo00<000000?ooo`3oool0GP3oool3003jVP@0003o1000nYZ^0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0G`3oool3003jVP80003o1000nYZ`0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo05l0oooo1@00nYX20000o`H00?ZJZ`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0600oooo1@00nYX00`000?l00?ZJ003jVP02
003jVZh0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0H03oool6003j
VP80003o1P00nYZY0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0H@3oool;003j
VZ`0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0H`3oool4003jVP@0
003o1000nYZX0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0I03oool4003jVP03
0000o`00nYX00?ZJ00800?ZJZ`3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool2000006H0oooo
1000nYX30000o`030?ooo`00nYX00?ZJ00<00?ZJY03oool2000002`0oooo0P00001W0?ooo`@00?ZJ
00<0003o003jVP00nYX00`00nYZW0?ooo`8000007`3oool002l0oooo00<000000?ooo`3oool0IP3o
ool5003jVP<0003o1P00nYZS0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0I`3o
ool:003jVZL0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0J03oool4
003jVPD0003o1@00nYZQ0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0J@3oool4
003jVP80003o0`00nYZV0?ooo`030000003oool0oooo01d0oooo000V0?ooo`<000001P3oool00`00
0000oooo0?ooo`1Z0?ooo`@00?ZJ10000?l00`3oool00?ZJ003jVP02003jVZ00oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`1[0?ooo`@00?ZJ00<0003o003jVP00nYX00`00nYZS0?oo
o`030000003oool0oooo01d0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`1[0?ooo`@00?ZJ00<0oooo0000o`000?l00P000?l00`3oool00?ZJ003jVP03003j
VYd0oooo00<000000?ooo`3oool08P3oool3000000D0oooo00<000000?ooo`3oool0K03oool4003j
VP030000o`00nYX00?ZJ00@00?ZJX@3oool00`000000oooo0?ooo`0M0?ooo`009@3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0K@3oool5003jVP@0003o1@00nYZL0?oo
o`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo06h0oooo1000nYX20000o`@00?ZJX03oool00`000000oooo0?ooo`0M0?ooo`009@3oool40000
00H0oooo0P00001_0?ooo`D00?ZJ10000?l20?ooo`<00?ZJV@3oool3000002<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`<00000K`3oool5003jVP80003o1000nYZL0?ooo`<000007`3oool0
02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1a0?ooo`<00?ZJ00<0oooo0000
o`000?l00`000?l5003jVYP0oooo00<000000?ooo`3oool08@3oool4000000D0oooo00<000000?oo
o`3oool0L@3oool4003jVP80003o1@00nYZL0?ooo`030000003oool0oooo01d0oooo000V0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0LP3oool4003jVPD0003o1`00nYZE0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1c0?ooo`D0
0?ZJ00<0003o003jVP00nYX00P00nYZK0?ooo`030000003oool0oooo01d0oooo000W0?ooo`800000
1P3oool00`000000oooo0?ooo`1c0?ooo`@00?ZJ0P3oool30000o`80oooo1@00nYZD0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1d0?ooo`D00?ZJ
0P000?l4003jVYT0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0M@3o
ool4003jVP030?ooo`000?l0003o0080003o0`3oool3003jVY<0oooo00<000000?ooo`3oool08`3o
ool2000000D0oooo00<000000?ooo`3oool0M`3oool3003jVP80003o1000nYZH0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo07H0oooo1000nYX00`3oool0003o0000o`02
0000o`<0oooo1@00nYZ@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0N03oool5
003jVP030000o`00nYX00?ZJ00800?ZJUP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool20000
07T0oooo1000nYX00`3oool0003o0000o`030000o`030?ooo`00nYX00?ZJ00<00?ZJSP3oool20000
02`0oooo0P00001j0?ooo`/00?ZJT`3oool2000001l0oooo000_0?ooo`030000003oool0oooo07T0
oooo1@00nYX50000o`<0oooo0P00nYZ?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0O03oool4003jVP030000o`00nYX00?ZJ00800?ZJT`3oool00`000000oooo0?ooo`0M0?ooo`00
;`3oool00`000000oooo0?ooo`1k0?ooo`@00?ZJ0P3oool30000o`80oooo0`00nYZ>0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0OP3oool3003jVP80003o1000nYZA0?ooo`030000
003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo07d0oooo1000nYX00`3oool0003o0000
o`030000o`800?ZJSP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo0`00
nYX20000o`@00?ZJT03oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`1n
0?ooo`@00?ZJ00<0oooo0000o`000?l00P000?l3003jVXd0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`200?ooo`D00?ZJ00<0003o003jVP00nYX00P00nYZ>0?ooo`030000003oool0
oooo01d0oooo000_0?ooo`800000P@3oool3003jVP<0oooo0P000?l3000008/0oooo0P00000/0?oo
o`030000003oool0oooo0840oooo2000nYX3000008`0oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0P@3oool3003jVP<0oooo1@00002;0?ooo`030000003oool0oooo02X0
oooo0P0000250?ooo`@00?ZJ1@00002:0?ooo`8000007`3oool002l0oooo00<000000?ooo`3oool0
PP3oool4003jVP030?ooo`000000000000<000000P00nYZ90?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0QP3oool2003jVPD00000R`3oool00`000000oooo0?ooo`0M0?ooo`00;`3o
ool00`000000oooo0?ooo`230?ooo`@00?ZJ1@000003003jVXP0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`270?ooo`03003jVP000000000000<000000`00nYZ80?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo08D0oooo0`00nYX300000003003jVP000?l0
0?ZJ00@00?ZJQ@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo08T0oooo0`000006
003jVXH0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0QP3oool3003j
VP030?ooo`00nYX00?ZJ00P00?ZJP`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
08/0oooo2000nYZ50?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000S03oool4003jVP80
003o1@00nYZ00?ooo`800000;03oool2000008d0oooo1000nYX010000?l00?ZJ003jVP00nYZ30?oo
o`8000007`3oool002l0oooo00<000000?ooo`3oool0S@3oool4003jVP80003o1000nYZ00?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0SP3oool7003jVX<0oooo00<000000?ooo`3o
ool07@3oool002l0oooo00<000000?ooo`3oool0SP3oool4003jVP80003o00<0oooo003jVP00nYX0
0P00nYYn0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0S`3oool8003jVX40oooo
00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0T03oool3003jVP<0003o1000
nYYm0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0T@3oool7003jVX00oooo00<0
00000?ooo`3oool07@3oool002H0oooo0`0000060?ooo`030000003oool0oooo0940oooo0`00nYX3
0000o`030?ooo`00nYX00?ZJ00<00?ZJNP3oool00`000000oooo0?ooo`0R0?ooo`<000001@3oool0
0`000000oooo0?ooo`2B0?ooo`<00?ZJ00<0003o003jVP00nYX00P00nYYn0?ooo`030000003oool0
oooo01d0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2B
0?ooo`@00?ZJ0`000?l5003jVWT0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0T`3oool8003jVWd0oooo00<000000?ooo`3oool07@3o
ool002D0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000U03oool4003jVPD0003o0`00
nYYf0?ooo`<000008`3oool01@000000oooo0?ooo`3oool0000000@0oooo0`00002D0?ooo`@00?ZJ
00@0003o003jVP00nYX00?ZJNP3oool3000001l0oooo000V0?ooo`<000001P3oool00`000000oooo
0?ooo`2E0?ooo`@00?ZJ10000?l5003jVWD0oooo00<000000?ooo`3oool08P3oool3000000D0oooo
00<000000?ooo`3oool0UP3oool7003jVW/0oooo00<000000?ooo`3oool07@3oool002D0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo09H0oooo1000nYX0103oool0003o
0000o`000?l5003jVW@0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0U`3oool8003jVWT0oooo00<000000?ooo`3oool07@3oool002D0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo09P0oooo1000nYX30000
o`80oooo0P00nYYd0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo09T0oooo1`00nYYh0?ooo`030000003oool0oooo01d0oooo000V0?oo
o`<000001P3oool00`000000oooo0?ooo`2I0?ooo`@00?ZJ10000?l3003jVW<0oooo00<000000?oo
o`3oool08P3oool3000000D0oooo00<000000?ooo`3oool0VP3oool3003jVP030000o`00nYX00?ZJ
00800?ZJMP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2K0?ooo`<0
0?ZJ10000?l2003jVW<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2K0?ooo`P0
0?ZJM@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool2000009d0oooo0`00nYX00`3oool0003o
0000o`03003jVW40oooo0P00000/0?ooo`800000W@3oool4003jVP040000o`00nYX00?ZJ003jVW<0
oooo0P00000O0?ooo`00;`3oool00`000000oooo0?ooo`2M0?ooo`@00?ZJ0P000?l2003jVW80oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2N0?ooo`H00?ZJM03oool00`000000oooo
0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2N0?ooo`@00?ZJ00@0003o0000000000000000
L@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09l0oooo1@00nYX300000740oooo
00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0X03oool2003jVPD00000L03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:40oooo0P00nYX500000700oooo00<0
00000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0X@3oool00`00nYX0000000000003
000000<00?ZJK@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:80oooo00<00?ZJ
0000000000000`000002003jVVh0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?oo
o`3oool0XP3oool5000000D00?ZJJ`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0:<0oooo1@000003003jVVd0oooo00<000000?ooo`3oool07@3oool002l0oooo0P00002T0?ooo`<0
000000<00?ZJ0000o`000?l01000nYYY0?ooo`800000;03oool200000:D0oooo0`0000000`00nYX0
003o003jVP03003jVVX0oooo0P00000O0?ooo`00;`3oool00`000000oooo0?ooo`2U0?ooo`@00?ZJ
0P000?l3003jVVT0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2V0?ooo`P00?ZJ
JP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2V0?ooo`@00?ZJ0P00
0?l3003jVVP0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2W0?ooo`@00?ZJ00<0
003o003jVP00nYX00P00nYYX0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0
oooo0:P0oooo1000nYX00`000?l00?ZJ003jVP03003jVVD0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`2Y0?ooo`T00?ZJIP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`2Y0?ooo`@00?ZJ00<0003o003jVP00nYX01000nYYS0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0ZP3oool4003jVP030000o`00nYX00?ZJ00800?ZJI@3oool00`00
0000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2[0?ooo`<00?ZJ0`000?l4003jVV80
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2/0?ooo`<00?ZJ0P000?l4003jVV<0
oooo00<000000?ooo`3oool07@3oool002l0oooo0P00002]0?ooo`800?ZJ10000?l0103oool00?ZJ
003jVP00nYYP0?ooo`800000;03oool200000:h0oooo0`00nYX20000o`@00?ZJH@3oool2000001l0
oooo000_0?ooo`030000003oool0oooo0:`0oooo0`00nYX00`3oool0003o0000o`020000o`<00?ZJ
H03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:h0oooo1000nYX20000o`<00?ZJ
H@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2]0?ooo`@00?ZJ1000
0?l5003jVUd0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2_0?ooo`@00?ZJ0P00
0?l3003jVV00oooo00<000000?ooo`3oool07@3oool00200oooo0`0000040?ooo`8000001P3oool0
0`000000oooo0?ooo`2^0?ooo`@00?ZJ00@0oooo0000o`000?l0003o1P00nYYK0?ooo`030000003o
ool0oooo01`0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`2a0?ooo`@00?ZJ00<0
003o003jVP00nYX00P00nYYN0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2`0?ooo`@00?ZJ0`00
0?l20?ooo`@00?ZJFP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`2b0?ooo`@00?ZJ00<0003o003jVP00nYX0
0P00nYYM0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001@3oool200000;80oooo1000nYX40000o`80oooo0`00nYYG0?ooo`<00000
7`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0]03oool3003jVP80003o0`00nYYL0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2c0?ooo`<0
0?ZJ10000?l20?ooo`800?ZJF@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool300000;D0oooo0`00nYX20000o`<00?ZJF@3oool30000
01l0oooo000Q0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`2d0?ooo`800?ZJ0P3oool40000o`<00?ZJF03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2f
0?ooo`@00?ZJ00@0003o003jVP00nYX00?ZJFP3oool00`000000oooo0?ooo`0M0?ooo`00803oool2
000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2d0?ooo`<00?ZJ0P3o
ool40000o`<00?ZJE`3oool00`000000oooo0?ooo`0L0?ooo`800000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0;L0oooo1000nYX010000?l00?ZJ003jVP00nYYI0?ooo`03
0000003oool0oooo01d0oooo000Q0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000
003oool0oooo0;D0oooo1000nYX20?ooo`<0003o0`00001F0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0^@3oool6003jVP<00000
EP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`2f0?ooo`@00?ZJ0P3o
ool00`000?l0000000000003000005D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`2j0?ooo`@00?ZJ1@00001E0?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000^@3oool4
003jVP030?ooo`000000000000<000000P00nYYB0?ooo`800000;03oool200000;d0oooo0P00nYX5
000005@0oooo0P00000O0?ooo`00;`3oool00`000000oooo0?ooo`2i0?ooo`@00?ZJ1@000003003j
VU80oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2m0?ooo`03003jVP0000000000
00<000000`00nYYB0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0;/0
oooo0`00nYX300000080003o1@00nYY?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0_`3oool3000000D00?ZJD@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo
0?ooo`2l0?ooo`H00?ZJ0P000?l5003jVTh0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`300?ooo`<00?ZJ0P000?l3003jVU00oooo00<000000?ooo`3oool07@3oool002l0oooo00<0
00000?ooo`3oool0`03oool4003jVP<0003o0`00nYY=0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0`@3oool4003jVP030000o`00nYX00?ZJ00800?ZJCP3oool00`000000oooo0?oo
o`0M0?ooo`00;`3oool00`000000oooo0?ooo`310?ooo`@00?ZJ0`000?l4003jVT/0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`320?ooo`@00?ZJ00<0003o003jVP00nYX00P00nYY=
0?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000a03oool3003jVP<0003o1000nYY90?oo
o`800000;03oool200000<D0oooo0`00nYX20000o`@00?ZJBP3oool2000001l0oooo000_0?ooo`03
0000003oool0oooo0<@0oooo0`00nYX30000o`030?ooo`00nYX00?ZJ00800?ZJB03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0<D0oooo0`00nYX20000o`@00?ZJBP3oool00`000000
oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`350?ooo`<00?ZJ10000?l4003jVTL0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`360?ooo`<00?ZJ0`000?l3003jVTT0oooo
00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0aP3oool3003jVP@0003o00<0
oooo003jVP00nYX00P00nYY50?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0a`3o
ool3003jVP<0003o0`00nYY80?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0
oooo0<L0oooo0`00nYX00`3oool0003o0000o`020000o`D00?ZJ@`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0<P0oooo0`00nYX30000o`<00?ZJA`3oool00`000000oooo0?ooo`0M
0?ooo`00;`3oool00`000000oooo0?ooo`380?ooo`@00?ZJ10000?l00`3oool00?ZJ003jVP02003j
VT80oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`390?ooo`@00?ZJ0P000?l3003j
VTH0oooo00<000000?ooo`3oool07@3oool002l0oooo0P00003:0?ooo`@00?ZJ00@0oooo0000o`00
0?l0003o0P3oool4003jVSl0oooo0P00000/0?ooo`800000b`3oool4003jVP80003o0`00nYY40?oo
o`8000007`3oool002l0oooo00<000000?ooo`3oool0b`3oool3003jVP040?ooo`000?l0003o0000
o`80oooo1000nYXo0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0c03oool3003j
VP80003o1000nYY30?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0<`0
oooo0`00nYX00`3oool0003o0000o`020000o`80oooo0`00nYXn0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0c@3oool3003jVP80003o1000nYY20?ooo`030000003oool0oooo01d0
oooo000P0?ooo`<000000P3oool5000000D0oooo00<000000?ooo`3oool0c@3oool3003jVP030?oo
o`000?l0003o0080003o0P3oool2003jVSh0oooo00<000000?ooo`3oool0703oool300000080oooo
1@0000040?ooo`030000003oool0oooo0<h0oooo1000nYX20000o`@00?ZJ@03oool00`000000oooo
0?ooo`0M0?ooo`008@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0cP3oool3003jVP80oooo10000?l3003jVSd0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0c`3oool4003jVP80003o1000nYXo0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3?0?ooo`<00?ZJ
0P3oool40000o`800?ZJ?@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3A0?ooo`@00?ZJ0P000?l3003jVSh0oooo
00<000000?ooo`3oool07@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`800000d@3oool3003jVP<0oooo0P000?l2003jVS/0oooo0`00000O0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool300000=80oooo1000nYX20000o`800?ZJ?03o
ool3000001l0oooo000Q0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0=40oooo0`00nYX30?ooo`030000o`00nYX0000000800000>`3o
ool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0=@0oooo1P00nYX3000003/0oooo00<000000?ooo`3oool0
7@3oool00200oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`3B0?ooo`<00?ZJ0P3oool00`000?l0000000000003000003X0oooo00<000000?ooo`3oool0
703oool2000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0=D0
oooo1000nYX5000003X0oooo00<000000?ooo`3oool07@3oool00240oooo00<000000?ooo`3oool0
0P3oool3000000H0oooo00<000000?ooo`3oool0d`3oool4003jVP030?ooo`000000000000<00000
0P00nYXh0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool0e`3oool2003jVPD00000>P3oool00`000000oooo0?ooo`0M0?ooo`00;`3o
ool00`000000oooo0?ooo`3D0?ooo`@00?ZJ1@000003003jVSL0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`3H0?ooo`03003jVP000000000000<000000P00nYXh0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo0=H0oooo0`00nYX300000080003o1000nYXe
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0fP3oool3000000@00?ZJ=`3oool0
0`000000oooo0?ooo`0M0?ooo`00;`3oool200000=P0oooo0P00nYX0103oool00?ZJ003jVP00nYX2
0000o`D00?ZJ<P3oool2000002`0oooo0P00003L0?ooo`<00?ZJ00@0003o003jVP00nYX00?ZJ=@3o
ool2000001l0oooo000_0?ooo`030000003oool0oooo0=/0oooo1000nYX20000o`@00?ZJ<P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=`0oooo0`00nYX010000?l00?ZJ003jVP00
nYXe0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0=`0oooo1000nYX2
0000o`040?ooo`00nYX00?ZJ003jVS40oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`3M0?ooo`<00?ZJ00@0003o003jVP00nYX00?ZJ=03oool00`000000oooo0?ooo`0M0?ooo`00;`3o
ool00`000000oooo0?ooo`3N0?ooo`<00?ZJ0`000?l2003jVS40oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`3N0?ooo`<00?ZJ00@0003o003jVP00nYX00?ZJ<`3oool00`000000oooo
0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`3O0?ooo`800?ZJ0`000?l3003jVS00oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`3O0?ooo`<00?ZJ00@0003o003jVP00nYX00?ZJ
<P3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool200000>00oooo0`00nYX00`3oool0003o0000
o`02003jVRl0oooo0P00000/0?ooo`800000h@3oool3003jVP040000o`00nYX00?ZJ003jVS00oooo
0P00000O0?ooo`00;`3oool00`000000oooo0?ooo`3P0?ooo`@00?ZJ00@0003o003jVP00nYX00?ZJ
;`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0>40oooo1`00nYX`0?ooo`030000
003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0>40oooo1000nYX00`000?l00?ZJ0000
0002000002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3R0?ooo`D00?ZJ0`00
000^0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0><0oooo0`00nYX5
000002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3T0?ooo`800?ZJ1@00000]
0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0>@0oooo0P00nYX50000
0003003jVP3oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3U0?oo
o`03003jVP000000000000<000000P00nYX[0?ooo`030000003oool0oooo01d0oooo000_0?ooo`03
0000003oool0oooo0>H0oooo1@000002003jVRX0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`3V0?ooo`D000000`00nYXZ0?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000
j03oool3000000030000o`00nYX00?ZJ00<00?ZJ9P3oool2000002`0oooo0P00003X0?ooo`<00000
0P000?l4003jVRL0oooo0P00000O0?ooo`00;`3oool00`000000oooo0?ooo`3X0?ooo`<00?ZJ00<0
003o003jVP00nYX01000nYXU0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0j03o
ool3003jVP80003o1000nYXW0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0
oooo0>T0oooo0`00nYX30000o`@00?ZJ903oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0>T0oooo1000nYX20000o`<00?ZJ9P3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`3Z0?ooo`800?ZJ10000?l0103oool00?ZJ003jVP00nYXS0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0jP3oool4003jVP80003o0`00nYXU0?ooo`030000003oool0
oooo01d0oooo000P0?ooo`<00000103oool3000000D0oooo00<000000?ooo`3oool0jP3oool3003j
VP030?ooo`000?l0003o0080003o0P00nYXS0?ooo`030000003oool0oooo01`0oooo0`0000040?oo
o`<00000103oool00`000000oooo0?ooo`3/0?ooo`@00?ZJ00@0003o003jVP00nYX00?ZJ903oool0
0`000000oooo0?ooo`0M0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0j`3oool4003jVP<0003o0`00nYXR0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0>d0oooo1000nYX010000?l00?ZJ003jVP00nYXS0?ooo`030000003oool0oooo01d0oooo000Q0?oo
o`040000003oool0oooo0?ooo`D000001@3oool200000>d0oooo1000nYX0103oool0003o0000o`00
nYX3000001h0oooo0`00000O0?ooo`040000003oool0oooo0?ooo`D00000103oool300000>l0oooo
0`00nYX00`000?l00?ZJ003jVP03000001h0oooo0`00000O0?ooo`008@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3^0?ooo`<00?ZJ
00<0oooo0000o`0000001000000O0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0l03oool3003jVP03
0000o`000000000000<000007`3oool00`000000oooo0?ooo`0M0?ooo`008@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0k`3oool3003jVP030?oo
o`000000000000<000000`00nYXL0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000050?ooo`030000003oool0oooo0?40oooo0`00nYX500000003003j
VP3oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00200oooo0P0000050?ooo`8000001P3o
ool00`000000oooo0?ooo`3`0?ooo`<00?ZJ1@000004003jVQ/0oooo00<000000?ooo`3oool0703o
ool2000000D0oooo0P0000050?ooo`030000003oool0oooo0?80oooo0P00nYX5000000800?ZJ7@3o
ool00`000000oooo0?ooo`0M0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0l@3oool3003jVP<000000`000?l3003jVQX0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0m@3oool3000000030000o`00nYX00?ZJ00800?ZJ6`3oool00`000000oooo0?ooo`0M
0?ooo`00;`3oool00`000000oooo0?ooo`3b0?ooo`800?ZJ00@0oooo003jVP00nYX00?ZJ0`000?l5
003jVQL0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3f0?ooo`<00?ZJ00<0003o
003jVP00nYX00P00nYXJ0?ooo`030000003oool0oooo01d0oooo000_0?ooo`800000m`3oool3003j
VP<0003o1@00nYXE0?ooo`800000;03oool200000?P0oooo0`00nYX20000o`<00?ZJ603oool20000
01l0oooo000_0?ooo`030000003oool0oooo0?L0oooo0`00nYX30000o`80oooo0P00nYXF0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0n03oool3003jVP80003o0`00nYXH0?ooo`03
0000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0?P0oooo0`00nYX40000o`<00?ZJ
5@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?T0oooo0`00nYX20000o`<00?ZJ
5`3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`3i0?ooo`<00?ZJ1000
0?l2003jVQD0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3j0?ooo`<00?ZJ0P00
0?l3003jVQH0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0nP3oool3
003jVP030?ooo`000?l0003o00<00?ZJ503oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0?/0oooo0`00nYX20000o`<00?ZJ5@3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`3k0?ooo`<00?ZJ00<0oooo0000o`000?l00`00000C0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0o03oool6003jVP<000004`3oool00`000000oooo0?ooo`0M0?oo
o`00;`3oool200000?d0oooo0`00nYX00`3oool000000000000300000140oooo0P00000/0?ooo`80
0000oP3oool4003jVPD000004@3oool2000001l0oooo000_0?ooo`030000003oool0oooo0?d0oooo
0`00nYX5000000<00?ZJ3`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo
0@3oool00`00nYX000000000000300000180oooo00<000000?ooo`3oool07@3oool002l0oooo00<0
00000?ooo`3oool0oP3oool2003jVPD000001P00nYX<0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`D000000P00nYX@0?ooo`030000003oool0oooo01d0oooo000_
0?ooo`030000003oool0oooo0?l0oooo0P00nYX3000000<0003o1P00nYX:0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0o`3oool30?ooo`<000001000nYX?0?ooo`030000003oool0
oooo01d0oooo000_0?ooo`030000003oool0oooo0?l0oooo0`3oool3003jVP<0003o0P3oool4003j
VPT0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0`00nYX00`00
0?l00?ZJ003jVP02003jVPd0oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`@00?ZJ0`000?l20?ooo`<00?ZJ203oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0?l0oooo1@3oool3003jVP030000o`00nYX00?ZJ00800?ZJ303oool00`000000
oooo0?ooo`0M0?ooo`00;`3oool200000?l0oooo1P3oool4003jVP<0003o0P3oool2003jVPL0oooo
0P00000/0?ooo`800000o`3oool70?ooo`<00?ZJ0P000?l3003jVPX0oooo0P00000O0?ooo`00;`3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0`00nYX40000o`800?ZJ203oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0?l0oooo1`3oool3003jVP80003o0P00nYX;0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo0?l0oooo203oool3003jVP<0003o0`00nYX7
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3oool80?ooo`L00?ZJ2P3oool0
0`000000oooo0?ooo`0M0?ooo`00803oool3000000<0oooo0`0000060?ooo`030000003oool0oooo
0?l0oooo2@3oool3003jVP030?ooo`000?l0003o00800?ZJ1`3oool00`000000oooo0?ooo`0L0?oo
o`<000000`3oool3000000D0oooo00<000000?ooo`3oool0o`3oool90?ooo`L00?ZJ2@3oool00`00
0000oooo0?ooo`0M0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0`00nYX0103oool0003o003jVP00nYX7
0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3oool;0?ooo`H00?ZJ203oool00`000000oooo0?oo
o`0M0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3o
ool200000?l0oooo303oool3003jVP040000o`00nYX00?ZJ003jVP@0oooo0`00000O0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`<00000o`3oool<0?ooo`80
0?ZJ00@0003o003jVP00nYX00?ZJ1@3oool3000001l0oooo000Q0?ooo`040000003oool0oooo0?oo
o`@000001P3oool00`000000oooo0?ooo`3o0?ooo``0oooo0`00nYX010000?l00000000000000005
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool0oooo100000050?ooo`030000003o
ool0oooo0?l0oooo303oool3003jVP030000o`00nYX00000008000001@3oool00`000000oooo0?oo
o`0M0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`800?ZJ1@0000040?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo0?l0oooo3@3oool3003jVPD00000103oool00`000000oooo
0?ooo`0M0?ooo`00803oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooo`h0oooo00<00?ZJ0000000000000`0000040?ooo`030000003oool0oooo01`0oooo0P00
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool>0?ooo`800?ZJ1@00
00040?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003oool0oooo00<0oooo0P000006
0?ooo`030000003oool0oooo0?l0oooo3`3oool5000000@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooa00oooo1@000004
0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo0?l0oooo403oool30000
00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooa40oooo0`0000050?oo
o`030000003oool0oooo01d0oooo000_0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool2000002`0oooo0P0000050?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`80
00007`3oool002l0ooooo`00000L000002`0ooooo`00000M000001l0oooo003o0?ooool0oooo/`3o
ool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool00?l0oooo
o`3ooonc0?ooo`00Z@3oool00`000000oooo0?ooo`0a0?ooo`<00000o`3ooolB0?ooo`030000003o
ool0oooo0340oooo0`0000290?ooo`00ZP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo0?l0oooo4P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo08P0oooo001g0?oo
o`D0000000<0oooo0000000000000`0000000`3oool0000000000003000000<0oooo0P0000030?oo
o`<000000P3oool3000000@0oooo0`0000030?ooo`@00000103oool00`000000oooo0?ooo`060?oo
o`D0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000800000203oool3
000000<0oooo0`0000020?ooo`050000003oool000000?ooo`0000000P3oool3000000<0oooo0`00
00020?ooo`<0000000@0oooo000000000000oooo0`0000020?ooo`<0000000<0oooo000000000000
0P3oool200000<00oooo100000020?ooo`050000003oool000000?ooo`0000000P3oool3000000<0
oooo0`0000040?ooo`8000000P3oool6000000040?ooo`0000000000000000<0oooo100000040?oo
o`030000003oool0oooo00H0oooo1@0000001@3oool00000000000000000oooo0080000000<0oooo
0000000000000P0000080?ooo`<000000`3oool300000080oooo00D000000?ooo`000000oooo0000
00020?ooo`<000000`3oool300000080oooo0`000000103oool000000000003oool300000080oooo
0`0000000`3oool00000000000020?ooo`800000JP3oool007T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000?0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000001P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000<<0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`040000003o
ool0oooo000000l0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000060?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000J@3oool007T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool500000080oooo00<000000?ooo`3oool00P3oool5000000050?ooo`000000oooo0?oo
o`000000403oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`060000003oool0oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000@000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0<40oooo0`0000020?ooo`070000003oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
1@3oool01@000000oooo0?ooo`000000oooo00D0000000D0oooo0000003oool0oooo0000000@0?oo
o`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0JP3oool007T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool000000080oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000`P3oool00`000000oooo0?oo
o`030?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000006`0oooo001h
0?ooo`@0000000@0oooo00000000000000001@3oool010000000oooo0?ooo`3oool4000000<0oooo
0`0000020?ooo`80000000<0oooo0000000000000P3oool3000000<0oooo0`00000>0?ooo`060000
003oool0oooo0?ooo`000000oooo100000030?ooo`<000002@3oool3000000<0oooo0`0000020?oo
o`80000000@0oooo0000003oool0oooo100000030?ooo`<000000P3oool4000000<0oooo0`000002
0?ooo`@000000P3oool400000<40oooo100000001@3oool000000000003oool0000000<0oooo0`00
00030?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000000`3oool3000000h0oooo00H0
00000?ooo`3oool0oooo0000003oool4000000<0oooo0`0000090?ooo`<000000`3oool300000080
oooo0P000000103oool000000?ooo`3oool4000000<0oooo0`0000020?ooo`@000000`3oool30000
0080oooo100000020?ooo`@00000JP3oool007T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo06X0oooo001j0?ooo`8000000`3oool010000000oooo0?ooo`3oool3000000@0oooo00<00000
0?ooo`3oool05P3oool2000000l0oooo0`00000:0?ooo`800000>@3oool00`000000oooo0?ooo`3I
0?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`8000003`3oool3000000X0oooo0P00000i
0?ooo`030000003oool0oooo06X0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00
=`3oool200000380oooo1@00000c0?ooo`<00000<P3oool300000380oooo0`00000`0?ooo`<00000
103oool2000003H0oooo0P00000b0?ooo`D00000<`3oool300000340oooo0`00000c0?ooo`<00000
<03oool3000000@0oooo0P00000P0?ooo`00=P3oool010000000oooo0?ooo`00000b0?ooo`040000
003oool0oooo000003@0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool00000
0300oooo00D000000?ooo`3oool0oooo0000000`0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000=03oool010000000oooo0?ooo`00000b0?ooo`040000003oool0oooo000003@0
oooo00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool000000340oooo00D000000?oo
o`3oool0oooo0000000`0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000007`3o
ool003H0oooo00@000000?ooo`3oool00000<`3oool00`000000oooo0?ooo`0a0?ooo`D00000<@3o
ool01@000000oooo0?ooo`3oool000000300oooo00D000000?ooo`3oool0oooo0000000`0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000c
0?ooo`030000003oool0oooo0340oooo1@00000`0?ooo`050000003oool0oooo0?ooo`000000<@3o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000O0?ooo`00=P3oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo0300
oooo00@000000?ooo`3oool00000<P3oool400000380oooo0`00000a0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000d0?ooo`030000003o
ool0oooo0300oooo00@000000?ooo`3oool00000<@3oool4000003<0oooo0`00000a0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000007`3oool003H0oooo00@000000?ooo`3oool0
0000<@3oool01@000000oooo0?ooo`3oool000000380oooo00<000000?ooo`000000<P3oool00`00
0000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000<@3oool01@000000oooo
0?ooo`3oool000000380oooo00<000000?ooo`000000<@3oool00`000000oooo0?ooo`0c0?ooo`05
0000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001l0oooo000f0?ooo`040000003oool0oooo00000340oooo00D000000?ooo`3oool0oooo0000
000c0?ooo`800000<`3oool00`000000oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`000000
;`3oool2000000@0oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000a0?oo
o`050000003oool0oooo0?ooo`000000<`3oool200000380oooo00<000000?ooo`3oool0<P3oool0
1@000000oooo0?ooo`3oool0000002l0oooo0P0000040?ooo`040000003oool0oooo000001l0oooo
000g0?ooo`800000<`3oool3000003D0oooo00<000000?ooo`3oool0<P3oool200000380oooo0`00
000a0?ooo`030000003oool0oooo00<0oooo0P00000f0?ooo`800000<`3oool3000003D0oooo00<0
00000?ooo`3oool0<@3oool2000003<0oooo0`00000a0?ooo`030000003oool0oooo00<0oooo0P00
000P0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00
o`3ooooo0?oook<0oooo000b0?ooool000007000000/0?ooool000007@00000L0?ooo`00<P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo0P0000050?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`800000703oool0
0380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0o`3ooolH0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo01X0
oooo000b0?ooo`8000000`3oool4003jV_l0oooo4@3oool2000002`0oooo00<000000?ooo`3oool0
0`3oool4003jV_l0oooo4P3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?oo
o`020?ooo`T00?ZJo`3oool=0?ooo`030000003oool0oooo0280oooo0`0000050?ooo`030000003o
ool0oooo00<0oooo0`000003003jV_l0oooo403oool00`000000oooo0?ooo`0J0?ooo`00<P3oool0
0`000000oooo0?ooo`050?ooo``00?ZJo`3oool70?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`D000002000nY[o0?ooo`X0oooo00<00000
0?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool02P3oool<003jV_l0oooo0P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool50000
00030?ooo`00nYX00?ZJ00X00?ZJo`3oool50?ooo`030000003oool0oooo01X0oooo000Y0?ooo`<0
00001P3oool00`000000oooo0?ooo`020?ooo`<000002`3oool;003jV_`0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`<000000P3oool5000000D0003o0P3oool<003jV_`0
oooo0`00000L0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`D0
00003`3oool8003jV_X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo0`00000<0000o`030?ooo`00nYX00?ZJ00X00?ZJn@3oool00`000000
oooo0?ooo`0J0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`D0
00000`000?lA0?ooo`@00?ZJn@3oool00`000000oooo0?ooo`0R0?ooo`8000001P3oool00`000000
oooo0?ooo`030?ooo`@00?ZJ103oool90000o`D0oooo2@00nY[f0?ooo`030000003oool0oooo01X0
oooo000Z0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`D0000020000?l>0?ooo`D00?ZJ
m03oool3000002D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`T00?ZJ
1@3oool90000o`@0oooo0`000006003jV_40oooo00<000000?ooo`3oool06P3oool002X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool;0000o`X0oooo2@00
nY[a0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool<003jVP030?ooo`00
0?l0003o00P0003o1@000008003jV^h0oooo00<000000?ooo`3oool06P3oool002T0oooo0P000007
0?ooo`030000003oool0oooo00d0oooo30000?l70?ooo``00?ZJj`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00/0oooo2@00nYX50?ooo`@0003o1@0000040?ooo`T00?ZJj@3oool0
0`000000oooo0?ooo`0J0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0180oooo2`000?l3000000D0oooo3000nY[V0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool04@3oool9003jVP<0oooo1@0000050000o`80oooo2@00nY[V0?ooo`030000003oool0oooo
01X0oooo000b0?ooo`030000003oool0oooo0080oooo1`00nYX?0?ooo`@0003o1@00000:0?ooo`T0
0?ZJh`3oool00`000000oooo0?ooo`0Z0?ooo`800000503oool;003jVP<000002@000?l40?ooo`T0
0?ZJh03oool2000001`0oooo000b0?ooo`030000003oool0oooo0080oooo2@00nYXA0?ooo`D00000
0`000?l<0?ooo`T00?ZJgP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo
2@00nYX40?ooo`T0003o0P3oool9003jV]h0oooo00<000000?ooo`3oool06P3oool00380oooo0P00
00090?ooo`T00?ZJ2`3oool5000000P0003o2P3oool9003jV]X0oooo0P00000/0?ooo`030000003o
ool0oooo01h0oooo2@00nYX20?ooo`T0003o103oool3003jVP<000000`00nY[I0?ooo`030000003o
ool0oooo01X0oooo000b0?ooo`030000003oool0oooo00X0oooo3000nYX70?ooo`<000000`3oool;
0000o`X0oooo2@00nY[F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool08@3oool9
003jVP@0oooo2@000?l00`3oool0000000000003000000D00?ZJeP3oool00`000000oooo0?ooo`0J
0?ooo`00<P3oool00`000000oooo0?ooo`0@0?ooo`T00?ZJ0`3oool5003jVPL0oooo2@000?l70?oo
o`<000003000nY[@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09P3oool6003j
VPD0oooo1`000?l5000000030?ooo`00nYX00?ZJ00D00?ZJd`3oool00`000000oooo0?ooo`0J0?oo
o`00<P3oool00`000000oooo0?ooo`0E0?ooo`l00?ZJ2@3oool90000o`030?ooo`000000000000<0
0000103oool<003jV//0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`T0
0?ZJ103oool20000o`D00000103oool6003jV]40oooo00<000000?ooo`3oool06P3oool00380oooo
00<000000?ooo`3oool0603oool5003jVP<0oooo2@00nYX70?ooo`L0003o1@00000:0?ooo`/00?ZJ
aP3oool00`000000oooo0?ooo`0Z0?ooo`800000;03oool9003jVPD0oooo0`0000030000o`D0oooo
2@00nY[:0?ooo`800000703oool00380oooo00<000000?ooo`3oool08`3oool9003jVPT0oooo0P00
0?l5000000D0003o2P3oool7003jV/D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0a0?ooo`T00?ZJ0P3oool90000o`030?ooo`00nYX00?ZJ00L00?ZJb@3oool00`000000oooo0?oo
o`0J0?ooo`00<P3oool2000002T0oooo2@00nYX70?ooo`<000002@000?l<0?ooo`800?ZJa03oool2
000002`0oooo00<000000?ooo`3oool0<`3oool:003jVP030?ooo`000?l0003o00L0003o1@3oool6
003jV/H0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0:`3oool9003j
VP`0oooo1`000?l90?ooo`<00?ZJa03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
03T0oooo1P00nYX50?ooo`H0003o103oool7003jV/<0oooo00<000000?ooo`3oool06P3oool00380
oooo00<000000?ooo`3oool0<03oool6003jVP030?ooo`00nYX00?ZJ00<00?ZJ1`3oool90000o`D0
oooo0`00nY[30?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0?03oool6003jVP@0
oooo1`000?l40?ooo`H00?ZJ`@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo
0?ooo`0c0?ooo`h00?ZJ1@3oool90000o`<0oooo1`00nYZn0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0?P3oool7003jVP@0oooo1P000?l50?ooo`H00?ZJ_P3oool00`000000oooo
0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`0e0?ooo`<00?ZJ0`3oool9003jVPL0oooo1`00
0?l00`3oool00?ZJ003jVP0:003jV[P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`110?ooo`H00?ZJ1@3oool60000o`@0oooo1`00nYZk0?ooo`030000003oool0oooo01X0oooo000b
0?ooo`030000003oool0oooo0400oooo1`00nYX70?ooo`D0003o1@3oool<003jV[<0oooo00<00000
0?ooo`3oool0:P3oool2000004D0oooo1P00nYX40?ooo`D0003o0`0000030?ooo`L00?ZJ]`3oool2
000001`0oooo000b0?ooo`030000003oool0oooo04<0oooo1P00nYX80?ooo`80003o0`0000080?oo
o`/00?ZJ[P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04H0oooo1`00nYX40?oo
o`030000o`000000000000<000001@3oool9003jV[<0oooo00<000000?ooo`3oool06P3oool00380
oooo0P0000170?ooo`H00?ZJ1P3oool5000000`0oooo3000nYZW0?ooo`800000;03oool00`000000
oooo0?ooo`190?ooo`H00?ZJ0`3oool5000000<0003o1@3oool9003jV[00oooo00<000000?ooo`3o
ool06P3oool00380oooo00<000000?ooo`3oool0B03oool7003jVP<0oooo1@0000050000o``0oooo
3000nYZS0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0C03oool6003jVPD00000
1P000?l70?ooo`D00?ZJ[`3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?oo
o`1;0?ooo`H00?ZJ00<0oooo0000000000000`0000080000o`l0oooo3000nYZM0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0CP3oool5003jVP<000000`3oool70000o`L0oooo0`00
nYZ^0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo04h0oooo1@00nYX3
000000D0oooo1P000?lB0?ooo``00?ZJV03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0540oooo1P00nYX50?ooo`D0003o1`3oool5003jVZ/0oooo00<000000?ooo`3oool06P3oool0
0380oooo00<000000?ooo`3oool0D03oool7003jVPL0oooo1P000?lE0?ooo`T00?ZJU@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo05@0oooo1@00nYX60?ooo`<0003o1`3oool7003j
VZP0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0D`3oool6003jVPL0
oooo1`000?lG0?ooo`T00?ZJT03oool00`000000oooo0?ooo`0Z0?ooo`800000E`3oool4003jVPH0
oooo1@000?l70?ooo`H00?ZJY@3oool2000001`0oooo000b0?ooo`800000E`3oool6003jVPL0oooo
2@000?lE0?ooo`L00?ZJSP3oool2000002`0oooo00<000000?ooo`3oool0F03oool5003jVP@0oooo
1`000?l70?ooo`H00?ZJX`3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?oo
o`1H0?ooo`L00?ZJ1`3oool90000oaL0oooo0P00nYZ?0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0F@3oool7003jVP@0oooo1P000?l70?ooo`H00?ZJX@3oool00`000000oooo0?oo
o`0J0?ooo`00<P3oool00`000000oooo0?ooo`1K0?ooo`D00?ZJ2`3oool70000oa@0oooo0P00nYZ?
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0G03oool5003jVPH0oooo1P000?l7
0?ooo`@00?ZJX03oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`1N0?oo
o`<00?ZJ3@3oool60000oa80oooo0`00nYZ>0?ooo`030000003oool0oooo01H0oooo0`0000040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo05l0oooo0`00nYX70?oo
o`H0003o1`3oool4003jVYh0oooo00<000000?ooo`3oool06P3oool001d0oooo0`0000040?ooo`03
0000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo05l0oooo1@00nYX=0?ooo`H0
003o403oool2003jVXh0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1P0?ooo`D00?ZJ1`3oool40000
o`L0oooo1P00nYZK0?ooo`030000003oool0oooo01X0oooo000N0?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0600oooo1`00nYX<0?oo
o`L0003o3@3oool2003jVXh0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0H@3oool7003jVPH0oooo10000?l70?oo
o`H00?ZJV@3oool00`000000oooo0?ooo`0J0?ooo`007P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0H`3oool6003jVPd0oooo1P000?l;0?ooo`80
0?ZJSP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool3000006@0oooo1@00nYX60?ooo`H0003o1`3oool4003jVYH0oooo0`00000L0?ooo`00
7P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0P00001W0?ooo`D00?ZJ
3P3oool60000o`P0oooo0`00nYZ;0?ooo`<000006@3oool00`000000oooo0?ooo`070?ooo`@00000
1@3oool00`000000oooo0?ooo`1W0?ooo`<00?ZJ1`3oool60000o`L0oooo0`00nYZG0?ooo`030000
003oool0oooo01X0oooo000N0?ooo`030000003oool0oooo00L0oooo100000060?ooo`030000003o
ool0oooo06P0oooo1000nYX?0?ooo`L0003o1P3oool2003jVXd0oooo00<000000?ooo`3oool05P3o
ool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1X0?ooo`D00?ZJ1`3o
ool40000o`L0oooo0`00nYZF0?ooo`030000003oool0oooo01X0oooo000M0?ooo`8000002@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06X0oooo1@00nYX?0?ooo`H0003o103oool2
003jVXd0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`D00000103oool0
0`000000oooo0?ooo`1Y0?ooo`L00?ZJ1P3oool40000o`H0oooo1@00nYZC0?ooo`030000003oool0
oooo01X0oooo000N0?ooo`030000003oool0oooo00L0oooo1@0000050?ooo`030000003oool0oooo
06/0oooo1`00nYX?0?ooo`H0003o00<0oooo003jVP00nYX0S@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo06`0oooo1@00nYX60?ooo`H0003o103oool6003jVY40oooo00<000000?oo
o`3oool06P3oool00380oooo00<000000?ooo`3oool0KP3oool6003jVPl0oooo1@000?l2003jVXd0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1_0?ooo`<00?ZJ1`3oool60000o`D0
oooo1000nYZ@0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0740oooo
1@00nYX@0?ooo`80003o0`00nYZ<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
L03oool5003jVPL0oooo10000?l60?ooo`@00?ZJSP3oool00`000000oooo0?ooo`0J0?ooo`00<P3o
ool2000007@0oooo1000nYX?0?ooo`<0003o0`00nYZ:0?ooo`800000;03oool200000780oooo1P00
nYX70?ooo`@0003o1@3oool4003jVX`0oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`1e
0?ooo`D00?ZJ3@3oool20000o`T00?ZJQ@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo07@0oooo1000nYX70?ooo`D0003o1@3oool4003jVX/0oooo00<000000?ooo`3oool06P3oool0
0380oooo00<000000?ooo`3oool0MP3oool5003jVP`0oooo0`000?l00`3oool00?ZJ003jVP07003j
VX<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1f0?ooo`@00?ZJ1`3oool40000
o`D0oooo1P00nYZ80?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo07T0
oooo0`00nYX<0?ooo`80003o1`3oool9003jVWd0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`1g0?ooo`H00?ZJ1P3oool50000o`@0oooo1P00nYZ60?ooo`030000003oool0oooo01X0
oooo000b0?ooo`030000003oool0oooo07X0oooo1@00nYX90?ooo`80003o2@3oool<003jVWP0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1i0?ooo`H00?ZJ1@3oool60000o`D0oooo
1000nYZ50?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo07/0oooo1`00
nYX60?ooo`<0000000<0003o0?ooo`3oool02`3oool9003jVWD0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`1l0?ooo`@00?ZJ1`3oool20000o`<000001@3oool4003jVX<0oooo00<0
00000?ooo`3oool06P3oool00380oooo0P00001o0?ooo`D00?ZJ103oool500000080003o403oool5
003jVW<0oooo0P00000/0?ooo`030000003oool0oooo07h0oooo1000nYX60?ooo`D000001@3oool6
003jVX00oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0P@3oool3003j
VP<0oooo1@0000030000oa80oooo0P00nYYd0?ooo`030000003oool0oooo02X0oooo0P0000200?oo
o`H00?ZJ0`3oool500000080003o1@3oool6003jVWd0oooo0P00000L0?ooo`00<P3oool00`000000
oooo0?ooo`220?ooo`D00?ZJ1@0000000`3oool0003o0000o`030000o`l0oooo0`00nYYc0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0P@3oool7003jVPD000000`000?l70?ooo`@0
0?ZJO@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`230?ooo`D00?ZJ
0`0000030?ooo`H0003o3P3oool2003jVW<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`240?ooo`D00?ZJ0`0000020?ooo`D0003o1P3oool3003jVW`0oooo00<000000?ooo`3oool0
6P3oool00380oooo00<000000?ooo`3oool0QP3oool5003jVPH0oooo1P000?l;0?ooo`800?ZJL`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo08L0oooo1@00nYX30?ooo`D0003o1P3o
ool3003jVW/0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0R@3oool3
003jVPL0oooo1P000?l90?ooo`<00?ZJLP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo08X0oooo0`00nYX50?ooo`<0003o1P3oool4003jVWT0oooo00<000000?ooo`3oool06P3oool0
0380oooo00<000000?ooo`3oool0RP3oool4003jVPP0oooo10000?l90?ooo`800?ZJLP3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo08/0oooo1000nYX40?ooo`D0003o103oool4003j
VWP0oooo00<000000?ooo`3oool06P3oool00380oooo0P00002<0?ooo`@00?ZJ2@3oool50000o`H0
oooo0P00nYYa0?ooo`800000;03oool2000008d0oooo1000nYX40?ooo`H0003o103oool4003jVWD0
oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`2=0?ooo`@00?ZJ203oool60000o`@0oooo
0`00nYYa0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0SP3oool4003jVPD0oooo
10000?l40?ooo`@00?ZJM@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?oo
o`2>0?ooo`@00?ZJ2P3oool60000o`80oooo0`00nYY`0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0S`3oool4003jVPH0oooo0`000?l50?ooo`<00?ZJM03oool00`000000oooo0?oo
o`0J0?ooo`00<P3oool00`000000oooo0?ooo`2@0?ooo`<00?ZJ2`3oool50000o`030?ooo`00nYX0
0?ZJ00L00?ZJJP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0940oooo0`00nYX6
0?ooo`<0003o1@3oool3003jVW<0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?oo
o`3oool0T@3oool3003jVPd0oooo0P000?l30?ooo``00?ZJI@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0980oooo0`00nYX60?ooo`D0003o0`3oool5003jVW00oooo00<000000?oo
o`3oool06P3oool00380oooo00<000000?ooo`3oool0TP3oool5003jVPX0oooo0`000?l80?ooo`T0
0?ZJHP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09<0oooo1@00nYX40?ooo`H0
003o0P3oool7003jVVd0oooo00<000000?ooo`3oool06P3oool00380oooo0P00002D0?ooo`H00?ZJ
2@3oool010000?l0000000000000000;0?ooo`H00?ZJG`3oool2000002`0oooo00<000000?ooo`3o
ool0U03oool6003jVPD0oooo10000?l40?ooo`H00?ZJJ`3oool00`000000oooo0?ooo`0J0?ooo`00
<P3oool00`000000oooo0?ooo`2F0?ooo`@00?ZJ203oool5000000d0oooo1P00nYYM0?ooo`030000
003oool0oooo02X0oooo0P00002H0?ooo`@00?ZJ1P3oool30000o`<000000`3oool4003jVVT0oooo
0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`2H0?ooo`@00?ZJ1P3oool500000080003o3@3o
ool8003jVUT0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2I0?ooo`@00?ZJ1@3o
ool00`000?l0000000000003000000@0oooo1000nYYX0?ooo`030000003oool0oooo01X0oooo000b
0?ooo`030000003oool0oooo09T0oooo1000nYX50?ooo`D000000`000?l?0?ooo`D00?ZJF@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09X0oooo1@00nYX40?ooo`D000001@3oool5
003jVVH0oooo00<000000?ooo`3oool06P3oool002P0oooo1@0000050?ooo`030000003oool0oooo
09/0oooo0`00nYX50?ooo`<000000P3oool50000o`l0oooo0P00nYYI0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0W03oool4003jVP<0oooo1@0000020000o`D0oooo1000nYYU0?oo
o`030000003oool0oooo01X0oooo000Y0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0W03oool3003jVPX0oooo1@000?l>0?ooo`<00?ZJF03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo09h0oooo1@00nYX0103oool000000000000000040000o`H0oooo1000nYYS
0?ooo`030000003oool0oooo01X0oooo000Z0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0W@3oool4003jVP80oooo0`00nYX60?ooo`<0003o3P3oool2003jVUP0oooo00<000000?oo
o`3oool08@3oool5000000@0oooo00<000000?ooo`3oool0W`3oool6003jVP@0oooo10000?l50?oo
o`@00?ZJHP3oool00`000000oooo0?ooo`0J0?ooo`00:`3oool00`000000oooo0?ooo`040?ooo`80
0000W`3oool9003jVPH0oooo1@000?l;0?ooo`800?ZJEP3oool3000002@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`2R0?ooo`@00?ZJ103oool40000o`H0oooo0`00nYYQ0?oo
o`030000003oool0oooo01X0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`2P0?ooo`@00?ZJ00<0oooo003jVP00nYX00P00nYX50?ooo`H0003o2@3oool2003j
VUP0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`<00000Y03oool3003j
VPD0oooo0`000?l60?ooo`<00?ZJGP3oool3000001`0oooo000X0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`2Q0?ooo`800?ZJ0`3oool4003jVPL0oooo10000?l80?oo
o`<00?ZJE`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0Y@3oool3003jVPD0oooo0`000?l60?ooo`<00?ZJG`3oool00`000000oooo0?ooo`0J0?oo
o`00:@3oool3000000H0oooo00<000000?ooo`3oool0Z03oool3003jVPP0oooo10000?l70?ooo`80
0?ZJE`3oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`2V0?ooo`@00?ZJ103oool40000o`D0oooo0`00nYYN0?ooo`030000003oool0oooo
01X0oooo000b0?ooo`030000003oool0oooo0:T0oooo0`00nYX80?ooo`D0003o1@3oool2003jVUL0
oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0Y`3oool4003jVP@0oooo10000?l50?ooo`<00?ZJG@3oool00`000000oooo0?ooo`0J0?oo
o`00<P3oool00`000000oooo0?ooo`2Z0?ooo`<00?ZJ2@3oool40000o`@0oooo0P00nYYG0?ooo`03
0000003oool0oooo0280oooo0`0000050?ooo`030000003oool0oooo0:T0oooo1000nYX40?ooo`@0
003o103oool4003jVU/0oooo00<000000?ooo`3oool06P3oool00380oooo0P00002/0?ooo`<00?ZJ
2P3oool40000o`80oooo0P00nYYF0?ooo`800000;03oool00`000000oooo0?ooo`2Z0?ooo`@00?ZJ
103oool40000o`@0oooo1000nYYJ0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003o
ool0oooo0:`0oooo0`00nYX:0?ooo`@0003o00@0oooo003jVP00nYX00?ZJEP3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0:`0oooo0`00nYX50?ooo`<0003o1@3oool3003jVUT0oooo
00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0[@3oool4003jVPX0oooo0`00
0?l00`3oool00?ZJ003jVP04003jVU80oooo00<000000?ooo`3oool0:P3oool200000:h0oooo0`00
nYX50?ooo`<0003o1@3oool2003jVUP0oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`2^
0?ooo`@00?ZJ2P3oool20000o`030?ooo`00nYX00?ZJ00L00?ZJC`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0:h0oooo1000nYX40?ooo`@0003o0`3oool3003jVUP0oooo00<00000
0?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0/03oool3003jVPT0oooo0`000?l50?oo
o`H00?ZJC@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:l0oooo1000nYX40?oo
o`@0003o0`3oool5003jVUD0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3o
ool0/@3oool3003jVPT0oooo0`000?l70?ooo`H00?ZJBP3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0;40oooo1000nYX40?ooo`@0003o0P3oool7003jVU80oooo00<000000?ooo`3o
ool06P3oool00380oooo00<000000?ooo`3oool0/P3oool3003jVPT0oooo0`0000080?ooo`L00?ZJ
A`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;80oooo1000nYX40?ooo`@0003o
103oool6003jVU00oooo00<000000?ooo`3oool06P3oool00380oooo0P00002d0?ooo`<00?ZJ1`3o
ool5000000X0oooo1P00nYY40?ooo`800000;03oool00`000000oooo0?ooo`2d0?ooo`<00?ZJ1@3o
ool30000o`H0oooo1@00nYY>0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0
oooo0;@0oooo0`00nYX60?ooo`D000003@3oool6003jVT80oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`2e0?ooo`<00?ZJ1@3oool20000o`<000001@3oool4003jVTd0oooo00<00000
0?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0]@3oool4003jVP@0oooo1@0000030000
o``0oooo1`00nYXo0?ooo`030000003oool0oooo02X0oooo0P00002g0?ooo`@00?ZJ103oool50000
00H0oooo1000nYY:0?ooo`800000703oool00380oooo00<000000?ooo`3oool0]P3oool4003jVP@0
oooo0`0000060000o`d0oooo1@00nYXn0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0]`3oool4003jVP<0oooo1@0000070?ooo`@00?ZJBP3oool00`000000oooo0?ooo`0J0?ooo`00
<P3oool00`000000oooo0?ooo`2h0?ooo`<00?ZJ2@3oool40000o`l0oooo0P00nYXn0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0^@3oool5003jVPD000000P000?l70?ooo`<00?ZJ
B@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`2i0?ooo`<00?ZJ0P3o
ool3003jVPD0oooo0`000?l>0?ooo`800?ZJ?P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0;X0oooo1@00nYX3000000@0003o1`3oool3003jVTP0oooo00<000000?ooo`3oool06P3o
ool00380oooo0P00002k0?ooo`L00?ZJ1P3oool30000o`d0oooo0P00nYXm0?ooo`800000;03oool0
0`000000oooo0?ooo`2m0?ooo`<00?ZJ103oool40000o`H0oooo1000nYY60?ooo`030000003oool0
oooo01X0oooo000b0?ooo`030000003oool0oooo0;/0oooo1`00nYX60?ooo`@0003o2`3oool3003j
VSd0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2n0?ooo`@00?ZJ0`3oool50000
o`D0oooo1000nYY50?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0;`0
oooo0P00nYX20?ooo`<00?ZJ1P3oool40000o`/0oooo0P00nYXm0?ooo`030000003oool0oooo02X0
oooo0P0000300?ooo`@00?ZJ103oool40000o`H0oooo1000nYY20?ooo`800000703oool00380oooo
00<000000?ooo`3oool0`@3oool3003jVPL0oooo10000?l90?ooo`800?ZJ?@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0<40oooo0`00nYX50?ooo`@0003o1@3oool4003jVT80oooo
00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0`P3oool3003jVPL0oooo1000
0?l80?ooo`800?ZJ?@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0<80oooo0`00
nYX50?ooo`@0003o1P3oool3003jVT40oooo00<000000?ooo`3oool06P3oool00380oooo00<00000
0?ooo`3oool0``3oool3003jVPP0oooo0`000?l70?ooo`800?ZJ?@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0<<0oooo0`00nYX60?ooo`<0003o1P3oool3003jVT00oooo00<00000
0?ooo`3oool06P3oool00380oooo0P0000350?ooo`<00?ZJ203oool30000o`H0oooo0`00nYXk0?oo
o`800000;03oool00`000000oooo0?ooo`340?ooo`<00?ZJ1P3oool30000o`H0oooo0`00nYXo0?oo
o`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0<D0oooo0`00nYX80?ooo`@0
003o1@3oool2003jVS`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`350?ooo`<0
0?ZJ1P3oool40000o`D0oooo0`00nYXn0?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000
003oool0oooo0<H0oooo0`00nYX80?ooo`@0003o103oool4003jVSX0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`360?ooo`<00?ZJ1P3oool40000o`D0oooo0P00nYXn0?ooo`030000
003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0<L0oooo0`00nYX90?ooo`@0003o0P3o
ool7003jVSL0oooo00<000000?ooo`3oool0:P3oool200000<P0oooo0`00nYX70?ooo`@0003o0`3o
ool3003jVS`0oooo0P00000L0?ooo`00703oool5000000<0oooo00<000000?ooo`3oool00P3oool3
000000H0oooo00<000000?ooo`3oool0b03oool3003jVPT0oooo10000?l40?ooo`H00?ZJ=@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0<P0oooo0`00nYX70?ooo`@0003o0`3oool2
003jVSd0oooo00<000000?ooo`3oool06P3oool001d0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0b@3oool3003jVPX0oooo0`00
0?l60?ooo`H00?ZJ<P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0<T0oooo1000
nYX70?ooo`@0003o00<0oooo003jVP00nYX01P00nYXg0?ooo`030000003oool0oooo01X0oooo000N
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3:
0?ooo`<00?ZJ2P3oool20000o`<000001@3oool<003jVRX0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`3:0?ooo`@00?ZJ1`3oool40000o`030?ooo`00nYX00?ZJ00L00?ZJ=@3oool0
0`000000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo0P00003<0?ooo`<00?ZJ2P3oool5000000L0oooo0`00nYX3000000H00?ZJ9@3oool30000
02`0oooo00<000000?ooo`3oool0c03oool3003jVPP0oooo0`000?l60?ooo`D00?ZJ<`3oool00`00
0000oooo0?ooo`0J0?ooo`00703oool01@000000oooo0?ooo`3oool0000000L0oooo100000060?oo
o`030000003oool0oooo0<`0oooo0`00nYX90?ooo`D000002@3oool5000000030?ooo`00nYX00?ZJ
00D00?ZJ903oool00`000000oooo0?ooo`0E0?ooo`D000000`3oool00`000000oooo0?ooo`020?oo
o`<000001@3oool00`000000oooo0?ooo`3=0?ooo`<00?ZJ203oool30000o`L0oooo1000nYXb0?oo
o`030000003oool0oooo01X0oooo000L0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0<d0oooo0`00nYX80?ooo`D0000000<0003o0?oo
o`3oool01P3oool5000000@0oooo1@00nYXS0?ooo`030000003oool0oooo01H0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0cP3o
ool5003jVPH0oooo00@0003o00000000000000001`3oool4003jVS00oooo00<000000?ooo`3oool0
6P3oool001d0oooo0`0000080?ooo`D000001@3oool00`000000oooo0?ooo`3>0?ooo`<00?ZJ203o
ool3000000<0003o1`3oool5000000L0oooo0P00nYXS0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`<00000c`3oool6003jVP@0oooo1@00
00070?ooo`@00?ZJ;@3oool3000001`0oooo000b0?ooo`030000003oool0oooo0<l0oooo0P00nYX<
0?ooo`<0003o1`3oool3000000P0oooo0P00nYXS0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=80oooo1000nYX3
0?ooo`D000000`000?l60?ooo`<00000;P3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`00
0000oooo0?ooo`3?0?ooo`<00?ZJ1`3oool2003jVP<0oooo0`000?l60?ooo`@0003o1`3oool2003j
VR<0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000000L0oooo10000005
0?ooo`030000003oool0oooo0=@0oooo1@00nYX5000000D0003o0`3oool5000002d0oooo00<00000
0?ooo`3oool06P3oool00380oooo0P00003A0?ooo`<00?ZJ1P3oool2003jVP@0oooo0`000?l40?oo
o`H0003o1P3oool2003jVR80oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0=D0oooo1@00nYX3000000<0oooo1P000?l5
00000003003jVP3oool0oooo02X0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?oo
o`3oool0d@3oool3003jVPD0oooo0`00nYX40?ooo`@0003o00@0oooo0000o`000?l0003o0P3oool3
0000o`D0oooo0`00nYXR0?ooo`030000003oool0oooo01H0oooo0`0000080?ooo`D00000103oool0
0`000000oooo0?ooo`3H0?ooo`D00?ZJ1@3oool40000o`D000000P00nYX[0?ooo`030000003oool0
oooo01X0oooo000b0?ooo`030000003oool0oooo0=80oooo0`00nYX30?ooo`D00?ZJ103oool60000
o`@0oooo0`000?l50?ooo`800?ZJ8P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0=X0oooo1000nYX70?ooo`80003o0`000000103oool00?ZJ003jVP00nYXZ0?ooo`030000003oool0
oooo01X0oooo000b0?ooo`030000003oool0oooo0=<0oooo0`00nYX20?ooo`800?ZJ00@0oooo003j
VP00nYX00?ZJ1@3oool40000o`800?ZJ0`3oool30000o`@0oooo0P00nYXR0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0g03oool4003jVPL0oooo0`000?l20?ooo`<00?ZJ:@3oool0
0`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3D0?ooo`<00?ZJ00<0oooo003j
VP00nYX00P3oool3003jVPD0oooo0P000?l00`3oool00?ZJ003jVP040?ooo`<0003o0`3oool2003j
VR80oooo00<000000?ooo`3oool0:P3oool200000=h0oooo1000nYX70?ooo`80003o0`3oool2003j
VRP0oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`3E0?ooo`D00?ZJ0`3oool3003jVPL0
oooo0`00nYX40?ooo`@0003o00<0oooo003jVP00nYX08P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0=l0oooo1000nYX50?ooo`<0003o0P3oool3003jVRP0oooo00<000000?ooo`3o
ool06P3oool00380oooo00<000000?ooo`3oool0eP3oool3003jVPD0oooo0`00nYX50?ooo`D00?ZJ
103oool40000o`800?ZJ8P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0>00oooo
1P00nYX30?ooo`<0003o0P3oool3003jVRL0oooo00<000000?ooo`3oool06P3oool00380oooo0P00
003H0?ooo`800?ZJ1P3oool2003jVPD0oooo0P00nYX0103oool00?ZJ003jVP00nYX50?ooo`80003o
0P00nYXQ0?ooo`800000;03oool00`000000oooo0?ooo`3R0?ooo`P00?ZJ0P000?l30?ooo`<00?ZJ
9P3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3O0?ooo`<00?ZJ103o
ool2003jVP80oooo0P00nYX60?ooo`040000o`00nYX00?ZJ003jVR40oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`3U0?ooo`D00?ZJ0`000?l30?ooo`800?ZJ9P3oool00`000000oooo
0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3P0?ooo`800?ZJ0`3oool3003jVP80oooo0`00
nYX50?ooo`80003o0P00nYXQ0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0j03o
ool3003jVP<0003o0P3oool3003jVRD0oooo00<000000?ooo`3oool06P3oool00380oooo00<00000
0?ooo`3oool0h03oool3003jVP80oooo0P00nYX40?ooo`<00?ZJ103oool20000o`800?ZJ8@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0>T0oooo0P00nYX0103oool0003o0000o`00
0?l20?ooo`800?ZJ9@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3Q
0?ooo`<00?ZJ00<0oooo003jVP00nYX01@3oool2003jVPD0oooo00<0003o003jVP00nYX01@00nYXL
0?ooo`030000003oool0oooo02X0oooo0P00003Z0?ooo`800?ZJ0P3oool30000o`040?ooo`00nYX0
0?ZJ003jVR<0oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`3R0?ooo`D00?ZJ1@3oool3
003jVP@0oooo00<0003o003jVP00nYX01`00nYXJ0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0j@3oool3003jVP80oooo0`000?l00`3oool00?ZJ003jVP0T0?ooo`030000003oool0
oooo01X0oooo000b0?ooo`800000i03oool3003jVPL0oooo0`00nYX30?ooo`80003o1@3oool5003j
VQL0oooo0P00000/0?ooo`030000003oool0oooo0>X0oooo0P00nYX30?ooo`<0003o0`00nYXS0?oo
o`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0>@0oooo0P00nYX80?ooo`<0
0?ZJ0P3oool30000o`H0oooo1000nYXG0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0jP3oool3003jVP<0oooo0P000?l0103oool00?ZJ003jVP00nYXR0?ooo`030000003oool0oooo
01X0oooo000b0?ooo`030000003oool0oooo0>l0oooo0P00nYX30?ooo`<000001`3oool3003jVQH0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3[0?ooo`<00?ZJ0P3oool30000o`03
0?ooo`00nYX00?ZJ0280oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0
k`3oool3003jVP030?ooo`000000000000<000001`3oool2003jVQH0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`3/0?ooo`<00?ZJ0P3oool20000o`030?ooo`00nYX00?ZJ00800?ZJ
803oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3`0?ooo`<00?ZJ1@00
00070?ooo`800?ZJ5P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0>d0oooo0P00
nYX20?ooo`<0003o00<0oooo003jVP00nYX00P00nYXO0?ooo`030000003oool0oooo01X0oooo000b
0?ooo`030000003oool0oooo0?40oooo0P00nYX5000000030000o`3oool0oooo00@0oooo0`00nYXE
0?ooo`030000003oool0oooo02X0oooo0P00003^0?ooo`<00?ZJ0P3oool20000o`<0oooo0`00nYXM
0?ooo`800000703oool00380oooo0P00003c0?ooo`800?ZJ0`0000030000o`H0oooo0P00nYXD0?oo
o`800000;03oool00`000000oooo0?ooo`3^0?ooo`<00?ZJ00@0oooo0000o`000?l0003o0`3oool2
003jVQh0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0l`3oool3003j
VP80oooo0`000?l50?ooo`800?ZJ5@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0>l0oooo0`00nYX00`3oool0003o0000o`03000000<00?ZJ7@3oool00`000000oooo0?ooo`0J0?oo
o`00<P3oool00`000000oooo0?ooo`3d0?ooo`800?ZJ0`3oool30000o`@0oooo0P00nYXE0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0l03oool2003jVP80oooo1@000003003jVQ`0
oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0m03oool3003jVP<0oooo
0`000?l30?ooo`800?ZJ5@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?00oooo
0`00nYX00`3oool0000000000003000000030?ooo`00nYX00?ZJ01`0oooo00<000000?ooo`3oool0
6P3oool002T0oooo0`0000060?ooo`030000003oool0oooo0?D0oooo0`00nYX30?ooo`<0003o0P3o
ool3003jVQ@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3a0?ooo`<00?ZJ1@00
0000103oool00?ZJ003jVP00nYXK0?ooo`030000003oool0oooo01X0oooo000X0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3f0?ooo`800?ZJ103oool30000o`80oooo
0P00nYXD0?ooo`030000003oool0oooo02X0oooo0P00003c0?ooo`<00?ZJ0`0000000`000?l0oooo
0?ooo`03003jVQT0oooo0P00000L0?ooo`00;03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?H0oooo0`00nYX40?ooo`<0003o00<0oooo003jVP00nYX0503oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0?<0oooo0`00nYX0103oool0003o0000o`000?l20?ooo`<00?ZJ
6@3oool00`000000oooo0?ooo`0J0?ooo`00:P3oool2000000H0oooo0P00003h0?ooo`800?ZJ1@3o
ool30000o`800?ZJ4P3oool3000002`0oooo00<000000?ooo`3oool0m03oool3003jVP030?ooo`00
0?l0003o00<0oooo0P00nYXI0?ooo`030000003oool0oooo01X0oooo000/0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0m`3oool3003jVPD0oooo0P000?l2003jVQ@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`3e0?ooo`800?ZJ00@0oooo0000o`000?l0003o0P3o
ool3003jVQP0oooo00<000000?ooo`3oool06P3oool002P0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0?P0oooo0`00nYX40?ooo`80003o0`00nYXC0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0m@3oool3003jVP040?ooo`000?l0003o0000o`80oooo
0`00nYXG0?ooo`030000003oool0oooo01X0oooo000Y0?ooo`<000001P3oool00`000000oooo0?oo
o`3i0?ooo`<00?ZJ103oool20000o`<00?ZJ4P3oool00`000000oooo0?ooo`0R0?ooo`<000001@3o
ool00`000000oooo0?ooo`3f0?ooo`<00?ZJ00<0oooo0000o`000?l00`3oool3003jVQH0oooo00<0
00000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0nP3oool2003jVP@0oooo0P000?l6
003jVPl0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0m`3oool2003jVP040?ooo`000?l0003o0000o`<0oooo0P00nYXF0?ooo`030000
003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0?X0oooo0`00nYX30?ooo`<0003o00<0
oooo003jVP00nYX01000nYX=0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3o
ool300000?L0oooo0`00nYX0103oool0003o0000o`000?l20?ooo`<00?ZJ4`3oool3000001`0oooo
000b0?ooo`800000o03oool2003jVP@0oooo0P000?l40?ooo`@00?ZJ2`3oool2000002D0oooo0P00
00050?ooo`030000003oool0oooo0?P0oooo0P00nYX20?ooo`<0003o0P3oool2003jVQD0oooo00<0
00000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0n`3oool3003jVP<0oooo0`000005
0?ooo`D00?ZJ2@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0n03oool3003jVP80oooo0`000?l0103oool00?ZJ003jVP00nYXD0?ooo`030000003o
ool0oooo01X0oooo000b0?ooo`030000003oool0oooo0?`0oooo0P00nYX20?ooo`D000001@3oool5
003jVPP0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0n@3oool2003jVP<0oooo0`000?l00`3oool00?ZJ003jVP0D0?ooo`030000003o
ool0oooo01X0oooo000b0?ooo`030000003oool0oooo0?`0oooo0`00nYX00`3oool0000000000003
000000P0oooo0P00nYX80?ooo`030000003oool0oooo0280oooo0`0000050?ooo`030000003oool0
oooo0?T0oooo0`00nYX30?ooo`<0003o1000nYXB0?ooo`030000003oool0oooo01X0oooo000b0?oo
o`030000003oool0oooo0?d0oooo0`00nYX5000000P0oooo0P00nYX80?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0nP3oool3003jVP<0oooo0P000?l00`3oool00?ZJ003jVP04003j
VPl0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0oP3oool3003jVP<0
00000P000?l70?ooo`<00?ZJ1`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?/0
oooo0`00nYX20?ooo`<0003o0P3oool5003jVPh0oooo00<000000?ooo`3oool06P3oool00380oooo
00<000000?ooo`3oool0o`3oool4003jVP040?ooo`000?l0003o0000o`L0oooo0P00nYX70?ooo`03
0000003oool0oooo02X0oooo0P00003m0?ooo`<00?ZJ0P3oool30000o`@0oooo0`00nYX<0?ooo`80
0000703oool00380oooo0P00003o0?ooo`<0oooo0`00nYX0103oool0003o0000o`000?l60?ooo`80
0?ZJ1P3oool2000002`0oooo00<000000?ooo`3oool0o@3oool2003jVP<0oooo0`0000040?ooo`<0
0?ZJ303oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
0P00nYX20?ooo`<0003o1@3oool3003jVPH0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`3m0?ooo`<00?ZJ00<0oooo0000000000000`0000040?ooo`<00?ZJ2`3oool00`000000oooo
0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo0`00nYX20?ooo`<0003o1@3o
ool2003jVPH0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3n0?ooo`<00?ZJ1@00
00050?ooo`800?ZJ2`3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo0P00nYX30?ooo`<0003o103oool2003jVPH0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`3o0?ooo`800?ZJ1@0000020000o`<0oooo0`00nYX:0?ooo`030000003oool0
oooo01X0oooo000b0?ooo`030000003oool0oooo0?l0oooo103oool2003jVP@0oooo0`000?l30?oo
o`<000001@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo0@3oool2003j
VP<0000010000?l30?ooo`<00?ZJ2@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo0`00nYX40?ooo`<0003o00<0oooo0000000000000`0000040?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3oool30?ooo`<00?ZJ0P3oool30000o`<0
oooo0P00nYX90?ooo`030000003oool0oooo01X0oooo000b0?ooo`800000o`3oool60?ooo`800?ZJ
1@3oool30000o`D000000`3oool2000002`0oooo0P00003o0?ooo`D0oooo0P00nYX30?ooo`<0003o
0P3oool3003jVPL0oooo0P00000L0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo0`00
nYX50?ooo`80003o1@0000040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`<00?ZJ0`3oool30000o`80oooo0`00nYX70?ooo`030000003oool0oooo01X0oooo000b
0?ooo`030000003oool0oooo0?l0oooo1P3oool3003jVPD0oooo0P000?l3000000D0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo0P00nYX40?ooo`<0003o0P3oool3
003jVPH0oooo00<000000?ooo`3oool06P3oool00380oooo00<000000?ooo`3oool0o`3oool70?oo
o`<00?ZJ3P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo1@3oool3003j
VP@0oooo0P000?l30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooo`P0oooo0P00nYX>0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`<00?ZJ0`3oool30000o`X0oooo00<000000?ooo`3oool06P3oool00380oooo
00<000000?ooo`3oool0o`3oool80?ooo`<00?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0`00nYX30?ooo`<0003o00@0oooo000000000000
00001@3oool00`000000oooo0?ooo`0J0?ooo`00<P3oool200000?l0oooo2P3oool3003jVP@0oooo
0P00nYX50?ooo`800000;03oool00`000000oooo0?ooo`3o0?ooo`P0oooo0`00nYX30?ooo`80003o
1@0000040?ooo`030000003oool0oooo01X0oooo000b0?ooo`030000003oool0oooo0?l0oooo2P3o
ool2003jVP@0oooo0P00nYX60?ooo`030000003oool0oooo02X0oooo0P00003o0?ooo`X0oooo0`00
nYX30?ooo`030000o`000000000000<000000`3oool2000001`0oooo000b0?ooo`030000003oool0
oooo0?l0oooo2P3oool3003jVP80oooo0`00nYX60?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`<00?ZJ0`3oool5000000@0oooo00<000000?ooo`3oool06P3oool0
0380oooo00<000000?ooo`3oool0o`3oool;0?ooo`800?ZJ0P3oool2003jVPL0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0`00nYX30?ooo`<000001@3oool00`00
0000oooo0?ooo`0J0?ooo`007@3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000H0
oooo00<000000?ooo`3oool0o`3oool;0?ooo`<00?ZJ00<0oooo003jVP00nYX01`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo303oool3003jVPX0oooo00<000000?ooo`3o
ool06P3oool001`0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`3o0?ooo``0oooo1@00nYX70?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0o`3oool=0?ooo`@00?ZJ203oool00`000000oooo0?ooo`0J0?oo
o`00803oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`@00?ZJ1`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0
oooo3P3oool4003jVPL0oooo00<000000?ooo`3oool06P3oool001h0oooo0P00000<0?ooo`030000
003oool0oooo00<0oooo0P00003o0?ooo`h0oooo0`00nYX60?ooo`<00000;03oool00`000000oooo
0?ooo`3o0?oooa00oooo0`00nYX60?ooo`030000003oool0oooo01X0oooo000P0?ooo`030000003o
ool0oooo00D0oooo100000060?ooo`030000003oool0oooo0?l0oooo3P3oool2003jVPP0oooo00<0
00000?ooo`3oool0:P3oool200000?l0oooo4P3oool2003jVPD0oooo0P00000L0?ooo`00703oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0J0?ooo`007@3oool3000000P0oooo1@0000050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo000b0?oo
ool000007000000/0?ooool000007@00000L0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo
/`3oool00?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo002/0?ooo`030000003oool0oooo
0340oooo0`00003o0?oooa80oooo00<000000?ooo`3oool0<@3oool3000008H0oooo002]0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0Q@3oool007X0oooo1@0000000`3oool0000000000003000000030?oo
o`000000000000<000000`3oool2000000<0oooo0`0000020?ooo`<00000103oool3000000<0oooo
100000040?ooo`030000003oool0oooo00L0oooo0`0000020?ooo`@00000103oool2000000T0oooo
0`0000030?ooo`<000000P3oool01@000000oooo0000003oool000000080oooo0`0000030?ooo`<0
00000P3oool3000000040?ooo`00000000000?ooo`<000000P3oool3000000030?ooo`0000000000
0080oooo0P0000300?ooo`@000000P3oool01@000000oooo0000003oool000000080oooo0`000003
0?ooo`<00000103oool200000080oooo1P000000103oool000000000000000030?ooo`@00000103o
ool00`000000oooo0?ooo`070?ooo`<000000P3oool4000000@0oooo0P0000090?ooo`<000000`3o
ool300000080oooo00D000000?ooo`000000oooo000000020?ooo`<000000`3oool300000080oooo
0`000000103oool000000000003oool300000080oooo0`0000000`3oool00000000000020?ooo`80
0000I`3oool007`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000033
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000001@3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`060000003o
ool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
00H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001V0?ooo`00O03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D0000000D0oooo
0000003oool0oooo0000000@0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool02`000000oooo0?ooo`3oool000000?ooo`00
0000oooo0000003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0`@3oool300000080oooo00L000000?ooo`000000oooo0000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`050000
003oool0oooo0000003oool01@0000001@3oool000000?ooo`3oool000000100oooo00<000000?oo
o`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
000400000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1W0?ooo`00O03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0203oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000`P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`060000003oool0oooo
0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001Y0?ooo`00N`3oool400000004
0?ooo`0000000000000000D0oooo00@000000?ooo`3oool0oooo100000030?ooo`<000000P3oool2
000000030?ooo`00000000000080oooo0`0000030?ooo`<00000403oool00`000000oooo0?ooo`02
0?ooo`@0000000<0oooo0000000000000P0000090?ooo`<000000`3oool300000080oooo0P000000
103oool000000?ooo`3oool4000000<0oooo0`0000020?ooo`@000000`3oool300000080oooo1000
00020?ooo`@00000`@3oool4000000050?ooo`00000000000?ooo`0000000`3oool3000000<0oooo
0`0000020?ooo`@000000`3oool3000000<0oooo0`0000030?ooo`<00000403oool00`000000oooo
0?ooo`020?ooo`@0000000<0oooo0000000000000P0000090?ooo`<000000`3oool300000080oooo
0P000000103oool000000?ooo`3oool4000000<0oooo0`0000020?ooo`@000000`3oool300000080
oooo100000020?ooo`@00000I`3oool007`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool2000000X0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`8000002P3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo06L0oooo001m0?ooo`8000000`3oool010000000oooo0?oo
o`3oool3000000@0oooo00<000000?ooo`3oool05P3oool200000100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0
0P3oool2000000`0oooo0P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool0
0?l0ooooo`3ooonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3o
oonc0?ooo`00o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00
o`3ooooo0?oook<0oooo003o0?ooool0oooo/`3oool00?l0ooooo`3ooonc0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 688.938}, {425.438, 0}} -> {-0.0508658, -0.0309082, \
0.00305069, 0.00305069}, {{16.625, 344.438}, {415.25, 212.688}} -> {-1.99996, \
-0.310248, 0.0371876, 0.0856936}, {{344.438, 672.25}, {415.25, 212.688}} -> \
{-14.1905, -0.357722, 0.0371876, 0.0859393}, {{16.625, 344.438}, {212.688, \
10.125}} -> {-2.11152, -2.67835, 0.0371876, 0.0156133}, {{344.438, 672.25}, \
{212.688, 10.125}} -> {-14.3021, -2.40641, 0.0371876, 0.0146419}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowToolbars->"EditBar",
Evaluator->"Local",
WindowSize->{994, 669},
WindowMargins->{{29, Automatic}, {Automatic, 6}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
0000001804P000000bd2=_oaoo43?095o`85N@?NW0002008ool000001@050001
0000I24A4R060`410@000BL?0040000000000000000004E3<34100;o00000001
000A0S<R<3`00Q3400018NOWinOWia4A\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3374837877-7494599"->{
    Cell[226846, 9382, 67, 1, 22, "Print",
      CellTags->"Info3374837877-7494599"],
    Cell[226916, 9385, 700, 17, 46, "Print",
      CellTags->"Info3374837877-7494599"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3374837877-7494599", 691282, 22246}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 1, 56, "Section"],
Cell[1853, 56, 1312, 22, 331, "Input"],

Cell[CellGroupData[{
Cell[3190, 82, 69, 1, 46, "Subsection"],

Cell[CellGroupData[{
Cell[3284, 87, 94, 4, 54, "Input"],
Cell[3381, 93, 119, 2, 21, "Message"],
Cell[3503, 97, 174, 3, 21, "Message"],
Cell[3680, 102, 115, 2, 21, "Message"],
Cell[3798, 106, 189, 3, 21, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4024, 114, 56, 1, 39, "Input"],
Cell[4083, 117, 1196, 18, 158, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5328, 141, 82, 1, 30, "Subsection"],
Cell[5413, 144, 69, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[5507, 149, 129, 4, 54, "Input"],
Cell[5639, 155, 107, 2, 54, "Output"]
}, Open  ]],
Cell[5761, 160, 188, 5, 54, "Input"],

Cell[CellGroupData[{
Cell[5974, 169, 69, 1, 39, "Input"],
Cell[6046, 172, 146, 2, 54, "Output"]
}, Open  ]],
Cell[6207, 177, 93, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[6325, 182, 94, 1, 39, "Input"],
Cell[6422, 185, 380, 9, 73, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6839, 199, 190, 6, 84, "Input"],
Cell[7032, 207, 175, 3, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7244, 215, 137, 4, 54, "Input"],
Cell[7384, 221, 175, 3, 54, "Output"]
}, Open  ]],
Cell[7574, 227, 93, 1, 30, "Text"],
Cell[7670, 230, 194, 7, 99, "Input"],

Cell[CellGroupData[{
Cell[7889, 241, 132, 4, 39, "Input"],
Cell[8024, 247, 64, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8125, 253, 311, 9, 99, "Input"],
Cell[8439, 264, 146, 2, 54, "Output"]
}, Open  ]],
Cell[8600, 269, 137, 5, 69, "Input"],

Cell[CellGroupData[{
Cell[8762, 278, 63, 1, 39, "Input"],
Cell[8828, 281, 66, 1, 40, "Output"]
}, Open  ]],
Cell[8909, 285, 104, 4, 54, "Input"],

Cell[CellGroupData[{
Cell[9038, 293, 124, 4, 54, "Input"],
Cell[9165, 299, 50, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9252, 305, 117, 4, 54, "Input"],
Cell[9372, 311, 60, 1, 38, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9481, 318, 66, 1, 46, "Subsection"],

Cell[CellGroupData[{
Cell[9572, 323, 333, 15, 219, "Input"],
Cell[9908, 340, 123, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10068, 347, 64, 1, 39, "Input"],
Cell[10135, 350, 46, 1, 38, "Output"]
}, Open  ]],
Cell[10196, 354, 78, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[10299, 359, 203, 8, 99, "Input"],
Cell[10505, 369, 69, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10611, 375, 144, 4, 54, "Input"],
Cell[10758, 381, 181, 3, 22, "Print"],
Cell[10942, 386, 83338, 3605, 182, 57237, 3278, "GraphicsData", "PostScript", \
"Graphics"],
Cell[94283, 3993, 130, 3, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[94462, 4002, 41, 0, 30, "Subsection"],
Cell[94506, 4004, 148, 5, 39, "Input"],

Cell[CellGroupData[{
Cell[94679, 4013, 52, 1, 39, "Input"],
Cell[94734, 4016, 185, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94956, 4024, 87, 4, 54, "Input"],
Cell[95046, 4030, 171, 3, 38, "Output"],
Cell[95220, 4035, 375, 6, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95632, 4046, 97, 1, 39, "Input"],
Cell[95732, 4049, 92, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95861, 4055, 194, 6, 84, "Input"],
Cell[96058, 4063, 20590, 705, 182, 6710, 529, "GraphicsData", "PostScript", \
"Graphics"],
Cell[116651, 4770, 130, 3, 38, "Output"],
Cell[116784, 4775, 24337, 888, 182, 9252, 697, "GraphicsData", "PostScript", \
"Graphics"],
Cell[141124, 5665, 130, 3, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[141303, 5674, 69, 1, 30, "Subsection"],

Cell[CellGroupData[{
Cell[141397, 5679, 359, 18, 264, "Input"],
Cell[141759, 5699, 123, 2, 38, "Output"]
}, Open  ]],
Cell[141897, 5704, 78, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[142000, 5709, 209, 5, 54, "Input"],
Cell[142212, 5716, 69, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142318, 5722, 109, 2, 39, "Input"],
Cell[142430, 5726, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142513, 5732, 141, 4, 39, "Input"],
Cell[142657, 5738, 181, 3, 22, "Print"],
Cell[142841, 5743, 83338, 3605, 182, 57237, 3278, "GraphicsData", \
"PostScript", "Graphics"],
Cell[226182, 9350, 130, 3, 38, "Output"]
}, Open  ]],
Cell[226327, 9356, 80, 1, 30, "Text"],
Cell[226410, 9359, 216, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[226651, 9370, 65, 1, 39, "Input"],
Cell[226719, 9373, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226802, 9379, 41, 1, 39, "Input"],
Cell[226846, 9382, 67, 1, 22, "Print",
  CellTags->"Info3374837877-7494599"],
Cell[226916, 9385, 700, 17, 46, "Print",
  CellTags->"Info3374837877-7494599"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[227665, 9408, 43, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[227733, 9412, 194, 8, 114, "Input"],
Cell[227930, 9422, 40, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228007, 9428, 112, 3, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[228144, 9435, 279, 5, 87, "Input"],
Cell[228426, 9442, 46, 1, 38, "Output"],
Cell[228475, 9445, 46, 1, 38, "Output"],
Cell[228524, 9448, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228607, 9454, 772, 16, 103, "Input"],
Cell[229382, 9472, 157, 3, 22, "Print"],
Cell[229542, 9477, 67, 1, 22, "Print"],
Cell[229612, 9480, 83, 1, 22, "Print"],
Cell[229698, 9483, 99, 2, 22, "Print"],
Cell[229800, 9487, 99, 2, 22, "Print"],
Cell[229902, 9491, 99, 2, 22, "Print"],
Cell[230004, 9495, 51, 1, 22, "Print"],
Cell[230058, 9498, 36, 1, 22, "Print"],
Cell[230097, 9501, 99, 2, 22, "Print"],
Cell[230199, 9505, 636, 14, 39, "Print"],
Cell[230838, 9521, 45, 1, 22, "Print"],
Cell[230886, 9524, 589, 14, 33, "Print"],
Cell[231478, 9540, 45, 1, 22, "Print"],
Cell[231526, 9543, 657, 15, 31, "Print"],
Cell[232186, 9560, 45, 1, 22, "Print"],
Cell[232234, 9563, 46, 1, 22, "Print"],
Cell[232283, 9566, 159, 3, 21, "Message"],
Cell[232445, 9571, 197, 5, 22, "Print"],
Cell[232645, 9578, 45, 1, 22, "Print"],
Cell[232693, 9581, 99, 2, 22, "Print"],
Cell[232795, 9585, 45, 1, 22, "Print"],
Cell[232843, 9588, 244, 5, 22, "Print"],
Cell[233090, 9595, 226, 4, 22, "Print"],
Cell[233319, 9601, 218, 4, 24, "Print"],
Cell[233540, 9607, 493, 9, 24, "Print"],
Cell[234036, 9618, 192, 3, 22, "Print"],
Cell[234231, 9623, 102, 2, 22, "Print"],
Cell[234336, 9627, 159, 3, 22, "Print"],
Cell[234498, 9632, 828, 18, 22, "Print"],
Cell[235329, 9652, 828, 18, 22, "Print"],
Cell[236160, 9672, 394, 10, 22, "Print"],
Cell[236557, 9684, 394, 10, 22, "Print"],
Cell[236954, 9696, 412, 10, 22, "Print"],
Cell[237369, 9708, 45, 1, 22, "Print"],
Cell[237417, 9711, 4132, 111, 117, "Print"],
Cell[241552, 9824, 46, 1, 22, "Print"],
Cell[241601, 9827, 4168, 121, 101, "Print"],
Cell[245772, 9950, 491, 9, 24, "Print"],
Cell[246266, 9961, 181, 3, 24, "Print"],
Cell[246450, 9966, 267, 5, 22, "Print"],
Cell[246720, 9973, 295, 6, 22, "Print"],
Cell[247018, 9981, 102, 2, 22, "Print"],
Cell[247123, 9985, 159, 3, 22, "Print"],
Cell[247285, 9990, 826, 18, 22, "Print"],
Cell[248114, 10010, 828, 18, 22, "Print"],
Cell[248945, 10030, 394, 10, 22, "Print"],
Cell[249342, 10042, 394, 10, 22, "Print"],
Cell[249739, 10054, 414, 10, 22, "Print"],
Cell[250156, 10066, 45, 1, 22, "Print"],
Cell[250204, 10069, 4229, 111, 117, "Print"],
Cell[254436, 10182, 46, 1, 22, "Print"],
Cell[254485, 10185, 4956, 121, 101, "Print"],
Cell[259444, 10308, 490, 9, 24, "Print"],
Cell[259937, 10319, 181, 3, 24, "Print"],
Cell[260121, 10324, 268, 5, 22, "Print"],
Cell[260392, 10331, 296, 6, 22, "Print"],
Cell[260691, 10339, 102, 2, 22, "Print"],
Cell[260796, 10343, 159, 3, 22, "Print"],
Cell[260958, 10348, 828, 18, 22, "Print"],
Cell[261789, 10368, 394, 10, 22, "Print"],
Cell[262186, 10380, 394, 10, 22, "Print"],
Cell[262583, 10392, 414, 10, 22, "Print"],
Cell[263000, 10404, 45, 1, 22, "Print"],
Cell[263048, 10407, 4219, 111, 117, "Print"],
Cell[267270, 10520, 46, 1, 22, "Print"],
Cell[267319, 10523, 5012, 121, 101, "Print"],
Cell[272334, 10646, 490, 9, 24, "Print"],
Cell[272827, 10657, 180, 3, 24, "Print"],
Cell[273010, 10662, 266, 5, 22, "Print"],
Cell[273279, 10669, 295, 6, 22, "Print"],
Cell[273577, 10677, 102, 2, 22, "Print"],
Cell[273682, 10681, 159, 3, 22, "Print"],
Cell[273844, 10686, 394, 10, 22, "Print"],
Cell[274241, 10698, 394, 10, 22, "Print"],
Cell[274638, 10710, 412, 10, 22, "Print"],
Cell[275053, 10722, 45, 1, 22, "Print"],
Cell[275101, 10725, 4249, 111, 117, "Print"],
Cell[279353, 10838, 46, 1, 22, "Print"],
Cell[279402, 10841, 4978, 121, 101, "Print"],
Cell[284383, 10964, 491, 9, 24, "Print"],
Cell[284877, 10975, 180, 3, 24, "Print"],
Cell[285060, 10980, 268, 5, 22, "Print"],
Cell[285331, 10987, 297, 6, 22, "Print"],
Cell[285631, 10995, 102, 2, 22, "Print"],
Cell[285736, 10999, 159, 3, 22, "Print"],
Cell[285898, 11004, 828, 18, 22, "Print"],
Cell[286729, 11024, 394, 10, 22, "Print"],
Cell[287126, 11036, 394, 10, 22, "Print"],
Cell[287523, 11048, 414, 10, 22, "Print"],
Cell[287940, 11060, 45, 1, 22, "Print"],
Cell[287988, 11063, 4249, 111, 117, "Print"],
Cell[292240, 11176, 46, 1, 22, "Print"],
Cell[292289, 11179, 4979, 121, 101, "Print"],
Cell[297271, 11302, 493, 9, 24, "Print"],
Cell[297767, 11313, 179, 3, 24, "Print"],
Cell[297949, 11318, 265, 5, 22, "Print"],
Cell[298217, 11325, 295, 6, 22, "Print"],
Cell[298515, 11333, 102, 2, 22, "Print"],
Cell[298620, 11337, 159, 3, 22, "Print"],
Cell[298782, 11342, 394, 10, 22, "Print"],
Cell[299179, 11354, 394, 10, 22, "Print"],
Cell[299576, 11366, 414, 10, 22, "Print"],
Cell[299993, 11378, 45, 1, 22, "Print"],
Cell[300041, 11381, 4230, 111, 117, "Print"],
Cell[304274, 11494, 46, 1, 22, "Print"],
Cell[304323, 11497, 4973, 121, 101, "Print"],
Cell[309299, 11620, 492, 9, 24, "Print"],
Cell[309794, 11631, 181, 3, 24, "Print"],
Cell[309978, 11636, 265, 5, 22, "Print"],
Cell[310246, 11643, 298, 6, 22, "Print"],
Cell[310547, 11651, 102, 2, 22, "Print"],
Cell[310652, 11655, 159, 3, 22, "Print"],
Cell[310814, 11660, 394, 10, 22, "Print"],
Cell[311211, 11672, 394, 10, 22, "Print"],
Cell[311608, 11684, 414, 10, 22, "Print"],
Cell[312025, 11696, 45, 1, 22, "Print"],
Cell[312073, 11699, 4248, 111, 117, "Print"],
Cell[316324, 11812, 46, 1, 22, "Print"],
Cell[316373, 11815, 4967, 121, 101, "Print"],
Cell[321343, 11938, 493, 9, 24, "Print"],
Cell[321839, 11949, 181, 3, 24, "Print"],
Cell[322023, 11954, 265, 5, 22, "Print"],
Cell[322291, 11961, 298, 6, 22, "Print"],
Cell[322592, 11969, 102, 2, 22, "Print"],
Cell[322697, 11973, 159, 3, 22, "Print"],
Cell[322859, 11978, 394, 10, 22, "Print"],
Cell[323256, 11990, 394, 10, 22, "Print"],
Cell[323653, 12002, 414, 10, 22, "Print"],
Cell[324070, 12014, 45, 1, 22, "Print"],
Cell[324118, 12017, 4248, 111, 117, "Print"],
Cell[328369, 12130, 46, 1, 22, "Print"],
Cell[328418, 12133, 4966, 121, 101, "Print"],
Cell[333387, 12256, 493, 9, 24, "Print"],
Cell[333883, 12267, 179, 3, 24, "Print"],
Cell[334065, 12272, 265, 5, 22, "Print"],
Cell[334333, 12279, 298, 6, 22, "Print"],
Cell[334634, 12287, 102, 2, 22, "Print"],
Cell[334739, 12291, 159, 3, 22, "Print"],
Cell[334901, 12296, 394, 10, 22, "Print"],
Cell[335298, 12308, 394, 10, 22, "Print"],
Cell[335695, 12320, 416, 10, 22, "Print"],
Cell[336114, 12332, 45, 1, 22, "Print"],
Cell[336162, 12335, 4249, 111, 117, "Print"],
Cell[340414, 12448, 46, 1, 22, "Print"],
Cell[340463, 12451, 4949, 121, 101, "Print"],
Cell[345415, 12574, 491, 9, 24, "Print"],
Cell[345909, 12585, 180, 3, 24, "Print"],
Cell[346092, 12590, 266, 5, 22, "Print"],
Cell[346361, 12597, 295, 6, 22, "Print"],
Cell[346659, 12605, 102, 2, 22, "Print"],
Cell[346764, 12609, 161, 3, 22, "Print"],
Cell[346928, 12614, 394, 10, 22, "Print"],
Cell[347325, 12626, 394, 10, 22, "Print"],
Cell[347722, 12638, 416, 10, 22, "Print"],
Cell[348141, 12650, 45, 1, 22, "Print"],
Cell[348189, 12653, 4255, 111, 117, "Print"],
Cell[352447, 12766, 46, 1, 22, "Print"],
Cell[352496, 12769, 4964, 121, 101, "Print"],
Cell[357463, 12892, 492, 9, 24, "Print"],
Cell[357958, 12903, 180, 3, 24, "Print"],
Cell[358141, 12908, 263, 5, 22, "Print"],
Cell[358407, 12915, 298, 6, 22, "Print"],
Cell[358708, 12923, 102, 2, 22, "Print"],
Cell[358813, 12927, 161, 3, 22, "Print"],
Cell[358977, 12932, 394, 10, 22, "Print"],
Cell[359374, 12944, 394, 10, 22, "Print"],
Cell[359771, 12956, 416, 10, 22, "Print"],
Cell[360190, 12968, 45, 1, 22, "Print"],
Cell[360238, 12971, 4255, 111, 117, "Print"],
Cell[364496, 13084, 46, 1, 22, "Print"],
Cell[364545, 13087, 4952, 121, 101, "Print"],
Cell[369500, 13210, 489, 9, 24, "Print"],
Cell[369992, 13221, 181, 3, 24, "Print"],
Cell[370176, 13226, 265, 5, 22, "Print"],
Cell[370444, 13233, 298, 6, 22, "Print"],
Cell[370745, 13241, 102, 2, 22, "Print"],
Cell[370850, 13245, 161, 3, 22, "Print"],
Cell[371014, 13250, 394, 10, 22, "Print"],
Cell[371411, 13262, 394, 10, 22, "Print"],
Cell[371808, 13274, 416, 10, 22, "Print"],
Cell[372227, 13286, 45, 1, 22, "Print"],
Cell[372275, 13289, 4255, 111, 117, "Print"],
Cell[376533, 13402, 46, 1, 22, "Print"],
Cell[376582, 13405, 4960, 121, 101, "Print"],
Cell[381545, 13528, 491, 9, 24, "Print"],
Cell[382039, 13539, 180, 3, 24, "Print"],
Cell[382222, 13544, 252, 4, 22, "Print"],
Cell[382477, 13550, 298, 6, 22, "Print"],
Cell[382778, 13558, 102, 2, 22, "Print"],
Cell[382883, 13562, 161, 3, 22, "Print"],
Cell[383047, 13567, 394, 10, 22, "Print"],
Cell[383444, 13579, 394, 10, 22, "Print"],
Cell[383841, 13591, 416, 10, 22, "Print"],
Cell[384260, 13603, 45, 1, 22, "Print"],
Cell[384308, 13606, 4252, 111, 117, "Print"],
Cell[388563, 13719, 46, 1, 22, "Print"],
Cell[388612, 13722, 4958, 121, 101, "Print"],
Cell[393573, 13845, 489, 9, 24, "Print"],
Cell[394065, 13856, 181, 3, 24, "Print"],
Cell[394249, 13861, 264, 5, 22, "Print"],
Cell[394516, 13868, 299, 6, 22, "Print"],
Cell[394818, 13876, 102, 2, 22, "Print"],
Cell[394923, 13880, 161, 3, 22, "Print"],
Cell[395087, 13885, 394, 10, 22, "Print"],
Cell[395484, 13897, 394, 10, 22, "Print"],
Cell[395881, 13909, 420, 10, 22, "Print"],
Cell[396304, 13921, 45, 1, 22, "Print"],
Cell[396352, 13924, 4262, 111, 117, "Print"],
Cell[400617, 14037, 46, 1, 22, "Print"],
Cell[400666, 14040, 4968, 121, 101, "Print"],
Cell[405637, 14163, 491, 9, 24, "Print"],
Cell[406131, 14174, 180, 3, 24, "Print"],
Cell[406314, 14179, 264, 5, 22, "Print"],
Cell[406581, 14186, 301, 6, 22, "Print"],
Cell[406885, 14194, 102, 2, 22, "Print"],
Cell[406990, 14198, 161, 3, 22, "Print"],
Cell[407154, 14203, 394, 10, 22, "Print"],
Cell[407551, 14215, 394, 10, 22, "Print"],
Cell[407948, 14227, 422, 10, 22, "Print"],
Cell[408373, 14239, 45, 1, 22, "Print"],
Cell[408421, 14242, 4278, 111, 117, "Print"],
Cell[412702, 14355, 46, 1, 22, "Print"],
Cell[412751, 14358, 4962, 121, 101, "Print"],
Cell[417716, 14481, 492, 9, 24, "Print"],
Cell[418211, 14492, 181, 3, 24, "Print"],
Cell[418395, 14497, 265, 5, 22, "Print"],
Cell[418663, 14504, 303, 6, 22, "Print"],
Cell[418969, 14512, 102, 2, 22, "Print"],
Cell[419074, 14516, 161, 3, 22, "Print"],
Cell[419238, 14521, 394, 10, 22, "Print"],
Cell[419635, 14533, 394, 10, 22, "Print"],
Cell[420032, 14545, 434, 10, 24, "Print"],
Cell[420469, 14557, 45, 1, 22, "Print"],
Cell[420517, 14560, 4286, 111, 117, "Print"],
Cell[424806, 14673, 46, 1, 22, "Print"],
Cell[424855, 14676, 4970, 121, 101, "Print"],
Cell[429828, 14799, 491, 9, 24, "Print"],
Cell[430322, 14810, 181, 3, 24, "Print"],
Cell[430506, 14815, 270, 5, 24, "Print"],
Cell[430779, 14822, 305, 6, 22, "Print"],
Cell[431087, 14830, 49, 1, 22, "Print"],
Cell[431139, 14833, 102, 2, 22, "Print"],
Cell[431244, 14837, 161, 3, 22, "Print"],
Cell[431408, 14842, 394, 10, 22, "Print"],
Cell[431805, 14854, 394, 10, 22, "Print"],
Cell[432202, 14866, 435, 10, 24, "Print"],
Cell[432640, 14878, 45, 1, 22, "Print"],
Cell[432688, 14881, 4220, 111, 117, "Print"],
Cell[436911, 14994, 46, 1, 22, "Print"],
Cell[436960, 14997, 4972, 121, 101, "Print"],
Cell[441935, 15120, 491, 9, 24, "Print"],
Cell[442429, 15131, 182, 3, 24, "Print"],
Cell[442614, 15136, 263, 4, 24, "Print"],
Cell[442880, 15142, 302, 6, 24, "Print"],
Cell[443185, 15150, 49, 1, 22, "Print"],
Cell[443237, 15153, 102, 2, 22, "Print"],
Cell[443342, 15157, 161, 3, 22, "Print"],
Cell[443506, 15162, 392, 10, 22, "Print"],
Cell[443901, 15174, 394, 10, 22, "Print"],
Cell[444298, 15186, 433, 10, 24, "Print"],
Cell[444734, 15198, 45, 1, 22, "Print"],
Cell[444782, 15201, 4107, 111, 117, "Print"],
Cell[448892, 15314, 46, 1, 22, "Print"],
Cell[448941, 15317, 4971, 121, 101, "Print"],
Cell[453915, 15440, 490, 9, 24, "Print"],
Cell[454408, 15451, 182, 3, 24, "Print"],
Cell[454593, 15456, 304, 6, 24, "Print"],
Cell[454900, 15464, 49, 1, 22, "Print"],
Cell[454952, 15467, 49, 1, 22, "Print"],
Cell[455004, 15470, 49, 1, 22, "Print"],
Cell[455056, 15473, 231, 4, 22, "Print"],
Cell[455290, 15479, 488, 12, 113, "Print"],
Cell[455781, 15493, 46, 1, 22, "Print"],
Cell[455830, 15496, 4971, 121, 101, "Print"],
Cell[460804, 15619, 4525, 86, 325, "Print"],
Cell[465332, 15707, 488, 9, 24, "Print"],
Cell[465823, 15718, 78, 1, 22, "Print"],
Cell[465904, 15721, 91, 1, 22, "Print"],
Cell[465998, 15724, 80, 1, 22, "Print"],
Cell[466081, 15727, 91, 1, 22, "Print"],
Cell[466175, 15730, 1619, 31, 93, "Print"],
Cell[467797, 15763, 89, 1, 22, "Print"],
Cell[467889, 15766, 45, 1, 22, "Print"],
Cell[467937, 15769, 89, 1, 22, "Print"],
Cell[468029, 15772, 542, 14, 31, "Print"],
Cell[468574, 15788, 67, 1, 22, "Print"],
Cell[468644, 15791, 89, 1, 22, "Print"],
Cell[468736, 15794, 66, 1, 22, "Print"],
Cell[468805, 15797, 89, 1, 22, "Print"],
Cell[468897, 15800, 89, 1, 22, "Print"],
Cell[468989, 15803, 208, 4, 22, "Print"],
Cell[469200, 15809, 1048, 24, 81, "Print"],
Cell[470251, 15835, 90, 1, 22, "Print"],
Cell[470344, 15838, 74, 1, 22, "Print"],
Cell[470421, 15841, 90, 1, 22, "Print"],
Cell[470514, 15844, 1338, 25, 101, "Print"],
Cell[471855, 15871, 91, 1, 22, "Print"],
Cell[471949, 15874, 97, 2, 22, "Print"],
Cell[472049, 15878, 91, 1, 22, "Print"],
Cell[472143, 15881, 1360, 25, 101, "Print"],
Cell[473506, 15908, 45, 1, 22, "Print"],
Cell[473554, 15911, 179, 3, 22, "Print"],
Cell[473736, 15916, 91, 1, 22, "Print"],
Cell[473830, 15919, 108, 2, 22, "Print"],
Cell[473941, 15923, 91, 1, 22, "Print"],
Cell[474035, 15926, 1286, 23, 101, "Print"],
Cell[475324, 15951, 45, 1, 22, "Print"],
Cell[475372, 15954, 171, 3, 22, "Print"],
Cell[475546, 15959, 91, 1, 22, "Print"],
Cell[475640, 15962, 58, 1, 22, "Print"],
Cell[475701, 15965, 91, 1, 22, "Print"],
Cell[475795, 15968, 201, 4, 22, "Print"],
Cell[475999, 15974, 109, 2, 22, "Print"],
Cell[476111, 15978, 742, 17, 41, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[476914, 16002, 103, 1, 46, "Subsection"],

Cell[CellGroupData[{
Cell[477042, 16007, 93, 5, 69, "Input"],
Cell[477138, 16014, 46, 1, 38, "Output"],
Cell[477187, 16017, 46, 1, 38, "Output"],
Cell[477236, 16020, 76, 1, 38, "Output"]
}, Open  ]],
Cell[477327, 16024, 97, 1, 30, "Text"],
Cell[477427, 16027, 200, 6, 54, "Input"],

Cell[CellGroupData[{
Cell[477652, 16037, 65, 1, 39, "Input"],
Cell[477720, 16040, 42, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[477799, 16046, 91, 1, 39, "Input"],
Cell[477893, 16049, 53, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[477983, 16055, 193, 7, 99, "Input"],
Cell[478179, 16064, 181, 3, 21, "Message"],
Cell[478363, 16069, 181, 3, 21, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[478581, 16077, 75, 1, 39, "Input"],
Cell[478659, 16080, 179, 3, 22, "Print"],
Cell[478841, 16085, 56716, 1263, 182, 10098, 683, "GraphicsData", \
"PostScript", "Graphics"],
Cell[535560, 17350, 130, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535727, 17358, 83, 1, 39, "Input"],
Cell[535813, 17361, 64, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535914, 17367, 49, 1, 39, "Input"],
Cell[535966, 17370, 46, 1, 38, "Output"]
}, Open  ]],
Cell[536027, 17374, 214, 6, 54, "Input"],

Cell[CellGroupData[{
Cell[536266, 17384, 501, 13, 129, "Input"],
Cell[536770, 17399, 179, 3, 22, "Print"],
Cell[536952, 17404, 179, 3, 22, "Print"],
Cell[537134, 17409, 179, 3, 22, "Print"],
Cell[537316, 17414, 179, 3, 22, "Print"],
Cell[537498, 17419, 152591, 4791, 435, 58601, 3627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[690092, 22212, 135, 3, 38, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

