(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    774681,      15181]*)
(*NotebookOutlinePosition[    776117,      15227]*)
(*  CellTagsIndexPosition[    775981,      15220]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Module", "Subsection",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Unprotect[He,phi,Phi];
    Clear[He,phi,Phi];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["He[n_,z_]:=HermiteH[n,z/Sqrt[2]] 2^(-n/2)//Simplify", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
phi=Exp[-#^2/2]/Sqrt[2Pi]&
Phi=CDF[NormalDistribution[0,1],#]&\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(#1\^2\/2\)\)\/\@\(2\ \[Pi]\) &\)], "Output",
  FontSize->14],

Cell[BoxData[
    \(CDF[NormalDistribution[0, 1], #1] &\)], "Output",
  FontSize->14]
}, Open  ]],

Cell["{He,phi,Phi}//Protect;", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "FourierKoeff1//Clear\n",
  StyleBox["FourierKoeff1",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,m_]:=\nModule[{z,rules},\nrules={z^k_->m[k],z->(m[1]=0),m[2]->1}; (*Z \
standard.*)\n\n(1/j!)(He[j,z]//Collect[#,z]&)//.rules\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion//Clear\n",
  StyleBox["HermiteExpansion",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=(phi[z]*(1+Sum[FourierKoeff1[j,m]*He[j,z],{j,3,M}]))"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["HermiteExpansion",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=\n\t\t(phi[z]*(1+Sum[FourierKoeff1[j,m]*He[j,z],{j,3,M}]))"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansionOhnePhi//Clear\n",
  StyleBox["HermiteExpansionOhnePhi",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=(1+Sum[FourierKoeff1[j,m]*He[j,z],{j,3,M}])"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["HermiteExpansionalt",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=(phi[z]*(Sum[FourierKoeff1[j,m]*He[j,z],{j,0,M}]))"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nHermiteExpansion",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,my_]:=\nBlock[{z,mmrule,M,m,mu,sigma},\n\n(* \
my={mu,m[2]=sigma^2,E[y-mu]^k} zentrierte Momente*)\n\nmu=my[[1]];\n\
sigma=my[[2]]//Sqrt;\nz=(y-mu)/sigma;\n\nm//Clear;\nM=Length[my];\n\
mmrule=Table[m[i]->my[[i]]/sigma^i,{i,3,M}]; (* stand. Momente E[z^k]*)\n\n\
(1/sigma)(HermiteExpansion[M,z,m]/.mmrule)\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nHermiteExpansionOhnePhi",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,my_]:=\nBlock[{z,mmrule,M,m,mu,sigma},\n\n(* \
my={mu,m[2]=sigma^2,E[y-mu]^k} zentrierte Momente*)\n\nmu=my[[1]];\n\
sigma=my[[2]]//Sqrt;\nz=(y-mu)/sigma;\n\nm//Clear;\nM=Length[my];\n\
mmrule=Table[m[i]->my[[i]]/sigma^i,{i,3,M}]; (* stand. Momente E[z^k]*)\n\n\
HermiteExpansionOhnePhi[M,z,m]/.mmrule\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nHermiteExpansionOhnePhiz",
    FontColor->RGBColor[1, 0, 0]],
  "[z_,my_]:=\nBlock[{z,mmrule,M,m,mu,sigma},\n\n(* \
my={mu,m[2]=sigma^2,E[y-mu]^k} zentrierte Momente*)\n\nm//Clear;\n\
M=Length[my];\nsigma=my[[2]]//Sqrt;\n\
mmrule=Table[m[i]->my[[i]]/sigma^i,{i,3,M}]; (* stand. Momente E[z^k]*)\n\n\
HermiteExpansionOhnePhi[M,z,m]/.mmrule\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nLogHermiteExpansion",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,my_]:=\nBlock[{z,mmrule,M,m,mu,sigma},\n\n(* \
my={mu,m[2]=sigma^2,E[y-mu]^k} zentrierte Momente*)\n\nmu=my[[1]];\n\
sigma=my[[2]]//Sqrt;\nz=(y-mu)/sigma;\n\nm//Clear;\nM=Length[my];\n\
mmrule=Table[m[i]->my[[i]]/sigma^i,{i,3,M}]; (* stand. Momente E[z^k]*)\n\n\
-0.5 (z^2 + Log[2 Pi \
sigma^2/(Sum[FourierKoeff1[j,m]*He[j,z],{j,0,M}]/.mmrule)^2])\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["HermiteExpansion[1.,{1,2,3,4}]//Log", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\(-1.5531941959364264`\)\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["LogHermiteExpansion[1.,{1,2,3,4}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\(-1.5531941959364264`\)\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "HermiteExpansionInt//Clear\n",
  StyleBox["HermiteExpansionInt",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=Phi[z]-(phi[z]*Sum[FourierKoeff1[j,m]*He[j-1,z],{j,1,M}])"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nHermiteExpansionInt",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,my_]:=\nModule[{z,mmrule,M,m,mu,sigma},\n\n(* \
my={mu,m[2]=sigma^2,E[y-mu]^k} zentrierte Momente*)\n\nmu=my[[1]];\n\
sigma=my[[2]]//Sqrt;\nz=(y-mu)/sigma;\n\nm//Clear;\nM=Length[my];\n\
mmrule=Table[m[i]->my[[i]]/sigma^i,{i,3,M}]; (* stand. Momente E[z^k]*)\n\n\
HermiteExpansionInt[M,z,m]/.mmrule\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["nur Zentrierung ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "FourierKoeff2//Clear\n",
  StyleBox["FourierKoeff2",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,m_]:=\nModule[{z,rules},\nrules={z^k_->m[k],z->(m[1]=0)};\n\n\
(1/j!)(He[j,z]//Collect[#,z]&)//.rules\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion2//Clear\n",
  StyleBox["HermiteExpansion2",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,z_,m_]:=(phi[z]*Sum[FourierKoeff2[j,m]*He[j,z],{j,0,M}])"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["\n\nHermiteExpansion2",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,my_]:=\nModule[{z,mmrule,M,m,mu,sigma},\n\n(* my={E[y],E[(y-mu)^k]} \
zentrierte Momente *)\n\nm//Clear;\nM=Length[my];\n\
mmrule=Table[m[i]->my[[i]],{i,1,M}]; (* zentr. Momente E[(y-mu)^k]*)\n\n\
HermiteExpansion2[M,y-my[[1]],m]/.mmrule\n\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["mit Hermite-Funktionen (Osz.-EF)", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "FourierKoeff3//Clear\n",
  StyleBox["FourierKoeff3",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,pz_,phi_]:=\nModule[{z},\n\n(1/j!)NIntegrate[He[j,z] pz[z] \
phi[z]^(1/2) ,{z,-Infinity,Infinity}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion3//Clear\n",
  StyleBox["HermiteExpansion3",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_,phi_]:=\nModule[{mue,sigma,pz,z},\n\n  mue= NIntegrate  [y \
p[y],{y,-Infinity,Infinity}];\nsigma=(NIntegrate[y^2 \
p[y],{y,-Infinity,Infinity}]-mue^2)//Sqrt;\n\nz=(y-mue)/sigma; \n\
pz[z_]:=sigma p[mue+z sigma];\n\n(1/sigma) phi[z]^(1/2) \
Sum[FourierKoeff3[j,pz,phi]*He[j,z],{j,0,M}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion3Test//Clear\n",
  StyleBox["HermiteExpansion3Test",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_,phi_]:=\nModule[{mue,sigma,pz,z,b=Table[0,{j,0,M}],out},\n\n  \
mue= NIntegrate  [y p[y],{y,-Infinity,Infinity}];\nsigma=(NIntegrate[y^2 \
p[y],{y,-Infinity,Infinity}]-mue^2)//Sqrt;\n\nz=(y-mue)/sigma; \n\
pz[z_]:=sigma p[mue+z sigma];\n\nout=(1/sigma) phi[z]^(1/2) \
Sum[(b[[j+1]]=FourierKoeff3[j,pz,phi])*He[j,z],{j,0,M}];\n{out,b}\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion3oz//Clear\n",
  StyleBox["HermiteExpansion3oz",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_,phi_]:=\nModule[{j},\n\nphi[y]^(1/2) \
Sum[FourierKoeff3[j,p,phi]*He[j,y],{j,0,M}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion3u//Clear\n",
  StyleBox["HermiteExpansion3u",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_,phi_]:=\nModule[{mue,sigma,sigma2,pu,u},\n\n  mue= NIntegrate  \
[y p[y],{y,-Infinity,Infinity}];\nsigma=(NIntegrate[y^2 \
p[y],{y,-Infinity,Infinity}]-mue^2)//Sqrt;\nsigma2=sigma/Sqrt[2];\n\n\
u=(y-mue)/sigma2; \npu[u_]:= sigma2 p[mue+u sigma2];\n\n(1/sigma2) \
phi[u]^(1/2) Sum[FourierKoeff3[j,pu,phi]*He[j,u],{j,0,M}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["mit Osz.-EF / Normierung exp(-z^2)", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["HermiteH[3,z]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\(-12\)\ z + 8\ z\^3\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["D[Exp[-z^2],{z,3}]*Exp[z^2]//Simplify", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(12\ z - 8\ z\^3\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
nu[l_]:=Sqrt[l! 2^l/(2 Sqrt[Pi])] (*mit Sqrt[2Pi] von phi[z]*)
nu[0]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(1\/\(\@2\ \[Pi]\^\(1/4\)\)\)], "Output",
  FontSize->14]
}, Open  ]],

Cell["psi[l_,z_]:=HermiteH[l, z] phi[z]/nu[l]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["psi[0,z]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(z\^2\/2\)\)\/\[Pi]\^\(1/4\)\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrate[psi[3,z]^2,{z,-Infinity,Infinity}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Pattern :: \\\"nodef\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    \(1\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrate[psi[3,z] psi[5,z],{z,-Infinity,Infinity}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(Pattern::"nodef"\), \(\(:\)\(\ \)\), "\<\"No default setting \
found for \\!\\(Times\\) in position \\!\\(2\\) when length is \\!\\(2\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Pattern::nodef\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Pattern :: \\\"nodef\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message",
  FontSize->14],

Cell[BoxData[
    \(0\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "FourierKoeff5//Clear\n",
  StyleBox["FourierKoeff5",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,pz_]:=\nModule[{z},\n\nNIntegrate[psi[j,z] pz[z] \
,{z,-Infinity,Infinity}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion5//Clear\n",
  StyleBox["HermiteExpansion5",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_]:=\nModule[{mue,sigma,pz,z},\n\n  mue= NIntegrate  [y \
p[y],{y,-Infinity,Infinity}];\nsigma=(NIntegrate[y^2 \
p[y],{y,-Infinity,Infinity}]-mue^2)//Sqrt;\n\nz=(y-mue)/sigma; \n\
pz[z_]:=sigma p[mue+z sigma];\n\n(1/sigma) \
Sum[FourierKoeff5[j,pz]*psi[j,z],{j,0,M}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell["Test", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "FourierKoeff4//Clear\n",
  StyleBox["FourierKoeff4",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,pz_,phi_]:=\nModule[{z},\n\n(1/j!)NIntegrate[He[j,z] \
pz[z],{z,-Infinity,Infinity}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansion4//Clear\n",
  StyleBox["HermiteExpansion4",
    FontColor->RGBColor[1, 0, 0]],
  "[M_,y_,p_,phi_]:=\nModule[{mue,sigma,pz,z},\n\n  mue= NIntegrate[y   \
p[y],{y,-Infinity,Infinity}];\nsigma=(NIntegrate[y^2 \
p[y],{y,-Infinity,Infinity}]-mue^2)//Sqrt;\n\nz=(y-mue)/sigma; \n\
pz[z_]:=sigma p[mue+z sigma];\n\n(1/sigma) phi[z] \
Sum[FourierKoeff4[j,pz,phi]*He[j,z],{j,0,M}]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multi (p=2)", "Subsection",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
HeMulti//Clear
HeMulti[l_,x_,op_:Times]:=Apply[op,MapThread[He[#1,#2]&,{l,x}]]\
\>", "Input",\

  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
mm//Clear
mm[k_,l_]:=mm[k,l]=Module[{x,y},
Integrate[p[{x,y}]x^k y^l,{x,-Infinity,Infinity},
                          {y,-Infinity,Infinity}]]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "FourierKoeffMulti//Clear\n",
  StyleBox["FourierKoeffMulti",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,m_]:=Module[{rules,x,y},\n\nrules={x^k_ y^l_->m[k,l],\n       x    \
y^l_->m[1,l],\n       x^k_ y   ->m[k,1],\n       x    y   ->m[1,1],\n       \
x^k_     ->m[k,0],\n            y^l_->m[0,l],\n       x        ->m[1,0],\n    \
   y        ->m[0,1]};\n\nApply[Times,1/j!] (HeMulti[j,{x,y}]//Expand)/.rules\
\n\n]\n         "
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansionMultiSym//Clear  \n",
  StyleBox["HermiteExpansionMultiSym",
    FontColor->RGBColor[1, 0, 0]],
  "[J_,x_,m_,Option_:\"{q,phiH}\"]:=\n(*symbolisch*)\t\n\nModule[{j1,j2},\n\n\
If[Option===\"{q,phiH}\",\nGaussKern[x,IdentityMatrix[2]]*\n\
Sum[FourierKoeffMulti[{j1,j2},m]*HeMulti[{j1,j2},x],{j1,0,J},{j2,0,J}],\n\n\
If[Option===\"{d,phiH}\",\nGaussKern[x,IdentityMatrix[2]]*\n\
Sum[FourierKoeffMulti[{j1,j2},m]*HeMulti[{j1,j2},x],{j1,0,J},{j2,0,J-j1}],\n\n\
If[Option===\"{q,H}\",\n\
Sum[FourierKoeffMulti[{j1,j2},m]*HeMulti[{j1,j2},x],{j1,0,J},{j2,0,J}],\n\n\
If[Option===\"{d,H}\",\n\
Sum[FourierKoeffMulti[{j1,j2},m]*HeMulti[{j1,j2},x],{j1,0,J},{j2,0,J-j1}]\n\n\
]]]]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
??HermiteExpansionMultiSym
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`HermiteExpansionMultiSym
HermiteExpansionMultiSym[J_, x_, m_, Option_:\"{q,phiH}\"] := 
   Module[{j1, j2}, If[Option === \"{q,phiH}\", GaussKern[x, \
IdentityMatrix[2]]*
      Sum[FourierKoeffMulti[{j1, j2}, m]*HeMulti[{j1, j2}, x], {j1, 0, J}, \
{j2, 0, J}], 
     If[Option === \"{d,phiH}\", GaussKern[x, IdentityMatrix[2]]*
       Sum[FourierKoeffMulti[{j1, j2}, m]*HeMulti[{j1, j2}, x], {j1, 0, J}, 
        {j2, 0, J - j1}], If[Option === \"{q,H}\", Sum[FourierKoeffMulti[{j1, \
j2}, m]*
         HeMulti[{j1, j2}, x], {j1, 0, J}, {j2, 0, J}], If[Option === \"{d,H}\
\", 
        Sum[FourierKoeffMulti[{j1, j2}, m]*HeMulti[{j1, j2}, x], {j1, 0, J}, 
         {j2, 0, J - j1}]]]]]]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
m//Clear
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
HermiteExpa
nsionMultiSym[2,{x,y},m,\"{d,phiH}\"]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + y*m[0, 1] + ((-1 + \
y^2)*(-1 + m[0, 2]))/2 + x*m[1, 0] + 

     x*y*m[1, 1] + ((-1 + x^2)*(-1 + m[2, \
0]))/2))/2.718281828459045^(0.5*(x^2 + y^2))\
\>", "\<\
                      \
             2
                            (-1 + y ) (-1 + m[0, 2])
 (0.159155 (1 + y m[0, 1] + ------------------------ + x m[1, 0] + x y m[1, \
1] + 
                                       2
         2                                  2    2
  (-1 + x ) (-1 + m[2, 0])            0.5 (x  + y )
  ------------------------)) / 2.71828
             2\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti
Sym[2,{x,y},m]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + y*m[0, 1] + ((-1 + \
y^2)*(-1 + m[0, 2]))/2 + x*m[1, 0] + 

     x*y*m[1, 1] + (x*(-1 + y^2)*(-m[1, 0] + m[1, 2]))/2 + ((-1 + x^2)*(-1 + \
m[2, 0]))/2 + 

     ((-1 + x^2)*y*(-m[0, 1] + m[2, 1]))/2 + 

     ((-1 + x^2)*(-1 + y^2)*(1 - m[0, 2] - m[2, 0] + m[2, 2]))/4))/

   2.718281828459045^(0.5*(x^2 + y^2))\
\>", "\<\
                            \
       2
                            (-1 + y ) (-1 + m[0, 2])
 (0.159155 (1 + y m[0, 1] + ------------------------ + x m[1, 0] + x y m[1, \
1] + 
                                       2
           2                                2
  x (-1 + y ) (-m[1, 0] + m[1, 2])   (-1 + x ) (-1 + m[2, 0])
  -------------------------------- + ------------------------ + 
                 2                              2
         2                                  2         2
  (-1 + x ) y (-m[0, 1] + m[2, 1])   (-1 + x ) (-1 + y ) (1 - m[0, 2] - m[2, \
0] + m[2, 2])
  -------------------------------- + \
-----------------------------------------------------))
                 2                                             4
                  2    2
            0.5 (x  + y )
   / 2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "iter//Clear\n",
  StyleBox["iter",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,a_,b_]:=Sequence@@MapThread[{j[#1],#2,#3}&,{a//Length//Range,a,b}]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["iter[j,{a1,a2,a3},{b1,b2,b3}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{j[1], a1, b1}\
\>", "\<\
Sequence[{j[1], a1, b1}, \
{j[2], a2, b2}, {j[3], a3, b3}]\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "(*mit Momenten my_{kl}=E[x^k y^l]*)\n",
  StyleBox["HermiteExpansionMulti",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,my_,Option_:\"{q,phiH}\"]:=\nModule[{m,J=(my//Length)-1,k,l},\n  \
(*J//Print;*)\n\t\the=HermiteExpansionMultiSym[J,x,m,Option]; \n\t\t\
he/.{m[k_,l_]->my[[k+1,l+1]]}\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti[{x,y},{{m00,m01,m02},
                             {m10,m11,m13},
                             {m20,m21,m22}},\"{d,H}\"]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
1 + m10*x + ((-1 + m20)*(-1 + x^2))/2 + m01*y + \
m11*x*y + ((-1 + m02)*(-1 + y^2))/2\
\>", "\<\
                              \
2                                        2
            (-1 + m20) (-1 + x )                     (-1 + m02) (-1 + y )
1 + m10 x + -------------------- + m01 y + m11 x y + --------------------
                     2                                        2\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti[{x,y},{{m00,m01,m02},
                             {m10,m11},
                             {m20}},\"{d,phiH}\"]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + m10*x + ((-1 + m20)*(-1 + \
x^2))/2 + m01*y + m11*x*y + 

     ((-1 + m02)*(-1 + y^2))/2))/2.718281828459045^(0.5*(x^2 + y^2))\
\>", \
"\<\
                                        2                                \
        2
                      (-1 + m20) (-1 + x )                     (-1 + m02) (-1 \
+ y )
0.159155 (1 + m10 x + -------------------- + m01 y + m11 x y + \
--------------------)
                               2                                        2
------------------------------------------------------------------------------\
------
                                             2    2
                                       0.5 (x  + y )
                                2.71828\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti[{x1,x2},{{1,2},
                               {1,1}}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
(0.15915494309189535*(1 + x1 + 2*x2 + \
x1*x2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "\<\
0.159155 (1 + x1 + 2 \
x2 + x1 x2)
--------------------------------
                   2     2
            0.5 (x1  + x2 )
     2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "HermiteExpansionMultiStand//Clear\n",
  StyleBox["HermiteExpansionMultiStand",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,M_,Option_:\"{q,phiH}\"]:=\n\nModule[{mue,Sigma,p,k,K,J,gamma},\n\
(*stand. Entwicklung; M={mu,m^2,m^3,..}, sym. vektorisiert*)\n\n\
{mue,Sigma}=M[[{1,2}]];\n\np=mue//Length;\nK=M//Length; (*K//Print;*)\n\n\
Sigma=momentexp2index[Sigma,2,p];  \n\
gamma=Sigma//CholeskyDecomposition//Transpose//Inverse;\n\n\nNue= \nTable[\n\t\
\tM1tensor=momentexp2index[M[[k]],k,p];\n\t\t\
momentindex2exp[nue[k,gamma,M1tensor],k,p]  (*stand. Momente Ordnung k; \
Vektor*)\n,{k,2,K}]; \n\nNue=Join[{{1}},{Shape[0,p]},Nue];\n\n\
If[Option===\"{q,phiH}\",\nJ=K/2;\nM2=MomentVec2Mat[Nue,J,p]; (*Momente \
E[z1^k z2^l]*)\nDet[gamma] \
HermiteExpansionMulti[gamma.(y-mue),M2,\"{q,phiH}\"],\n\n\
If[Option===\"{d,phiH}\",\nJ=K;\nM2=MomentVec2MatD[Nue,J,p]; (*Momente E[z1^k \
z2^l]*)\nDet[gamma] HermiteExpansionMulti[gamma.(y-mue),M2,\"{d,phiH}\"],\n\n\
If[Option===\"{q,H}\",\nJ=K/2;\nM2=MomentVec2Mat[Nue,J,p]; (*Momente E[z1^k \
z2^l]*)\nHermiteExpansionMulti[gamma.(y-mue),M2,\"{q,H}\"],\n\n\
If[Option===\"{d,H}\",\nJ=K;\nM2=MomentVec2MatD[Nue,J,p]; (*Momente E[z1^k \
z2^l]*)\nHermiteExpansionMulti[gamma.(y-mue),M2,\"{d,H}\"]\n]]]]\n\n]\n\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
M={{m10,m01},{m20,m11,m02},{m30,m21,m12,m03},{m40,m31,m22,m13,m04}}\
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{m10, m01}, {m20, m11, m02}, {m30, m21, m12, m03}, \
{m40, m31, m22, m13, m04}}\
\>", "\<\
{{m10, m01}, {m20, m11, m02}, {m30, \
m21, m12, m03}, {m40, m31, m22, m13, m04}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["M={{0,0},{1,.5,2},{1,0,0,1}}", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{0, 0}, {1, 0.5, 2}, {1, 0, 0, 1}}\
\>", "\<\
{{0, \
0}, {1, 0.5, 2}, {1, 0, 0, 1}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["x", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {0.03744628327253238, 0.5977065188964417, \
1.3213883219790674, 0.5090987168183178, 

   2.3610520343037296, -0.2374750166567883, 1.0422353084643843, \
1.8186220269038504, 

   0.38950008571522543, 0.6566786957153314, -0.10176282509923641, \
1.2170491589939327, 

   1.9240632911868496, 0.23316624899841795, -0.12271028447678238, \
0.32400358118989014, 

   1.1332769958060034, 1.6876790086373432, 0.04289657971770089, \
-0.13859680834388668, 

   1.1301222793328165, 0.770690320251385, 1.0913268602778614, \
-0.11067977549338971, 

   0.8674507050224831}\
\>", "\<\
 {0.0374463, 0.597707, 1.32139, 0.509099, \
2.36105, -0.237475, 1.04224, 1.81862, 0.3895, 
  0.656679, -0.101763, 1.21705, 1.92406, 0.233166, -0.12271, 0.324004, \
1.13328, 1.68768, 
  0.0428966, -0.138597, 1.13012, 0.77069, 1.09133, -0.11068, 0.867451}\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["HermiteExpansionMultiStand[{xx,yy},M,\"{d,H}\"]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["3", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 1 + 0.022271770159368688*(0. + 3.207134902949092*xx \
+ 

     2.8284271247461894*(-0.3779644730092272*xx + 0.7559289460184544*yy)^3 - 

     6.414269805898184*yy) + 0.05892556509887895*(0. - 8.48528137423857*xx + 

     2.8284271247461894*(1.*xx + 0.*yy)^3 + 0.*yy) + \
0.*(0.9999999999999998*xx + 0.*yy)*

    (-0.3779644730092271*xx + 0.7559289460184542*yy) + 

   0.*(-1. + 0.9999999999999998*xx^2 + 0.*xx*yy + 0.*yy^2) - 

   0.1889822365046136*(-0.3779644730092271*xx + 0.7559289460184542*yy)*

    (-1. + 0.9999999999999998*xx^2 + 0.*xx*yy + 0.*yy^2) - 

   1.1102230246251565*^-16*(-1. + 0.1428571428571428*xx^2 - \
0.5714285714285712*xx*yy + 

     0.5714285714285712*yy^2) + 0.07142857142857141*(0.9999999999999998*xx + \
0.*yy)*

    (-1. + 0.1428571428571428*xx^2 - 0.5714285714285712*xx*yy + \
0.5714285714285712*yy^2)\
\>", "\<\
                                          \
                            3
 1 + 0.0222718 (0. + 3.20713 xx + 2.82843 (-0.377964 xx + 0.755929 yy)  - \
6.41427 yy) + 
                                                      3
  0.0589256 (0. - 8.48528 xx + 2.82843 (1. xx + 0. yy)  + 0. yy) + 
                                                                   2          \
         2
  0. (1. xx + 0. yy) (-0.377964 xx + 0.755929 yy) + 0. (-1. + 1. xx  + 0. xx \
yy + 0. yy ) - 
                                                    2                   2
  0.188982 (-0.377964 xx + 0.755929 yy) (-1. + 1. xx  + 0. xx yy + 0. yy ) - 
            -16                   2                               2
  1.11022 10    (-1. + 0.142857 xx  - 0.571429 xx yy + 0.571429 yy ) + 
                                              2                               \
2
  0.0714286 (1. xx + 0. yy) (-1. + 0.142857 xx  - 0.571429 xx yy + 0.571429 \
yy )\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["M={{1,1},{1,0,2},{0,0,0,0},{3,0,2,0,6}}", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1}, {1, 0, 2}, {0, 0, 0, 0}, {3, 0, 2, 0, 6}}\
\
\>", "\<\
{{1, 1}, {1, 0, 2}, {0, 0, 0, 0}, {3, 0, 2, 0, 6}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
py=HermiteExpansionMultiStand[{y1,y2},M]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
4
2\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
0.11253953951963826/2.718281828459045^(0.5*((-1. + \
y1)^2 + 0.5*(-1. + y2)^2))\
\>", "\<\
                 0.11254
------------------------------------------
                      2                 2
       0.5 ((-1. + y1)  + 0.5 (-1. + y2) )
2.71828\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "HermiteExpansionMultiStandApost//Clear\n",
  StyleBox["HermiteExpansionMultiStandApost",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,{mue0_,Sigma0_},M_,Option_:\"{q,phiH}\"]:=\n\n(*stand. Entwicklung; \
M={mu,m^2,m^3,..}, sym. vektorisiert*)\n(*f\[UDoubleDot]hrende apost. \
Gaussdichte phi0*)\n\nModule[{mue,Sigma,p,k,K,J,gamma,sigma0},\n\n\n\
{mue,Sigma}=M[[{1,2}]];\n\np=mue//Length;\nK=M//Length;\n\n\
Sigma=momentexp2index[Sigma,2,p];  \n\
gamma=Sigma//CholeskyDecomposition//Transpose//Inverse;\n\
sigma0=momentexp2index[Sigma0,2,p]; \n\nNue= \nTable[\n\t\t\
M1tensor=momentexp2index[M[[k]],k,p];\n\t\t\
momentindex2exp[nue[k,gamma,M1tensor],k,p]  (*stand. Momente Ordnung k; \
Vektor*)\n,{k,2,K}]; \n\nNue=Join[{{1}},{Shape[0,p]},Nue];\n\n\
If[Option===\"{q,phiH}\",\nJ=K/2;\nM2=MomentVec2Mat[Nue,J,p]; (*Momente \
E[z1^k z2^l]*)\n\
GaussDichte[y,{mue0,sigma0}]*HermiteExpansionMulti[gamma.(y-mue),M2,\"{q,H}\"]\
,\n\nIf[Option===\"{d,phiH}\",\nJ=K;\nM2=MomentVec2MatD[Nue,J,p]; (*Momente \
E[z1^k z2^l]*)\n\
GaussDichte[y,{mue0,sigma0}]*HermiteExpansionMulti[gamma.(y-mue),M2,\"{d,H}\"]\
\n]]\n\n]\n\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
M//Clear (*Indizes; 1<=ij<=p*)
M[x_,i_]    :=Product[x[i[[j]]], {j,1,i//Length}] (*Length[i]-tes Moment*)
M[x_List,i_]:=Product[x[[i[[j]]]], {j,1,i//Length}] (*Length[i]-tes \
Moment*)\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "MM//Clear (*Exponenten; ij>=0*)\nMM[x_,i_]    :=Product[x[j]^i[[j]], \
{j,1,i//Length}] (*Plus@@i-tes Moment*)\nOff[",
  StyleBox["Power::indet]",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  "\nMM[x_List,i_]:=Product[x[[j]]^i[[j]]/.{0^0->1}, \
{j,1,i//Length}](*Plus@@i-tes Moment*)"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
Clear[x,y,z]

 M[x,{1,2}]
MM[x,{1,1}]
 M[{x,y,z},{1,1,2}]
MM[{x,y,0},{2,1,0}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
x[1]*x[2]\
\>", "\<\
x[1] x[2]\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
x[1]*x[2]\
\>", "\<\
x[1] x[2]\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
x^2*y\
\>", "\<\
 2
x  y\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
x^2*y\
\>", "\<\
 2
x  y\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Map[MM[#,{2,1}]&,{{1,2},{2,3}}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{2, 12}\
\>", "\<\
{2, 12}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["??MM", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`MM
MM[x_List, i_] := Product[x[[j]]^i[[j]], {j, 1, Length[i]}]
 
MM[x_, i_] := Product[x[j]^i[[j]], {j, 1, Length[i]}]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["e[i_,p_]:=IdentityMatrix[p][[i]]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["Apply[Plus,Map[e[#,2]&,{1,2,1}]]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{2, 1}\
\>", "\<\
{2, 1}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["index2exp[{1,2,1},2]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{2, 1}\
\>", "\<\
{2, 1}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
nue//Clear
nue[k_,gamma_,m_]:=(*stand. Momente Ordnung k*)
Module[{nue1,op},

op=gamma.Transpose[#,RotateRight[k//Range]]&;(*1->4, 2->1,3->2,...*)
nue1=Nest[op,gamma.m,k-1]

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["exp2index",
    FontColor->RGBColor[1, 0, 0]],
  "[exp_]:=APLExpand[max[exp,0],exp//Length//Range]//Flatten\n"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["index2exp",
    FontColor->RGBColor[1, 0, 0]],
  "[index_,p_]:=Map[Count[index,#]&,p//Range]\n\nkexp//Clear\n",
  StyleBox["kexp",
    FontColor->RGBColor[1, 0, 0]],
  "[k_,p_]:=\nModule[{exp}, (*Exponenten zur Ordnung k=k1+k2+...kp*)\n\n\
exp=tupel[Range[0,k]//Reverse,p,List];\nSelect[exp,(Apply[Plus,#]==k)&]\n]\n"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "kexpalt//Clear\n",
  StyleBox["kexpalt",
    FontColor->RGBColor[1, 0, 0]],
  "[k_,p_]:=\nModule[{exp}, (*Exponenten zur Ordnung k=k1+k2+...kp*)\n\n\
exp=Flatten[Transpose[Array[List,Shape[k+1,p]]-1,p//Range//Reverse],p-1];\n\
Select[exp,(Apply[Plus,#]==k)&]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["linpos",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,p_]:=Position[kexp[Plus@@j,p],j][[1,1]]\n",
  StyleBox["linposalt",
    FontColor->RGBColor[1, 0, 0]],
  "[j_,p_]:=Position[kexpalt[Plus@@j,p],j][[1,1]]\n",
  StyleBox["linposindex",
    FontColor->RGBColor[1, 0, 0]],
  "[ind_,p_]:=linpos[index2exp[ind,p],p]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
kexp[0,2]
linpos[{0,0},2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{0, 0}}\
\>", "\<\
{{0, 0}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
1\
\>", "\<\
1\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
e1=kexp[3,3]
e2=kexpalt[3,3]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{3, 0, 0}, {2, 1, 0}, {2, 0, 1}, {1, 2, 0}, {1, 1, \
1}, {1, 0, 2}, {0, 3, 0}, {0, 2, 1}, {0, 1, 2}, {0, 0, 3}}\
\>", "\<\
{{3, 0, \
0}, {2, 1, 0}, {2, 0, 1}, {1, 2, 0}, {1, 1, 1}, {1, 0, 2}, {0, 3, 0}, {0, 2, \
1}, {0, 1, 2}, {0, 0, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{3, 0, 0}, {2, 1, 0}, {1, 2, 0}, {0, 3, 0}, {2, 0, \
1}, {1, 1, 1}, {0, 2, 1}, {1, 0, 2}, {0, 1, 2}, {0, 0, 3}}\
\>", "\<\
{{3, 0, \
0}, {2, 1, 0}, {1, 2, 0}, {0, 3, 0}, {2, 0, 1}, {1, 1, 1}, {0, 2, 1}, {1, 0, \
2}, {0, 1, 2}, {0, 0, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Map[exp2index,e1]
Map[exp2index,e2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1, 1}, {1, 1, 2}, {1, 1, 3}, {1, 2, 2}, {1, 2, \
3}, {1, 3, 3}, {2, 2, 2}, {2, 2, 3}, {2, 3, 3}, {3, 3, 3}}\
\>", "\<\
{{1, 1, \
1}, {1, 1, 2}, {1, 1, 3}, {1, 2, 2}, {1, 2, 3}, {1, 3, 3}, {2, 2, 2}, {2, 2, \
3}, {2, 3, 3}, {3, 3, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1, 1}, {1, 1, 2}, {1, 2, 2}, {2, 2, 2}, {1, 1, \
3}, {1, 2, 3}, {2, 2, 3}, {1, 3, 3}, {2, 3, 3}, {3, 3, 3}}\
\>", "\<\
{{1, 1, \
1}, {1, 1, 2}, {1, 2, 2}, {2, 2, 2}, {1, 1, 3}, {1, 2, 3}, {2, 2, 3}, {1, 3, \
3}, {2, 3, 3}, {3, 3, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
kexp[Plus@@{3,3},2]
kexpalt[Plus@@{3,3},2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{6, 0}, {5, 1}, {4, 2}, {3, 3}, {2, 4}, {1, 5}, {0, \
6}}\
\>", "\<\
{{6, 0}, {5, 1}, {4, 2}, {3, 3}, {2, 4}, {1, 5}, {0, \
6}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{6, 0}, {5, 1}, {4, 2}, {3, 3}, {2, 4}, {1, 5}, {0, \
6}}\
\>", "\<\
{{6, 0}, {5, 1}, {4, 2}, {3, 3}, {2, 4}, {1, 5}, {0, \
6}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
linpos[{3,3},p=2]
linposalt[{3,3},p=2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
4\
\>", "\<\
4\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
4\
\>", "\<\
4\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ke=kexp[k=2,p=3]
Map[exp2index,ke]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{2, 0, 0}, {1, 1, 0}, {1, 0, 1}, {0, 2, 0}, {0, 1, \
1}, {0, 0, 2}}\
\>", "\<\
{{2, 0, 0}, {1, 1, 0}, {1, 0, 1}, {0, 2, 0}, {0, 1, \
1}, {0, 0, 2}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1}, {1, 2}, {1, 3}, {2, 2}, {2, 3}, {3, \
3}}\
\>", "\<\
{{1, 1}, {1, 2}, {1, 3}, {2, 2}, {2, 3}, {3, 3}}\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ke=kexp[k=3,p=3]
Map[exp2index,ke]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{3, 0, 0}, {2, 1, 0}, {2, 0, 1}, {1, 2, 0}, {1, 1, \
1}, {1, 0, 2}, {0, 3, 0}, {0, 2, 1}, 

   {0, 1, 2}, {0, 0, 3}}\
\>", "\<\
 {{3, 0, 0}, {2, 1, 0}, {2, 0, 1}, {1, 2, \
0}, {1, 1, 1}, {1, 0, 2}, {0, 3, 0}, {0, 2, 1}, 
  {0, 1, 2}, {0, 0, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{1, 1, 1}, {1, 1, 2}, {1, 1, 3}, {1, 2, 2}, {1, 2, \
3}, {1, 3, 3}, {2, 2, 2}, {2, 2, 3}, 

   {2, 3, 3}, {3, 3, 3}}\
\>", "\<\
 {{1, 1, 1}, {1, 1, 2}, {1, 1, 3}, {1, 2, \
2}, {1, 2, 3}, {1, 3, 3}, {2, 2, 2}, {2, 2, 3}, 
  {2, 3, 3}, {3, 3, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
e1
ind=Map[exp2index,e1]
Map[linpos[index2exp[#,3],3]&,ind]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{3, 0, 0}, {2, 1, 0}, {2, 0, 1}, {1, 2, 0}, {1, 1, \
1}, {1, 0, 2}, {0, 3, 0}, {0, 2, 1}, 

   {0, 1, 2}, {0, 0, 3}}\
\>", "\<\
 {{3, 0, 0}, {2, 1, 0}, {2, 0, 1}, {1, 2, \
0}, {1, 1, 1}, {1, 0, 2}, {0, 3, 0}, {0, 2, 1}, 
  {0, 1, 2}, {0, 0, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{1, 1, 1}, {1, 1, 2}, {1, 1, 3}, {1, 2, 2}, {1, 2, \
3}, {1, 3, 3}, {2, 2, 2}, {2, 2, 3}, 

   {2, 3, 3}, {3, 3, 3}}\
\>", "\<\
 {{1, 1, 1}, {1, 1, 2}, {1, 1, 3}, {1, 2, \
2}, {1, 2, 3}, {1, 3, 3}, {2, 2, 2}, {2, 2, 3}, 
  {2, 3, 3}, {3, 3, 3}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}\
\>", "\<\
{1, 2, 3, \
4, 5, 6, 7, 8, 9, 10}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["linposindex[{2,3,3,3,3,3},3]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{0.*Second, 27}\
\>", "\<\
{0. Second, 27}\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["linposindex1[{2,3,3,3,3,3},3]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{0.016666666662786156*Second, 27}\
\>", \
"\<\
{0.0166667 Second, 27}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["linposindex2[{2,3,3,3,3,3},3]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{0.03333333333284827*Second, 27}\
\>", \
"\<\
{0.0333333 Second, 27}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["linposindex2[{2,2,2},3]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
7\
\>", "\<\
7\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["linposdiag",
    FontColor->RGBColor[1, 0, 0]],
  "[k_,p_]:=Table[linposindex2[Shape[i,k],p],{i,p}]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["linposdiag[2,4]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \({1, 5, 8, 10}\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "VecDiagSymmetric//Clear\n",
  StyleBox["VecDiagSymmetric",
    FontColor->RGBColor[1, 0, 0]],
  "[A_,k_,p_]:=A[[linposdiag[k,p]]]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["VecDiagSymmetric[{a,b,c,d,e,f},2,3]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{a, d, f}\
\>", "\<\
{a, d, f}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "linposindex1//Clear",
  StyleBox["\nlinposindex1",
    FontColor->RGBColor[1, 0, 0]],
  "[ind_,p_]:=\nBlock[{k,ivec,i,tab},\nk=ind//Length;\nivec=Array[i,k];\n\
tab=Table[ivec,iter[i,{1,Drop[ivec,-1]}//Flatten,Shape[p,k]]//Evaluate];\n\
tab=Flatten[tab,k-1];\nPosition[tab,ind][[1,1]]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["linposindex2",
    FontColor->RGBColor[1, 0, 0]],
  "[ind_,p_]:=\nBlock[{k=ind//Length,tab},\n\
tab=Select[tupel[p//Range,k,List],LessEqual@@#&];\nPosition[tab,ind][[1,1]]\n\
]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentexp2index[m_,k_,p_]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{i,index},\nindex=Array[i,{k}];\n\
Table[m[[linpos[index2exp[index,p],p]]],Sequence@@Map[{#,p}&,index]//Evaluate]\
\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentindex2exp[m_,k_,p_]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{kvec},\nkvec=kexp[k,p];\nMap[m[[Sequence@@exp2index[#]]]&,kvec]\n\
]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentindex2exp1[m_,k_,p_]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{kvec},\nkvec=kexp[k,p];\nExtract[m,Map[exp2index,kvec]]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "flattensymmetric[m_]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{kvec,dim,p,k},\ndim=m//Dimensions;\np=dim//First;\nk=dim//Length;\n\
kvec=kexp[k,p];\nMap[m[[Sequence@@exp2index[#]]]&,kvec]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "indexflattensymmetric[k_,p_]:=Map[exp2index,kexp[k,p]]\n",
  StyleBox["(***************************************************************)\
\t\t\t ",
    FontWeight->"Plain"]
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
flattensymmetric[I3]
indexflattensymmetric[4,2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{1, 0, 0, 1, 0, 1}\
\>", "\<\
{1, 0, 0, 1, 0, \
1}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1, 1, 1}, {1, 1, 1, 2}, {1, 1, 2, 2}, {1, 2, 2, \
2}, {2, 2, 2, 2}}\
\>", "\<\
{{1, 1, 1, 1}, {1, 1, 1, 2}, {1, 1, 2, 2}, {1, \
2, 2, 2}, {2, 2, 2, 2}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
mm//Dimensions
mm//TensorRank\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{2, 2, 2}\
\>", "\<\
{2, 2, 2}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
3\
\>", "\<\
3\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
momentindex2exp1[{{m11,m12},{m21,m22}},2,2]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{m11, m12, m22}\
\>", "\<\
{m11, m12, m22}\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
momentindex2exp[{{m11,m12},{m21,m22}},2,2]
m=momentindex2exp[mm={{{m111,m112},{m121,m122}},{{m211,m212},{m221,m222}}},3,\
2]
momentexp2index[m,3,p=2]
indexflattensymmetric[k=4,p=2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{m11, m12, m22}\
\>", "\<\
{m11, m12, m22}\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{m111, m112, m122, m222}\
\>", "\<\
{m111, m112, \
m122, m222}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{{m111, m112}, {m112, m122}}, {{m112, m122}, {m122, \
m222}}}\
\>", "\<\
{{{m111, m112}, {m112, m122}}, {{m112, m122}, {m122, \
m222}}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{1, 1, 1, 1}, {1, 1, 1, 2}, {1, 1, 2, 2}, {1, 2, 2, \
2}, {2, 2, 2, 2}}\
\>", "\<\
{{1, 1, 1, 1}, {1, 1, 1, 2}, {1, 1, 2, 2}, {1, \
2, 2, 2}, {2, 2, 2, 2}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
MomentVec2Mat[M_,J_,p_]:=
(*Vektor von Momentenmatrizen M={m0,m1,m2,..}->E[z1^k z2^l]*)
Module[{k,l},
Table[M[[k+l+1]][[linpos[{k,l},p]]],{k,0,J},{l,0,J}]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
MomentVec2MatD[M_,J_,p_]:=
(*Vektor von Momentenmatrizen M={m0,m1,m2,..}->E[z1^k z2^l]; l>=k*)
Module[{k,l},
Table[M[[k+l+1]][[linpos[{k,l},p]]],{k,0,J},{l,0,J-k}]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
M={{1},{m10,m01},{m20,m11,m02},{m30,m21,m12,m03},{m40,m31,m22,m13,\
m04}};
MomentVec2Mat[M,2,2]//MatrixForm
MomentVec2MatD[M,2,2]//MatrixForm\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
MatrixForm[{{1, m01, m02}, {m10, m11, m12}, {m20, \
m21, m22}}]\
\>", "\<\
    1   2   3

1   1   m01 m02
2   m10 m11 m12
3   m20 m21 m22\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
MatrixForm[{{1, m01, m02}, {m10, m11}, {m20}}]\
\>", \
"\<\

1   {1, m01, m02}
2   {m10, m11}
3   {m20}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
M={{1},{m10,m01},{m20,m11,m02},{m30,m21,m12,m03},{m40,m31,m22,m13,\
m04}};
MomentVec2Mat[M,1,2]//MatrixForm\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
MatrixForm[{{1, m01}, {m10, m11}}]\
\>", "\<\
    1  \
 2

1   1   m01
2   m10 m11\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
MomentMat2Vec[M_,J_,p_]:=
(* M=E[z1^l z2^m]->Vektor von Momentenmatrizen {m0,m1,m2,..}*)
Module[{k},

Table[Map[M[[Sequence@@(#+1)]]&,kexp[k,p]],{k,0,2J}]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["MomentMat2Vec[MMM,1,2]//MatrixForm", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::partd: Part specification MMM[[1,1]] is longer than depth of \
object.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::partd: Part specification MMM[[2,1]] is longer than depth of \
object.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::partd: Part specification MMM[[1,2]] is longer than depth of \
object.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
General::stop: Further output of Part::partd will be suppressed \
during this calculation.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
MatrixForm[{{MMM[[1,1]]}, {MMM[[2,1]], MMM[[1,2]]}, \
{MMM[[3,1]], MMM[[2,2]], MMM[[1,3]]}}]\
\>", "\<\

1   {MMM[[1,1]]}
2   {MMM[[2,1]], MMM[[1,2]]}
3   {MMM[[3,1]], MMM[[2,2]], MMM[[1,3]]}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multi (p>=2)", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "momentrules//Clear\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentrules[x_,m_,p_,K_]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t ",
    FontWeight->"Plain"],
  "\nModule[{xx,xxx,mm},\n\nxx=Array[x,p];\n\nTable[\n\
xxx=Map[Apply[Times,Power[xx,#]]&,kexp[k,p]];\nmm=Map[Apply[m,#]&,kexp[k,p]];\
\nMapThread[Rule,{xxx,mm}],\n{k,K,1,-1}]//Flatten\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
Clear[z,m]
momentrules[z,m,p=2,K=3]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \({z[1]\^3 \[Rule] m[3, 0], z[1]\^2\ z[2] \[Rule] m[2, 1], 
      z[1]\ z[2]\^2 \[Rule] m[1, 2], z[2]\^3 \[Rule] m[0, 3], 
      z[1]\^2 \[Rule] m[2, 0], z[1]\ z[2] \[Rule] m[1, 1], 
      z[2]\^2 \[Rule] m[0, 2], z[1] \[Rule] m[1, 0], 
      z[2] \[Rule] m[0, 1]}\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "momentrules1//Clear\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentrules1[x_,m_,p_,K_]:=Module[{xx,xxx},\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "\nxx=Array[x,p];\n\nTable[\nxxx=Map[Apply[Times,Power[xx,#]]&,kexp[k,p]];\n\
MapThread[Rule,{xxx,m[[k]]}],\n{k,K,1,-1}]//Flatten\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
momentrules1[x,{{m10,m01},{m20,m11,m02},{m30,m21,m12,m03}},p=2,K=3]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {x[1]^3 -> m30, x[1]^2*x[2] -> m21, x[1]*x[2]^2 -> \
m12, x[2]^3 -> m03, x[1]^2 -> m20, 

   x[1]*x[2] -> m11, x[2]^2 -> m02, x[1] -> m10, x[2] -> m01}\
\>", "\<\
     \
 3             2                       2             3             2
 {x[1]  -> m30, x[1]  x[2] -> m21, x[1] x[2]  -> m12, x[2]  -> m03, x[1]  -> \
m20, 
                        2
  x[1] x[2] -> m11, x[2]  -> m02, x[1] -> m10, x[2] -> m01}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["Off[Part::partd]; \n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  "momentrules2//Clear\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "momentrules2[x_,m_,p_,K_,stand_:False]:=Module[{xx,xxx,expos,dim},\n",
  StyleBox["(***************************************************************)\
\t\t\t \n(*",
    FontWeight->"Plain"],
  "m[[k,l]]=k-tes Moment, vektorisiert = \n    \
{{m1,m2},{m11,m12,m22},{m111,m112,..}",
  StyleBox["*)\n  ",
    FontWeight->"Plain"],
  "\nxx=Array[x,p];\n\nTable[\n\nexpos=kexp[k,p];  \ndim=expos//Length;\n\
xxx=Map[Apply[Times,Power[xx,#]]&,expos]; (*Potenzen von x[i]*)\n\ntab=\n\
If[stand,\n\n    If[k==1,Table[0,{l,1,dim}],\n    \
If[k==2,flattensymmetric[IdentityMatrix[p]],\n    \
Table[m[[k,l]],{l,1,dim}]]],\n\nTable[m[[k,l]],{l,1,dim}]\n];\n\n\
MapThread[Rule,{xxx,tab}],\n{k,K,1,-1}]//Flatten\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["kexp[4,3]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{4, 0, 0}, {3, 1, 0}, {3, 0, 1}, {2, 2, 0}, {2, 1, \
1}, {2, 0, 2}, {1, 3, 0}, {1, 2, 1}, 

   {1, 1, 2}, {1, 0, 3}, {0, 4, 0}, {0, 3, 1}, {0, 2, 2}, {0, 1, 3}, {0, 0, \
4}}\
\>", "\<\
 {{4, 0, 0}, {3, 1, 0}, {3, 0, 1}, {2, 2, 0}, {2, 1, 1}, {2, \
0, 2}, {1, 3, 0}, {1, 2, 1}, 
  {1, 1, 2}, {1, 0, 3}, {0, 4, 0}, {0, 3, 1}, {0, 2, 2}, {0, 1, 3}, {0, 0, \
4}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
momentrules2[x,m,p=3,K=4,True]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {x[1]^4 -> m[[4,1]], x[1]^3*x[2] -> m[[4,2]], \
x[1]^3*x[3] -> m[[4,3]], 

   x[1]^2*x[2]^2 -> m[[4,4]], x[1]^2*x[2]*x[3] -> m[[4,5]], x[1]^2*x[3]^2 -> \
m[[4,6]], 

   x[1]*x[2]^3 -> m[[4,7]], x[1]*x[2]^2*x[3] -> m[[4,8]], x[1]*x[2]*x[3]^2 -> \
m[[4,9]], 

   x[1]*x[3]^3 -> m[[4,10]], x[2]^4 -> m[[4,11]], x[2]^3*x[3] -> m[[4,12]], 

   x[2]^2*x[3]^2 -> m[[4,13]], x[2]*x[3]^3 -> m[[4,14]], x[3]^4 -> m[[4,15]], \


   x[1]^3 -> m[[3,1]], x[1]^2*x[2] -> m[[3,2]], x[1]^2*x[3] -> m[[3,3]], 

   x[1]*x[2]^2 -> m[[3,4]], x[1]*x[2]*x[3] -> m[[3,5]], x[1]*x[3]^2 -> \
m[[3,6]], 

   x[2]^3 -> m[[3,7]], x[2]^2*x[3] -> m[[3,8]], x[2]*x[3]^2 -> m[[3,9]], \
x[3]^3 ->\\
  m[[3,10]], 
 x[1]^2 -> 1, x[1]*x[2] -> 0, x[1]*x[3] -> 0, x[2]^2 -> 1, x[2]*x[3] -> 0,\\
  x[3]^2 -> 1, 
 x[1] -> 0, x[2] -> 0, x[3] -> 0}\
\>", "\<\
      4                  3       \
                3
 {x[1]  -> m[[4,1]], x[1]  x[2] -> m[[4,2]], x[1]  x[3] -> m[[4,3]], 
      2     2                  2                            2     2
  x[1]  x[2]  -> m[[4,4]], x[1]  x[2] x[3] -> m[[4,5]], x[1]  x[3]  -> \
m[[4,6]], 
           3                       2                                 2
  x[1] x[2]  -> m[[4,7]], x[1] x[2]  x[3] -> m[[4,8]], x[1] x[2] x[3]  -> \
m[[4,9]], 
           3                   4                   3
  x[1] x[3]  -> m[[4,10]], x[2]  -> m[[4,11]], x[2]  x[3] -> m[[4,12]], 
      2     2                        3                   4                   \
3
  x[2]  x[3]  -> m[[4,13]], x[2] x[3]  -> m[[4,14]], x[3]  -> m[[4,15]], x[1] \
 -> m[[3,1]], 
      2                       2                            2
  x[1]  x[2] -> m[[3,2]], x[1]  x[3] -> m[[3,3]], x[1] x[2]  -> m[[3,4]], 
                                       2                  3
  x[1] x[2] x[3] -> m[[3,5]], x[1] x[3]  -> m[[3,6]], x[2]  -> m[[3,7]], 
      2                            2                  3                   2
  x[2]  x[3] -> m[[3,8]], x[2] x[3]  -> m[[3,9]], x[3]  -> m[[3,10]], x[1]  \
-> 1, 
                                      2                           2
  x[1] x[2] -> 0, x[1] x[3] -> 0, x[2]  -> 1, x[2] x[3] -> 0, x[3]  -> 1, \
x[1] -> 0, 
  x[2] -> 0, x[3] -> 0}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["test[x_,o1_:\"o1\",o2_:\"o2\"]:=Print[o1,\"  \",o2]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["test[xee,uuu]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["uuu  o2", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "(*symbolisch*)\n",
  StyleBox["HermiteExpansionMultiSymp//Clear",
    FontColor->RGBColor[1, 0, 0]],
  "\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  StyleBox["HermiteExpansionMultiSymp",
    FontColor->RGBColor[1, 0, 0]],
  "[J_,y_,m_,opt_:\"phiH\",stand_:False]:=\t\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{p,rule,x,xx,ind,fak,hprods,mm,H},\np=y//Length;\n\nClear[rule,x];\n\
\nxx=Array[x,p];\nrule=momentrules2[x,m,p,J,stand];\n\nH=Sum[\n\n\
ind=kexp[k,p]; \nfak=Apply[Times,ind!,1];\n\
hprods=Map[HeMulti[#,xx]&,ind]//Expand;\nmm=hprods/.rule;\n\
(mm/fak).(hprods/.MapThread[Rule,{xx,y}])\n\n,{k,0,J}];\n\n\
If[opt==\"phiH\",GaussKern[y,IdentityMatrix[p]]*H,\nIf[opt==\"H\",H]]\n\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Clear[x,m]\n\
p2=HermiteExpansionMultiSymp[3,{x[[1]],x[[2]]},m,\"phiH\",False]",
  FontColor->RGBColor[1, 0, 0]]], "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + x[[1]]*m[[1,1]] + \
x[[2]]*m[[1,2]] + ((-1 + x[[1]]^2)*(-1 + m[[2,1]]))/2 + \
x[[1]]*x[[2]]*m[[2,2]] + ((-1 + x[[2]]^2)*(-1 + m[[2,3]]))/2 + ((-3*x[[1]] + \
x[[1]]^3)*(-3*m[[1,1]] + m[[3,1]]))/6 + ((-x[[2]] + \
x[[1]]^2*x[[2]])*(-m[[1,2]] + m[[3,2]]))/2 + 

     ((-x[[1]] + x[[1]]*x[[2]]^2)*(-m[[1,1]] + m[[3,3]]))/2 + ((-3*x[[2]] + \
x[[2]]^3)*(-3*m[[1,2]] + m[[3,4]]))/6))/2.718281828459045^(0.5*(x[[1]]^2 + \
x[[2]]^2))\
\>", "\<\
                                                        \
        2                                                         2           \
                            3                                              2  \
                                                        2
                                                    (-1 + x[[1]] ) (-1 + \
m[[2,1]])                            (-1 + x[[2]] ) (-1 + m[[2,3]])   (-3 \
x[[1]] + x[[1]] ) (-3 m[[1,1]] + m[[3,1]])   (-x[[2]] + x[[1]]  x[[2]]) \
(-m[[1,2]] + m[[3,2]])   (-x[[1]] + x[[1]] x[[2]] ) (-m[[1,1]] + m[[3,3]])
 (0.159155 (1 + x[[1]] m[[1,1]] + x[[2]] m[[1,2]] + \
------------------------------ + x[[1]] x[[2]] m[[2,2]] + \
------------------------------ + \
---------------------------------------------- + \
------------------------------------------------- + \
------------------------------------------------- + 
                                                                  2           \
                                              2                               \
         6                                                  2                 \
                                  2
                     3                                                 2      \
   2
  (-3 x[[2]] + x[[2]] ) (-3 m[[1,2]] + m[[3,4]])            0.5 (x[[1]]  + \
x[[2]] )
  ----------------------------------------------)) / 2.71828
                        6\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["p1=HermiteExpansionMultiSym[3,{x1,x2},m,\"{d,phiH}\"]\
",
  FontColor->RGBColor[1, 0, 0]]], "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + x2*m[0, 1] + ((-1 + \
x2^2)*(-1 + m[0, 2]))/2 + 

     (x2*(-3 + x2^2)*(-3*m[0, 1] + m[0, 3]))/6 + x1*m[1, 0] + x1*x2*m[1, 1] + \


     (x1*(-1 + x2^2)*(-m[1, 0] + m[1, 2]))/2 + ((-1 + x1^2)*(-1 + m[2, 0]))/2 \
+ 

     ((-1 + x1^2)*x2*(-m[0, 1] + m[2, 1]))/2 + (x1*(-3 + x1^2)*(-3*m[1, 0] + \
m[3, 0]))/6))/

   2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "\<\
                          \
           2
                             (-1 + x2 ) (-1 + m[0, 2])
 (0.159155 (1 + x2 m[0, 1] + ------------------------- + 
                                         2
             2
  x2 (-3 + x2 ) (-3 m[0, 1] + m[0, 3])
  ------------------------------------ + x1 m[1, 0] + x1 x2 m[1, 1] + 
                   6
             2                                 2
  x1 (-1 + x2 ) (-m[1, 0] + m[1, 2])   (-1 + x1 ) (-1 + m[2, 0])
  ---------------------------------- + ------------------------- + 
                  2                                2
          2                                       2
  (-1 + x1 ) x2 (-m[0, 1] + m[2, 1])   x1 (-3 + x1 ) (-3 m[1, 0] + m[3, 0])
  ---------------------------------- + ------------------------------------)) \
/ 
                  2                                     6
                2     2
         0.5 (x1  + x2 )
  2.71828\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
p1/.{x1->1,x2->2}
p2/.{x[[1]]->1,x[[2]]->2}\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 0.013064233284684921*(1 + 2*m[0, 1] + (3*(-1 + m[0, \
2]))/2 + (-3*m[0, 1] + m[0, 3])/3 + 

    m[1, 0] + 2*m[1, 1] + (3*(-m[1, 0] + m[1, 2]))/2 + (3*m[1, 0] - m[3, \
0])/3)\
\>", "\<\
                            3 (-1 + m[0, 2])   -3 m[0, 1] + \
m[0, 3]
 0.0130642 (1 + 2 m[0, 1] + ---------------- + -------------------- + m[1, 0] \
+ 2 m[1, 1] + 
                                   2                    3
  3 (-m[1, 0] + m[1, 2])   3 m[1, 0] - m[3, 0]
  ---------------------- + -------------------)
            2                       3\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 0.013064233284684921*(1 + m[[1,1]] + 2*m[[1,2]] + \
2*m[[2,2]] + (3*(-1 + m[[2,3]]))/2 + 

    (3*m[[1,1]] - m[[3,1]])/3 + (3*(-m[[1,1]] + m[[3,3]]))/2 + (-3*m[[1,2]] + \
m[[3,4]])/3)\
\>", "\<\
                                                     \
3 (-1 + m[[2,3]])
 0.0130642 (1 + m[[1,1]] + 2 m[[1,2]] + 2 m[[2,2]] + ----------------- + 
                                                             2
  3 m[[1,1]] - m[[3,1]]   3 (-m[[1,1]] + m[[3,3]])   -3 m[[1,2]] + m[[3,4]]
  --------------------- + ------------------------ + ----------------------)
            3                        2                         3\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "(*mit Momenten*)\n",
  StyleBox["HermiteExpansionMultip//Clear",
    FontColor->RGBColor[1, 0, 0]],
  "\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  StyleBox["HermiteExpansionMultip",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,m_,opt_:\"phiH\"]:=\t\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "Module[{p,J,rule,x,xx,H,ind,fak,hprods,mm},\np=y//Length;\nJ=m//Length;  \
(*Vektorisiertes m*)\n\nClear[x];\n\nxx=Array[x,p];\n\
rule=momentrules2[x,m,p,J];\n\nH=Sum[\nind=kexp[k,p];\n\
fak=Apply[Times,ind!,1];\nhprods=Map[HeMulti[#,xx]&,ind]//Expand;\n\
mm=hprods/.rule;\n\n(*(mm/fak)//Print; *)  (*mm/fak=c_k*)\n\n\
(mm/fak).(hprods/.MapThread[Rule,{xx,y}]) \n\n,{k,0,J}];\n\n\
If[opt==\"phiH\",GaussKern[y,1]*H,\nIf[opt==\"H\",H]]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["??GaussKern", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
GaussKern = (2 Pi sigma)^(-.5 p) Exp[-.5 (x.x)/sigma]
GaussKern[(Hermann`KernDichte`Private`x_)?VectorQ, 
    {(Hermann`KernDichte`Private`sigma_)?MatrixQ, \
(Hermann`KernDichte`Private`sigma1_)?
      MatrixQ}] := 
   N[Exp[-0.5*Hermann`KernDichte`Private`x . \
Hermann`KernDichte`Private`sigma1 . 
        Hermann`KernDichte`Private`x]/Det[2*Pi*Hermann`KernDichte`Private`\
sigma]^0.5]
 
GaussKern[(Hermann`KernDichte`Private`x_)?VectorQ, \
(Hermann`KernDichte`Private`sigma_)?
     MatrixQ] := Module[{Hermann`KernDichte`Private`p = 
      Length[Hermann`KernDichte`Private`x], Hermann`KernDichte`Private`sigma1 \
= 
      Inverse[Hermann`KernDichte`Private`sigma]}, 
    N[Exp[-0.5*Hermann`KernDichte`Private`x . \
Hermann`KernDichte`Private`sigma1 . 
         Hermann`KernDichte`Private`x]/Det[2*Pi*Hermann`KernDichte`Private`\
sigma]^0.5]]
 
GaussKern[(Hermann`KernDichte`Private`x_)?VectorQ, \
(Hermann`KernDichte`Private`sigma_)?
     ScalarQ] := Module[{Hermann`KernDichte`Private`p = 
      Length[Hermann`KernDichte`Private`x]}, 
    N[Exp[(-0.5*Hermann`KernDichte`Private`x . Hermann`KernDichte`Private`x)/
        Hermann`KernDichte`Private`sigma]/(2*Pi*Hermann`KernDichte`Private`\
sigma)^
       (0.5*Hermann`KernDichte`Private`p)]]
 
GaussKern[(Hermann`KernDichte`Private`x_)?VectorQ, 
    {(Hermann`KernDichte`Private`sigma_)?ScalarQ}] := 
   Module[{Hermann`KernDichte`Private`p = \
Length[Hermann`KernDichte`Private`x]}, 
    N[Exp[(-0.5*Hermann`KernDichte`Private`x . Hermann`KernDichte`Private`x)/
        Hermann`KernDichte`Private`sigma]/(2*Pi*Hermann`KernDichte`Private`\
sigma)^
       (0.5*Hermann`KernDichte`Private`p)]]
 
GaussKern[(Hermann`KernDichte`Private`x_)?ScalarQ, \
(Hermann`KernDichte`Private`sigma_)?
     ScalarQ] := Module[{}, 
    N[Exp[(-0.5*(Hermann`KernDichte`Private`x*Hermann`KernDichte`Private`x))/
        Hermann`KernDichte`Private`sigma]/(2*Pi*Hermann`KernDichte`Private`\
sigma)^0.5]]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Clear[x,m]
momentrules2[x,m,2,4]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {x[1]^4 -> m[[4,1]], x[1]^3*x[2] -> m[[4,2]], \
x[1]^2*x[2]^2 -> m[[4,3]], 

   x[1]*x[2]^3 -> m[[4,4]], x[2]^4 -> m[[4,5]], x[1]^3 -> m[[3,1]], \
x[1]^2*x[2] ->\\
  m[[3,2]], 
 x[1]*x[2]^2 -> m[[3,3]], x[2]^3 -> m[[3,4]], x[1]^2 -> m[[2,1]], x[1]*x[2] \
->\\
  m[[2,2]], 
 x[2]^2 -> m[[2,3]], x[1] -> m[[1,1]], x[2] -> m[[1,2]]}\
\>", "\<\
      4   \
               3                       2     2
 {x[1]  -> m[[4,1]], x[1]  x[2] -> m[[4,2]], x[1]  x[2]  -> m[[4,3]], 
           3                  4                  3                  2
  x[1] x[2]  -> m[[4,4]], x[2]  -> m[[4,5]], x[1]  -> m[[3,1]], x[1]  x[2] -> \
m[[3,2]], 
           2                  3                  2
  x[1] x[2]  -> m[[3,3]], x[2]  -> m[[3,4]], x[1]  -> m[[2,1]], x[1] x[2] -> \
m[[2,2]], 
      2
  x[2]  -> m[[2,3]], x[1] -> m[[1,1]], x[2] -> m[[1,2]]}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultip[{x1,x2},{{m10,m01},{m20,m11,m02}}]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + m10*x1 + ((-1 + m20)*(-1 \
+ x1^2))/2 + m01*x2 + m11*x1*x2 + 

     ((-1 + m02)*(-1 + x2^2))/2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", \
"\<\
                                          2                              \
              2
                       (-1 + m20) (-1 + x1 )                        (-1 + \
m02) (-1 + x2 )
0.159155 (1 + m10 x1 + --------------------- + m01 x2 + m11 x1 x2 + \
---------------------)
                                 2                                            \
2
------------------------------------------------------------------------------\
------------
                                                2     2
                                         0.5 (x1  + x2 )
                                  2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultip[{x1,x2},{{m10,m01},{m20,m11,m02}}]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + m10*x1 + ((-1 + m20)*(-1 \
+ x1^2))/2 + m01*x2 + m11*x1*x2 + 

     ((-1 + m02)*(-1 + x2^2))/2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", \
"\<\
                                          2                              \
              2
                       (-1 + m20) (-1 + x1 )                        (-1 + \
m02) (-1 + x2 )
0.159155 (1 + m10 x1 + --------------------- + m01 x2 + m11 x1 x2 + \
---------------------)
                                 2                                            \
2
------------------------------------------------------------------------------\
------------
                                                2     2
                                         0.5 (x1  + x2 )
                                  2.71828\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["??HermiteExpansionMultiSymp", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["Global`HermiteExpansionMultiSymp", "Print",
  FontSize->14,
  CellTags->"Info3406902286-9666275"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(HermiteExpansionMultiSymp[J_, y_, m_, opt_ : "phiH", 
                      stand_ : False] := 
                    Module[{p, rule, x, xx, ind, fak, hprods, mm, H}, 
                      p = Length[y]; Clear[rule, x]; xx = Array[x, p]; 
                      rule = momentrules2[x, m, p, J, stand]; 
                      H = \[Sum]\+\(k = 0\)\%J\((ind = kexp[k, p]; 
                            fak = Apply[Times, \(ind!\), 1]; 
                            hprods = Expand[\((HeMulti[#1, xx] &)\) /@ ind]; 
                            mm = hprods /. \[InvisibleSpace]rule; \(mm\/fak\) \
. \((hprods /. \[InvisibleSpace]MapThread[Rule, {xx, y}])\))\); 
                      If[opt \[Equal] "phiH", 
                        GaussKern[y, IdentityMatrix[p]]\ H, 
                        If[opt \[Equal] "H", H]]]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "HermiteExpansionMultiSymp"],
      Editable->False]], "Print",
  FontSize->14,
  CellTags->"Info3406902286-9666275"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\tHermiteExpansionMultiSymp[2,{x1,x2},M,\"H\",True]
\t\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
1\
\>", "\<\
1\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["(*explizite Formeln*)\n\n",
    FontColor->RGBColor[1, 0, 0]],
  "Clear[Hermite,x1,x2,x3,M];\n\n\nDo[Hermite[k,{x1_},M_,   \"H\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1},M,   \"H\"],{k,1,8}]\n\t\t\n\
Do[Hermite[k,{x1_},M_,\"phiH\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1},M,\"phiH\"],{k,1,8}]\n   \n\n\
Do[Hermite[k,{x1_,x2_},M_,   \"H\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2},M,   \"H\"],{k,1,8}]\n\t\t\n\
Do[Hermite[k,{x1_,x2_},M_,\"phiH\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2},M,\"phiH\"],{k,1,8}]\n\t\t\n\
Do[Hermite[k,{x1_,x2_,x3_},M_,   \"H\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2,x3},M,   \"H\"],{k,1,8}]\n\t\t\n\
Do[Hermite[k,{x1_,x2_,x3_},M_,\"phiH\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2,x3},M,\"phiH\"],{k,1,8}]\n\n   "
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["??Hermite", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`Hermite
Hermite[1, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]]
 
Hermite[2, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2
 
Hermite[3, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6
 
Hermite[4, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24
 
Hermite[5, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120
 
Hermite[6, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720
 
Hermite[7, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040
 
Hermite[8, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*
      (105 - 420*M[[2,1]] + 210*M[[4,1]] - 28*M[[6,1]] + M[[8,1]]))/40320
 
Hermite[1, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]]))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[2, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[3, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6))/2.718281828459045^(0.5*x1^2)
 
Hermite[4, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + \
M[[4,1]]))/24))/2.718281828459045^(0.5*x1^2)
 
Hermite[5, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + \
M[[5,1]]))/120))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[6, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[7, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040))/2.718281828459045^(0.5*x1^2)
 
Hermite[8, {x1_}, M_, \"phiH\"] = 
   (0.3989422804014327*(1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*
        (105 - 420*M[[2,1]] + 210*M[[4,1]] - 28*M[[6,1]] + \
M[[8,1]]))/40320))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[1, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]]
 
Hermite[2, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2
 
Hermite[3, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6
 
Hermite[4, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24
 
Hermite[5, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120
 
Hermite[6, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720
 
Hermite[7, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
    ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + 45*M[[3,3]] \
- 
       15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + x2^7)*
      (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040
 
Hermite[8, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
    ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + 45*M[[3,3]] \
- 
       15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + x2^7)*
      (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040 + 
    ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*(105 - 420*M[[2,1]] + \
210*M[[4,1]] - 
       28*M[[6,1]] + M[[8,1]]))/40320 + ((-105*x1*x2 + 105*x1^3*x2 - \
21*x1^5*x2 + x1^7*x2)*
      (-105*M[[2,2]] + 105*M[[4,2]] - 21*M[[6,2]] + M[[8,2]]))/5040 + 
    ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 + \
x1^6*x2^2)*
      (15 - 45*M[[2,1]] - 15*M[[2,3]] + 15*M[[4,1]] + 45*M[[4,3]] - M[[6,1]] \
- 
       15*M[[6,3]] + M[[8,3]]))/1440 + 
    ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 + 15*x1*x2^3 - 10*x1^3*x2^3 + \
x1^5*x2^3)*
      (-45*M[[2,2]] + 30*M[[4,2]] + 15*M[[4,4]] - 3*M[[6,2]] - 10*M[[6,4]] + \
M[[8,4]]))/
     720 + ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + 36*x1^2*x2^2 - 6*x1^4*x2^2 + \
3*x2^4 - 
       6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - 18*M[[2,3]] + 3*M[[4,1]] + \
36*M[[4,3]] + 
       3*M[[4,5]] - 6*M[[6,3]] - 6*M[[6,5]] + M[[8,5]]))/576 + 
    ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
      (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,4]] - 10*M[[6,4]] - 3*M[[6,6]] + \
M[[8,6]]))/
     720 + ((15 - 15*x1^2 - 45*x2^2 + 45*x1^2*x2^2 + 15*x2^4 - 15*x1^2*x2^4 - \
x2^6 + 
       x1^2*x2^6)*(15 - 15*M[[2,1]] - 45*M[[2,3]] + 45*M[[4,3]] + 15*M[[4,5]] \
- 
       15*M[[6,5]] - M[[6,7]] + M[[8,7]]))/1440 + 
    ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,4]] - 
       21*M[[6,6]] + M[[8,8]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - 28*x2^6 \
+ x2^8)*
      (105 - 420*M[[2,3]] + 210*M[[4,5]] - 28*M[[6,7]] + M[[8,9]]))/40320
 
Hermite[1, {x1_, x2_}, M_, \"phiH\"] = (0.15915494309189535*(1 + x1*M[[1,1]] \
+ x2*M[[1,2]]))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[2, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[3, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[4, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[5, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[6, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,4]] + M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - \
x2^4 + 
         x1^2*x2^4)*(-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + \
M[[6,5]]))/48 + 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[7, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,4]] + M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - \
x2^4 + 
         x1^2*x2^4)*(-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + \
M[[6,5]]))/48 + 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
        (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/
       240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + \
x1^4*x2^3)*
        (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/
       144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + \
x1^3*x2^4)*
        (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/
       144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + \
x1^2*x2^5)*
        (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,3]] - 
         15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[8, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x1 + \
x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/
       2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,4]] + M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - \
x2^4 + 
         x1^2*x2^4)*(-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + \
M[[6,5]]))/48 + 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
        (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/
       240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + \
x1^4*x2^3)*
        (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/
       144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + \
x1^3*x2^4)*
        (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/
       144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + \
x1^2*x2^5)*
        (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,3]] - 
         15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040 + 
      ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*(105 - 420*M[[2,1]] + \
210*M[[4,1]] - 
         28*M[[6,1]] + M[[8,1]]))/40320 + ((-105*x1*x2 + 105*x1^3*x2 - \
21*x1^5*x2 + 
         x1^7*x2)*(-105*M[[2,2]] + 105*M[[4,2]] - 21*M[[6,2]] + \
M[[8,2]]))/5040 + 
      ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 \
+ x1^6*x2^2)*
        (15 - 45*M[[2,1]] - 15*M[[2,3]] + 15*M[[4,1]] + 45*M[[4,3]] - \
M[[6,1]] - 
         15*M[[6,3]] + M[[8,3]]))/1440 + ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 \
+ 
         15*x1*x2^3 - 10*x1^3*x2^3 + x1^5*x2^3)*(-45*M[[2,2]] + 30*M[[4,2]] + \
15*M[[4,4]] - 
         3*M[[6,2]] - 10*M[[6,4]] + M[[8,4]]))/720 + 
      ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + 36*x1^2*x2^2 - 6*x1^4*x2^2 + 3*x2^4 \
- 
         6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - 18*M[[2,3]] + 3*M[[4,1]] \
+ 
         36*M[[4,3]] + 3*M[[4,5]] - 6*M[[6,3]] - 6*M[[6,5]] + M[[8,5]]))/576 \
+ 
      ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
        (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,4]] - 10*M[[6,4]] - 3*M[[6,6]] \
+ M[[8,6]]))/
       720 + ((15 - 15*x1^2 - 45*x2^2 + 45*x1^2*x2^2 + 15*x2^4 - 15*x1^2*x2^4 \
- x2^6 + 
         x1^2*x2^6)*(15 - 15*M[[2,1]] - 45*M[[2,3]] + 45*M[[4,3]] + \
15*M[[4,5]] - 
         15*M[[6,5]] - M[[6,7]] + M[[8,7]]))/1440 + 
      ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,4]] - 
         21*M[[6,6]] + M[[8,8]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - \
28*x2^6 + x2^8)*
        (105 - 420*M[[2,3]] + 210*M[[4,5]] - 28*M[[6,7]] + \
M[[8,9]]))/40320))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[1, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]]
 
Hermite[2, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2
 
Hermite[3, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6
 
Hermite[4, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6 + ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 + 
    ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
    ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
    ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
    ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
    ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
    ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
    ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 + \

    ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
    ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24
 
Hermite[5, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6 + ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 + 
    ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
    ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
    ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
    ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
    ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
    ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
    ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 + \

    ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
    ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + M[[5,4]]))/
     12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + M[[5,5]]))/6 + 
    ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + M[[5,6]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,7]] + 
       M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
      (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
    ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - M[[3,9]] \
+ M[[5,9]]))/
     4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
       M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
       M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
    ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - M[[3,6]] \
+ M[[5,13]]))/
     4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + M[[5,14]]))/6 + 
    ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 + \

    ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 + 
    ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 + \

    ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
       M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*
      (3*M[[1,3]] - 3*M[[3,8]] - M[[3,10]] + M[[5,19]]))/12 + 
    ((3*x2 - 6*x2*x3^2 + x2*x3^4)*(3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + \

    ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120
 
Hermite[6, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6 + ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 + 
    ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
    ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
    ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
    ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
    ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
    ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
    ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 + \

    ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
    ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + M[[5,4]]))/
     12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + M[[5,5]]))/6 + 
    ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + M[[5,6]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,7]] + 
       M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
      (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
    ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - M[[3,9]] \
+ M[[5,9]]))/
     4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
       M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
       M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
    ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - M[[3,6]] \
+ M[[5,13]]))/
     4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + M[[5,14]]))/6 + 
    ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 + \

    ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 + 
    ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 + \

    ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
       M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*
      (3*M[[1,3]] - 3*M[[3,8]] - M[[3,10]] + M[[5,19]]))/12 + 
    ((3*x2 - 6*x2*x3^2 + x2*x3^4)*(3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + \

    ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 + \

    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + \

    ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,7]] + 
       M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + x1^3*x2^2*x3)*
      (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
    ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - M[[4,2]] \
- 
       3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
      (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
    ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 \
+ 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
       x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
       M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
       x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/48 + 
    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/120 + 
    ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] + \
M[[6,17]]))/24 + 
    ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - M[[4,7]] \
- 
       3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
      (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
    ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
    ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/720 + 
    ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/120 + 
    ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
      (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
    ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - 3*M[[4,12]] \
- 
       3*M[[4,14]] + M[[6,25]]))/36 + 
    ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 - x3^4 + x2^2*x3^4)*
      (-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/48 + 
    ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/120 + 
    ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - 15*M[[4,15]] + \
M[[6,28]]))/720
 
Hermite[7, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6 + ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 + 
    ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
    ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
    ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
    ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
    ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
    ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
    ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 + \

    ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
    ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + M[[5,4]]))/
     12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + M[[5,5]]))/6 + 
    ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + M[[5,6]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,7]] + 
       M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
      (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
    ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - M[[3,9]] \
+ M[[5,9]]))/
     4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
       M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
       M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
    ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - M[[3,6]] \
+ M[[5,13]]))/
     4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + M[[5,14]]))/6 + 
    ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 + \

    ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 + 
    ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 + \

    ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
       M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*
      (3*M[[1,3]] - 3*M[[3,8]] - M[[3,10]] + M[[5,19]]))/12 + 
    ((3*x2 - 6*x2*x3^2 + x2*x3^4)*(3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + \

    ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 + \

    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + \

    ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,7]] + 
       M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + x1^3*x2^2*x3)*
      (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
    ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - M[[4,2]] \
- 
       3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
      (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
    ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 \
+ 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
       x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
       M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
       x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/48 + 
    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/120 + 
    ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] + \
M[[6,17]]))/24 + 
    ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - M[[4,7]] \
- 
       3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
      (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
    ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
    ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/720 + 
    ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/120 + 
    ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
      (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
    ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - 3*M[[4,12]] \
- 
       3*M[[4,14]] + M[[6,25]]))/36 + 
    ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 - x3^4 + x2^2*x3^4)*
      (-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/48 + 
    ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/120 + 
    ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - 15*M[[4,15]] + \
M[[6,28]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x3 + 45*x1^2*x3 - 15*x1^4*x3 + x1^6*x3)*(-15*M[[1,3]] + 45*M[[3,3]] \
- 
       15*M[[5,3]] + M[[7,3]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,4]] - M[[5,1]] - 10*M[[5,4]] + \
M[[7,4]]))/240 + 
    ((15*x1*x2*x3 - 10*x1^3*x2*x3 + x1^5*x2*x3)*(15*M[[3,5]] - 10*M[[5,5]] + \
M[[7,5]]))/
     120 + ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x3^2 - 10*x1^3*x3^2 + \
x1^5*x3^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,6]] - M[[5,1]] - 10*M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,7]] - 3*M[[5,2]] - 6*M[[5,7]] + \
M[[7,7]]))/144 + 
    ((-3*x3 + 6*x1^2*x3 - x1^4*x3 + 3*x2^2*x3 - 6*x1^2*x2^2*x3 + \
x1^4*x2^2*x3)*
      (-3*M[[1,3]] + 6*M[[3,3]] + 3*M[[3,8]] - M[[5,3]] - 6*M[[5,8]] + \
M[[7,8]]))/48 + 
    ((-3*x2 + 6*x1^2*x2 - x1^4*x2 + 3*x2*x3^2 - 6*x1^2*x2*x3^2 + \
x1^4*x2*x3^2)*
      (-3*M[[1,2]] + 6*M[[3,2]] + 3*M[[3,9]] - M[[5,2]] - 6*M[[5,9]] + \
M[[7,9]]))/48 + 
    ((-9*x3 + 18*x1^2*x3 - 3*x1^4*x3 + 3*x3^3 - 6*x1^2*x3^3 + x1^4*x3^3)*
      (-9*M[[1,3]] + 18*M[[3,3]] + 3*M[[3,10]] - 3*M[[5,3]] - 6*M[[5,10]] + \
M[[7,10]]))/
     144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + \
x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,4]] - 6*M[[5,4]] - 3*M[[5,11]] + \
M[[7,11]]))/
     144 + ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2^3*x3 + x1^3*x2^3*x3)*
      (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,12]] + M[[7,12]]))/36 + 
    ((-3*x1 + x1^3 + 3*x1*x2^2 - x1^3*x2^2 + 3*x1*x3^2 - x1^3*x3^2 - \
3*x1*x2^2*x3^2 + 
       x1^3*x2^2*x3^2)*(-3*M[[1,1]] + M[[3,1]] + 3*M[[3,4]] + 3*M[[3,6]] - \
M[[5,4]] - 
       M[[5,6]] - 3*M[[5,13]] + M[[7,13]]))/24 + 
    ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2*x3^3 + x1^3*x2*x3^3)*
      (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,14]] + M[[7,14]]))/36 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x3^2 - 6*x1^3*x3^2 - 3*x1*x3^4 + x1^3*x3^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,6]] - 6*M[[5,6]] - 3*M[[5,15]] + \
M[[7,15]]))/
     144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + \
x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,7]] - 10*M[[5,7]] - M[[5,16]] + \
M[[7,16]]))/
     240 + ((-3*x3 + 3*x1^2*x3 + 6*x2^2*x3 - 6*x1^2*x2^2*x3 - x2^4*x3 + \
x1^2*x2^4*x3)*
      (-3*M[[1,3]] + 3*M[[3,3]] + 6*M[[3,8]] - 6*M[[5,8]] - M[[5,17]] + \
M[[7,17]]))/48 + 
    ((-3*x2 + 3*x1^2*x2 + x2^3 - x1^2*x2^3 + 3*x2*x3^2 - 3*x1^2*x2*x3^2 - \
x2^3*x3^2 + 
       x1^2*x2^3*x3^2)*(-3*M[[1,2]] + 3*M[[3,2]] + M[[3,7]] + 3*M[[3,9]] - \
M[[5,7]] - 
       3*M[[5,9]] - M[[5,18]] + M[[7,18]]))/24 + 
    ((-3*x3 + 3*x1^2*x3 + 3*x2^2*x3 - 3*x1^2*x2^2*x3 + x3^3 - x1^2*x3^3 - \
x2^2*x3^3 + 
       x1^2*x2^2*x3^3)*(-3*M[[1,3]] + 3*M[[3,3]] + 3*M[[3,8]] + M[[3,10]] - \
3*M[[5,8]] - 
       M[[5,10]] - M[[5,19]] + M[[7,19]]))/24 + 
    ((-3*x2 + 3*x1^2*x2 + 6*x2*x3^2 - 6*x1^2*x2*x3^2 - x2*x3^4 + \
x1^2*x2*x3^4)*
      (-3*M[[1,2]] + 3*M[[3,2]] + 6*M[[3,9]] - 6*M[[5,9]] - M[[5,20]] + \
M[[7,20]]))/48 + 
    ((-15*x3 + 15*x1^2*x3 + 10*x3^3 - 10*x1^2*x3^3 - x3^5 + x1^2*x3^5)*
      (-15*M[[1,3]] + 15*M[[3,3]] + 10*M[[3,10]] - 10*M[[5,10]] - M[[5,21]] + \
M[[7,21]]))/
     240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,4]] - 
       15*M[[5,11]] + M[[7,22]]))/720 + ((15*x1*x2*x3 - 10*x1*x2^3*x3 + \
x1*x2^5*x3)*
      (15*M[[3,5]] - 10*M[[5,12]] + M[[7,23]]))/120 + 
    ((-3*x1 + 6*x1*x2^2 - x1*x2^4 + 3*x1*x3^2 - 6*x1*x2^2*x3^2 + \
x1*x2^4*x3^2)*
      (-3*M[[1,1]] + 6*M[[3,4]] + 3*M[[3,6]] - M[[5,11]] - 6*M[[5,13]] + \
M[[7,24]]))/48 + 
    ((9*x1*x2*x3 - 3*x1*x2^3*x3 - 3*x1*x2*x3^3 + x1*x2^3*x3^3)*
      (9*M[[3,5]] - 3*M[[5,12]] - 3*M[[5,14]] + M[[7,25]]))/36 + 
    ((-3*x1 + 3*x1*x2^2 + 6*x1*x3^2 - 6*x1*x2^2*x3^2 - x1*x3^4 + \
x1*x2^2*x3^4)*
      (-3*M[[1,1]] + 3*M[[3,4]] + 6*M[[3,6]] - 6*M[[5,13]] - M[[5,15]] + \
M[[7,26]]))/48 + 
    ((15*x1*x2*x3 - 10*x1*x2*x3^3 + x1*x2*x3^5)*(15*M[[3,5]] - 10*M[[5,14]] + \
M[[7,27]]))/
     120 + ((-15*x1 + 45*x1*x3^2 - 15*x1*x3^4 + x1*x3^6)*(-15*M[[1,1]] + \
45*M[[3,6]] - 
       15*M[[5,15]] + M[[7,28]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
      (-105*M[[1,2]] + 105*M[[3,7]] - 21*M[[5,16]] + M[[7,29]]))/5040 + 
    ((-15*x3 + 45*x2^2*x3 - 15*x2^4*x3 + x2^6*x3)*(-15*M[[1,3]] + 45*M[[3,8]] \
- 
       15*M[[5,17]] + M[[7,30]]))/720 + 
    ((-15*x2 + 10*x2^3 - x2^5 + 15*x2*x3^2 - 10*x2^3*x3^2 + x2^5*x3^2)*
      (-15*M[[1,2]] + 10*M[[3,7]] + 15*M[[3,9]] - M[[5,16]] - 10*M[[5,18]] + \
M[[7,31]]))/
     240 + ((-9*x3 + 18*x2^2*x3 - 3*x2^4*x3 + 3*x3^3 - 6*x2^2*x3^3 + \
x2^4*x3^3)*
      (-9*M[[1,3]] + 18*M[[3,8]] + 3*M[[3,10]] - 3*M[[5,17]] - 6*M[[5,19]] + \
M[[7,32]]))/
     144 + ((-9*x2 + 3*x2^3 + 18*x2*x3^2 - 6*x2^3*x3^2 - 3*x2*x3^4 + \
x2^3*x3^4)*
      (-9*M[[1,2]] + 3*M[[3,7]] + 18*M[[3,9]] - 6*M[[5,18]] - 3*M[[5,20]] + \
M[[7,33]]))/
     144 + ((-15*x3 + 15*x2^2*x3 + 10*x3^3 - 10*x2^2*x3^3 - x3^5 + \
x2^2*x3^5)*
      (-15*M[[1,3]] + 15*M[[3,8]] + 10*M[[3,10]] - 10*M[[5,19]] - M[[5,21]] + \
M[[7,34]]))/
     240 + ((-15*x2 + 45*x2*x3^2 - 15*x2*x3^4 + x2*x3^6)*(-15*M[[1,2]] + \
45*M[[3,9]] - 
       15*M[[5,20]] + M[[7,35]]))/720 + ((-105*x3 + 105*x3^3 - 21*x3^5 + \
x3^7)*
      (-105*M[[1,3]] + 105*M[[3,10]] - 21*M[[5,21]] + M[[7,36]]))/5040
 
Hermite[8, {x1_, x2_, x3_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + \
x3*M[[1,3]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
    ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x3 + x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/2 + 
    ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
    ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + ((-3*x2 + x2^3)*(-3*M[[1,2]] \
+ M[[3,7]]))/
     6 + ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + 
    ((-x2 + x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] \
+ M[[3,10]]))/
     6 + ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 + 
    ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
    ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
    ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
    ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
    ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
    ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
    ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 + \

    ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
    ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + M[[5,4]]))/
     12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + M[[5,5]]))/6 + 
    ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + M[[5,6]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,7]] + 
       M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
      (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
    ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - M[[3,9]] \
+ M[[5,9]]))/
     4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
       M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
       M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
    ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - M[[3,6]] \
+ M[[5,13]]))/
     4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + M[[5,14]]))/6 + 
    ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 + \

    ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 + 
    ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 + \

    ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
       M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*
      (3*M[[1,3]] - 3*M[[3,8]] - M[[3,10]] + M[[5,19]]))/12 + 
    ((3*x2 - 6*x2*x3^2 + x2*x3^4)*(3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + \

    ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 + \

    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + \

    ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*
      (-3 + 6*M[[2,1]] + 3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + \

    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,7]] + 
       M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + x1^3*x2^2*x3)*
      (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
    ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - M[[4,2]] \
- 
       3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
      (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
    ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 \
+ 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
       x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
       M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
    ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
       M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
       x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/48 + 
    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/120 + 
    ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] + \
M[[6,17]]))/24 + 
    ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - M[[4,7]] \
- 
       3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
      (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
    ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
    ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/720 + 
    ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/120 + 
    ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
      (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
    ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - 3*M[[4,12]] \
- 
       3*M[[4,14]] + M[[6,25]]))/36 + 
    ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 - x3^4 + x2^2*x3^4)*
      (-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/48 + 
    ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/120 + 
    ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - 15*M[[4,15]] + \
M[[6,28]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x3 + 45*x1^2*x3 - 15*x1^4*x3 + x1^6*x3)*(-15*M[[1,3]] + 45*M[[3,3]] \
- 
       15*M[[5,3]] + M[[7,3]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,4]] - M[[5,1]] - 10*M[[5,4]] + \
M[[7,4]]))/240 + 
    ((15*x1*x2*x3 - 10*x1^3*x2*x3 + x1^5*x2*x3)*(15*M[[3,5]] - 10*M[[5,5]] + \
M[[7,5]]))/
     120 + ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x3^2 - 10*x1^3*x3^2 + \
x1^5*x3^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,6]] - M[[5,1]] - 10*M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,7]] - 3*M[[5,2]] - 6*M[[5,7]] + \
M[[7,7]]))/144 + 
    ((-3*x3 + 6*x1^2*x3 - x1^4*x3 + 3*x2^2*x3 - 6*x1^2*x2^2*x3 + \
x1^4*x2^2*x3)*
      (-3*M[[1,3]] + 6*M[[3,3]] + 3*M[[3,8]] - M[[5,3]] - 6*M[[5,8]] + \
M[[7,8]]))/48 + 
    ((-3*x2 + 6*x1^2*x2 - x1^4*x2 + 3*x2*x3^2 - 6*x1^2*x2*x3^2 + \
x1^4*x2*x3^2)*
      (-3*M[[1,2]] + 6*M[[3,2]] + 3*M[[3,9]] - M[[5,2]] - 6*M[[5,9]] + \
M[[7,9]]))/48 + 
    ((-9*x3 + 18*x1^2*x3 - 3*x1^4*x3 + 3*x3^3 - 6*x1^2*x3^3 + x1^4*x3^3)*
      (-9*M[[1,3]] + 18*M[[3,3]] + 3*M[[3,10]] - 3*M[[5,3]] - 6*M[[5,10]] + \
M[[7,10]]))/
     144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + \
x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,4]] - 6*M[[5,4]] - 3*M[[5,11]] + \
M[[7,11]]))/
     144 + ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2^3*x3 + x1^3*x2^3*x3)*
      (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,12]] + M[[7,12]]))/36 + 
    ((-3*x1 + x1^3 + 3*x1*x2^2 - x1^3*x2^2 + 3*x1*x3^2 - x1^3*x3^2 - \
3*x1*x2^2*x3^2 + 
       x1^3*x2^2*x3^2)*(-3*M[[1,1]] + M[[3,1]] + 3*M[[3,4]] + 3*M[[3,6]] - \
M[[5,4]] - 
       M[[5,6]] - 3*M[[5,13]] + M[[7,13]]))/24 + 
    ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2*x3^3 + x1^3*x2*x3^3)*
      (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,14]] + M[[7,14]]))/36 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x3^2 - 6*x1^3*x3^2 - 3*x1*x3^4 + x1^3*x3^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,6]] - 6*M[[5,6]] - 3*M[[5,15]] + \
M[[7,15]]))/
     144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + \
x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,7]] - 10*M[[5,7]] - M[[5,16]] + \
M[[7,16]]))/
     240 + ((-3*x3 + 3*x1^2*x3 + 6*x2^2*x3 - 6*x1^2*x2^2*x3 - x2^4*x3 + \
x1^2*x2^4*x3)*
      (-3*M[[1,3]] + 3*M[[3,3]] + 6*M[[3,8]] - 6*M[[5,8]] - M[[5,17]] + \
M[[7,17]]))/48 + 
    ((-3*x2 + 3*x1^2*x2 + x2^3 - x1^2*x2^3 + 3*x2*x3^2 - 3*x1^2*x2*x3^2 - \
x2^3*x3^2 + 
       x1^2*x2^3*x3^2)*(-3*M[[1,2]] + 3*M[[3,2]] + M[[3,7]] + 3*M[[3,9]] - \
M[[5,7]] - 
       3*M[[5,9]] - M[[5,18]] + M[[7,18]]))/24 + 
    ((-3*x3 + 3*x1^2*x3 + 3*x2^2*x3 - 3*x1^2*x2^2*x3 + x3^3 - x1^2*x3^3 - \
x2^2*x3^3 + 
       x1^2*x2^2*x3^3)*(-3*M[[1,3]] + 3*M[[3,3]] + 3*M[[3,8]] + M[[3,10]] - \
3*M[[5,8]] - 
       M[[5,10]] - M[[5,19]] + M[[7,19]]))/24 + 
    ((-3*x2 + 3*x1^2*x2 + 6*x2*x3^2 - 6*x1^2*x2*x3^2 - x2*x3^4 + \
x1^2*x2*x3^4)*
      (-3*M[[1,2]] + 3*M[[3,2]] + 6*M[[3,9]] - 6*M[[5,9]] - M[[5,20]] + \
M[[7,20]]))/48 + 
    ((-15*x3 + 15*x1^2*x3 + 10*x3^3 - 10*x1^2*x3^3 - x3^5 + x1^2*x3^5)*
      (-15*M[[1,3]] + 15*M[[3,3]] + 10*M[[3,10]] - 10*M[[5,10]] - M[[5,21]] + \
M[[7,21]]))/
     240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,4]] - 
       15*M[[5,11]] + M[[7,22]]))/720 + ((15*x1*x2*x3 - 10*x1*x2^3*x3 + \
x1*x2^5*x3)*
      (15*M[[3,5]] - 10*M[[5,12]] + M[[7,23]]))/120 + 
    ((-3*x1 + 6*x1*x2^2 - x1*x2^4 + 3*x1*x3^2 - 6*x1*x2^2*x3^2 + \
x1*x2^4*x3^2)*
      (-3*M[[1,1]] + 6*M[[3,4]] + 3*M[[3,6]] - M[[5,11]] - 6*M[[5,13]] + \
M[[7,24]]))/48 + 
    ((9*x1*x2*x3 - 3*x1*x2^3*x3 - 3*x1*x2*x3^3 + x1*x2^3*x3^3)*
      (9*M[[3,5]] - 3*M[[5,12]] - 3*M[[5,14]] + M[[7,25]]))/36 + 
    ((-3*x1 + 3*x1*x2^2 + 6*x1*x3^2 - 6*x1*x2^2*x3^2 - x1*x3^4 + \
x1*x2^2*x3^4)*
      (-3*M[[1,1]] + 3*M[[3,4]] + 6*M[[3,6]] - 6*M[[5,13]] - M[[5,15]] + \
M[[7,26]]))/48 + 
    ((15*x1*x2*x3 - 10*x1*x2*x3^3 + x1*x2*x3^5)*(15*M[[3,5]] - 10*M[[5,14]] + \
M[[7,27]]))/
     120 + ((-15*x1 + 45*x1*x3^2 - 15*x1*x3^4 + x1*x3^6)*(-15*M[[1,1]] + \
45*M[[3,6]] - 
       15*M[[5,15]] + M[[7,28]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
      (-105*M[[1,2]] + 105*M[[3,7]] - 21*M[[5,16]] + M[[7,29]]))/5040 + 
    ((-15*x3 + 45*x2^2*x3 - 15*x2^4*x3 + x2^6*x3)*(-15*M[[1,3]] + 45*M[[3,8]] \
- 
       15*M[[5,17]] + M[[7,30]]))/720 + 
    ((-15*x2 + 10*x2^3 - x2^5 + 15*x2*x3^2 - 10*x2^3*x3^2 + x2^5*x3^2)*
      (-15*M[[1,2]] + 10*M[[3,7]] + 15*M[[3,9]] - M[[5,16]] - 10*M[[5,18]] + \
M[[7,31]]))/
     240 + ((-9*x3 + 18*x2^2*x3 - 3*x2^4*x3 + 3*x3^3 - 6*x2^2*x3^3 + \
x2^4*x3^3)*
      (-9*M[[1,3]] + 18*M[[3,8]] + 3*M[[3,10]] - 3*M[[5,17]] - 6*M[[5,19]] + \
M[[7,32]]))/
     144 + ((-9*x2 + 3*x2^3 + 18*x2*x3^2 - 6*x2^3*x3^2 - 3*x2*x3^4 + \
x2^3*x3^4)*
      (-9*M[[1,2]] + 3*M[[3,7]] + 18*M[[3,9]] - 6*M[[5,18]] - 3*M[[5,20]] + \
M[[7,33]]))/
     144 + ((-15*x3 + 15*x2^2*x3 + 10*x3^3 - 10*x2^2*x3^3 - x3^5 + \
x2^2*x3^5)*
      (-15*M[[1,3]] + 15*M[[3,8]] + 10*M[[3,10]] - 10*M[[5,19]] - M[[5,21]] + \
M[[7,34]]))/
     240 + ((-15*x2 + 45*x2*x3^2 - 15*x2*x3^4 + x2*x3^6)*(-15*M[[1,2]] + \
45*M[[3,9]] - 
       15*M[[5,20]] + M[[7,35]]))/720 + ((-105*x3 + 105*x3^3 - 21*x3^5 + \
x3^7)*
      (-105*M[[1,3]] + 105*M[[3,10]] - 21*M[[5,21]] + M[[7,36]]))/5040 + 
    ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*(105 - 420*M[[2,1]] + \
210*M[[4,1]] - 
       28*M[[6,1]] + M[[8,1]]))/40320 + ((-105*x1*x2 + 105*x1^3*x2 - \
21*x1^5*x2 + x1^7*x2)*
      (-105*M[[2,2]] + 105*M[[4,2]] - 21*M[[6,2]] + M[[8,2]]))/5040 + 
    ((-105*x1*x3 + 105*x1^3*x3 - 21*x1^5*x3 + x1^7*x3)*(-105*M[[2,3]] + \
105*M[[4,3]] - 
       21*M[[6,3]] + M[[8,3]]))/5040 + 
    ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 + \
x1^6*x2^2)*
      (15 - 45*M[[2,1]] - 15*M[[2,4]] + 15*M[[4,1]] + 45*M[[4,4]] - M[[6,1]] \
- 
       15*M[[6,4]] + M[[8,4]]))/1440 + 
    ((-15*x2*x3 + 45*x1^2*x2*x3 - 15*x1^4*x2*x3 + x1^6*x2*x3)*(-15*M[[2,5]] + \
45*M[[4,5]] - 
       15*M[[6,5]] + M[[8,5]]))/720 + 
    ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x3^2 + 45*x1^2*x3^2 - 15*x1^4*x3^2 + \
x1^6*x3^2)*
      (15 - 45*M[[2,1]] - 15*M[[2,6]] + 15*M[[4,1]] + 45*M[[4,6]] - M[[6,1]] \
- 
       15*M[[6,6]] + M[[8,6]]))/1440 + 
    ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 + 15*x1*x2^3 - 10*x1^3*x2^3 + \
x1^5*x2^3)*
      (-45*M[[2,2]] + 30*M[[4,2]] + 15*M[[4,7]] - 3*M[[6,2]] - 10*M[[6,7]] + \
M[[8,7]]))/
     720 + ((-15*x1*x3 + 10*x1^3*x3 - x1^5*x3 + 15*x1*x2^2*x3 - \
10*x1^3*x2^2*x3 + 
       x1^5*x2^2*x3)*(-15*M[[2,3]] + 10*M[[4,3]] + 15*M[[4,8]] - M[[6,3]] - \
10*M[[6,8]] + 
       M[[8,8]]))/240 + ((-15*x1*x2 + 10*x1^3*x2 - x1^5*x2 + 15*x1*x2*x3^2 - 
       10*x1^3*x2*x3^2 + x1^5*x2*x3^2)*(-15*M[[2,2]] + 10*M[[4,2]] + \
15*M[[4,9]] - 
       M[[6,2]] - 10*M[[6,9]] + M[[8,9]]))/240 + 
    ((-45*x1*x3 + 30*x1^3*x3 - 3*x1^5*x3 + 15*x1*x3^3 - 10*x1^3*x3^3 + \
x1^5*x3^3)*
      (-45*M[[2,3]] + 30*M[[4,3]] + 15*M[[4,10]] - 3*M[[6,3]] - 10*M[[6,10]] \
+ M[[8,10]]))/
     720 + ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + 36*x1^2*x2^2 - 6*x1^4*x2^2 + \
3*x2^4 - 
       6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - 18*M[[2,4]] + 3*M[[4,1]] + \
36*M[[4,4]] + 
       3*M[[4,11]] - 6*M[[6,4]] - 6*M[[6,11]] + M[[8,11]]))/576 + 
    ((-9*x2*x3 + 18*x1^2*x2*x3 - 3*x1^4*x2*x3 + 3*x2^3*x3 - 6*x1^2*x2^3*x3 + \
x1^4*x2^3*x3)*
      (-9*M[[2,5]] + 18*M[[4,5]] + 3*M[[4,12]] - 3*M[[6,5]] - 6*M[[6,12]] + \
M[[8,12]]))/
     144 + ((3 - 6*x1^2 + x1^4 - 3*x2^2 + 6*x1^2*x2^2 - x1^4*x2^2 - 3*x3^2 + \
6*x1^2*x3^2 - 
       x1^4*x3^2 + 3*x2^2*x3^2 - 6*x1^2*x2^2*x3^2 + x1^4*x2^2*x3^2)*
      (3 - 6*M[[2,1]] - 3*M[[2,4]] - 3*M[[2,6]] + M[[4,1]] + 6*M[[4,4]] + \
6*M[[4,6]] + 
       3*M[[4,13]] - M[[6,4]] - M[[6,6]] - 6*M[[6,13]] + M[[8,13]]))/96 + 
    ((-9*x2*x3 + 18*x1^2*x2*x3 - 3*x1^4*x2*x3 + 3*x2*x3^3 - 6*x1^2*x2*x3^3 + \
x1^4*x2*x3^3)*
      (-9*M[[2,5]] + 18*M[[4,5]] + 3*M[[4,14]] - 3*M[[6,5]] - 6*M[[6,14]] + \
M[[8,14]]))/
     144 + ((9 - 18*x1^2 + 3*x1^4 - 18*x3^2 + 36*x1^2*x3^2 - 6*x1^4*x3^2 + \
3*x3^4 - 
       6*x1^2*x3^4 + x1^4*x3^4)*(9 - 18*M[[2,1]] - 18*M[[2,6]] + 3*M[[4,1]] + \
36*M[[4,6]] + 
       3*M[[4,15]] - 6*M[[6,6]] - 6*M[[6,15]] + M[[8,15]]))/576 + 
    ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
      (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,7]] - 10*M[[6,7]] - 3*M[[6,16]] + \
M[[8,16]]))/
     720 + ((-9*x1*x3 + 3*x1^3*x3 + 18*x1*x2^2*x3 - 6*x1^3*x2^2*x3 - \
3*x1*x2^4*x3 + 
       x1^3*x2^4*x3)*(-9*M[[2,3]] + 3*M[[4,3]] + 18*M[[4,8]] - 6*M[[6,8]] - \
3*M[[6,17]] + 
       M[[8,17]]))/144 + ((-9*x1*x2 + 3*x1^3*x2 + 3*x1*x2^3 - x1^3*x2^3 + \
9*x1*x2*x3^2 - 
       3*x1^3*x2*x3^2 - 3*x1*x2^3*x3^2 + x1^3*x2^3*x3^2)*(-9*M[[2,2]] + \
3*M[[4,2]] + 
       3*M[[4,7]] + 9*M[[4,9]] - M[[6,7]] - 3*M[[6,9]] - 3*M[[6,18]] + \
M[[8,18]]))/72 + 
    ((-9*x1*x3 + 3*x1^3*x3 + 9*x1*x2^2*x3 - 3*x1^3*x2^2*x3 + 3*x1*x3^3 - \
x1^3*x3^3 - 
       3*x1*x2^2*x3^3 + x1^3*x2^2*x3^3)*(-9*M[[2,3]] + 3*M[[4,3]] + \
9*M[[4,8]] + 
       3*M[[4,10]] - 3*M[[6,8]] - M[[6,10]] - 3*M[[6,19]] + M[[8,19]]))/72 + 
    ((-9*x1*x2 + 3*x1^3*x2 + 18*x1*x2*x3^2 - 6*x1^3*x2*x3^2 - 3*x1*x2*x3^4 + \
x1^3*x2*x3^4)*
      (-9*M[[2,2]] + 3*M[[4,2]] + 18*M[[4,9]] - 6*M[[6,9]] - 3*M[[6,20]] + \
M[[8,20]]))/
     144 + ((-45*x1*x3 + 15*x1^3*x3 + 30*x1*x3^3 - 10*x1^3*x3^3 - 3*x1*x3^5 + \
x1^3*x3^5)*
      (-45*M[[2,3]] + 15*M[[4,3]] + 30*M[[4,10]] - 10*M[[6,10]] - 3*M[[6,21]] \
+ M[[8,21]]))/
     720 + ((15 - 15*x1^2 - 45*x2^2 + 45*x1^2*x2^2 + 15*x2^4 - 15*x1^2*x2^4 - \
x2^6 + 
       x1^2*x2^6)*(15 - 15*M[[2,1]] - 45*M[[2,4]] + 45*M[[4,4]] + \
15*M[[4,11]] - 
       15*M[[6,11]] - M[[6,22]] + M[[8,22]]))/1440 + 
    ((-15*x2*x3 + 15*x1^2*x2*x3 + 10*x2^3*x3 - 10*x1^2*x2^3*x3 - x2^5*x3 + \
x1^2*x2^5*x3)*
      (-15*M[[2,5]] + 15*M[[4,5]] + 10*M[[4,12]] - 10*M[[6,12]] - M[[6,23]] + \
M[[8,23]]))/
     240 + ((3 - 3*x1^2 - 6*x2^2 + 6*x1^2*x2^2 + x2^4 - x1^2*x2^4 - 3*x3^2 + \
3*x1^2*x3^2 + 
       6*x2^2*x3^2 - 6*x1^2*x2^2*x3^2 - x2^4*x3^2 + x1^2*x2^4*x3^2)*
      (3 - 3*M[[2,1]] - 6*M[[2,4]] - 3*M[[2,6]] + 6*M[[4,4]] + 3*M[[4,6]] + \
M[[4,11]] + 
       6*M[[4,13]] - M[[6,11]] - 6*M[[6,13]] - M[[6,24]] + M[[8,24]]))/96 + 
    ((-9*x2*x3 + 9*x1^2*x2*x3 + 3*x2^3*x3 - 3*x1^2*x2^3*x3 + 3*x2*x3^3 - \
3*x1^2*x2*x3^3 - 
       x2^3*x3^3 + x1^2*x2^3*x3^3)*(-9*M[[2,5]] + 9*M[[4,5]] + 3*M[[4,12]] + \
3*M[[4,14]] - 
       3*M[[6,12]] - 3*M[[6,14]] - M[[6,25]] + M[[8,25]]))/72 + 
    ((3 - 3*x1^2 - 3*x2^2 + 3*x1^2*x2^2 - 6*x3^2 + 6*x1^2*x3^2 + 6*x2^2*x3^2 \
- 
       6*x1^2*x2^2*x3^2 + x3^4 - x1^2*x3^4 - x2^2*x3^4 + x1^2*x2^2*x3^4)*
      (3 - 3*M[[2,1]] - 3*M[[2,4]] - 6*M[[2,6]] + 3*M[[4,4]] + 6*M[[4,6]] + \
6*M[[4,13]] + 
       M[[4,15]] - 6*M[[6,13]] - M[[6,15]] - M[[6,26]] + M[[8,26]]))/96 + 
    ((-15*x2*x3 + 15*x1^2*x2*x3 + 10*x2*x3^3 - 10*x1^2*x2*x3^3 - x2*x3^5 + \
x1^2*x2*x3^5)*
      (-15*M[[2,5]] + 15*M[[4,5]] + 10*M[[4,14]] - 10*M[[6,14]] - M[[6,27]] + \
M[[8,27]]))/
     240 + ((15 - 15*x1^2 - 45*x3^2 + 45*x1^2*x3^2 + 15*x3^4 - 15*x1^2*x3^4 - \
x3^6 + 
       x1^2*x3^6)*(15 - 15*M[[2,1]] - 45*M[[2,6]] + 45*M[[4,6]] + \
15*M[[4,15]] - 
       15*M[[6,15]] - M[[6,28]] + M[[8,28]]))/1440 + 
    ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,7]] - 
       21*M[[6,16]] + M[[8,29]]))/5040 + 
    ((-15*x1*x3 + 45*x1*x2^2*x3 - 15*x1*x2^4*x3 + x1*x2^6*x3)*(-15*M[[2,3]] + \
45*M[[4,8]] - 
       15*M[[6,17]] + M[[8,30]]))/720 + 
    ((-15*x1*x2 + 10*x1*x2^3 - x1*x2^5 + 15*x1*x2*x3^2 - 10*x1*x2^3*x3^2 + \
x1*x2^5*x3^2)*
      (-15*M[[2,2]] + 10*M[[4,7]] + 15*M[[4,9]] - M[[6,16]] - 10*M[[6,18]] + \
M[[8,31]]))/
     240 + ((-9*x1*x3 + 18*x1*x2^2*x3 - 3*x1*x2^4*x3 + 3*x1*x3^3 - \
6*x1*x2^2*x3^3 + 
       x1*x2^4*x3^3)*(-9*M[[2,3]] + 18*M[[4,8]] + 3*M[[4,10]] - 3*M[[6,17]] - \
6*M[[6,19]] + 
       M[[8,32]]))/144 + ((-9*x1*x2 + 3*x1*x2^3 + 18*x1*x2*x3^2 - \
6*x1*x2^3*x3^2 - 
       3*x1*x2*x3^4 + x1*x2^3*x3^4)*(-9*M[[2,2]] + 3*M[[4,7]] + 18*M[[4,9]] - \
6*M[[6,18]] - 
       3*M[[6,20]] + M[[8,33]]))/144 + 
    ((-15*x1*x3 + 15*x1*x2^2*x3 + 10*x1*x3^3 - 10*x1*x2^2*x3^3 - x1*x3^5 + \
x1*x2^2*x3^5)*
      (-15*M[[2,3]] + 15*M[[4,8]] + 10*M[[4,10]] - 10*M[[6,19]] - M[[6,21]] + \
M[[8,34]]))/
     240 + ((-15*x1*x2 + 45*x1*x2*x3^2 - 15*x1*x2*x3^4 + x1*x2*x3^6)*
      (-15*M[[2,2]] + 45*M[[4,9]] - 15*M[[6,20]] + M[[8,35]]))/720 + 
    ((-105*x1*x3 + 105*x1*x3^3 - 21*x1*x3^5 + x1*x3^7)*(-105*M[[2,3]] + \
105*M[[4,10]] - 
       21*M[[6,21]] + M[[8,36]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - \
28*x2^6 + x2^8)*
      (105 - 420*M[[2,4]] + 210*M[[4,11]] - 28*M[[6,22]] + M[[8,37]]))/40320 \
+ 
    ((-105*x2*x3 + 105*x2^3*x3 - 21*x2^5*x3 + x2^7*x3)*(-105*M[[2,5]] + \
105*M[[4,12]] - 
       21*M[[6,23]] + M[[8,38]]))/5040 + 
    ((15 - 45*x2^2 + 15*x2^4 - x2^6 - 15*x3^2 + 45*x2^2*x3^2 - 15*x2^4*x3^2 + \
x2^6*x3^2)*
      (15 - 45*M[[2,4]] - 15*M[[2,6]] + 15*M[[4,11]] + 45*M[[4,13]] - \
M[[6,22]] - 
       15*M[[6,24]] + M[[8,39]]))/1440 + 
    ((-45*x2*x3 + 30*x2^3*x3 - 3*x2^5*x3 + 15*x2*x3^3 - 10*x2^3*x3^3 + \
x2^5*x3^3)*
      (-45*M[[2,5]] + 30*M[[4,12]] + 15*M[[4,14]] - 3*M[[6,23]] - \
10*M[[6,25]] + 
       M[[8,40]]))/720 + ((9 - 18*x2^2 + 3*x2^4 - 18*x3^2 + 36*x2^2*x3^2 - \
6*x2^4*x3^2 + 
       3*x3^4 - 6*x2^2*x3^4 + x2^4*x3^4)*(9 - 18*M[[2,4]] - 18*M[[2,6]] + \
3*M[[4,11]] + 
       36*M[[4,13]] + 3*M[[4,15]] - 6*M[[6,24]] - 6*M[[6,26]] + \
M[[8,41]]))/576 + 
    ((-45*x2*x3 + 15*x2^3*x3 + 30*x2*x3^3 - 10*x2^3*x3^3 - 3*x2*x3^5 + \
x2^3*x3^5)*
      (-45*M[[2,5]] + 15*M[[4,12]] + 30*M[[4,14]] - 10*M[[6,25]] - \
3*M[[6,27]] + 
       M[[8,42]]))/720 + ((15 - 15*x2^2 - 45*x3^2 + 45*x2^2*x3^2 + 15*x3^4 - \
15*x2^2*x3^4 - 
       x3^6 + x2^2*x3^6)*(15 - 15*M[[2,4]] - 45*M[[2,6]] + 45*M[[4,13]] + \
15*M[[4,15]] - 
       15*M[[6,26]] - M[[6,28]] + M[[8,43]]))/1440 + 
    ((-105*x2*x3 + 105*x2*x3^3 - 21*x2*x3^5 + x2*x3^7)*(-105*M[[2,5]] + \
105*M[[4,14]] - 
       21*M[[6,27]] + M[[8,44]]))/5040 + ((105 - 420*x3^2 + 210*x3^4 - \
28*x3^6 + x3^8)*
      (105 - 420*M[[2,6]] + 210*M[[4,15]] - 28*M[[6,28]] + M[[8,45]]))/40320
 
Hermite[1, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]]))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[2, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[3, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[4, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 \
+ 
      ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
      ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
      ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
      ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
      ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
      ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
      ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 \
+ 
      ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
      ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[5, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 \
+ 
      ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
      ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
      ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
      ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
      ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
      ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
      ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 \
+ 
      ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
      ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + 
         M[[5,4]]))/12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + \
M[[5,5]]))/6 + 
      ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + 
         M[[5,6]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,7]] + M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
        (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
      ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - \
M[[3,9]] + M[[5,9]]))/
       4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
         M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
         M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
      ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - \
M[[3,6]] + 
         M[[5,13]]))/4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + \
M[[5,14]]))/6 + 
      ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 \
+ 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 \
+ 
      ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 \
+ 
      ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
         M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*(3*M[[1,3]] \
- 3*M[[3,8]] - 
         M[[3,10]] + M[[5,19]]))/12 + ((3*x2 - 6*x2*x3^2 + x2*x3^4)*
        (3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + 
      ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + \
M[[5,21]]))/120))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[6, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 \
+ 
      ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
      ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
      ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
      ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
      ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
      ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
      ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 \
+ 
      ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
      ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + 
         M[[5,4]]))/12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + \
M[[5,5]]))/6 + 
      ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + 
         M[[5,6]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,7]] + M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
        (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
      ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - \
M[[3,9]] + M[[5,9]]))/
       4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
         M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
         M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
      ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - \
M[[3,6]] + 
         M[[5,13]]))/4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + \
M[[5,14]]))/6 + 
      ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 \
+ 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 \
+ 
      ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 \
+ 
      ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
         M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*(3*M[[1,3]] \
- 3*M[[3,8]] - 
         M[[3,10]] + M[[5,19]]))/12 + ((3*x2 - 6*x2*x3^2 + x2*x3^4)*
        (3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + 
      ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 \
+ 
      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + 
      ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,7]] + M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + \
x1^3*x2^2*x3)*
        (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
      ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - \
M[[4,2]] - 
         3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
        (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
      ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*(-3 + \
3*M[[2,1]] + 
         6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
         x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
         M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
         x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/
       48 + ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/
       120 + ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] \
+ M[[6,17]]))/
       24 + ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - \
M[[4,7]] - 
         3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
        (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
      ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
      ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/
       720 + ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/
       120 + ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
        (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
      ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - \
3*M[[4,12]] - 
         3*M[[4,14]] + M[[6,25]]))/36 + ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 \
- x3^4 + 
         x2^2*x3^4)*(-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/
       48 + ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/
       120 + ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - \
15*M[[4,15]] + 
         M[[6,28]]))/720))/2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))
 
Hermite[7, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 \
+ 
      ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
      ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
      ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
      ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
      ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
      ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
      ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 \
+ 
      ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
      ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + 
         M[[5,4]]))/12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + \
M[[5,5]]))/6 + 
      ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + 
         M[[5,6]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,7]] + M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
        (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
      ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - \
M[[3,9]] + M[[5,9]]))/
       4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
         M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
         M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
      ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - \
M[[3,6]] + 
         M[[5,13]]))/4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + \
M[[5,14]]))/6 + 
      ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 \
+ 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 \
+ 
      ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 \
+ 
      ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
         M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*(3*M[[1,3]] \
- 3*M[[3,8]] - 
         M[[3,10]] + M[[5,19]]))/12 + ((3*x2 - 6*x2*x3^2 + x2*x3^4)*
        (3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + 
      ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 \
+ 
      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + 
      ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,7]] + M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + \
x1^3*x2^2*x3)*
        (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
      ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - \
M[[4,2]] - 
         3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
        (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
      ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*(-3 + \
3*M[[2,1]] + 
         6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
         x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
         M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
         x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/
       48 + ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/
       120 + ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] \
+ M[[6,17]]))/
       24 + ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - \
M[[4,7]] - 
         3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
        (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
      ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
      ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/
       720 + ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/
       120 + ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
        (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
      ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - \
3*M[[4,12]] - 
         3*M[[4,14]] + M[[6,25]]))/36 + ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 \
- x3^4 + 
         x2^2*x3^4)*(-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/
       48 + ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/
       120 + ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - \
15*M[[4,15]] + 
         M[[6,28]]))/720 + ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*
        (-105*M[[1,1]] + 105*M[[3,1]] - 21*M[[5,1]] + M[[7,1]]))/5040 + 
      ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*(-15*M[[1,2]] + \
45*M[[3,2]] - 
         15*M[[5,2]] + M[[7,2]]))/720 + ((-15*x3 + 45*x1^2*x3 - 15*x1^4*x3 + \
x1^6*x3)*
        (-15*M[[1,3]] + 45*M[[3,3]] - 15*M[[5,3]] + M[[7,3]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,4]] - M[[5,1]] - 10*M[[5,4]] + \
M[[7,4]]))/
       240 + ((15*x1*x2*x3 - 10*x1^3*x2*x3 + x1^5*x2*x3)*(15*M[[3,5]] - \
10*M[[5,5]] + 
         M[[7,5]]))/120 + ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x3^2 - \
10*x1^3*x3^2 + 
         x1^5*x3^2)*(-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,6]] - M[[5,1]] - \
10*M[[5,6]] + 
         M[[7,6]]))/240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - \
6*x1^2*x2^3 + 
         x1^4*x2^3)*(-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,7]] - 3*M[[5,2]] - \
6*M[[5,7]] + 
         M[[7,7]]))/144 + ((-3*x3 + 6*x1^2*x3 - x1^4*x3 + 3*x2^2*x3 - \
6*x1^2*x2^2*x3 + 
         x1^4*x2^2*x3)*(-3*M[[1,3]] + 6*M[[3,3]] + 3*M[[3,8]] - M[[5,3]] - \
6*M[[5,8]] + 
         M[[7,8]]))/48 + ((-3*x2 + 6*x1^2*x2 - x1^4*x2 + 3*x2*x3^2 - \
6*x1^2*x2*x3^2 + 
         x1^4*x2*x3^2)*(-3*M[[1,2]] + 6*M[[3,2]] + 3*M[[3,9]] - M[[5,2]] - \
6*M[[5,9]] + 
         M[[7,9]]))/48 + ((-9*x3 + 18*x1^2*x3 - 3*x1^4*x3 + 3*x3^3 - \
6*x1^2*x3^3 + 
         x1^4*x3^3)*(-9*M[[1,3]] + 18*M[[3,3]] + 3*M[[3,10]] - 3*M[[5,3]] - \
6*M[[5,10]] + 
         M[[7,10]]))/144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - \
3*x1*x2^4 + 
         x1^3*x2^4)*(-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,4]] - 6*M[[5,4]] - \
3*M[[5,11]] + 
         M[[7,11]]))/144 + ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2^3*x3 + \
x1^3*x2^3*x3)*
        (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,12]] + M[[7,12]]))/36 + 
      ((-3*x1 + x1^3 + 3*x1*x2^2 - x1^3*x2^2 + 3*x1*x3^2 - x1^3*x3^2 - \
3*x1*x2^2*x3^2 + 
         x1^3*x2^2*x3^2)*(-3*M[[1,1]] + M[[3,1]] + 3*M[[3,4]] + 3*M[[3,6]] - \
M[[5,4]] - 
         M[[5,6]] - 3*M[[5,13]] + M[[7,13]]))/24 + 
      ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2*x3^3 + x1^3*x2*x3^3)*(9*M[[3,5]] \
- 3*M[[5,5]] - 
         3*M[[5,14]] + M[[7,14]]))/36 + ((-9*x1 + 3*x1^3 + 18*x1*x3^2 - \
6*x1^3*x3^2 - 
         3*x1*x3^4 + x1^3*x3^4)*(-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,6]] - \
6*M[[5,6]] - 
         3*M[[5,15]] + M[[7,15]]))/144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - \
10*x1^2*x2^3 - 
         x2^5 + x1^2*x2^5)*(-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,7]] - \
10*M[[5,7]] - 
         M[[5,16]] + M[[7,16]]))/240 + ((-3*x3 + 3*x1^2*x3 + 6*x2^2*x3 - \
6*x1^2*x2^2*x3 - 
         x2^4*x3 + x1^2*x2^4*x3)*(-3*M[[1,3]] + 3*M[[3,3]] + 6*M[[3,8]] - \
6*M[[5,8]] - 
         M[[5,17]] + M[[7,17]]))/48 + ((-3*x2 + 3*x1^2*x2 + x2^3 - x1^2*x2^3 \
+ 3*x2*x3^2 - 
         3*x1^2*x2*x3^2 - x2^3*x3^2 + x1^2*x2^3*x3^2)*(-3*M[[1,2]] + \
3*M[[3,2]] + 
         M[[3,7]] + 3*M[[3,9]] - M[[5,7]] - 3*M[[5,9]] - M[[5,18]] + \
M[[7,18]]))/24 + 
      ((-3*x3 + 3*x1^2*x3 + 3*x2^2*x3 - 3*x1^2*x2^2*x3 + x3^3 - x1^2*x3^3 - \
x2^2*x3^3 + 
         x1^2*x2^2*x3^3)*(-3*M[[1,3]] + 3*M[[3,3]] + 3*M[[3,8]] + M[[3,10]] - \
3*M[[5,8]] - 
         M[[5,10]] - M[[5,19]] + M[[7,19]]))/24 + 
      ((-3*x2 + 3*x1^2*x2 + 6*x2*x3^2 - 6*x1^2*x2*x3^2 - x2*x3^4 + \
x1^2*x2*x3^4)*
        (-3*M[[1,2]] + 3*M[[3,2]] + 6*M[[3,9]] - 6*M[[5,9]] - M[[5,20]] + \
M[[7,20]]))/48 + 
      ((-15*x3 + 15*x1^2*x3 + 10*x3^3 - 10*x1^2*x3^3 - x3^5 + x1^2*x3^5)*
        (-15*M[[1,3]] + 15*M[[3,3]] + 10*M[[3,10]] - 10*M[[5,10]] - M[[5,21]] \
+ M[[7,21]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,4]] - 
         15*M[[5,11]] + M[[7,22]]))/720 + ((15*x1*x2*x3 - 10*x1*x2^3*x3 + \
x1*x2^5*x3)*
        (15*M[[3,5]] - 10*M[[5,12]] + M[[7,23]]))/120 + 
      ((-3*x1 + 6*x1*x2^2 - x1*x2^4 + 3*x1*x3^2 - 6*x1*x2^2*x3^2 + \
x1*x2^4*x3^2)*
        (-3*M[[1,1]] + 6*M[[3,4]] + 3*M[[3,6]] - M[[5,11]] - 6*M[[5,13]] + \
M[[7,24]]))/48 + 
      ((9*x1*x2*x3 - 3*x1*x2^3*x3 - 3*x1*x2*x3^3 + x1*x2^3*x3^3)*
        (9*M[[3,5]] - 3*M[[5,12]] - 3*M[[5,14]] + M[[7,25]]))/36 + 
      ((-3*x1 + 3*x1*x2^2 + 6*x1*x3^2 - 6*x1*x2^2*x3^2 - x1*x3^4 + \
x1*x2^2*x3^4)*
        (-3*M[[1,1]] + 3*M[[3,4]] + 6*M[[3,6]] - 6*M[[5,13]] - M[[5,15]] + \
M[[7,26]]))/48 + 
      ((15*x1*x2*x3 - 10*x1*x2*x3^3 + x1*x2*x3^5)*(15*M[[3,5]] - 10*M[[5,14]] \
+ M[[7,27]]))/
       120 + ((-15*x1 + 45*x1*x3^2 - 15*x1*x3^4 + x1*x3^6)*(-15*M[[1,1]] + \
45*M[[3,6]] - 
         15*M[[5,15]] + M[[7,28]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,7]] - 21*M[[5,16]] + M[[7,29]]))/5040 + 
      ((-15*x3 + 45*x2^2*x3 - 15*x2^4*x3 + x2^6*x3)*(-15*M[[1,3]] + \
45*M[[3,8]] - 
         15*M[[5,17]] + M[[7,30]]))/720 + ((-15*x2 + 10*x2^3 - x2^5 + \
15*x2*x3^2 - 
         10*x2^3*x3^2 + x2^5*x3^2)*(-15*M[[1,2]] + 10*M[[3,7]] + 15*M[[3,9]] \
- M[[5,16]] - 
         10*M[[5,18]] + M[[7,31]]))/240 + ((-9*x3 + 18*x2^2*x3 - 3*x2^4*x3 + \
3*x3^3 - 
         6*x2^2*x3^3 + x2^4*x3^3)*(-9*M[[1,3]] + 18*M[[3,8]] + 3*M[[3,10]] - \
3*M[[5,17]] - 
         6*M[[5,19]] + M[[7,32]]))/144 + ((-9*x2 + 3*x2^3 + 18*x2*x3^2 - \
6*x2^3*x3^2 - 
         3*x2*x3^4 + x2^3*x3^4)*(-9*M[[1,2]] + 3*M[[3,7]] + 18*M[[3,9]] - \
6*M[[5,18]] - 
         3*M[[5,20]] + M[[7,33]]))/144 + ((-15*x3 + 15*x2^2*x3 + 10*x3^3 - \
10*x2^2*x3^3 - 
         x3^5 + x2^2*x3^5)*(-15*M[[1,3]] + 15*M[[3,8]] + 10*M[[3,10]] - \
10*M[[5,19]] - 
         M[[5,21]] + M[[7,34]]))/240 + ((-15*x2 + 45*x2*x3^2 - 15*x2*x3^4 + \
x2*x3^6)*
        (-15*M[[1,2]] + 45*M[[3,9]] - 15*M[[5,20]] + M[[7,35]]))/720 + 
      ((-105*x3 + 105*x3^3 - 21*x3^5 + x3^7)*(-105*M[[1,3]] + 105*M[[3,10]] - \

         21*M[[5,21]] + M[[7,36]]))/5040))/2.718281828459045^(0.5*(x1^2 + \
x2^2 + x3^2))
 
Hermite[8, {x1_, x2_, x3_}, M_, \"phiH\"] = 
   (0.06349363593424097*(1 + x1*M[[1,1]] + x2*M[[1,2]] + x3*M[[1,3]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + x1*x3*M[[2,3]] + 
      ((-1 + x2^2)*(-1 + M[[2,4]]))/2 + x2*x3*M[[2,5]] + ((-1 + x3^2)*(-1 + \
M[[2,6]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
      ((-x2 + x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/2 + ((-x3 + \
x1^2*x3)*(-M[[1,3]] + M[[3,3]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,4]]))/2 + x1*x2*x3*M[[3,5]] + 
      ((-x1 + x1*x3^2)*(-M[[1,1]] + M[[3,6]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,7]]))/6 + 
      ((-x3 + x2^2*x3)*(-M[[1,3]] + M[[3,8]]))/2 + ((-x2 + \
x2*x3^2)*(-M[[1,2]] + M[[3,9]]))/
       2 + ((-3*x3 + x3^3)*(-3*M[[1,3]] + M[[3,10]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((-3*x1*x3 + x1^3*x3)*(-3*M[[2,3]] + M[[4,3]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,4]] + M[[4,4]]))/4 \
+ 
      ((-(x2*x3) + x1^2*x2*x3)*(-M[[2,5]] + M[[4,5]]))/2 + 
      ((1 - x1^2 - x3^2 + x1^2*x3^2)*(1 - M[[2,1]] - M[[2,6]] + M[[4,6]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,7]]))/6 + 
      ((-(x1*x3) + x1*x2^2*x3)*(-M[[2,3]] + M[[4,8]]))/2 + 
      ((-(x1*x2) + x1*x2*x3^2)*(-M[[2,2]] + M[[4,9]]))/2 + 
      ((-3*x1*x3 + x1*x3^3)*(-3*M[[2,3]] + M[[4,10]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,4]] + M[[4,11]]))/24 + 
      ((-3*x2*x3 + x2^3*x3)*(-3*M[[2,5]] + M[[4,12]]))/6 + 
      ((1 - x2^2 - x3^2 + x2^2*x3^2)*(1 - M[[2,4]] - M[[2,6]] + M[[4,13]]))/4 \
+ 
      ((-3*x2*x3 + x2*x3^3)*(-3*M[[2,5]] + M[[4,14]]))/6 + 
      ((3 - 6*x3^2 + x3^4)*(3 - 6*M[[2,6]] + M[[4,15]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x3 - 6*x1^2*x3 + x1^4*x3)*(3*M[[1,3]] - 6*M[[3,3]] + M[[5,3]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,4]] + 
         M[[5,4]]))/12 + ((-3*x1*x2*x3 + x1^3*x2*x3)*(-3*M[[3,5]] + \
M[[5,5]]))/6 + 
      ((3*x1 - x1^3 - 3*x1*x3^2 + x1^3*x3^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,6]] + 
         M[[5,6]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,7]] + M[[5,7]]))/12 + ((x3 - x1^2*x3 - x2^2*x3 + x1^2*x2^2*x3)*
        (M[[1,3]] - M[[3,3]] - M[[3,8]] + M[[5,8]]))/4 + 
      ((x2 - x1^2*x2 - x2*x3^2 + x1^2*x2*x3^2)*(M[[1,2]] - M[[3,2]] - \
M[[3,9]] + M[[5,9]]))/
       4 + ((3*x3 - 3*x1^2*x3 - x3^3 + x1^2*x3^3)*(3*M[[1,3]] - 3*M[[3,3]] - \
M[[3,10]] + 
         M[[5,10]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - \
6*M[[3,4]] + 
         M[[5,11]]))/24 + ((-3*x1*x2*x3 + x1*x2^3*x3)*(-3*M[[3,5]] + \
M[[5,12]]))/6 + 
      ((x1 - x1*x2^2 - x1*x3^2 + x1*x2^2*x3^2)*(M[[1,1]] - M[[3,4]] - \
M[[3,6]] + 
         M[[5,13]]))/4 + ((-3*x1*x2*x3 + x1*x2*x3^3)*(-3*M[[3,5]] + \
M[[5,14]]))/6 + 
      ((3*x1 - 6*x1*x3^2 + x1*x3^4)*(3*M[[1,1]] - 6*M[[3,6]] + M[[5,15]]))/24 \
+ 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,7]] + M[[5,16]]))/120 \
+ 
      ((3*x3 - 6*x2^2*x3 + x2^4*x3)*(3*M[[1,3]] - 6*M[[3,8]] + M[[5,17]]))/24 \
+ 
      ((3*x2 - x2^3 - 3*x2*x3^2 + x2^3*x3^2)*(3*M[[1,2]] - M[[3,7]] - \
3*M[[3,9]] + 
         M[[5,18]]))/12 + ((3*x3 - 3*x2^2*x3 - x3^3 + x2^2*x3^3)*(3*M[[1,3]] \
- 3*M[[3,8]] - 
         M[[3,10]] + M[[5,19]]))/12 + ((3*x2 - 6*x2*x3^2 + x2*x3^4)*
        (3*M[[1,2]] - 6*M[[3,9]] + M[[5,20]]))/24 + 
      ((15*x3 - 10*x3^3 + x3^5)*(15*M[[1,3]] - 10*M[[3,10]] + M[[5,21]]))/120 \
+ 
      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((15*x1*x3 - 10*x1^3*x3 + x1^5*x3)*(15*M[[2,3]] - 10*M[[4,3]] + \
M[[6,3]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,4]] - M[[4,1]] - 6*M[[4,4]] + M[[6,4]]))/48 + 
      ((3*x2*x3 - 6*x1^2*x2*x3 + x1^4*x2*x3)*(3*M[[2,5]] - 6*M[[4,5]] + \
M[[6,5]]))/24 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x3^2 - 6*x1^2*x3^2 + x1^4*x3^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,6]] - M[[4,1]] - 6*M[[4,6]] + M[[6,6]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 
         3*M[[4,7]] + M[[6,7]]))/36 + ((3*x1*x3 - x1^3*x3 - 3*x1*x2^2*x3 + \
x1^3*x2^2*x3)*
        (3*M[[2,3]] - M[[4,3]] - 3*M[[4,8]] + M[[6,8]]))/12 + 
      ((3*x1*x2 - x1^3*x2 - 3*x1*x2*x3^2 + x1^3*x2*x3^2)*(3*M[[2,2]] - \
M[[4,2]] - 
         3*M[[4,9]] + M[[6,9]]))/12 + ((9*x1*x3 - 3*x1^3*x3 - 3*x1*x3^3 + \
x1^3*x3^3)*
        (9*M[[2,3]] - 3*M[[4,3]] - 3*M[[4,10]] + M[[6,10]]))/36 + 
      ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + x1^2*x2^4)*(-3 + \
3*M[[2,1]] + 
         6*M[[2,4]] - 6*M[[4,4]] - M[[4,11]] + M[[6,11]]))/48 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2^3*x3 + x1^2*x2^3*x3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,12]] + M[[6,12]]))/12 + ((-1 + x1^2 + x2^2 - x1^2*x2^2 + x3^2 - \
x1^2*x3^2 - 
         x2^2*x3^2 + x1^2*x2^2*x3^2)*(-1 + M[[2,1]] + M[[2,4]] + M[[2,6]] - \
M[[4,4]] - 
         M[[4,6]] - M[[4,13]] + M[[6,13]]))/8 + 
      ((3*x2*x3 - 3*x1^2*x2*x3 - x2*x3^3 + x1^2*x2*x3^3)*(3*M[[2,5]] - \
3*M[[4,5]] - 
         M[[4,14]] + M[[6,14]]))/12 + ((-3 + 3*x1^2 + 6*x3^2 - 6*x1^2*x3^2 - \
x3^4 + 
         x1^2*x3^4)*(-3 + 3*M[[2,1]] + 6*M[[2,6]] - 6*M[[4,6]] - M[[4,15]] + \
M[[6,15]]))/
       48 + ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,7]] + \
M[[6,16]]))/
       120 + ((3*x1*x3 - 6*x1*x2^2*x3 + x1*x2^4*x3)*(3*M[[2,3]] - 6*M[[4,8]] \
+ M[[6,17]]))/
       24 + ((3*x1*x2 - x1*x2^3 - 3*x1*x2*x3^2 + x1*x2^3*x3^2)*(3*M[[2,2]] - \
M[[4,7]] - 
         3*M[[4,9]] + M[[6,18]]))/12 + ((3*x1*x3 - 3*x1*x2^2*x3 - x1*x3^3 + \
x1*x2^2*x3^3)*
        (3*M[[2,3]] - 3*M[[4,8]] - M[[4,10]] + M[[6,19]]))/12 + 
      ((3*x1*x2 - 6*x1*x2*x3^2 + x1*x2*x3^4)*(3*M[[2,2]] - 6*M[[4,9]] + \
M[[6,20]]))/24 + 
      ((15*x1*x3 - 10*x1*x3^3 + x1*x3^5)*(15*M[[2,3]] - 10*M[[4,10]] + \
M[[6,21]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,4]] - 15*M[[4,11]] + \
M[[6,22]]))/
       720 + ((15*x2*x3 - 10*x2^3*x3 + x2^5*x3)*(15*M[[2,5]] - 10*M[[4,12]] + \
M[[6,23]]))/
       120 + ((-3 + 6*x2^2 - x2^4 + 3*x3^2 - 6*x2^2*x3^2 + x2^4*x3^2)*
        (-3 + 6*M[[2,4]] + 3*M[[2,6]] - M[[4,11]] - 6*M[[4,13]] + \
M[[6,24]]))/48 + 
      ((9*x2*x3 - 3*x2^3*x3 - 3*x2*x3^3 + x2^3*x3^3)*(9*M[[2,5]] - \
3*M[[4,12]] - 
         3*M[[4,14]] + M[[6,25]]))/36 + ((-3 + 3*x2^2 + 6*x3^2 - 6*x2^2*x3^2 \
- x3^4 + 
         x2^2*x3^4)*(-3 + 3*M[[2,4]] + 6*M[[2,6]] - 6*M[[4,13]] - M[[4,15]] + \
M[[6,26]]))/
       48 + ((15*x2*x3 - 10*x2*x3^3 + x2*x3^5)*(15*M[[2,5]] - 10*M[[4,14]] + \
M[[6,27]]))/
       120 + ((-15 + 45*x3^2 - 15*x3^4 + x3^6)*(-15 + 45*M[[2,6]] - \
15*M[[4,15]] + 
         M[[6,28]]))/720 + ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*
        (-105*M[[1,1]] + 105*M[[3,1]] - 21*M[[5,1]] + M[[7,1]]))/5040 + 
      ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*(-15*M[[1,2]] + \
45*M[[3,2]] - 
         15*M[[5,2]] + M[[7,2]]))/720 + ((-15*x3 + 45*x1^2*x3 - 15*x1^4*x3 + \
x1^6*x3)*
        (-15*M[[1,3]] + 45*M[[3,3]] - 15*M[[5,3]] + M[[7,3]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,4]] - M[[5,1]] - 10*M[[5,4]] + \
M[[7,4]]))/
       240 + ((15*x1*x2*x3 - 10*x1^3*x2*x3 + x1^5*x2*x3)*(15*M[[3,5]] - \
10*M[[5,5]] + 
         M[[7,5]]))/120 + ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x3^2 - \
10*x1^3*x3^2 + 
         x1^5*x3^2)*(-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,6]] - M[[5,1]] - \
10*M[[5,6]] + 
         M[[7,6]]))/240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - \
6*x1^2*x2^3 + 
         x1^4*x2^3)*(-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,7]] - 3*M[[5,2]] - \
6*M[[5,7]] + 
         M[[7,7]]))/144 + ((-3*x3 + 6*x1^2*x3 - x1^4*x3 + 3*x2^2*x3 - \
6*x1^2*x2^2*x3 + 
         x1^4*x2^2*x3)*(-3*M[[1,3]] + 6*M[[3,3]] + 3*M[[3,8]] - M[[5,3]] - \
6*M[[5,8]] + 
         M[[7,8]]))/48 + ((-3*x2 + 6*x1^2*x2 - x1^4*x2 + 3*x2*x3^2 - \
6*x1^2*x2*x3^2 + 
         x1^4*x2*x3^2)*(-3*M[[1,2]] + 6*M[[3,2]] + 3*M[[3,9]] - M[[5,2]] - \
6*M[[5,9]] + 
         M[[7,9]]))/48 + ((-9*x3 + 18*x1^2*x3 - 3*x1^4*x3 + 3*x3^3 - \
6*x1^2*x3^3 + 
         x1^4*x3^3)*(-9*M[[1,3]] + 18*M[[3,3]] + 3*M[[3,10]] - 3*M[[5,3]] - \
6*M[[5,10]] + 
         M[[7,10]]))/144 + ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - \
3*x1*x2^4 + 
         x1^3*x2^4)*(-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,4]] - 6*M[[5,4]] - \
3*M[[5,11]] + 
         M[[7,11]]))/144 + ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2^3*x3 + \
x1^3*x2^3*x3)*
        (9*M[[3,5]] - 3*M[[5,5]] - 3*M[[5,12]] + M[[7,12]]))/36 + 
      ((-3*x1 + x1^3 + 3*x1*x2^2 - x1^3*x2^2 + 3*x1*x3^2 - x1^3*x3^2 - \
3*x1*x2^2*x3^2 + 
         x1^3*x2^2*x3^2)*(-3*M[[1,1]] + M[[3,1]] + 3*M[[3,4]] + 3*M[[3,6]] - \
M[[5,4]] - 
         M[[5,6]] - 3*M[[5,13]] + M[[7,13]]))/24 + 
      ((9*x1*x2*x3 - 3*x1^3*x2*x3 - 3*x1*x2*x3^3 + x1^3*x2*x3^3)*(9*M[[3,5]] \
- 3*M[[5,5]] - 
         3*M[[5,14]] + M[[7,14]]))/36 + ((-9*x1 + 3*x1^3 + 18*x1*x3^2 - \
6*x1^3*x3^2 - 
         3*x1*x3^4 + x1^3*x3^4)*(-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,6]] - \
6*M[[5,6]] - 
         3*M[[5,15]] + M[[7,15]]))/144 + ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - \
10*x1^2*x2^3 - 
         x2^5 + x1^2*x2^5)*(-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,7]] - \
10*M[[5,7]] - 
         M[[5,16]] + M[[7,16]]))/240 + ((-3*x3 + 3*x1^2*x3 + 6*x2^2*x3 - \
6*x1^2*x2^2*x3 - 
         x2^4*x3 + x1^2*x2^4*x3)*(-3*M[[1,3]] + 3*M[[3,3]] + 6*M[[3,8]] - \
6*M[[5,8]] - 
         M[[5,17]] + M[[7,17]]))/48 + ((-3*x2 + 3*x1^2*x2 + x2^3 - x1^2*x2^3 \
+ 3*x2*x3^2 - 
         3*x1^2*x2*x3^2 - x2^3*x3^2 + x1^2*x2^3*x3^2)*(-3*M[[1,2]] + \
3*M[[3,2]] + 
         M[[3,7]] + 3*M[[3,9]] - M[[5,7]] - 3*M[[5,9]] - M[[5,18]] + \
M[[7,18]]))/24 + 
      ((-3*x3 + 3*x1^2*x3 + 3*x2^2*x3 - 3*x1^2*x2^2*x3 + x3^3 - x1^2*x3^3 - \
x2^2*x3^3 + 
         x1^2*x2^2*x3^3)*(-3*M[[1,3]] + 3*M[[3,3]] + 3*M[[3,8]] + M[[3,10]] - \
3*M[[5,8]] - 
         M[[5,10]] - M[[5,19]] + M[[7,19]]))/24 + 
      ((-3*x2 + 3*x1^2*x2 + 6*x2*x3^2 - 6*x1^2*x2*x3^2 - x2*x3^4 + \
x1^2*x2*x3^4)*
        (-3*M[[1,2]] + 3*M[[3,2]] + 6*M[[3,9]] - 6*M[[5,9]] - M[[5,20]] + \
M[[7,20]]))/48 + 
      ((-15*x3 + 15*x1^2*x3 + 10*x3^3 - 10*x1^2*x3^3 - x3^5 + x1^2*x3^5)*
        (-15*M[[1,3]] + 15*M[[3,3]] + 10*M[[3,10]] - 10*M[[5,10]] - M[[5,21]] \
+ M[[7,21]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,4]] - 
         15*M[[5,11]] + M[[7,22]]))/720 + ((15*x1*x2*x3 - 10*x1*x2^3*x3 + \
x1*x2^5*x3)*
        (15*M[[3,5]] - 10*M[[5,12]] + M[[7,23]]))/120 + 
      ((-3*x1 + 6*x1*x2^2 - x1*x2^4 + 3*x1*x3^2 - 6*x1*x2^2*x3^2 + \
x1*x2^4*x3^2)*
        (-3*M[[1,1]] + 6*M[[3,4]] + 3*M[[3,6]] - M[[5,11]] - 6*M[[5,13]] + \
M[[7,24]]))/48 + 
      ((9*x1*x2*x3 - 3*x1*x2^3*x3 - 3*x1*x2*x3^3 + x1*x2^3*x3^3)*
        (9*M[[3,5]] - 3*M[[5,12]] - 3*M[[5,14]] + M[[7,25]]))/36 + 
      ((-3*x1 + 3*x1*x2^2 + 6*x1*x3^2 - 6*x1*x2^2*x3^2 - x1*x3^4 + \
x1*x2^2*x3^4)*
        (-3*M[[1,1]] + 3*M[[3,4]] + 6*M[[3,6]] - 6*M[[5,13]] - M[[5,15]] + \
M[[7,26]]))/48 + 
      ((15*x1*x2*x3 - 10*x1*x2*x3^3 + x1*x2*x3^5)*(15*M[[3,5]] - 10*M[[5,14]] \
+ M[[7,27]]))/
       120 + ((-15*x1 + 45*x1*x3^2 - 15*x1*x3^4 + x1*x3^6)*(-15*M[[1,1]] + \
45*M[[3,6]] - 
         15*M[[5,15]] + M[[7,28]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,7]] - 21*M[[5,16]] + M[[7,29]]))/5040 + 
      ((-15*x3 + 45*x2^2*x3 - 15*x2^4*x3 + x2^6*x3)*(-15*M[[1,3]] + \
45*M[[3,8]] - 
         15*M[[5,17]] + M[[7,30]]))/720 + ((-15*x2 + 10*x2^3 - x2^5 + \
15*x2*x3^2 - 
         10*x2^3*x3^2 + x2^5*x3^2)*(-15*M[[1,2]] + 10*M[[3,7]] + 15*M[[3,9]] \
- M[[5,16]] - 
         10*M[[5,18]] + M[[7,31]]))/240 + ((-9*x3 + 18*x2^2*x3 - 3*x2^4*x3 + \
3*x3^3 - 
         6*x2^2*x3^3 + x2^4*x3^3)*(-9*M[[1,3]] + 18*M[[3,8]] + 3*M[[3,10]] - \
3*M[[5,17]] - 
         6*M[[5,19]] + M[[7,32]]))/144 + ((-9*x2 + 3*x2^3 + 18*x2*x3^2 - \
6*x2^3*x3^2 - 
         3*x2*x3^4 + x2^3*x3^4)*(-9*M[[1,2]] + 3*M[[3,7]] + 18*M[[3,9]] - \
6*M[[5,18]] - 
         3*M[[5,20]] + M[[7,33]]))/144 + ((-15*x3 + 15*x2^2*x3 + 10*x3^3 - \
10*x2^2*x3^3 - 
         x3^5 + x2^2*x3^5)*(-15*M[[1,3]] + 15*M[[3,8]] + 10*M[[3,10]] - \
10*M[[5,19]] - 
         M[[5,21]] + M[[7,34]]))/240 + ((-15*x2 + 45*x2*x3^2 - 15*x2*x3^4 + \
x2*x3^6)*
        (-15*M[[1,2]] + 45*M[[3,9]] - 15*M[[5,20]] + M[[7,35]]))/720 + 
      ((-105*x3 + 105*x3^3 - 21*x3^5 + x3^7)*(-105*M[[1,3]] + 105*M[[3,10]] - \

         21*M[[5,21]] + M[[7,36]]))/5040 + ((105 - 420*x1^2 + 210*x1^4 - \
28*x1^6 + x1^8)*
        (105 - 420*M[[2,1]] + 210*M[[4,1]] - 28*M[[6,1]] + M[[8,1]]))/40320 + \

      ((-105*x1*x2 + 105*x1^3*x2 - 21*x1^5*x2 + x1^7*x2)*(-105*M[[2,2]] + \
105*M[[4,2]] - 
         21*M[[6,2]] + M[[8,2]]))/5040 + ((-105*x1*x3 + 105*x1^3*x3 - \
21*x1^5*x3 + x1^7*x3)*
        (-105*M[[2,3]] + 105*M[[4,3]] - 21*M[[6,3]] + M[[8,3]]))/5040 + 
      ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 \
+ x1^6*x2^2)*
        (15 - 45*M[[2,1]] - 15*M[[2,4]] + 15*M[[4,1]] + 45*M[[4,4]] - \
M[[6,1]] - 
         15*M[[6,4]] + M[[8,4]]))/1440 + ((-15*x2*x3 + 45*x1^2*x2*x3 - \
15*x1^4*x2*x3 + 
         x1^6*x2*x3)*(-15*M[[2,5]] + 45*M[[4,5]] - 15*M[[6,5]] + \
M[[8,5]]))/720 + 
      ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x3^2 + 45*x1^2*x3^2 - 15*x1^4*x3^2 \
+ x1^6*x3^2)*
        (15 - 45*M[[2,1]] - 15*M[[2,6]] + 15*M[[4,1]] + 45*M[[4,6]] - \
M[[6,1]] - 
         15*M[[6,6]] + M[[8,6]]))/1440 + ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 \
+ 
         15*x1*x2^3 - 10*x1^3*x2^3 + x1^5*x2^3)*(-45*M[[2,2]] + 30*M[[4,2]] + \
15*M[[4,7]] - 
         3*M[[6,2]] - 10*M[[6,7]] + M[[8,7]]))/720 + 
      ((-15*x1*x3 + 10*x1^3*x3 - x1^5*x3 + 15*x1*x2^2*x3 - 10*x1^3*x2^2*x3 + \
x1^5*x2^2*x3)*
        (-15*M[[2,3]] + 10*M[[4,3]] + 15*M[[4,8]] - M[[6,3]] - 10*M[[6,8]] + \
M[[8,8]]))/
       240 + ((-15*x1*x2 + 10*x1^3*x2 - x1^5*x2 + 15*x1*x2*x3^2 - \
10*x1^3*x2*x3^2 + 
         x1^5*x2*x3^2)*(-15*M[[2,2]] + 10*M[[4,2]] + 15*M[[4,9]] - M[[6,2]] - \
10*M[[6,9]] + 
         M[[8,9]]))/240 + ((-45*x1*x3 + 30*x1^3*x3 - 3*x1^5*x3 + 15*x1*x3^3 - \

         10*x1^3*x3^3 + x1^5*x3^3)*(-45*M[[2,3]] + 30*M[[4,3]] + 15*M[[4,10]] \
- 
         3*M[[6,3]] - 10*M[[6,10]] + M[[8,10]]))/720 + 
      ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + 36*x1^2*x2^2 - 6*x1^4*x2^2 + 3*x2^4 \
- 
         6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - 18*M[[2,4]] + 3*M[[4,1]] \
+ 
         36*M[[4,4]] + 3*M[[4,11]] - 6*M[[6,4]] - 6*M[[6,11]] + \
M[[8,11]]))/576 + 
      ((-9*x2*x3 + 18*x1^2*x2*x3 - 3*x1^4*x2*x3 + 3*x2^3*x3 - 6*x1^2*x2^3*x3 \
+ 
         x1^4*x2^3*x3)*(-9*M[[2,5]] + 18*M[[4,5]] + 3*M[[4,12]] - 3*M[[6,5]] \
- 
         6*M[[6,12]] + M[[8,12]]))/144 + ((3 - 6*x1^2 + x1^4 - 3*x2^2 + \
6*x1^2*x2^2 - 
         x1^4*x2^2 - 3*x3^2 + 6*x1^2*x3^2 - x1^4*x3^2 + 3*x2^2*x3^2 - \
6*x1^2*x2^2*x3^2 + 
         x1^4*x2^2*x3^2)*(3 - 6*M[[2,1]] - 3*M[[2,4]] - 3*M[[2,6]] + M[[4,1]] \
+ 
         6*M[[4,4]] + 6*M[[4,6]] + 3*M[[4,13]] - M[[6,4]] - M[[6,6]] - \
6*M[[6,13]] + 
         M[[8,13]]))/96 + ((-9*x2*x3 + 18*x1^2*x2*x3 - 3*x1^4*x2*x3 + \
3*x2*x3^3 - 
         6*x1^2*x2*x3^3 + x1^4*x2*x3^3)*(-9*M[[2,5]] + 18*M[[4,5]] + \
3*M[[4,14]] - 
         3*M[[6,5]] - 6*M[[6,14]] + M[[8,14]]))/144 + 
      ((9 - 18*x1^2 + 3*x1^4 - 18*x3^2 + 36*x1^2*x3^2 - 6*x1^4*x3^2 + 3*x3^4 \
- 
         6*x1^2*x3^4 + x1^4*x3^4)*(9 - 18*M[[2,1]] - 18*M[[2,6]] + 3*M[[4,1]] \
+ 
         36*M[[4,6]] + 3*M[[4,15]] - 6*M[[6,6]] - 6*M[[6,15]] + \
M[[8,15]]))/576 + 
      ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
        (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,7]] - 10*M[[6,7]] - 3*M[[6,16]] \
+ M[[8,16]]))/
       720 + ((-9*x1*x3 + 3*x1^3*x3 + 18*x1*x2^2*x3 - 6*x1^3*x2^2*x3 - \
3*x1*x2^4*x3 + 
         x1^3*x2^4*x3)*(-9*M[[2,3]] + 3*M[[4,3]] + 18*M[[4,8]] - 6*M[[6,8]] - \
3*M[[6,17]] + 
         M[[8,17]]))/144 + ((-9*x1*x2 + 3*x1^3*x2 + 3*x1*x2^3 - x1^3*x2^3 + \
9*x1*x2*x3^2 - 
         3*x1^3*x2*x3^2 - 3*x1*x2^3*x3^2 + x1^3*x2^3*x3^2)*(-9*M[[2,2]] + \
3*M[[4,2]] + 
         3*M[[4,7]] + 9*M[[4,9]] - M[[6,7]] - 3*M[[6,9]] - 3*M[[6,18]] + \
M[[8,18]]))/72 + 
      ((-9*x1*x3 + 3*x1^3*x3 + 9*x1*x2^2*x3 - 3*x1^3*x2^2*x3 + 3*x1*x3^3 - \
x1^3*x3^3 - 
         3*x1*x2^2*x3^3 + x1^3*x2^2*x3^3)*(-9*M[[2,3]] + 3*M[[4,3]] + \
9*M[[4,8]] + 
         3*M[[4,10]] - 3*M[[6,8]] - M[[6,10]] - 3*M[[6,19]] + M[[8,19]]))/72 \
+ 
      ((-9*x1*x2 + 3*x1^3*x2 + 18*x1*x2*x3^2 - 6*x1^3*x2*x3^2 - 3*x1*x2*x3^4 \
+ 
         x1^3*x2*x3^4)*(-9*M[[2,2]] + 3*M[[4,2]] + 18*M[[4,9]] - 6*M[[6,9]] - \
3*M[[6,20]] + 
         M[[8,20]]))/144 + ((-45*x1*x3 + 15*x1^3*x3 + 30*x1*x3^3 - \
10*x1^3*x3^3 - 
         3*x1*x3^5 + x1^3*x3^5)*(-45*M[[2,3]] + 15*M[[4,3]] + 30*M[[4,10]] - \
10*M[[6,10]] - 
         3*M[[6,21]] + M[[8,21]]))/720 + ((15 - 15*x1^2 - 45*x2^2 + \
45*x1^2*x2^2 + 
         15*x2^4 - 15*x1^2*x2^4 - x2^6 + x1^2*x2^6)*(15 - 15*M[[2,1]] - \
45*M[[2,4]] + 
         45*M[[4,4]] + 15*M[[4,11]] - 15*M[[6,11]] - M[[6,22]] + \
M[[8,22]]))/1440 + 
      ((-15*x2*x3 + 15*x1^2*x2*x3 + 10*x2^3*x3 - 10*x1^2*x2^3*x3 - x2^5*x3 + \
x1^2*x2^5*x3)*
        (-15*M[[2,5]] + 15*M[[4,5]] + 10*M[[4,12]] - 10*M[[6,12]] - M[[6,23]] \
+ M[[8,23]]))/
       240 + ((3 - 3*x1^2 - 6*x2^2 + 6*x1^2*x2^2 + x2^4 - x1^2*x2^4 - 3*x3^2 \
+ 
         3*x1^2*x3^2 + 6*x2^2*x3^2 - 6*x1^2*x2^2*x3^2 - x2^4*x3^2 + \
x1^2*x2^4*x3^2)*
        (3 - 3*M[[2,1]] - 6*M[[2,4]] - 3*M[[2,6]] + 6*M[[4,4]] + 3*M[[4,6]] + \
M[[4,11]] + 
         6*M[[4,13]] - M[[6,11]] - 6*M[[6,13]] - M[[6,24]] + M[[8,24]]))/96 + \

      ((-9*x2*x3 + 9*x1^2*x2*x3 + 3*x2^3*x3 - 3*x1^2*x2^3*x3 + 3*x2*x3^3 - \
3*x1^2*x2*x3^3 - 
         x2^3*x3^3 + x1^2*x2^3*x3^3)*(-9*M[[2,5]] + 9*M[[4,5]] + 3*M[[4,12]] \
+ 
         3*M[[4,14]] - 3*M[[6,12]] - 3*M[[6,14]] - M[[6,25]] + M[[8,25]]))/72 \
+ 
      ((3 - 3*x1^2 - 3*x2^2 + 3*x1^2*x2^2 - 6*x3^2 + 6*x1^2*x3^2 + \
6*x2^2*x3^2 - 
         6*x1^2*x2^2*x3^2 + x3^4 - x1^2*x3^4 - x2^2*x3^4 + x1^2*x2^2*x3^4)*
        (3 - 3*M[[2,1]] - 3*M[[2,4]] - 6*M[[2,6]] + 3*M[[4,4]] + 6*M[[4,6]] + \
6*M[[4,13]] + 
         M[[4,15]] - 6*M[[6,13]] - M[[6,15]] - M[[6,26]] + M[[8,26]]))/96 + 
      ((-15*x2*x3 + 15*x1^2*x2*x3 + 10*x2*x3^3 - 10*x1^2*x2*x3^3 - x2*x3^5 + \
x1^2*x2*x3^5)*
        (-15*M[[2,5]] + 15*M[[4,5]] + 10*M[[4,14]] - 10*M[[6,14]] - M[[6,27]] \
+ M[[8,27]]))/
       240 + ((15 - 15*x1^2 - 45*x3^2 + 45*x1^2*x3^2 + 15*x3^4 - 15*x1^2*x3^4 \
- x3^6 + 
         x1^2*x3^6)*(15 - 15*M[[2,1]] - 45*M[[2,6]] + 45*M[[4,6]] + \
15*M[[4,15]] - 
         15*M[[6,15]] - M[[6,28]] + M[[8,28]]))/1440 + 
      ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,7]] - 
         21*M[[6,16]] + M[[8,29]]))/5040 + ((-15*x1*x3 + 45*x1*x2^2*x3 - \
15*x1*x2^4*x3 + 
         x1*x2^6*x3)*(-15*M[[2,3]] + 45*M[[4,8]] - 15*M[[6,17]] + \
M[[8,30]]))/720 + 
      ((-15*x1*x2 + 10*x1*x2^3 - x1*x2^5 + 15*x1*x2*x3^2 - 10*x1*x2^3*x3^2 + \
x1*x2^5*x3^2)*
        (-15*M[[2,2]] + 10*M[[4,7]] + 15*M[[4,9]] - M[[6,16]] - 10*M[[6,18]] \
+ M[[8,31]]))/
       240 + ((-9*x1*x3 + 18*x1*x2^2*x3 - 3*x1*x2^4*x3 + 3*x1*x3^3 - \
6*x1*x2^2*x3^3 + 
         x1*x2^4*x3^3)*(-9*M[[2,3]] + 18*M[[4,8]] + 3*M[[4,10]] - 3*M[[6,17]] \
- 
         6*M[[6,19]] + M[[8,32]]))/144 + ((-9*x1*x2 + 3*x1*x2^3 + \
18*x1*x2*x3^2 - 
         6*x1*x2^3*x3^2 - 3*x1*x2*x3^4 + x1*x2^3*x3^4)*(-9*M[[2,2]] + \
3*M[[4,7]] + 
         18*M[[4,9]] - 6*M[[6,18]] - 3*M[[6,20]] + M[[8,33]]))/144 + 
      ((-15*x1*x3 + 15*x1*x2^2*x3 + 10*x1*x3^3 - 10*x1*x2^2*x3^3 - x1*x3^5 + \
x1*x2^2*x3^5)*
        (-15*M[[2,3]] + 15*M[[4,8]] + 10*M[[4,10]] - 10*M[[6,19]] - M[[6,21]] \
+ M[[8,34]]))/
       240 + ((-15*x1*x2 + 45*x1*x2*x3^2 - 15*x1*x2*x3^4 + x1*x2*x3^6)*
        (-15*M[[2,2]] + 45*M[[4,9]] - 15*M[[6,20]] + M[[8,35]]))/720 + 
      ((-105*x1*x3 + 105*x1*x3^3 - 21*x1*x3^5 + x1*x3^7)*(-105*M[[2,3]] + \
105*M[[4,10]] - 
         21*M[[6,21]] + M[[8,36]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - \
28*x2^6 + x2^8)*
        (105 - 420*M[[2,4]] + 210*M[[4,11]] - 28*M[[6,22]] + \
M[[8,37]]))/40320 + 
      ((-105*x2*x3 + 105*x2^3*x3 - 21*x2^5*x3 + x2^7*x3)*(-105*M[[2,5]] + \
105*M[[4,12]] - 
         21*M[[6,23]] + M[[8,38]]))/5040 + 
      ((15 - 45*x2^2 + 15*x2^4 - x2^6 - 15*x3^2 + 45*x2^2*x3^2 - 15*x2^4*x3^2 \
+ x2^6*x3^2)*
        (15 - 45*M[[2,4]] - 15*M[[2,6]] + 15*M[[4,11]] + 45*M[[4,13]] - \
M[[6,22]] - 
         15*M[[6,24]] + M[[8,39]]))/1440 + 
      ((-45*x2*x3 + 30*x2^3*x3 - 3*x2^5*x3 + 15*x2*x3^3 - 10*x2^3*x3^3 + \
x2^5*x3^3)*
        (-45*M[[2,5]] + 30*M[[4,12]] + 15*M[[4,14]] - 3*M[[6,23]] - \
10*M[[6,25]] + 
         M[[8,40]]))/720 + ((9 - 18*x2^2 + 3*x2^4 - 18*x3^2 + 36*x2^2*x3^2 - \
6*x2^4*x3^2 + 
         3*x3^4 - 6*x2^2*x3^4 + x2^4*x3^4)*(9 - 18*M[[2,4]] - 18*M[[2,6]] + \
3*M[[4,11]] + 
         36*M[[4,13]] + 3*M[[4,15]] - 6*M[[6,24]] - 6*M[[6,26]] + \
M[[8,41]]))/576 + 
      ((-45*x2*x3 + 15*x2^3*x3 + 30*x2*x3^3 - 10*x2^3*x3^3 - 3*x2*x3^5 + \
x2^3*x3^5)*
        (-45*M[[2,5]] + 15*M[[4,12]] + 30*M[[4,14]] - 10*M[[6,25]] - \
3*M[[6,27]] + 
         M[[8,42]]))/720 + ((15 - 15*x2^2 - 45*x3^2 + 45*x2^2*x3^2 + 15*x3^4 \
- 
         15*x2^2*x3^4 - x3^6 + x2^2*x3^6)*(15 - 15*M[[2,4]] - 45*M[[2,6]] + \
45*M[[4,13]] + 
         15*M[[4,15]] - 15*M[[6,26]] - M[[6,28]] + M[[8,43]]))/1440 + 
      ((-105*x2*x3 + 105*x2*x3^3 - 21*x2*x3^5 + x2*x3^7)*(-105*M[[2,5]] + \
105*M[[4,14]] - 
         21*M[[6,27]] + M[[8,44]]))/5040 + ((105 - 420*x3^2 + 210*x3^4 - \
28*x3^6 + x3^8)*
        (105 - 420*M[[2,6]] + 210*M[[4,15]] - 28*M[[6,28]] + \
M[[8,45]]))/40320))/
    2.718281828459045^(0.5*(x1^2 + x2^2 + x3^2))\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Closed]],

Cell[TextData[{
  StyleBox["(*explizite Formeln, standardisiert*)\n\n",
    FontColor->RGBColor[1, 0, 0]],
  "Clear[HermiteStand,x1,x2,M];\n\n\nDo[HermiteStand[k,{x1_},M_,   \"H\"]=\n\t\
\tHermiteExpansionMultiSymp[k,{x1}   ,M,   \"H\",True],{k,1,8}]\n\t\t\n\
Do[HermiteStand[k,{x1_},M_,\"phiH\"]=\n\t\tHermiteExpansionMultiSymp[k,{x1}   \
,M,\"phiH\",True],{k,1,8}]\n   \n\nDo[HermiteStand[k,{x1_,x2_},M_,   \"H\"]=\n\
\t\tHermiteExpansionMultiSymp[k,{x1,x2},M,   \"H\",True],{k,1,8}]\n\t\t\n\
Do[HermiteStand[k,{x1_,x2_},M_,\"phiH\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2},M,\"phiH\",True],{k,1,8}]\n\t\t\n\
Do[HermiteStand[k,{x1_,x2_,x3_},M_,   \"H\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2,x3},M,   \"H\",True],{k,1,8}]\n\t\t\n\
Do[HermiteStand[k,{x1_,x2_,x3_},M_,\"phiH\"]=\n\t\t\
HermiteExpansionMultiSymp[k,{x1,x2,x3},M,\"phiH\",True],{k,1,8}]\n   \n   "
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["??HermiteStand", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["Global`HermiteStand", "Print",
  FontSize->14,
  CellTags->"Info3406902320-6947369"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(HermiteStand[1, {x1_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[2, {x1_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[3, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket]\)},
                {" "},
                {\(HermiteStand[4, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[5, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[6, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[7, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 + \
105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040\)},
                {" "},
                {\(HermiteStand[8, {x1_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 + \
105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320\)},
                {" "},
                {\(HermiteStand[1, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\)},
                {" "},
                {\(HermiteStand[2, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\)},
                {" "},
                {\(HermiteStand[3, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[4, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[5, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[6, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[7, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040)\)\)},
                {" "},
                {\(HermiteStand[8, {x1_}, M_, "phiH"] = 
                    0.3989422804014327`\ 2.718281828459045`\^\(\(-0.5`\)\ \
x1\^2\)\ \((1 + 1\/6\ \((\(-3\)\ x1 + x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320)\)\)},
                {" "},
                {\(HermiteStand[1, {x1_, x2_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[2, {x1_, x2_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[3, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket]\)},
                {" "},
                {\(HermiteStand[4, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[5, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[6, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[7, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 + \
105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                            15\ x1\^4\ x2 + 
                            x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              2\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                            x1\^5\ x2\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              3\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 3\ x1\^4\ x2 + 
                            3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                            x1\^4\ x2\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              4\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                            6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                            x1\^3\ x2\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              5\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 10\ x2\^3 - 
                            10\ x1\^2\ x2\^3 - x2\^5 + 
                            x1\^2\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                            15\ x1\ x2\^4 + 
                            x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              7\[RightDoubleBracket])\) + \(\((\(-105\)\ x2 + \
105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 8\[RightDoubleBracket])\)\)\/5040\)},
                {" "},
                {\(HermiteStand[8, {x1_, x2_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          4\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 + \
105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                            15\ x1\^4\ x2 + 
                            x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              2\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                            x1\^5\ x2\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              3\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 3\ x1\^4\ x2 + 
                            3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                            x1\^4\ x2\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              4\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                            6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                            x1\^3\ x2\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              5\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 10\ x2\^3 - 
                            10\ x1\^2\ x2\^3 - x2\^5 + 
                            x1\^2\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              6\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                            15\ x1\ x2\^4 + 
                            x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              7\[RightDoubleBracket])\) + \(\((\(-105\)\ x2 + \
105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 8\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ x1\ x2 + 105\ x1\^3\ x2 - \
21\ x1\^5\ x2 + x1\^7\ x2)\)\ \((105\ M\[LeftDoubleBracket]4, 2\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 2\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 2\[RightDoubleBracket])\)\)\/5040 + \(\((15 - 45\ \
x1\^2 + 15\ x1\^4 - x1\^6 - 15\ x2\^2 + 45\ x1\^2\ x2\^2 - 15\ x1\^4\ x2\^2 + \
x1\^6\ x2\^2)\)\ \((\(-45\) + 15\ M\[LeftDoubleBracket]4, 1\
\[RightDoubleBracket] + 45\ M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - \
M\[LeftDoubleBracket]6, 1\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, \
3\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
3\[RightDoubleBracket])\)\)\/1440 + 
                      1\/720\ \((\(-45\)\ x1\ x2 + 30\ x1\^3\ x2 - 
                            3\ x1\^5\ x2 + 15\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 + 
                            x1\^5\ x2\^3)\)\ \((30\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                2\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              4\[RightDoubleBracket])\) + 
                      1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x2\^2 + 
                            36\ x1\^2\ x2\^2 - 6\ x1\^4\ x2\^2 + 3\ x2\^4 - 
                            6\ x1\^2\ x2\^4 + x1\^4\ x2\^4)\)\ \((\(-27\) + 
                            3\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            36\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                5\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              5\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-45\)\ x1\ x2 + 15\ x1\^3\ x2 + 
                            30\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 - 3\ x1\ x2\^5 + 
                            x1\^3\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            30\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              6\[RightDoubleBracket])\) + \(\((15 - 15\ x1\^2 \
- 45\ x2\^2 + 45\ x1\^2\ x2\^2 + 15\ x2\^4 - 15\ x1\^2\ x2\^4 - x2\^6 + x1\^2\
\ x2\^6)\)\ \((\(-45\) + 45\ M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + \
15\ M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 15\ \
M\[LeftDoubleBracket]6, 5\[RightDoubleBracket] - M\[LeftDoubleBracket]6, 7\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
7\[RightDoubleBracket])\)\)\/1440 + \(\((\(-105\)\ x1\ x2 + 105\ x1\ x2\^3 - \
21\ x1\ x2\^5 + x1\ x2\^7)\)\ \((105\ M\[LeftDoubleBracket]4, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 8\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x2\^2 + 210\ x2\^4 - 28\ x2\^6 + x2\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 7\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
9\[RightDoubleBracket])\)\)\/40320\)},
                {" "},
                {\(HermiteStand[1, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\)},
                {" "},
                {\(HermiteStand[2, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\)},
                {" "},
                {\(HermiteStand[3, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[4, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  3\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[5, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  3\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[6, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  3\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[7, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  3\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                                15\ x1\^4\ x2 + 
                                x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    2\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  2\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                                x1\^5\ x2\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  3\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 
                                3\ x1\^4\ x2 + 3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                                x1\^4\ x2\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  4\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                                6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                                x1\^3\ x2\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  5\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 
                                10\ x2\^3 - 10\ x1\^2\ x2\^3 - x2\^5 + 
                                x1\^2\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                                15\ x1\ x2\^4 + 
                                x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  7\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x2 + 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 8\[RightDoubleBracket])\)\)\/5040)\)\)},
                {" "},
                {\(HermiteStand[8, {x1_, x2_}, M_, "phiH"] = 
                    0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  3\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                                15\ x1\^4\ x2 + 
                                x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    2\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  2\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                                x1\^5\ x2\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  3\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 
                                3\ x1\^4\ x2 + 3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                                x1\^4\ x2\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  4\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                                6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                                x1\^3\ x2\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  5\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 
                                10\ x2\^3 - 10\ x1\^2\ x2\^3 - x2\^5 + 
                                
                                x1\^2\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  6\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                                15\ x1\ x2\^4 + 
                                x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  7\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x2 + 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 8\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ x1\ x2 + 105\ x1\^3\ x2 - \
21\ x1\^5\ x2 + x1\^7\ x2)\)\ \((105\ M\[LeftDoubleBracket]4, 2\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 2\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 2\[RightDoubleBracket])\)\)\/5040 + \(\((15 - 45\ \
x1\^2 + 15\ x1\^4 - x1\^6 - 15\ x2\^2 + 45\ x1\^2\ x2\^2 - 15\ x1\^4\ x2\^2 + \
x1\^6\ x2\^2)\)\ \((\(-45\) + 15\ M\[LeftDoubleBracket]4, 1\
\[RightDoubleBracket] + 45\ M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - \
M\[LeftDoubleBracket]6, 1\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, \
3\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
3\[RightDoubleBracket])\)\)\/1440 + 
                          1\/720\ \((\(-45\)\ x1\ x2 + 30\ x1\^3\ x2 - 
                                3\ x1\^5\ x2 + 15\ x1\ x2\^3 - 
                                10\ x1\^3\ x2\^3 + 
                                x1\^5\ x2\^3)\)\ \((30\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    2\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  4\[RightDoubleBracket])\) + 
                          1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x2\^2 + 
                                36\ x1\^2\ x2\^2 - 6\ x1\^4\ x2\^2 + 
                                3\ x2\^4 - 6\ x1\^2\ x2\^4 + 
                                x1\^4\ x2\^4)\)\ \((\(-27\) + 
                                3\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                36\ M\[LeftDoubleBracket]4, 
                                    3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    5\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  5\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-45\)\ x1\ x2 + 15\ x1\^3\ x2 + 
                                30\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 - 
                                3\ x1\ x2\^5 + 
                                x1\^3\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                30\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  6\[RightDoubleBracket])\) + \(\((15 - 15\ \
x1\^2 - 45\ x2\^2 + 45\ x1\^2\ x2\^2 + 15\ x2\^4 - 15\ x1\^2\ x2\^4 - x2\^6 + \
x1\^2\ x2\^6)\)\ \((\(-45\) + 45\ M\[LeftDoubleBracket]4, 3\
\[RightDoubleBracket] + 15\ M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - \
15\ M\[LeftDoubleBracket]6, 5\[RightDoubleBracket] - M\[LeftDoubleBracket]6, \
7\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
7\[RightDoubleBracket])\)\)\/1440 + \(\((\(-105\)\ x1\ x2 + 105\ x1\ x2\^3 - \
21\ x1\ x2\^5 + x1\ x2\^7)\)\ \((105\ M\[LeftDoubleBracket]4, 4\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 8\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x2\^2 + 210\ x2\^4 - 28\ x2\^6 + x2\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 7\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
9\[RightDoubleBracket])\)\)\/40320)\)\)},
                {" "},
                {\(HermiteStand[1, {x1_, x2_, x3_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[2, {x1_, x2_, x3_}, M_, "H"] = 1\)},
                {" "},
                {\(HermiteStand[3, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket]\)},
                {" "},
                {\(HermiteStand[4, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          3\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket])\) + 
                      1\/2\ \((\(-x2\)\ x3 + 
                            x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          5\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x3\^2 + 
                            x1\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              6\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x3 + 
                            x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x2 + 
                            x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          12\[RightDoubleBracket] + 
                      1\/4\ \((1 - x2\^2 - x3\^2 + 
                            x2\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          14\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              15\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[5, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          3\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket])\) + 
                      1\/2\ \((\(-x2\)\ x3 + 
                            x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          5\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x3\^2 + 
                            x1\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              6\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x3 + 
                            x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x2 + 
                            x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          12\[RightDoubleBracket] + 
                      1\/4\ \((1 - x2\^2 - x3\^2 + 
                            x2\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          14\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                            x1\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\^3\ x2\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                            x1\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              7\[RightDoubleBracket])\) + 
                      1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                            x1\^2\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              8\[RightDoubleBracket])\) + 
                      1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                            x1\^2\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              9\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                            x1\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              10\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\^3\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              12\[RightDoubleBracket])\) + 
                      1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                            x1\ x2\^2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              14\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                            x1\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                            x2\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                            x2\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                            x2\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                            x2\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x3 - 10\ x3\^3 + 
                            x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              21\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[6, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          3\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket])\) + 
                      1\/2\ \((\(-x2\)\ x3 + 
                            x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          5\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x3\^2 + 
                            x1\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              6\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x3 + 
                            x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x2 + 
                            x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          12\[RightDoubleBracket] + 
                      1\/4\ \((1 - x2\^2 - x3\^2 + 
                            x2\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          14\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                            x1\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\^3\ x2\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                            x1\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              7\[RightDoubleBracket])\) + 
                      1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                            x1\^2\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              8\[RightDoubleBracket])\) + 
                      1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                            x1\^2\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              9\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                            x1\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              10\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\^3\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              12\[RightDoubleBracket])\) + 
                      1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                            x1\ x2\^2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              14\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                            x1\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                            x2\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                            x2\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                            x2\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                            x2\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x3 - 10\ x3\^3 + 
                            x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                            x1\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                            x1\^4\ x2\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                            6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 3\ x1\ x2\^2\ x3 + 
                            x1\^3\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              8\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 3\ x1\ x2\ x3\^2 + 
                            x1\^3\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              9\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                            x1\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              10\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              11\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\^3\ x3 + 
                            x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              12\[RightDoubleBracket])\) + 
                      1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                            x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                            x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                            M\[LeftDoubleBracket]4, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              13\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\ x3\^3 + 
                            x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              14\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                            6\ x1\^2\ x3\^2 - x3\^4 + x1\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                            x1\ x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 3\ x1\ x2\ x3\^2 + 
                            x1\ x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - x1\ x3\^3 + 
                            x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                            x1\ x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                            x1\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              22\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                            x2\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              23\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                            6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              24\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                            x2\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              25\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                            6\ x2\^2\ x3\^2 - x3\^4 + x2\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              26\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                            x2\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              27\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                            x3\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              28\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[7, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          3\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket])\) + 
                      1\/2\ \((\(-x2\)\ x3 + 
                            x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          5\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x3\^2 + 
                            x1\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              6\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x3 + 
                            x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x2 + 
                            x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          12\[RightDoubleBracket] + 
                      1\/4\ \((1 - x2\^2 - x3\^2 + 
                            x2\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          14\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                            x1\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\^3\ x2\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                            x1\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              7\[RightDoubleBracket])\) + 
                      1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                            x1\^2\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              8\[RightDoubleBracket])\) + 
                      1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                            x1\^2\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              9\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                            x1\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              10\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\^3\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              12\[RightDoubleBracket])\) + 
                      1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                            x1\ x2\^2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              14\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                            x1\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                            x2\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                            x2\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                            x2\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                            x2\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x3 - 10\ x3\^3 + 
                            x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                            x1\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                            x1\^4\ x2\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                            6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 3\ x1\ x2\^2\ x3 + 
                            x1\^3\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              8\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 3\ x1\ x2\ x3\^2 + 
                            x1\^3\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              9\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                            x1\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              10\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              11\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\^3\ x3 + 
                            x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              12\[RightDoubleBracket])\) + 
                      1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                            x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                            x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                            M\[LeftDoubleBracket]4, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              13\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\ x3\^3 + 
                            x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              14\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                            6\ x1\^2\ x3\^2 - x3\^4 + x1\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                            x1\ x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 3\ x1\ x2\ x3\^2 + 
                            x1\ x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - x1\ x3\^3 + 
                            x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                            x1\ x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                            x1\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              22\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                            x2\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              23\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                            6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              24\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                            x2\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              25\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                            6\ x2\^2\ x3\^2 - x3\^4 + x2\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              26\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                            x2\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              27\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                            x3\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              28\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 \
+ 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                            15\ x1\^4\ x2 + 
                            x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              2\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x3 + 45\ x1\^2\ x3 - 
                            15\ x1\^4\ x3 + 
                            x1\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              3\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                            x1\^5\ x2\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              4\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\^3\ x2\ x3 + 
                            x1\^5\ x2\ x3)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              5\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x3\^2 - 10\ x1\^3\ x3\^2 + 
                            x1\^5\ x3\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              6\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 3\ x1\^4\ x2 + 
                            3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                            x1\^4\ x2\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              7\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x3 + 6\ x1\^2\ x3 - x1\^4\ x3 + 
                            3\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 + 
                            x1\^4\ x2\^2\ x3)\)\ \((6\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              8\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x2 + 6\ x1\^2\ x2 - x1\^4\ x2 + 
                            3\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 + 
                            x1\^4\ x2\ x3\^2)\)\ \((6\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              9\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x3 + 18\ x1\^2\ x3 - 3\ x1\^4\ x3 + 
                            3\ x3\^3 - 6\ x1\^2\ x3\^3 + 
                            x1\^4\ x3\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              10\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                            6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                            x1\^3\ x2\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              11\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                            3\ x1\ x2\^3\ x3 + 
                            x1\^3\ x2\^3\ x3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              12\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x1 + x1\^3 + 3\ x1\ x2\^2 - 
                            x1\^3\ x2\^2 + 3\ x1\ x3\^2 - x1\^3\ x3\^2 - 
                            3\ x1\ x2\^2\ x3\^2 + 
                            x1\^3\ x2\^2\ x3\^2)\)\ \
\((M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              13\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                            3\ x1\ x2\ x3\^3 + 
                            x1\^3\ x2\ x3\^3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              14\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x3\^2 - 
                            6\ x1\^3\ x3\^2 - 3\ x1\ x3\^4 + 
                            x1\^3\ x3\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                6\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              15\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 10\ x2\^3 - 
                            10\ x1\^2\ x2\^3 - x2\^5 + 
                            x1\^2\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                7\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              16\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 6\ x2\^2\ x3 - 
                            6\ x1\^2\ x2\^2\ x3 - x2\^4\ x3 + 
                            x1\^2\ x2\^4\ x3)\)\ \((3\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              17\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + x2\^3 - 
                            x1\^2\ x2\^3 + 3\ x2\ x3\^2 - 
                            3\ x1\^2\ x2\ x3\^2 - x2\^3\ x3\^2 + 
                            x1\^2\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              18\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 3\ x2\^2\ x3 - 
                            3\ x1\^2\ x2\^2\ x3 + x3\^3 - x1\^2\ x3\^3 - 
                            x2\^2\ x3\^3 + 
                            x1\^2\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 10\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              19\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + 6\ x2\ x3\^2 - 
                            6\ x1\^2\ x2\ x3\^2 - x2\ x3\^4 + 
                            x1\^2\ x2\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              20\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x3 + 15\ x1\^2\ x3 + 10\ x3\^3 - 
                            10\ x1\^2\ x3\^3 - x3\^5 + 
                            x1\^2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                10\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                            15\ x1\ x2\^4 + 
                            x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              22\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\^3\ x3 + 
                            x1\ x2\^5\ x3)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              23\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x1 + 6\ x1\ x2\^2 - x1\ x2\^4 + 
                            3\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 + 
                            x1\ x2\^4\ x3\^2)\)\ \((6\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              24\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\ x2\^3\ x3 - 
                            3\ x1\ x2\ x3\^3 + 
                            x1\ x2\^3\ x3\^3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              25\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x1 + 3\ x1\ x2\^2 + 6\ x1\ x3\^2 - 
                            6\ x1\ x2\^2\ x3\^2 - x1\ x3\^4 + 
                            x1\ x2\^2\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              26\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\ x3\^3 + 
                            x1\ x2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              27\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x3\^2 - 
                            15\ x1\ x3\^4 + 
                            x1\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              28\[RightDoubleBracket])\) + \(\((\(-105\)\ x2 \
+ 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 7\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 29\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x3 + 45\ x2\^2\ x3 - 
                            15\ x2\^4\ x3 + 
                            x2\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              30\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 10\ x2\^3 - x2\^5 + 
                            15\ x2\ x3\^2 - 10\ x2\^3\ x3\^2 + 
                            x2\^5\ x3\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              31\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x3 + 18\ x2\^2\ x3 - 3\ x2\^4\ x3 + 
                            3\ x3\^3 - 6\ x2\^2\ x3\^3 + 
                            x2\^4\ x3\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                17\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              32\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 3\ x2\^3 + 18\ x2\ x3\^2 - 
                            6\ x2\^3\ x3\^2 - 3\ x2\ x3\^4 + 
                            x2\^3\ x3\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                18\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              33\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x3 + 15\ x2\^2\ x3 + 10\ x3\^3 - 
                            10\ x2\^2\ x3\^3 - x3\^5 + 
                            x2\^2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                19\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              34\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x2\ x3\^2 - 
                            15\ x2\ x3\^4 + 
                            x2\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              35\[RightDoubleBracket])\) + \(\((\(-105\)\ x3 \
+ 105\ x3\^3 - 21\ x3\^5 + x3\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 10\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 36\[RightDoubleBracket])\)\)\/5040\)},
                {" "},
                {\(HermiteStand[8, {x1_, x2_, x3_}, M_, "H"] = 
                    1 + 1\/6\ \((\(-3\)\ x1 + 
                            x1\^3)\)\ M\[LeftDoubleBracket]3, 
                          1\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                          2\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          3\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                          4\[RightDoubleBracket] + 
                      x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                          5\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\) + 
                            x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          6\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x2 + x2\^3)\)\ M\[LeftDoubleBracket]3, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x3\) + 
                            x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x2\) + 
                            x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x3 + x3\^3)\)\ M\[LeftDoubleBracket]3, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              1\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                          2\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          3\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x2\^2 + 
                            x1\^2\ x2\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              4\[RightDoubleBracket])\) + 
                      1\/2\ \((\(-x2\)\ x3 + 
                            x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          5\[RightDoubleBracket] + 
                      1\/4\ \((1 - x1\^2 - x3\^2 + 
                            x1\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              6\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2 + 
                            x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                          7\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x3 + 
                            x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                          8\[RightDoubleBracket] + 
                      1\/2\ \((\(-x1\)\ x2 + 
                            x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                          9\[RightDoubleBracket] + 
                      1\/6\ \((\(-3\)\ x1\ x3 + 
                            x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          10\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                          12\[RightDoubleBracket] + 
                      1\/4\ \((1 - x2\^2 - x3\^2 + 
                            x2\^2\ x3\^2)\)\ \((\(-1\) + 
                            M\[LeftDoubleBracket]4, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x2\ x3 + 
                            x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                          14\[RightDoubleBracket] + 
                      1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                            M\[LeftDoubleBracket]4, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1 - 10\ x1\^3 + 
                            x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              1\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                            x1\^4\ x2)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              2\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                            x1\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              3\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                            x1\^3\ x2\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              4\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\^3\ x2\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              5\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                            x1\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              6\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                            x1\^2\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              7\[RightDoubleBracket])\) + 
                      1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                            x1\^2\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              8\[RightDoubleBracket])\) + 
                      1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                            x1\^2\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              9\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                            x1\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              10\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                            x1\ x2\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              11\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\^3\ x3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              12\[RightDoubleBracket])\) + 
                      1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                            x1\ x2\^2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                            M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              13\[RightDoubleBracket])\) + 
                      1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                            x1\ x2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              14\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                            x1\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2 - 10\ x2\^3 + 
                            x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                            x2\^4\ x3)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                            x2\^3\ x3\^2)\)\ \((\(-M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                            x2\^2\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                            x2\ x3\^4)\)\ \((\(-6\)\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x3 - 10\ x3\^3 + 
                            x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]5, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                            x1\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              1\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                            x1\^5\ x2)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              2\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                            x1\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              3\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                            6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              4\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                            x1\^4\ x2\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              5\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                            6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              6\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                            x1\^3\ x2\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              7\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 3\ x1\ x2\^2\ x3 + 
                            x1\^3\ x2\^2\ x3)\)\ \
\((\(-M\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              8\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 3\ x1\ x2\ x3\^2 + 
                            x1\^3\ x2\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              9\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                            x1\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              10\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                            6\ x1\^2\ x2\^2 - x2\^4 + x1\^2\ x2\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              11\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\^3\ x3 + 
                            x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              12\[RightDoubleBracket])\) + 
                      1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                            x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                            x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                            M\[LeftDoubleBracket]4, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              13\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - x2\ x3\^3 + 
                            x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              14\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                            6\ x1\^2\ x3\^2 - x3\^4 + x1\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              15\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                            x1\ x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              16\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                            x1\ x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              17\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 3\ x1\ x2\ x3\^2 + 
                            x1\ x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                            3\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              18\[RightDoubleBracket])\) + 
                      1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - x1\ x3\^3 + 
                            x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              19\[RightDoubleBracket])\) + 
                      1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                            x1\ x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              20\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                            x1\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                            x2\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              22\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                            x2\^5\ x3)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              23\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                            6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              24\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                            x2\^3\ x3\^3)\)\ \((\(-3\)\ \
M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              25\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                            6\ x2\^2\ x3\^2 - x3\^4 + x2\^2\ x3\^4)\)\ \((6 - 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              26\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                            x2\ x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              27\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                            x3\^6)\)\ \((30 - 
                            15\ M\[LeftDoubleBracket]4, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]6, 
                              28\[RightDoubleBracket])\) + \(\((\(-105\)\ x1 \
+ 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                            15\ x1\^4\ x2 + 
                            x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              2\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x3 + 45\ x1\^2\ x3 - 
                            15\ x1\^4\ x3 + 
                            x1\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              3\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                            x1\^5\ x2\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              4\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\^3\ x2\ x3 + 
                            x1\^5\ x2\ x3)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              5\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                            15\ x1\ x3\^2 - 10\ x1\^3\ x3\^2 + 
                            x1\^5\ x3\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              6\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 3\ x1\^4\ x2 + 
                            3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                            x1\^4\ x2\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              7\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x3 + 6\ x1\^2\ x3 - x1\^4\ x3 + 
                            3\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 + 
                            x1\^4\ x2\^2\ x3)\)\ \((6\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              8\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x2 + 6\ x1\^2\ x2 - x1\^4\ x2 + 
                            3\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 + 
                            x1\^4\ x2\ x3\^2)\)\ \((6\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 2\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              9\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x3 + 18\ x1\^2\ x3 - 3\ x1\^4\ x3 + 
                            3\ x3\^3 - 6\ x1\^2\ x3\^3 + 
                            x1\^4\ x3\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                3\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              10\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                            6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                            x1\^3\ x2\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                4\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              11\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                            3\ x1\ x2\^3\ x3 + 
                            x1\^3\ x2\^3\ x3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              12\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x1 + x1\^3 + 3\ x1\ x2\^2 - 
                            x1\^3\ x2\^2 + 3\ x1\ x3\^2 - x1\^3\ x3\^2 - 
                            3\ x1\ x2\^2\ x3\^2 + 
                            x1\^3\ x2\^2\ x3\^2)\)\ \
\((M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 6\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              13\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                            3\ x1\ x2\ x3\^3 + 
                            x1\^3\ x2\ x3\^3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              14\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x3\^2 - 
                            6\ x1\^3\ x3\^2 - 3\ x1\ x3\^4 + 
                            x1\^3\ x3\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                1\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                6\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              15\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 10\ x2\^3 - 
                            10\ x1\^2\ x2\^3 - x2\^5 + 
                            x1\^2\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                2\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                7\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              16\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 6\ x2\^2\ x3 - 
                            6\ x1\^2\ x2\^2\ x3 - x2\^4\ x3 + 
                            x1\^2\ x2\^4\ x3)\)\ \((3\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              17\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + x2\^3 - 
                            x1\^2\ x2\^3 + 3\ x2\ x3\^2 - 
                            3\ x1\^2\ x2\ x3\^2 - x2\^3\ x3\^2 + 
                            x1\^2\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              18\[RightDoubleBracket])\) + 
                      1\/24\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 3\ x2\^2\ x3 - 
                            3\ x1\^2\ x2\^2\ x3 + x3\^3 - x1\^2\ x3\^3 - 
                            x2\^2\ x3\^3 + 
                            x1\^2\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]3, 10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 10\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              19\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + 6\ x2\ x3\^2 - 
                            6\ x1\^2\ x2\ x3\^2 - x2\ x3\^4 + 
                            x1\^2\ x2\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              20\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x3 + 15\ x1\^2\ x3 + 10\ x3\^3 - 
                            10\ x1\^2\ x3\^3 - x3\^5 + 
                            x1\^2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                3\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                10\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              21\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                            15\ x1\ x2\^4 + 
                            x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                4\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              22\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\^3\ x3 + 
                            x1\ x2\^5\ x3)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              23\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x1 + 6\ x1\ x2\^2 - x1\ x2\^4 + 
                            3\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 + 
                            x1\ x2\^4\ x3\^2)\)\ \((6\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              24\[RightDoubleBracket])\) + 
                      1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\ x2\^3\ x3 - 
                            3\ x1\ x2\ x3\^3 + 
                            x1\ x2\^3\ x3\^3)\)\ \((9\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              25\[RightDoubleBracket])\) + 
                      1\/48\ \((\(-3\)\ x1 + 3\ x1\ x2\^2 + 6\ x1\ x3\^2 - 
                            6\ x1\ x2\^2\ x3\^2 - x1\ x3\^4 + 
                            x1\ x2\^2\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              26\[RightDoubleBracket])\) + 
                      1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\ x3\^3 + 
                            x1\ x2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                5\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              27\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1 + 45\ x1\ x3\^2 - 
                            15\ x1\ x3\^4 + 
                            x1\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                6\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              28\[RightDoubleBracket])\) + \(\((\(-105\)\ x2 \
+ 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 7\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 29\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x3 + 45\ x2\^2\ x3 - 
                            15\ x2\^4\ x3 + 
                            x2\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              30\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2 + 10\ x2\^3 - x2\^5 + 
                            15\ x2\ x3\^2 - 10\ x2\^3\ x3\^2 + 
                            x2\^5\ x3\^2)\)\ \((10\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              31\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x3 + 18\ x2\^2\ x3 - 3\ x2\^4\ x3 + 
                            3\ x3\^3 - 6\ x2\^2\ x3\^3 + 
                            x2\^4\ x3\^3)\)\ \((18\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                17\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              32\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2 + 3\ x2\^3 + 18\ x2\ x3\^2 - 
                            6\ x2\^3\ x3\^2 - 3\ x2\ x3\^4 + 
                            x2\^3\ x3\^4)\)\ \((3\ M\[LeftDoubleBracket]3, 
                                7\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]5, 
                                18\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]5, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              33\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x3 + 15\ x2\^2\ x3 + 10\ x3\^3 - 
                            10\ x2\^2\ x3\^3 - x3\^5 + 
                            x2\^2\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]3, 
                                8\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]3, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]5, 
                                19\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              34\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x2 + 45\ x2\ x3\^2 - 
                            15\ x2\ x3\^4 + 
                            x2\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                9\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]5, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]7, 
                              35\[RightDoubleBracket])\) + \(\((\(-105\)\ x3 \
+ 105\ x3\^3 - 21\ x3\^5 + x3\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 10\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 36\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ x1\ x2 + 105\ x1\^3\ x2 - \
21\ x1\^5\ x2 + x1\^7\ x2)\)\ \((105\ M\[LeftDoubleBracket]4, 2\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 2\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 2\[RightDoubleBracket])\)\)\/5040 + \(\((\(-105\)\ x1\
\ x3 + 105\ x1\^3\ x3 - 21\ x1\^5\ x3 + x1\^7\ x3)\)\ \((105\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 3\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
3\[RightDoubleBracket])\)\)\/5040 + \(\((15 - 45\ x1\^2 + 15\ x1\^4 - x1\^6 - \
15\ x2\^2 + 45\ x1\^2\ x2\^2 - 15\ x1\^4\ x2\^2 + x1\^6\ x2\^2)\)\ \((\(-45\) \
+ 15\ M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] + 45\ M\
\[LeftDoubleBracket]4, 4\[RightDoubleBracket] - M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, 4\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 4\[RightDoubleBracket])\)\)\/1440 + 
                      1\/720\ \((\(-15\)\ x2\ x3 + 45\ x1\^2\ x2\ x3 - 
                            15\ x1\^4\ x2\ x3 + 
                            x1\^6\ x2\ x3)\)\ \((45\ M\[LeftDoubleBracket]4, 
                                5\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]6, 
                                5\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              5\[RightDoubleBracket])\) + \(\((15 - 45\ x1\^2 \
+ 15\ x1\^4 - x1\^6 - 15\ x3\^2 + 45\ x1\^2\ x3\^2 - 15\ x1\^4\ x3\^2 + x1\^6\
\ x3\^2)\)\ \((\(-45\) + 15\ M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] + \
45\ M\[LeftDoubleBracket]4, 6\[RightDoubleBracket] - M\[LeftDoubleBracket]6, \
1\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, 6\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 6\[RightDoubleBracket])\)\)\/1440 + 
                      1\/720\ \((\(-45\)\ x1\ x2 + 30\ x1\^3\ x2 - 
                            3\ x1\^5\ x2 + 15\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 + 
                            x1\^5\ x2\^3)\)\ \((30\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                2\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                7\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              7\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1\ x3 + 10\ x1\^3\ x3 - 
                            x1\^5\ x3 + 15\ x1\ x2\^2\ x3 - 
                            10\ x1\^3\ x2\^2\ x3 + 
                            x1\^5\ x2\^2\ x3)\)\ \((10\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 3\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                8\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              8\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1\ x2 + 10\ x1\^3\ x2 - 
                            x1\^5\ x2 + 15\ x1\ x2\ x3\^2 - 
                            10\ x1\^3\ x2\ x3\^2 + 
                            x1\^5\ x2\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 2\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                9\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              9\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-45\)\ x1\ x3 + 30\ x1\^3\ x3 - 
                            3\ x1\^5\ x3 + 15\ x1\ x3\^3 - 10\ x1\^3\ x3\^3 + 
                            x1\^5\ x3\^3)\)\ \((30\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                3\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                10\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              10\[RightDoubleBracket])\) + 
                      1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x2\^2 + 
                            36\ x1\^2\ x2\^2 - 6\ x1\^4\ x2\^2 + 3\ x2\^4 - 
                            6\ x1\^2\ x2\^4 + x1\^4\ x2\^4)\)\ \((\(-27\) + 
                            3\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            36\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                4\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                11\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              11\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2\ x3 + 18\ x1\^2\ x2\ x3 - 
                            3\ x1\^4\ x2\ x3 + 3\ x2\^3\ x3 - 
                            6\ x1\^2\ x2\^3\ x3 + 
                            x1\^4\ x2\^3\ x3)\)\ \((18\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                5\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                12\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              12\[RightDoubleBracket])\) + 
                      1\/96\ \((3 - 6\ x1\^2 + x1\^4 - 3\ x2\^2 + 
                            6\ x1\^2\ x2\^2 - x1\^4\ x2\^2 - 3\ x3\^2 + 
                            6\ x1\^2\ x3\^2 - x1\^4\ x3\^2 + 
                            3\ x2\^2\ x3\^2 - 6\ x1\^2\ x2\^2\ x3\^2 + 
                            x1\^4\ x2\^2\ x3\^2)\)\ \((\(-9\) + 
                            M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 4\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              13\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x2\ x3 + 18\ x1\^2\ x2\ x3 - 
                            3\ x1\^4\ x2\ x3 + 3\ x2\ x3\^3 - 
                            6\ x1\^2\ x2\ x3\^3 + 
                            x1\^4\ x2\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                5\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                14\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              14\[RightDoubleBracket])\) + 
                      1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x3\^2 + 
                            36\ x1\^2\ x3\^2 - 6\ x1\^4\ x3\^2 + 3\ x3\^4 - 
                            6\ x1\^2\ x3\^4 + x1\^4\ x3\^4)\)\ \((\(-27\) + 
                            3\ M\[LeftDoubleBracket]4, 
                                1\[RightDoubleBracket] + 
                            36\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                15\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                6\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                15\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              15\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-45\)\ x1\ x2 + 15\ x1\^3\ x2 + 
                            30\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 - 3\ x1\ x2\^5 + 
                            x1\^3\ x2\^5)\)\ \((15\ M\[LeftDoubleBracket]4, 
                                2\[RightDoubleBracket] + 
                            30\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                16\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              16\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1\ x3 + 3\ x1\^3\ x3 + 
                            18\ x1\ x2\^2\ x3 - 6\ x1\^3\ x2\^2\ x3 - 
                            3\ x1\ x2\^4\ x3 + 
                            x1\^3\ x2\^4\ x3)\)\ \((3\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                8\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              17\[RightDoubleBracket])\) + 
                      1\/72\ \((\(-9\)\ x1\ x2 + 3\ x1\^3\ x2 + 
                            3\ x1\ x2\^3 - x1\^3\ x2\^3 + 9\ x1\ x2\ x3\^2 - 
                            3\ x1\^3\ x2\ x3\^2 - 3\ x1\ x2\^3\ x3\^2 + 
                            x1\^3\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                7\[RightDoubleBracket] + 
                            9\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 7\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                9\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              18\[RightDoubleBracket])\) + 
                      1\/72\ \((\(-9\)\ x1\ x3 + 3\ x1\^3\ x3 + 
                            9\ x1\ x2\^2\ x3 - 3\ x1\^3\ x2\^2\ x3 + 
                            3\ x1\ x3\^3 - x1\^3\ x3\^3 - 
                            3\ x1\ x2\^2\ x3\^3 + 
                            x1\^3\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                            9\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                8\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              19\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1\ x2 + 3\ x1\^3\ x2 + 
                            18\ x1\ x2\ x3\^2 - 6\ x1\^3\ x2\ x3\^2 - 
                            3\ x1\ x2\ x3\^4 + 
                            x1\^3\ x2\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                9\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              20\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-45\)\ x1\ x3 + 15\ x1\^3\ x3 + 
                            30\ x1\ x3\^3 - 10\ x1\^3\ x3\^3 - 3\ x1\ x3\^5 + 
                            x1\^3\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]4, 
                                3\[RightDoubleBracket] + 
                            30\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              21\[RightDoubleBracket])\) + \(\((15 - 15\ \
x1\^2 - 45\ x2\^2 + 45\ x1\^2\ x2\^2 + 15\ x2\^4 - 15\ x1\^2\ x2\^4 - x2\^6 + \
x1\^2\ x2\^6)\)\ \((\(-45\) + 45\ M\[LeftDoubleBracket]4, 4\
\[RightDoubleBracket] + 15\ M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] - \
15\ M\[LeftDoubleBracket]6, 11\[RightDoubleBracket] - M\[LeftDoubleBracket]6, \
22\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
22\[RightDoubleBracket])\)\)\/1440 + 
                      1\/240\ \((\(-15\)\ x2\ x3 + 15\ x1\^2\ x2\ x3 + 
                            10\ x2\^3\ x3 - 10\ x1\^2\ x2\^3\ x3 - 
                            x2\^5\ x3 + 
                            x1\^2\ x2\^5\ x3)\)\ \((15\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                12\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 23\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              23\[RightDoubleBracket])\) + 
                      1\/96\ \((3 - 3\ x1\^2 - 6\ x2\^2 + 6\ x1\^2\ x2\^2 + 
                            x2\^4 - x1\^2\ x2\^4 - 3\ x3\^2 + 
                            3\ x1\^2\ x3\^2 + 6\ x2\^2\ x3\^2 - 
                            6\ x1\^2\ x2\^2\ x3\^2 - x2\^4\ x3\^2 + 
                            x1\^2\ x2\^4\ x3\^2)\)\ \((\(-9\) + 
                            6\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]4, 11\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 11\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 24\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              24\[RightDoubleBracket])\) + 
                      1\/72\ \((\(-9\)\ x2\ x3 + 9\ x1\^2\ x2\ x3 + 
                            3\ x2\^3\ x3 - 3\ x1\^2\ x2\^3\ x3 + 
                            3\ x2\ x3\^3 - 3\ x1\^2\ x2\ x3\^3 - 
                            x2\^3\ x3\^3 + 
                            x1\^2\ x2\^3\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                12\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                14\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 25\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              25\[RightDoubleBracket])\) + 
                      1\/96\ \((3 - 3\ x1\^2 - 3\ x2\^2 + 3\ x1\^2\ x2\^2 - 
                            6\ x3\^2 + 6\ x1\^2\ x3\^2 + 6\ x2\^2\ x3\^2 - 
                            6\ x1\^2\ x2\^2\ x3\^2 + x3\^4 - x1\^2\ x3\^4 - 
                            x2\^2\ x3\^4 + 
                            x1\^2\ x2\^2\ x3\^4)\)\ \((\(-9\) + 
                            3\ M\[LeftDoubleBracket]4, 
                                4\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]4, 
                                6\[RightDoubleBracket] + 
                            6\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                13\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 15\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 26\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              26\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x2\ x3 + 15\ x1\^2\ x2\ x3 + 
                            10\ x2\ x3\^3 - 10\ x1\^2\ x2\ x3\^3 - 
                            x2\ x3\^5 + 
                            x1\^2\ x2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                14\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 27\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              27\[RightDoubleBracket])\) + \(\((15 - 15\ \
x1\^2 - 45\ x3\^2 + 45\ x1\^2\ x3\^2 + 15\ x3\^4 - 15\ x1\^2\ x3\^4 - x3\^6 + \
x1\^2\ x3\^6)\)\ \((\(-45\) + 45\ M\[LeftDoubleBracket]4, 6\
\[RightDoubleBracket] + 15\ M\[LeftDoubleBracket]4, 15\[RightDoubleBracket] - \
15\ M\[LeftDoubleBracket]6, 15\[RightDoubleBracket] - M\[LeftDoubleBracket]6, \
28\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
28\[RightDoubleBracket])\)\)\/1440 + \(\((\(-105\)\ x1\ x2 + 105\ x1\ x2\^3 - \
21\ x1\ x2\^5 + x1\ x2\^7)\)\ \((105\ M\[LeftDoubleBracket]4, 7\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 16\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 29\[RightDoubleBracket])\)\)\/5040 + 
                      1\/720\ \((\(-15\)\ x1\ x3 + 45\ x1\ x2\^2\ x3 - 
                            15\ x1\ x2\^4\ x3 + 
                            x1\ x2\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]4, 
                                8\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]6, 
                                17\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              30\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1\ x2 + 10\ x1\ x2\^3 - 
                            x1\ x2\^5 + 15\ x1\ x2\ x3\^2 - 
                            10\ x1\ x2\^3\ x3\^2 + 
                            x1\ x2\^5\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 16\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                18\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              31\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1\ x3 + 18\ x1\ x2\^2\ x3 - 
                            3\ x1\ x2\^4\ x3 + 3\ x1\ x3\^3 - 
                            6\ x1\ x2\^2\ x3\^3 + 
                            x1\ x2\^4\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                17\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                19\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              32\[RightDoubleBracket])\) + 
                      1\/144\ \((\(-9\)\ x1\ x2 + 3\ x1\ x2\^3 + 
                            18\ x1\ x2\ x3\^2 - 6\ x1\ x2\^3\ x3\^2 - 
                            3\ x1\ x2\ x3\^4 + 
                            x1\ x2\^3\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                            18\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                18\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              33\[RightDoubleBracket])\) + 
                      1\/240\ \((\(-15\)\ x1\ x3 + 15\ x1\ x2\^2\ x3 + 
                            10\ x1\ x3\^3 - 10\ x1\ x2\^2\ x3\^3 - 
                            x1\ x3\^5 + 
                            x1\ x2\^2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                            10\ M\[LeftDoubleBracket]4, 
                                10\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                19\[RightDoubleBracket] - 
                            M\[LeftDoubleBracket]6, 21\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              34\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-15\)\ x1\ x2 + 45\ x1\ x2\ x3\^2 - 
                            15\ x1\ x2\ x3\^4 + 
                            x1\ x2\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]4, 
                                9\[RightDoubleBracket] - 
                            15\ M\[LeftDoubleBracket]6, 
                                20\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              35\[RightDoubleBracket])\) + \(\((\(-105\)\ x1\ \
x3 + 105\ x1\ x3\^3 - 21\ x1\ x3\^5 + x1\ x3\^7)\)\ \((105\ M\
\[LeftDoubleBracket]4, 10\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, \
21\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
36\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ x2\^2 + 210\ x2\^4 - 28\ \
x2\^6 + x2\^8)\)\ \((\(-315\) + 210\ M\[LeftDoubleBracket]4, 11\
\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 22\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 37\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ \
x2\ x3 + 105\ x2\^3\ x3 - 21\ x2\^5\ x3 + x2\^7\ x3)\)\ \((105\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, \
23\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
38\[RightDoubleBracket])\)\)\/5040 + \(\(1\/1440\)\((\((15 - 45\ x2\^2 + 
                              15\ x2\^4 - x2\^6 - 15\ x3\^2 + 
                              45\ x2\^2\ x3\^2 - 15\ x2\^4\ x3\^2 + 
                              x2\^6\ x3\^2)\)\ \((\(-45\) + 
                              15\ M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] + 
                              45\ M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket] - 
                              M\[LeftDoubleBracket]6, 
                                22\[RightDoubleBracket] - 
                              15\ M\[LeftDoubleBracket]6, 
                                  24\[RightDoubleBracket] + 
                              M\[LeftDoubleBracket]8, 
                                39\[RightDoubleBracket])\))\)\) + 
                      1\/720\ \((\(-45\)\ x2\ x3 + 30\ x2\^3\ x3 - 
                            3\ x2\^5\ x3 + 15\ x2\ x3\^3 - 10\ x2\^3\ x3\^3 + 
                            x2\^5\ x3\^3)\)\ \((30\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            15\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                23\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                25\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              40\[RightDoubleBracket])\) + 
                      1\/576\ \((9 - 18\ x2\^2 + 3\ x2\^4 - 18\ x3\^2 + 
                            36\ x2\^2\ x3\^2 - 6\ x2\^4\ x3\^2 + 3\ x3\^4 - 
                            6\ x2\^2\ x3\^4 + x2\^4\ x3\^4)\)\ \((\(-27\) + 
                            3\ M\[LeftDoubleBracket]4, 
                                11\[RightDoubleBracket] + 
                            36\ M\[LeftDoubleBracket]4, 
                                13\[RightDoubleBracket] + 
                            3\ M\[LeftDoubleBracket]4, 
                                15\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                24\[RightDoubleBracket] - 
                            6\ M\[LeftDoubleBracket]6, 
                                26\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              41\[RightDoubleBracket])\) + 
                      1\/720\ \((\(-45\)\ x2\ x3 + 15\ x2\^3\ x3 + 
                            30\ x2\ x3\^3 - 10\ x2\^3\ x3\^3 - 3\ x2\ x3\^5 + 
                            x2\^3\ x3\^5)\)\ \((15\ M\[LeftDoubleBracket]4, 
                                12\[RightDoubleBracket] + 
                            30\ M\[LeftDoubleBracket]4, 
                                14\[RightDoubleBracket] - 
                            10\ M\[LeftDoubleBracket]6, 
                                25\[RightDoubleBracket] - 
                            3\ M\[LeftDoubleBracket]6, 
                                27\[RightDoubleBracket] + 
                            M\[LeftDoubleBracket]8, 
                              42\[RightDoubleBracket])\) + \
\(\(1\/1440\)\((\((15 - 15\ x2\^2 - 45\ x3\^2 + 45\ x2\^2\ x3\^2 + 
                              15\ x3\^4 - 15\ x2\^2\ x3\^4 - x3\^6 + 
                              x2\^2\ x3\^6)\)\ \((\(-45\) + 
                              45\ M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket] + 
                              15\ M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] - 
                              15\ M\[LeftDoubleBracket]6, 
                                  26\[RightDoubleBracket] - 
                              M\[LeftDoubleBracket]6, 
                                28\[RightDoubleBracket] + 
                              M\[LeftDoubleBracket]8, 
                                43\[RightDoubleBracket])\))\)\) + \(\((\(-105\
\)\ x2\ x3 + 105\ x2\ x3\^3 - 21\ x2\ x3\^5 + x2\ x3\^7)\)\ \((105\ M\
\[LeftDoubleBracket]4, 14\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, \
27\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
44\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ x3\^2 + 210\ x3\^4 - 28\ \
x3\^6 + x3\^8)\)\ \((\(-315\) + 210\ M\[LeftDoubleBracket]4, 15\
\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 28\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 45\[RightDoubleBracket])\)\)\/40320\)},
                {" "},
                {\(HermiteStand[1, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\)},
                {" "},
                {\(HermiteStand[2, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\)},
                {" "},
                {\(HermiteStand[3, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket])\)\)},
                {" "},
                {\(HermiteStand[4, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket])\) + 
                          1\/2\ \((\(-x2\)\ x3 + 
                                x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x3\^2 + 
                                x1\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x3 + 
                                x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x2 + 
                                x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              12\[RightDoubleBracket] + 
                          1\/4\ \((1 - x2\^2 - x3\^2 + 
                                x2\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              14\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[5, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket])\) + 
                          1\/2\ \((\(-x2\)\ x3 + 
                                x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x3\^2 + 
                                x1\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x3 + 
                                x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x2 + 
                                x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              12\[RightDoubleBracket] + 
                          1\/4\ \((1 - x2\^2 - x3\^2 + 
                                x2\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              14\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                                x1\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\^3\ x2\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                                x1\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket])\) + 
                          1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                                x1\^2\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  8\[RightDoubleBracket])\) + 
                          1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                                x1\^2\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  9\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                                x1\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  12\[RightDoubleBracket])\) + 
                          1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                                x1\ x2\^2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  14\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                                x1\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                                x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                                x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                                x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                                x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x3 - 10\ x3\^3 + 
                                x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[6, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket])\) + 
                          1\/2\ \((\(-x2\)\ x3 + 
                                x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x3\^2 + 
                                x1\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x3 + 
                                x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x2 + 
                                x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              12\[RightDoubleBracket] + 
                          1\/4\ \((1 - x2\^2 - x3\^2 + 
                                x2\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              14\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                                x1\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\^3\ x2\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                                x1\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket])\) + 
                          1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                                x1\^2\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  8\[RightDoubleBracket])\) + 
                          1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                                x1\^2\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  9\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                                x1\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  12\[RightDoubleBracket])\) + 
                          1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                                x1\ x2\^2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  14\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                                x1\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                                x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                                x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                                x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                                x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x3 - 10\ x3\^3 + 
                                x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                                x1\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                                x1\^4\ x2\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                                6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 
                                3\ x1\ x2\^2\ x3 + 
                                x1\^3\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  8\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\^3\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  9\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                                x1\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  10\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  11\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\^3\ x3 + 
                                x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  12\[RightDoubleBracket])\) + 
                          1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                                x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                                x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  13\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\ x3\^3 + 
                                x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  14\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                                6\ x1\^2\ x3\^2 - x3\^4 + 
                                x1\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                                x1\ x2\^4\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\ x2\^3\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - 
                                x1\ x3\^3 + 
                                x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                                x1\ x2\ x3\^4)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                                x1\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  22\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                                x2\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  23\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                                6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  24\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                                x2\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  25\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                                6\ x2\^2\ x3\^2 - x3\^4 + 
                                x2\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  26\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                                x2\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  27\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                                x3\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  28\[RightDoubleBracket])\))\)\)},
                {" "},
                {\(HermiteStand[7, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket])\) + 
                          1\/2\ \((\(-x2\)\ x3 + 
                                x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x3\^2 + 
                                x1\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x3 + 
                                x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x2 + 
                                x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              12\[RightDoubleBracket] + 
                          1\/4\ \((1 - x2\^2 - x3\^2 + 
                                x2\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              14\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                                x1\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\^3\ x2\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                                x1\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket])\) + 
                          1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                                x1\^2\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  8\[RightDoubleBracket])\) + 
                          1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                                x1\^2\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  9\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                                x1\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  12\[RightDoubleBracket])\) + 
                          1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                                x1\ x2\^2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  14\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                                x1\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                                x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                                x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                                x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                                x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x3 - 10\ x3\^3 + 
                                x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                                x1\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                                x1\^4\ x2\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                                6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 
                                3\ x1\ x2\^2\ x3 + 
                                x1\^3\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  8\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\^3\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  9\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                                x1\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  10\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  11\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\^3\ x3 + 
                                x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  12\[RightDoubleBracket])\) + 
                          1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                                x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                                x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  13\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\ x3\^3 + 
                                x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  14\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                                6\ x1\^2\ x3\^2 - x3\^4 + 
                                x1\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                                x1\ x2\^4\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\ x2\^3\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - 
                                x1\ x3\^3 + 
                                x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                                x1\ x2\ x3\^4)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                                
                                x1\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  22\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                                x2\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  23\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                                6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  24\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                                x2\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  25\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                                6\ x2\^2\ x3\^2 - x3\^4 + 
                                x2\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  26\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                                x2\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  27\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                                x3\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  28\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                                15\ x1\^4\ x2 + 
                                x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    2\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  2\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x3 + 45\ x1\^2\ x3 - 
                                15\ x1\^4\ x3 + 
                                x1\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  3\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                                x1\^5\ x2\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  4\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\^3\ x2\ x3 + 
                                x1\^5\ x2\ x3)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  5\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x3\^2 - 10\ x1\^3\ x3\^2 + 
                                x1\^5\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  6\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 
                                3\ x1\^4\ x2 + 3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                                x1\^4\ x2\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  7\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x3 + 6\ x1\^2\ x3 - x1\^4\ x3 + 
                                3\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 + 
                                x1\^4\ x2\^2\ x3)\)\ \((6\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  8\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x2 + 6\ x1\^2\ x2 - x1\^4\ x2 + 
                                3\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 + 
                                x1\^4\ x2\ x3\^2)\)\ \((6\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  9\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x3 + 18\ x1\^2\ x3 - 
                                3\ x1\^4\ x3 + 3\ x3\^3 - 6\ x1\^2\ x3\^3 + 
                                x1\^4\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  10\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                                6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                                x1\^3\ x2\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  11\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                                3\ x1\ x2\^3\ x3 + 
                                x1\^3\ x2\^3\ x3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  12\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x1 + x1\^3 + 3\ x1\ x2\^2 - 
                                x1\^3\ x2\^2 + 3\ x1\ x3\^2 - x1\^3\ x3\^2 - 
                                3\ x1\ x2\^2\ x3\^2 + 
                                x1\^3\ x2\^2\ x3\^2)\)\ \((M\
\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  13\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                                3\ x1\ x2\ x3\^3 + 
                                x1\^3\ x2\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  14\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x3\^2 - 
                                6\ x1\^3\ x3\^2 - 3\ x1\ x3\^4 + 
                                x1\^3\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    6\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  15\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 
                                10\ x2\^3 - 10\ x1\^2\ x2\^3 - x2\^5 + 
                                x1\^2\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    7\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  16\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 
                                6\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 - 
                                x2\^4\ x3 + 
                                x1\^2\ x2\^4\ x3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  17\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + x2\^3 - 
                                x1\^2\ x2\^3 + 3\ x2\ x3\^2 - 
                                3\ x1\^2\ x2\ x3\^2 - x2\^3\ x3\^2 + 
                                x1\^2\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  18\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 
                                3\ x2\^2\ x3 - 3\ x1\^2\ x2\^2\ x3 + x3\^3 - 
                                x1\^2\ x3\^3 - x2\^2\ x3\^3 + 
                                x1\^2\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  19\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + 
                                6\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 - 
                                x2\ x3\^4 + 
                                x1\^2\ x2\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  20\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x3 + 15\ x1\^2\ x3 + 
                                10\ x3\^3 - 10\ x1\^2\ x3\^3 - x3\^5 + 
                                x1\^2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    10\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                                15\ x1\ x2\^4 + 
                                x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  22\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\^3\ x3 + 
                                x1\ x2\^5\ x3)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  23\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x1 + 6\ x1\ x2\^2 - x1\ x2\^4 + 
                                3\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 + 
                                x1\ x2\^4\ x3\^2)\)\ \((6\ M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  24\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\ x2\^3\ x3 - 
                                3\ x1\ x2\ x3\^3 + 
                                x1\ x2\^3\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  25\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x1 + 3\ x1\ x2\^2 + 
                                6\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 - 
                                x1\ x3\^4 + 
                                x1\ x2\^2\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  26\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\ x3\^3 + 
                                x1\ x2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  27\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x3\^2 - 
                                15\ x1\ x3\^4 + 
                                x1\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  28\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x2 + 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 7\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 29\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x3 + 45\ x2\^2\ x3 - 
                                15\ x2\^4\ x3 + 
                                x2\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  30\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 10\ x2\^3 - x2\^5 + 
                                15\ x2\ x3\^2 - 10\ x2\^3\ x3\^2 + 
                                x2\^5\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  31\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x3 + 18\ x2\^2\ x3 - 
                                3\ x2\^4\ x3 + 3\ x3\^3 - 6\ x2\^2\ x3\^3 + 
                                x2\^4\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    17\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  32\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 3\ x2\^3 + 18\ x2\ x3\^2 - 
                                6\ x2\^3\ x3\^2 - 3\ x2\ x3\^4 + 
                                x2\^3\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    18\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  33\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x3 + 15\ x2\^2\ x3 + 
                                10\ x3\^3 - 10\ x2\^2\ x3\^3 - x3\^5 + 
                                x2\^2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    19\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  34\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x2\ x3\^2 - 
                                15\ x2\ x3\^4 + 
                                x2\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  35\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x3 + 105\ x3\^3 - 21\ x3\^5 + x3\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 10\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 36\[RightDoubleBracket])\)\)\/5040)\)\)},
                {" "},
                {\(HermiteStand[8, {x1_, x2_, x3_}, M_, "phiH"] = 
                    0.06349363593424097`\ 2.718281828459045`\^\(\(-0.5`\)\ \
\((x1\^2 + x2\^2 + x3\^2)\)\)\ \((1 + 
                          1\/6\ \((\(-3\)\ x1 + 
                                x1\^3)\)\ M\[LeftDoubleBracket]3, 
                              1\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x1\^2\ x2)\)\ M\[LeftDoubleBracket]3, 
                              2\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x1\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              3\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x2\^2)\)\ M\[LeftDoubleBracket]3, 
                              4\[RightDoubleBracket] + 
                          x1\ x2\ x3\ M\[LeftDoubleBracket]3, 
                              5\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\) + 
                                x1\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              6\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x2 + 
                                x2\^3)\)\ M\[LeftDoubleBracket]3, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x3\) + 
                                x2\^2\ x3)\)\ M\[LeftDoubleBracket]3, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x2\) + 
                                x2\ x3\^2)\)\ M\[LeftDoubleBracket]3, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x3 + 
                                x3\^3)\)\ M\[LeftDoubleBracket]3, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x1\^2 + x1\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\^3\ x2)\)\ M\[LeftDoubleBracket]4, 
                              2\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              3\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x2\^2 + 
                                x1\^2\ x2\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket])\) + 
                          1\/2\ \((\(-x2\)\ x3 + 
                                x1\^2\ x2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              5\[RightDoubleBracket] + 
                          1\/4\ \((1 - x1\^2 - x3\^2 + 
                                x1\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2 + 
                                x1\ x2\^3)\)\ M\[LeftDoubleBracket]4, 
                              7\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x3 + 
                                x1\ x2\^2\ x3)\)\ M\[LeftDoubleBracket]4, 
                              8\[RightDoubleBracket] + 
                          1\/2\ \((\(-x1\)\ x2 + 
                                x1\ x2\ x3\^2)\)\ M\[LeftDoubleBracket]4, 
                              9\[RightDoubleBracket] + 
                          1\/6\ \((\(-3\)\ x1\ x3 + 
                                x1\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              10\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x2\^2 + x2\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\^3\ x3)\)\ M\[LeftDoubleBracket]4, 
                              12\[RightDoubleBracket] + 
                          1\/4\ \((1 - x2\^2 - x3\^2 + 
                                x2\^2\ x3\^2)\)\ \((\(-1\) + 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x2\ x3 + 
                                x2\ x3\^3)\)\ M\[LeftDoubleBracket]4, 
                              14\[RightDoubleBracket] + 
                          1\/24\ \((3 - 6\ x3\^2 + x3\^4)\)\ \((\(-3\) + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1 - 10\ x1\^3 + 
                                x1\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x1\^2\ x2 + 
                                x1\^4\ x2)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x1\^2\ x3 + 
                                x1\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x2\^2 + 
                                x1\^3\ x2\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\^3\ x2\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  5\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1 - x1\^3 - 3\ x1\ x3\^2 + 
                                x1\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 1\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - 3\ x1\^2\ x2 - x2\^3 + 
                                x1\^2\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket])\) + 
                          1\/4\ \((x3 - x1\^2\ x3 - x2\^2\ x3 + 
                                x1\^2\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  8\[RightDoubleBracket])\) + 
                          1\/4\ \((x2 - x1\^2\ x2 - x2\ x3\^2 + 
                                x1\^2\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  9\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x1\^2\ x3 - x3\^3 + 
                                x1\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x2\^2 + 
                                x1\ x2\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  12\[RightDoubleBracket])\) + 
                          1\/4\ \((x1 - x1\ x2\^2 - x1\ x3\^2 + 
                                x1\ x2\^2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket]\) - 
                                M\[LeftDoubleBracket]3, 
                                  6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  13\[RightDoubleBracket])\) + 
                          1\/6\ \((\(-3\)\ x1\ x2\ x3 + 
                                x1\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  14\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1 - 6\ x1\ x3\^2 + 
                                x1\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2 - 10\ x2\^3 + 
                                x2\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x3 - 6\ x2\^2\ x3 + 
                                x2\^4\ x3)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2 - x2\^3 - 3\ x2\ x3\^2 + 
                                x2\^3\ x3\^2)\)\ \
\((\(-M\[LeftDoubleBracket]3, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x3 - 3\ x2\^2\ x3 - x3\^3 + 
                                x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]3, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2 - 6\ x2\ x3\^2 + 
                                x2\ x3\^4)\)\ \((\(-6\)\ \
M\[LeftDoubleBracket]3, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x3 - 10\ x3\^3 + 
                                x3\^5)\)\ \((\(-10\)\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x1\^2 - 15\ x1\^4 + 
                                x1\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  1\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\^3\ x2 + 
                                x1\^5\ x2)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\^3\ x3 + 
                                x1\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x2\^2 - 
                                6\ x1\^2\ x2\^2 + x1\^4\ x2\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x2\ x3 - 6\ x1\^2\ x2\ x3 + 
                                x1\^4\ x2\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  5\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x1\^2 - x1\^4 + 3\ x3\^2 - 
                                6\ x1\^2\ x3\^2 + x1\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2 - 3\ x1\^3\ x2 - 3\ x1\ x2\^3 + 
                                x1\^3\ x2\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - x1\^3\ x3 - 
                                3\ x1\ x2\^2\ x3 + 
                                x1\^3\ x2\^2\ x3)\)\ \((\(-M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  8\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\^3\ x2 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\^3\ x2\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  9\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x3 - 3\ x1\^3\ x3 - 3\ x1\ x3\^3 + 
                                x1\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  10\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x2\^2 - 
                                6\ x1\^2\ x2\^2 - x2\^4 + 
                                x1\^2\ x2\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  11\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\^3\ x3 + 
                                x1\^2\ x2\^3\ x3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  12\[RightDoubleBracket])\) + 
                          1\/8\ \((\(-1\) + x1\^2 + x2\^2 - x1\^2\ x2\^2 + 
                                x3\^2 - x1\^2\ x3\^2 - x2\^2\ x3\^2 + 
                                x1\^2\ x2\^2\ x3\^2)\)\ \((2 - 
                                M\[LeftDoubleBracket]4, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  13\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x2\ x3 - 3\ x1\^2\ x2\ x3 - 
                                x2\ x3\^3 + 
                                x1\^2\ x2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  14\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x1\^2 + 6\ x3\^2 - 
                                6\ x1\^2\ x3\^2 - x3\^4 + 
                                x1\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  15\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2 - 10\ x1\ x2\^3 + 
                                x1\ x2\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  16\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x3 - 6\ x1\ x2\^2\ x3 + 
                                x1\ x2\^4\ x3)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  17\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x2 - x1\ x2\^3 - 
                                3\ x1\ x2\ x3\^2 + 
                                x1\ x2\^3\ x3\^2)\)\ \((\(-M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket]\) - 
                                3\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  18\[RightDoubleBracket])\) + 
                          1\/12\ \((3\ x1\ x3 - 3\ x1\ x2\^2\ x3 - 
                                x1\ x3\^3 + 
                                x1\ x2\^2\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  19\[RightDoubleBracket])\) + 
                          1\/24\ \((3\ x1\ x2 - 6\ x1\ x2\ x3\^2 + 
                                x1\ x2\ x3\^4)\)\ \((\(-6\)\ M\
\[LeftDoubleBracket]4, 9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  20\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x3 - 10\ x1\ x3\^3 + 
                                x1\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x2\^2 - 15\ x2\^4 + 
                                x2\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  22\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\^3\ x3 + 
                                x2\^5\ x3)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  23\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 6\ x2\^2 - x2\^4 + 3\ x3\^2 - 
                                6\ x2\^2\ x3\^2 + x2\^4\ x3\^2)\)\ \((6 - 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  24\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x2\ x3 - 3\ x2\^3\ x3 - 3\ x2\ x3\^3 + 
                                x2\^3\ x3\^3)\)\ \((\(-3\)\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  25\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\) + 3\ x2\^2 + 6\ x3\^2 - 
                                6\ x2\^2\ x3\^2 - x3\^4 + 
                                x2\^2\ x3\^4)\)\ \((6 - 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  26\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x2\ x3 - 10\ x2\ x3\^3 + 
                                x2\ x3\^5)\)\ \((\(-10\)\ M\
\[LeftDoubleBracket]4, 14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  27\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\) + 45\ x3\^2 - 15\ x3\^4 + 
                                x3\^6)\)\ \((30 - 
                                15\ M\[LeftDoubleBracket]4, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]6, 
                                  28\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1 + 105\ x1\^3 - 21\ x1\^5 + x1\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 1\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 1\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 1\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x1\^2\ x2 - 
                                15\ x1\^4\ x2 + 
                                x1\^6\ x2)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    2\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  2\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x3 + 45\ x1\^2\ x3 - 
                                15\ x1\^4\ x3 + 
                                x1\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    3\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  3\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x2\^2 - 10\ x1\^3\ x2\^2 + 
                                x1\^5\ x2\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  4\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\^3\ x2\ x3 + 
                                x1\^5\ x2\ x3)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  5\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1 + 10\ x1\^3 - x1\^5 + 
                                15\ x1\ x3\^2 - 10\ x1\^3\ x3\^2 + 
                                x1\^5\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  1\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  6\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 18\ x1\^2\ x2 - 
                                3\ x1\^4\ x2 + 3\ x2\^3 - 6\ x1\^2\ x2\^3 + 
                                x1\^4\ x2\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  7\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x3 + 6\ x1\^2\ x3 - x1\^4\ x3 + 
                                3\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 + 
                                x1\^4\ x2\^2\ x3)\)\ \((6\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  8\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x2 + 6\ x1\^2\ x2 - x1\^4\ x2 + 
                                3\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 + 
                                x1\^4\ x2\ x3\^2)\)\ \((6\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  2\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  9\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x3 + 18\ x1\^2\ x3 - 
                                3\ x1\^4\ x3 + 3\ x3\^3 - 6\ x1\^2\ x3\^3 + 
                                x1\^4\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    3\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  10\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x2\^2 - 
                                6\ x1\^3\ x2\^2 - 3\ x1\ x2\^4 + 
                                x1\^3\ x2\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    4\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  11\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                                3\ x1\ x2\^3\ x3 + 
                                x1\^3\ x2\^3\ x3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  12\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x1 + x1\^3 + 3\ x1\ x2\^2 - 
                                x1\^3\ x2\^2 + 3\ x1\ x3\^2 - x1\^3\ x3\^2 - 
                                3\ x1\ x2\^2\ x3\^2 + 
                                x1\^3\ x2\^2\ x3\^2)\)\ \((M\
\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  6\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  13\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\^3\ x2\ x3 - 
                                3\ x1\ x2\ x3\^3 + 
                                x1\^3\ x2\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  14\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1 + 3\ x1\^3 + 18\ x1\ x3\^2 - 
                                6\ x1\^3\ x3\^2 - 3\ x1\ x3\^4 + 
                                x1\^3\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 1\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    6\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  15\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 15\ x1\^2\ x2 + 
                                10\ x2\^3 - 10\ x1\^2\ x2\^3 - x2\^5 + 
                                x1\^2\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    7\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    7\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  16\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 
                                6\ x2\^2\ x3 - 6\ x1\^2\ x2\^2\ x3 - 
                                x2\^4\ x3 + 
                                x1\^2\ x2\^4\ x3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  17\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + x2\^3 - 
                                x1\^2\ x2\^3 + 3\ x2\ x3\^2 - 
                                3\ x1\^2\ x2\ x3\^2 - x2\^3\ x3\^2 + 
                                x1\^2\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]3, 
                                  7\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  18\[RightDoubleBracket])\) + 
                          1\/24\ \((\(-3\)\ x3 + 3\ x1\^2\ x3 + 
                                3\ x2\^2\ x3 - 3\ x1\^2\ x2\^2\ x3 + x3\^3 - 
                                x1\^2\ x3\^3 - x2\^2\ x3\^3 + 
                                x1\^2\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]3, 
                                  10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  10\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  19\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x2 + 3\ x1\^2\ x2 + 
                                6\ x2\ x3\^2 - 6\ x1\^2\ x2\ x3\^2 - 
                                x2\ x3\^4 + 
                                x1\^2\ x2\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]3, 2\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  20\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x3 + 15\ x1\^2\ x3 + 
                                10\ x3\^3 - 10\ x1\^2\ x3\^3 - x3\^5 + 
                                x1\^2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 3\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    10\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  21\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x2\^2 - 
                                15\ x1\ x2\^4 + 
                                x1\ x2\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    4\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  22\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\^3\ x3 + 
                                x1\ x2\^5\ x3)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  23\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x1 + 6\ x1\ x2\^2 - x1\ x2\^4 + 
                                3\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 + 
                                x1\ x2\^4\ x3\^2)\)\ \((6\ M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  24\[RightDoubleBracket])\) + 
                          1\/36\ \((9\ x1\ x2\ x3 - 3\ x1\ x2\^3\ x3 - 
                                3\ x1\ x2\ x3\^3 + 
                                x1\ x2\^3\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  25\[RightDoubleBracket])\) + 
                          1\/48\ \((\(-3\)\ x1 + 3\ x1\ x2\^2 + 
                                6\ x1\ x3\^2 - 6\ x1\ x2\^2\ x3\^2 - 
                                x1\ x3\^4 + 
                                x1\ x2\^2\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]3, 4\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  26\[RightDoubleBracket])\) + 
                          1\/120\ \((15\ x1\ x2\ x3 - 10\ x1\ x2\ x3\^3 + 
                                x1\ x2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 5\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  27\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1 + 45\ x1\ x3\^2 - 
                                15\ x1\ x3\^4 + 
                                x1\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    6\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  28\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x2 + 105\ x2\^3 - 21\ x2\^5 + x2\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 7\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 16\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 29\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x3 + 45\ x2\^2\ x3 - 
                                15\ x2\^4\ x3 + 
                                x2\^6\ x3)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    8\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  30\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2 + 10\ x2\^3 - x2\^5 + 
                                15\ x2\ x3\^2 - 10\ x2\^3\ x3\^2 + 
                                x2\^5\ x3\^2)\)\ \((10\ \
M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  16\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  31\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x3 + 18\ x2\^2\ x3 - 
                                3\ x2\^4\ x3 + 3\ x3\^3 - 6\ x2\^2\ x3\^3 + 
                                x2\^4\ x3\^3)\)\ \((18\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    17\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  32\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2 + 3\ x2\^3 + 18\ x2\ x3\^2 - 
                                6\ x2\^3\ x3\^2 - 3\ x2\ x3\^4 + 
                                x2\^3\ x3\^4)\)\ \((3\ \
M\[LeftDoubleBracket]3, 7\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]5, 
                                    18\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]5, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  33\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x3 + 15\ x2\^2\ x3 + 
                                10\ x3\^3 - 10\ x2\^2\ x3\^3 - x3\^5 + 
                                x2\^2\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]3, 8\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]3, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]5, 
                                    19\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]5, 
                                  21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  34\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x2 + 45\ x2\ x3\^2 - 
                                15\ x2\ x3\^4 + 
                                x2\ x3\^6)\)\ \((45\ M\[LeftDoubleBracket]3, 
                                    9\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]5, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]7, 
                                  35\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x3 + 105\ x3\^3 - 21\ x3\^5 + x3\^7)\)\ \((105\ M\[LeftDoubleBracket]3, 10\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]5, 21\[RightDoubleBracket] + \
M\[LeftDoubleBracket]7, 36\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ \
x1\^2 + 210\ x1\^4 - 28\ x1\^6 + x1\^8)\)\ \((\(-315\) + 210\ M\
\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
1\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ x1\ x2 + 105\ x1\^3\ x2 - \
21\ x1\^5\ x2 + x1\^7\ x2)\)\ \((105\ M\[LeftDoubleBracket]4, 2\
\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 2\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 2\[RightDoubleBracket])\)\)\/5040 + \(\((\(-105\)\ x1\
\ x3 + 105\ x1\^3\ x3 - 21\ x1\^5\ x3 + x1\^7\ x3)\)\ \((105\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, 3\
\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
3\[RightDoubleBracket])\)\)\/5040 + \(\((15 - 45\ x1\^2 + 15\ x1\^4 - x1\^6 - \
15\ x2\^2 + 45\ x1\^2\ x2\^2 - 15\ x1\^4\ x2\^2 + x1\^6\ x2\^2)\)\ \((\(-45\) \
+ 15\ M\[LeftDoubleBracket]4, 1\[RightDoubleBracket] + 45\ M\
\[LeftDoubleBracket]4, 4\[RightDoubleBracket] - M\[LeftDoubleBracket]6, 1\
\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, 4\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 4\[RightDoubleBracket])\)\)\/1440 + 
                          1\/720\ \((\(-15\)\ x2\ x3 + 45\ x1\^2\ x2\ x3 - 
                                15\ x1\^4\ x2\ x3 + 
                                x1\^6\ x2\ x3)\)\ \((45\ \
M\[LeftDoubleBracket]4, 5\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]6, 
                                    5\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  5\[RightDoubleBracket])\) + \(\((15 - 45\ \
x1\^2 + 15\ x1\^4 - x1\^6 - 15\ x3\^2 + 45\ x1\^2\ x3\^2 - 15\ x1\^4\ x3\^2 + \
x1\^6\ x3\^2)\)\ \((\(-45\) + 15\ M\[LeftDoubleBracket]4, 1\
\[RightDoubleBracket] + 45\ M\[LeftDoubleBracket]4, 6\[RightDoubleBracket] - \
M\[LeftDoubleBracket]6, 1\[RightDoubleBracket] - 15\ M\[LeftDoubleBracket]6, \
6\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
6\[RightDoubleBracket])\)\)\/1440 + 
                          1\/720\ \((\(-45\)\ x1\ x2 + 30\ x1\^3\ x2 - 
                                3\ x1\^5\ x2 + 15\ x1\ x2\^3 - 
                                10\ x1\^3\ x2\^3 + 
                                x1\^5\ x2\^3)\)\ \((30\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    2\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    7\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  7\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1\ x3 + 10\ x1\^3\ x3 - 
                                x1\^5\ x3 + 15\ x1\ x2\^2\ x3 - 
                                10\ x1\^3\ x2\^2\ x3 + 
                                x1\^5\ x2\^2\ x3)\)\ \((10\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  3\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    8\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  8\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1\ x2 + 10\ x1\^3\ x2 - 
                                x1\^5\ x2 + 15\ x1\ x2\ x3\^2 - 
                                10\ x1\^3\ x2\ x3\^2 + 
                                x1\^5\ x2\ x3\^2)\)\ \((10\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  2\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    9\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  9\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-45\)\ x1\ x3 + 30\ x1\^3\ x3 - 
                                3\ x1\^5\ x3 + 15\ x1\ x3\^3 - 
                                10\ x1\^3\ x3\^3 + 
                                x1\^5\ x3\^3)\)\ \((30\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    3\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    10\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  10\[RightDoubleBracket])\) + 
                          1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x2\^2 + 
                                36\ x1\^2\ x2\^2 - 6\ x1\^4\ x2\^2 + 
                                3\ x2\^4 - 6\ x1\^2\ x2\^4 + 
                                x1\^4\ x2\^4)\)\ \((\(-27\) + 
                                3\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                36\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    4\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    11\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  11\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2\ x3 + 18\ x1\^2\ x2\ x3 - 
                                3\ x1\^4\ x2\ x3 + 3\ x2\^3\ x3 - 
                                6\ x1\^2\ x2\^3\ x3 + 
                                x1\^4\ x2\^3\ x3)\)\ \((18\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    5\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    12\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  12\[RightDoubleBracket])\) + 
                          1\/96\ \((3 - 6\ x1\^2 + x1\^4 - 3\ x2\^2 + 
                                6\ x1\^2\ x2\^2 - x1\^4\ x2\^2 - 3\ x3\^2 + 
                                6\ x1\^2\ x3\^2 - x1\^4\ x3\^2 + 
                                3\ x2\^2\ x3\^2 - 6\ x1\^2\ x2\^2\ x3\^2 + 
                                x1\^4\ x2\^2\ x3\^2)\)\ \((\(-9\) + 
                                M\[LeftDoubleBracket]4, 
                                  1\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  4\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  13\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x2\ x3 + 18\ x1\^2\ x2\ x3 - 
                                3\ x1\^4\ x2\ x3 + 3\ x2\ x3\^3 - 
                                6\ x1\^2\ x2\ x3\^3 + 
                                x1\^4\ x2\ x3\^3)\)\ \((18\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    5\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    14\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  14\[RightDoubleBracket])\) + 
                          1\/576\ \((9 - 18\ x1\^2 + 3\ x1\^4 - 18\ x3\^2 + 
                                36\ x1\^2\ x3\^2 - 6\ x1\^4\ x3\^2 + 
                                3\ x3\^4 - 6\ x1\^2\ x3\^4 + 
                                x1\^4\ x3\^4)\)\ \((\(-27\) + 
                                3\ M\[LeftDoubleBracket]4, 
                                    1\[RightDoubleBracket] + 
                                36\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    15\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    6\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    15\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  15\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-45\)\ x1\ x2 + 15\ x1\^3\ x2 + 
                                30\ x1\ x2\^3 - 10\ x1\^3\ x2\^3 - 
                                3\ x1\ x2\^5 + 
                                x1\^3\ x2\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                30\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    16\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  16\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1\ x3 + 3\ x1\^3\ x3 + 
                                18\ x1\ x2\^2\ x3 - 6\ x1\^3\ x2\^2\ x3 - 
                                3\ x1\ x2\^4\ x3 + 
                                x1\^3\ x2\^4\ x3)\)\ \((3\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    8\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  17\[RightDoubleBracket])\) + 
                          1\/72\ \((\(-9\)\ x1\ x2 + 3\ x1\^3\ x2 + 
                                3\ x1\ x2\^3 - x1\^3\ x2\^3 + 
                                9\ x1\ x2\ x3\^2 - 3\ x1\^3\ x2\ x3\^2 - 
                                3\ x1\ x2\^3\ x3\^2 + 
                                x1\^3\ x2\^3\ x3\^2)\)\ \((3\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    7\[RightDoubleBracket] + 
                                9\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  7\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    9\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  18\[RightDoubleBracket])\) + 
                          1\/72\ \((\(-9\)\ x1\ x3 + 3\ x1\^3\ x3 + 
                                9\ x1\ x2\^2\ x3 - 3\ x1\^3\ x2\^2\ x3 + 
                                3\ x1\ x3\^3 - x1\^3\ x3\^3 - 
                                3\ x1\ x2\^2\ x3\^3 + 
                                x1\^3\ x2\^2\ x3\^3)\)\ \((3\ M\
\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                9\ M\[LeftDoubleBracket]4, 
                                    8\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    8\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  19\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1\ x2 + 3\ x1\^3\ x2 + 
                                18\ x1\ x2\ x3\^2 - 6\ x1\^3\ x2\ x3\^2 - 
                                3\ x1\ x2\ x3\^4 + 
                                x1\^3\ x2\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]4, 2\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    9\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  20\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-45\)\ x1\ x3 + 15\ x1\^3\ x3 + 
                                30\ x1\ x3\^3 - 10\ x1\^3\ x3\^3 - 
                                3\ x1\ x3\^5 + 
                                x1\^3\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 3\[RightDoubleBracket] + 
                                30\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  21\[RightDoubleBracket])\) + \
\(\(1\/1440\)\((\((15 - 15\ x1\^2 - 45\ x2\^2 + 45\ x1\^2\ x2\^2 + 
                                  15\ x2\^4 - 15\ x1\^2\ x2\^4 - x2\^6 + 
                                  x1\^2\ x2\^6)\)\ \((\(-45\) + 
                                  45\ M\[LeftDoubleBracket]4, 
                                      4\[RightDoubleBracket] + 
                                  15\ M\[LeftDoubleBracket]4, 
                                      11\[RightDoubleBracket] - 
                                  15\ M\[LeftDoubleBracket]6, 
                                      11\[RightDoubleBracket] - 
                                  M\[LeftDoubleBracket]6, 
                                    22\[RightDoubleBracket] + 
                                  M\[LeftDoubleBracket]8, 
                                    22\[RightDoubleBracket])\))\)\) + 
                          1\/240\ \((\(-15\)\ x2\ x3 + 15\ x1\^2\ x2\ x3 + 
                                10\ x2\^3\ x3 - 10\ x1\^2\ x2\^3\ x3 - 
                                x2\^5\ x3 + 
                                x1\^2\ x2\^5\ x3)\)\ \((15\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]4, 
                                    12\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    12\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  23\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  23\[RightDoubleBracket])\) + 
                          1\/96\ \((3 - 3\ x1\^2 - 6\ x2\^2 + 
                                6\ x1\^2\ x2\^2 + x2\^4 - x1\^2\ x2\^4 - 
                                3\ x3\^2 + 3\ x1\^2\ x3\^2 + 
                                6\ x2\^2\ x3\^2 - 6\ x1\^2\ x2\^2\ x3\^2 - 
                                x2\^4\ x3\^2 + 
                                x1\^2\ x2\^4\ x3\^2)\)\ \((\(-9\) + 
                                6\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]4, 
                                  11\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  11\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  24\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  24\[RightDoubleBracket])\) + 
                          1\/72\ \((\(-9\)\ x2\ x3 + 9\ x1\^2\ x2\ x3 + 
                                3\ x2\^3\ x3 - 3\ x1\^2\ x2\^3\ x3 + 
                                3\ x2\ x3\^3 - 3\ x1\^2\ x2\ x3\^3 - 
                                x2\^3\ x3\^3 + 
                                x1\^2\ x2\^3\ x3\^3)\)\ \((9\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    12\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    12\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    14\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  25\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  25\[RightDoubleBracket])\) + 
                          1\/96\ \((3 - 3\ x1\^2 - 3\ x2\^2 + 
                                3\ x1\^2\ x2\^2 - 6\ x3\^2 + 
                                6\ x1\^2\ x3\^2 + 6\ x2\^2\ x3\^2 - 
                                6\ x1\^2\ x2\^2\ x3\^2 + x3\^4 - 
                                x1\^2\ x3\^4 - x2\^2\ x3\^4 + 
                                x1\^2\ x2\^2\ x3\^4)\)\ \((\(-9\) + 
                                3\ M\[LeftDoubleBracket]4, 
                                    4\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]4, 
                                    6\[RightDoubleBracket] + 
                                6\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]4, 
                                  15\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    13\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  15\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  26\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  26\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x2\ x3 + 15\ x1\^2\ x2\ x3 + 
                                10\ x2\ x3\^3 - 10\ x1\^2\ x2\ x3\^3 - 
                                x2\ x3\^5 + 
                                x1\^2\ x2\ x3\^5)\)\ \((15\ M\
\[LeftDoubleBracket]4, 5\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    14\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  27\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  27\[RightDoubleBracket])\) + \
\(\(1\/1440\)\((\((15 - 15\ x1\^2 - 45\ x3\^2 + 45\ x1\^2\ x3\^2 + 
                                  15\ x3\^4 - 15\ x1\^2\ x3\^4 - x3\^6 + 
                                  x1\^2\ x3\^6)\)\ \((\(-45\) + 
                                  45\ M\[LeftDoubleBracket]4, 
                                      6\[RightDoubleBracket] + 
                                  15\ M\[LeftDoubleBracket]4, 
                                      15\[RightDoubleBracket] - 
                                  15\ M\[LeftDoubleBracket]6, 
                                      15\[RightDoubleBracket] - 
                                  M\[LeftDoubleBracket]6, 
                                    28\[RightDoubleBracket] + 
                                  M\[LeftDoubleBracket]8, 
                                    28\[RightDoubleBracket])\))\)\) + \
\(\((\(-105\)\ x1\ x2 + 105\ x1\ x2\^3 - 21\ x1\ x2\^5 + x1\ x2\^7)\)\ \((105\
\ M\[LeftDoubleBracket]4, 7\[RightDoubleBracket] - 21\ \
M\[LeftDoubleBracket]6, 16\[RightDoubleBracket] + M\[LeftDoubleBracket]8, 29\
\[RightDoubleBracket])\)\)\/5040 + 
                          1\/720\ \((\(-15\)\ x1\ x3 + 45\ x1\ x2\^2\ x3 - 
                                15\ x1\ x2\^4\ x3 + 
                                x1\ x2\^6\ x3)\)\ \((45\ \
M\[LeftDoubleBracket]4, 8\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]6, 
                                    17\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  30\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1\ x2 + 10\ x1\ x2\^3 - 
                                x1\ x2\^5 + 15\ x1\ x2\ x3\^2 - 
                                10\ x1\ x2\^3\ x3\^2 + 
                                x1\ x2\^5\ x3\^2)\)\ \((10\ M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  16\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    18\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  31\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1\ x3 + 18\ x1\ x2\^2\ x3 - 
                                3\ x1\ x2\^4\ x3 + 3\ x1\ x3\^3 - 
                                6\ x1\ x2\^2\ x3\^3 + 
                                x1\ x2\^4\ x3\^3)\)\ \((18\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    17\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    19\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  32\[RightDoubleBracket])\) + 
                          1\/144\ \((\(-9\)\ x1\ x2 + 3\ x1\ x2\^3 + 
                                18\ x1\ x2\ x3\^2 - 6\ x1\ x2\^3\ x3\^2 - 
                                3\ x1\ x2\ x3\^4 + 
                                x1\ x2\^3\ x3\^4)\)\ \((3\ M\
\[LeftDoubleBracket]4, 7\[RightDoubleBracket] + 
                                18\ M\[LeftDoubleBracket]4, 
                                    9\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    18\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  33\[RightDoubleBracket])\) + 
                          1\/240\ \((\(-15\)\ x1\ x3 + 15\ x1\ x2\^2\ x3 + 
                                10\ x1\ x3\^3 - 10\ x1\ x2\^2\ x3\^3 - 
                                x1\ x3\^5 + 
                                x1\ x2\^2\ x3\^5)\)\ \((15\ M\
\[LeftDoubleBracket]4, 8\[RightDoubleBracket] + 
                                10\ M\[LeftDoubleBracket]4, 
                                    10\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    19\[RightDoubleBracket] - 
                                M\[LeftDoubleBracket]6, 
                                  21\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  34\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-15\)\ x1\ x2 + 45\ x1\ x2\ x3\^2 - 
                                15\ x1\ x2\ x3\^4 + 
                                x1\ x2\ x3\^6)\)\ \((45\ \
M\[LeftDoubleBracket]4, 9\[RightDoubleBracket] - 
                                15\ M\[LeftDoubleBracket]6, 
                                    20\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  35\[RightDoubleBracket])\) + \(\((\(-105\)\ \
x1\ x3 + 105\ x1\ x3\^3 - 21\ x1\ x3\^5 + x1\ x3\^7)\)\ \((105\ M\
\[LeftDoubleBracket]4, 10\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, \
21\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
36\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ x2\^2 + 210\ x2\^4 - 28\ \
x2\^6 + x2\^8)\)\ \((\(-315\) + 210\ M\[LeftDoubleBracket]4, 11\
\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 22\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 37\[RightDoubleBracket])\)\)\/40320 + \(\((\(-105\)\ \
x2\ x3 + 105\ x2\^3\ x3 - 21\ x2\^5\ x3 + x2\^7\ x3)\)\ \((105\ M\
\[LeftDoubleBracket]4, 12\[RightDoubleBracket] - 21\ M\[LeftDoubleBracket]6, \
23\[RightDoubleBracket] + M\[LeftDoubleBracket]8, \
38\[RightDoubleBracket])\)\)\/5040 + \(\(1\/1440\)\((\((15 - 45\ x2\^2 + 
                                  15\ x2\^4 - x2\^6 - 15\ x3\^2 + 
                                  45\ x2\^2\ x3\^2 - 15\ x2\^4\ x3\^2 + 
                                  x2\^6\ x3\^2)\)\ \((\(-45\) + 
                                  15\ M\[LeftDoubleBracket]4, 
                                      11\[RightDoubleBracket] + 
                                  45\ M\[LeftDoubleBracket]4, 
                                      13\[RightDoubleBracket] - 
                                  M\[LeftDoubleBracket]6, 
                                    22\[RightDoubleBracket] - 
                                  15\ M\[LeftDoubleBracket]6, 
                                      24\[RightDoubleBracket] + 
                                  M\[LeftDoubleBracket]8, 
                                    39\[RightDoubleBracket])\))\)\) + 
                          1\/720\ \((\(-45\)\ x2\ x3 + 30\ x2\^3\ x3 - 
                                3\ x2\^5\ x3 + 15\ x2\ x3\^3 - 
                                10\ x2\^3\ x3\^3 + 
                                x2\^5\ x3\^3)\)\ \((30\ \
M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                                15\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    23\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    25\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  40\[RightDoubleBracket])\) + 
                          1\/576\ \((9 - 18\ x2\^2 + 3\ x2\^4 - 18\ x3\^2 + 
                                36\ x2\^2\ x3\^2 - 6\ x2\^4\ x3\^2 + 
                                3\ x3\^4 - 6\ x2\^2\ x3\^4 + 
                                x2\^4\ x3\^4)\)\ \((\(-27\) + 
                                3\ M\[LeftDoubleBracket]4, 
                                    11\[RightDoubleBracket] + 
                                36\ M\[LeftDoubleBracket]4, 
                                    13\[RightDoubleBracket] + 
                                3\ M\[LeftDoubleBracket]4, 
                                    15\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    24\[RightDoubleBracket] - 
                                6\ M\[LeftDoubleBracket]6, 
                                    26\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  41\[RightDoubleBracket])\) + 
                          1\/720\ \((\(-45\)\ x2\ x3 + 15\ x2\^3\ x3 + 
                                30\ x2\ x3\^3 - 10\ x2\^3\ x3\^3 - 
                                3\ x2\ x3\^5 + 
                                x2\^3\ x3\^5)\)\ \((15\ \
M\[LeftDoubleBracket]4, 12\[RightDoubleBracket] + 
                                30\ M\[LeftDoubleBracket]4, 
                                    14\[RightDoubleBracket] - 
                                10\ M\[LeftDoubleBracket]6, 
                                    25\[RightDoubleBracket] - 
                                3\ M\[LeftDoubleBracket]6, 
                                    27\[RightDoubleBracket] + 
                                M\[LeftDoubleBracket]8, 
                                  42\[RightDoubleBracket])\) + \
\(\(1\/1440\)\((\((15 - 15\ x2\^2 - 45\ x3\^2 + 45\ x2\^2\ x3\^2 + 
                                  15\ x3\^4 - 15\ x2\^2\ x3\^4 - x3\^6 + 
                                  x2\^2\ x3\^6)\)\ \((\(-45\) + 
                                  45\ M\[LeftDoubleBracket]4, 
                                      13\[RightDoubleBracket] + 
                                  15\ M\[LeftDoubleBracket]4, 
                                      15\[RightDoubleBracket] - 
                                  15\ M\[LeftDoubleBracket]6, 
                                      26\[RightDoubleBracket] - 
                                  M\[LeftDoubleBracket]6, 
                                    28\[RightDoubleBracket] + 
                                  M\[LeftDoubleBracket]8, 
                                    43\[RightDoubleBracket])\))\)\) + \
\(\((\(-105\)\ x2\ x3 + 105\ x2\ x3\^3 - 21\ x2\ x3\^5 + x2\ x3\^7)\)\ \((105\
\ M\[LeftDoubleBracket]4, 14\[RightDoubleBracket] - 21\ \
M\[LeftDoubleBracket]6, 27\[RightDoubleBracket] + M\[LeftDoubleBracket]8, 44\
\[RightDoubleBracket])\)\)\/5040 + \(\((105 - 420\ x3\^2 + 210\ x3\^4 - 28\ \
x3\^6 + x3\^8)\)\ \((\(-315\) + 210\ M\[LeftDoubleBracket]4, 15\
\[RightDoubleBracket] - 28\ M\[LeftDoubleBracket]6, 28\[RightDoubleBracket] + \
M\[LeftDoubleBracket]8, 45\[RightDoubleBracket])\)\)\/40320)\)\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "HermiteStand"],
      Editable->False]], "Print",
  FontSize->14,
  CellTags->"Info3406902320-6947369"]
}, Closed]],

Cell[CellGroupData[{

Cell["SetDirectory[\"/Mathematica/Packages/Hermann/\"]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \("/Mathematica/Packages/Hermann"\)], "Output",
  FontSize->14]
}, Open  ]],

Cell["Save[\"HermiteFormel\",Hermite]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(Save["\<HermiteFormelStand\>", HermiteStand]\)], "Input",
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
Hermite[2,{x1,x2},{{m10,m01},{m20,m11,m02}},\"phiH\"]//Timing
   \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \({0.0001589999999396241`\ Second, 
      0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \((x1\^2 + \
x2\^2)\)\)\ \((1 + m10\ x1 + 1\/2\ \((\(-1\) + m20)\)\ \((\(-1\) + x1\^2)\) + 
            m01\ x2 + m11\ x1\ x2 + 
            1\/2\ \((\(-1\) + m02)\)\ \((\(-1\) + x2\^2)\))\)}\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultip[{x1,x2},{{m10,m01},{m20,m11,m02}},\"phiH\"]//\
Timing
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \({0.004660000000058062`\ Second, 
      0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \((x1\^2 + \
x2\^2)\)\)\ \((1 + m10\ x1 + 1\/2\ \((\(-1\) + m20)\)\ \((\(-1\) + x1\^2)\) + 
            m01\ x2 + m11\ x1\ x2 + 
            1\/2\ \((\(-1\) + m02)\)\ \((\(-1\) + x2\^2)\))\)}\)], "Output",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti[{x1,x2},{{m00,m01,m02},
                               {m10,m11,_},
                               {m20,_,_}},\"{d,phiH}\"]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[BoxData[
    \(0.15915494309189535`\ 2.718281828459045`\^\(\(-0.5`\)\ \((x1\^2 + \
x2\^2)\)\)\ \((1 + m10\ x1 + 1\/2\ \((\(-1\) + m20)\)\ \((\(-1\) + x1\^2)\) + 
          m01\ x2 + m11\ x1\ x2 + 
          1\/2\ \((\(-1\) + m02)\)\ \((\(-1\) + x2\^2)\))\)\)], "Output",
  FontSize->14]
}, Open  ]],

Cell["m//Clear", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultiSym[2,{x1,x2},m,\"{d,phiH}\"]
HermiteExpansionMultiSymp[2,{x1,x2},m]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + x2*m[0, 1] + ((-1 + \
x2^2)*(-1 + m[0, 2]))/2 + x1*m[1, 0] + 

     x1*x2*m[1, 1] + ((-1 + x1^2)*(-1 + m[2, \
0]))/2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "\<\
                    \
                 2
                             (-1 + x2 ) (-1 + m[0, 2])
 (0.159155 (1 + x2 m[0, 1] + ------------------------- + x1 m[1, 0] + x1 x2 \
m[1, 1] + 
                                         2
          2                                   2     2
  (-1 + x1 ) (-1 + m[2, 0])            0.5 (x1  + x2 )
  -------------------------)) / 2.71828
              2\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 (0.15915494309189535*(1 + x1*m[[1,1]] + x2*m[[1,2]] \
+ ((-1 + x1^2)*(-1 + m[[2,1]]))/2 + 

     x1*x2*m[[2,2]] + ((-1 + x2^2)*(-1 + \
m[[2,3]]))/2))/2.718281828459045^(0.5*(x1^2 +\\
  x2^2))\
\>", "\<\
                                                    2
                                            (-1 + x1 ) (-1 + m[[2,1]])
 (0.159155 (1 + x1 m[[1,1]] + x2 m[[1,2]] + -------------------------- + x1 \
x2 m[[2,2]] + 
                                                        2
          2                                    2     2
  (-1 + x2 ) (-1 + m[[2,3]])            0.5 (x1  + x2 )
  --------------------------)) / 2.71828
              2\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMulti[{x1,x2},{{1,2,1},
                               {1,.5},
                               {1}},\"{d,phiH}\"]
                               
HermiteExpansionMultip[{x1,x2},{{1,2},{1,.5,1}}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
(0.15915494309189535*(1 + x1 + 2*x2 + \
0.5*x1*x2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "\<\
0.159155 (1 + x1 \
+ 2 x2 + 0.5 x1 x2)
------------------------------------
                     2     2
              0.5 (x1  + x2 )
       2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
(0.15915494309189535*(1 + x1 + 2*x2 + \
0.5*x1*x2))/2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "\<\
0.159155 (1 + x1 \
+ 2 x2 + 0.5 x1 x2)
------------------------------------
                     2     2
              0.5 (x1  + x2 )
       2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "HermiteExpansionMultipStand//Clear\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  StyleBox["HermiteExpansionMultipStand",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,M_,Option_:\"phiH\"]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "\nModule[{mue,Sigma,p,k,K,gamma,Nue},\n\n(*stand. Entwicklung; \
M={mu,m^2,m^3,..}, sym. vektorisiert*)\n\n{mue,Sigma}=M[[{1,2}]];\n\n\
p=mue//Length;\nK=M//Length; (*K//Print;*)\n\n\
Sigma=momentexp2index[Sigma,2,p];  \n(*Sigma=Shift[Sigma,10^-16];*)\n\
gamma=Sigma//CholeskyDecomposition//Transpose//Inverse;\n\n\nNue= \nTable[\n\t\
\tM1tensor=momentexp2index[M[[k]],k,p];\n\t\t\
momentindex2exp[nue[k,gamma,M1tensor],k,p]  (*stand. Momente Ordnung k; \
Vektor*)\n,{k,2,K}]; \n\nNue=Join[{Shape[0,p]},Nue]; (*Nue//Print;*)\n\n\
(*pz(z)dz = pz(gamma(y-mue) |gamma| dy = py(y) dy*)\n\nIf[Option===\"phiH\",\n\
\n(*Det[gamma] HermiteExpansionMultip[gamma.(y-mue),Nue,\"phiH\"]*)\n\
Det[gamma] HermiteStand[K,gamma.(y-mue),Nue,\"phiH\"]\n\n,(*else*)\n\n\
If[Option===\"H\",\n(*HermiteExpansionMultip[gamma.(y-mue),Nue,\"H\"]*)\n\
HermiteStand[K,gamma.(y-mue),Nue,\"H\"]\n]]\n\n]\n\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[{
  "HermiteExpansionMultipStandz//Clear\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  StyleBox["HermiteExpansionMultipStandz",
    FontColor->RGBColor[1, 0, 0]],
  "[z_,M_,Option_:\"phiH\"]:=\n",
  StyleBox["(***************************************************************)\
\t\t\t \n",
    FontWeight->"Plain"],
  "\nModule[{mue,Sigma,p,k,K,gamma,Nue},\n\n(*stand. Entwicklung; \
M={mu,m^2,m^3,..}, sym. vektorisiert*)\n\n{mue,Sigma}=M[[{1,2}]];\n\n\
p=mue//Length;\nK=M//Length; (*K//Print;*)\n\n\
Sigma=momentexp2index[Sigma,2,p]; \n(*Sigma=Shift[Sigma,10^-16];*) \n\
gamma=Sigma//CholeskyDecomposition//Transpose//Inverse;\n\n\nNue= \nTable[\n\t\
\tM1tensor=momentexp2index[M[[k]],k,p];\n\t\t\
momentindex2exp[nue[k,gamma,M1tensor],k,p]  (*stand. Momente Ordnung k; \
Vektor*)\n,{k,2,K}]; \n\nNue=Join[{Shape[0,p]},Nue]; (*Nue//Print;*)\n\n\
(*pz(z)dz = pz(gamma(y-mue) |gamma| dy = py(y) dy*)\n\nIf[Option===\"phiH\",\n\
\n(*Det[gamma] HermiteExpansionMultip[z,Nue,\"phiH\"]*)\nDet[gamma] \
HermiteStand[K,z,Nue,\"phiH\"]\n\n,(*else*)\n\nIf[Option===\"H\",\n\
(*HermiteExpansionMultip[z,Nue,\"H\"]*)\nHermiteStand[K,z,Nue,\"H\"]\n]]\n\n]\
\n\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["??Hermite", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`Hermite
Hermite[1, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]]
 
Hermite[2, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2
 
Hermite[3, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6
 
Hermite[4, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24
 
Hermite[5, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120
 
Hermite[6, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720
 
Hermite[7, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040
 
Hermite[8, {x1_}, M_, \"H\"] = 1 + x1*M[[1,1]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*
      (105 - 420*M[[2,1]] + 210*M[[4,1]] - 28*M[[6,1]] + M[[8,1]]))/40320
 
Hermite[1, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]]))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[2, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2))/2.718281828459045^(0.5*x1^2)
 
Hermite[3, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[4, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + \
M[[4,1]]))/24))/2.718281828459045^(0.5*x1^2)
 
Hermite[5, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + \
M[[5,1]]))/120))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[6, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[7, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040))/2.718281828459045^(0.5*x1^2)
 
Hermite[8, {x1_}, M_, \"phiH\"] = (0.3989422804014327*(1 + x1*M[[1,1]] + 
      ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + ((-3*x1 + x1^3)*(-3*M[[1,1]] + \
M[[3,1]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*
        (105 - 420*M[[2,1]] + 210*M[[4,1]] - 28*M[[6,1]] + \
M[[8,1]]))/40320))/
    2.718281828459045^(0.5*x1^2)
 
Hermite[1, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]]
 
Hermite[2, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2
 
Hermite[3, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6
 
Hermite[4, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24
 
Hermite[5, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120
 
Hermite[6, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + 6*M[[2,1]] \
+ 3*M[[2,3]] - 
       M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720
 
Hermite[7, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + 6*M[[2,1]] \
+ 3*M[[2,3]] - 
       M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
    ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + 45*M[[3,3]] \
- 
       15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + x2^7)*
      (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040
 
Hermite[8, {x1_, x2_}, M_, \"H\"] = 1 + x1*M[[1,1]] + x2*M[[1,2]] + 
    ((-1 + x1^2)*(-1 + M[[2,1]]))/2 + x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + \
M[[2,3]]))/2 + 
    ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + x1^2*x2)*(-M[[1,2]] \
+ M[[3,2]]))/
     2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
    ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
    ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
    ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
    ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 + 
    ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
    ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
    ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + 
    ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 + 
    ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + M[[5,3]]))/
     12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - 3*M[[3,2]] - \
M[[3,4]] + 
       M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*(3*M[[1,1]] - 6*M[[3,3]] \
+ M[[5,5]]))/
     24 + ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120 + 
    ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
    ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
    ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + 6*M[[2,1]] \
+ 3*M[[2,3]] - 
       M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
    ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] - \
3*M[[4,4]] + 
       M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
      (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 + \

    ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
    ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
    ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
       M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
      (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
    ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
      (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/240 + 
    ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + x1^4*x2^3)*
      (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
    ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
      (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
    ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
      (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/240 + 
    ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + 45*M[[3,3]] \
- 
       15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + x2^7)*
      (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040 + 
    ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*(105 - 420*M[[2,1]] + \
210*M[[4,1]] - 
       28*M[[6,1]] + M[[8,1]]))/40320 + ((-105*x1*x2 + 105*x1^3*x2 - \
21*x1^5*x2 + x1^7*x2)*
      (-105*M[[2,2]] + 105*M[[4,2]] - 21*M[[6,2]] + M[[8,2]]))/5040 + 
    ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 + \
x1^6*x2^2)*
      (15 - 45*M[[2,1]] - 15*M[[2,3]] + 15*M[[4,1]] + 45*M[[4,3]] - M[[6,1]] \
- 15*M[[6,3]] + 
       M[[8,3]]))/1440 + ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 + 15*x1*x2^3 - \
10*x1^3*x2^3 + 
       x1^5*x2^3)*(-45*M[[2,2]] + 30*M[[4,2]] + 15*M[[4,4]] - 3*M[[6,2]] - \
10*M[[6,4]] + 
       M[[8,4]]))/720 + ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + 36*x1^2*x2^2 - \
6*x1^4*x2^2 + 
       3*x2^4 - 6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - 18*M[[2,3]] + \
3*M[[4,1]] + 
       36*M[[4,3]] + 3*M[[4,5]] - 6*M[[6,3]] - 6*M[[6,5]] + M[[8,5]]))/576 + 
    ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
      (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,4]] - 10*M[[6,4]] - 3*M[[6,6]] + \
M[[8,6]]))/
     720 + ((15 - 15*x1^2 - 45*x2^2 + 45*x1^2*x2^2 + 15*x2^4 - 15*x1^2*x2^4 - \
x2^6 + 
       x1^2*x2^6)*(15 - 15*M[[2,1]] - 45*M[[2,3]] + 45*M[[4,3]] + 15*M[[4,5]] \
- 
       15*M[[6,5]] - M[[6,7]] + M[[8,7]]))/1440 + 
    ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,4]] - 
       21*M[[6,6]] + M[[8,8]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - 28*x2^6 \
+ x2^8)*
      (105 - 420*M[[2,3]] + 210*M[[4,5]] - 28*M[[6,7]] + M[[8,9]]))/40320
 
Hermite[1, {x1_, x2_}, M_, \"phiH\"] = (0.15915494309189535*(1 + x1*M[[1,1]] \
+ x2*M[[1,2]]))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[2, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[3, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + \
M[[3,4]]))/6))/2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[4, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[5, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + \
M[[5,6]]))/120))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[6, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 3*M[[4,4]] + 
         M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
        (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 \
+ 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[7, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 3*M[[4,4]] + 
         M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
        (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 \
+ 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
        (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/
       240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + \
x1^4*x2^3)*
        (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
      ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
        (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
      ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
        (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,3]] - 
         15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040))/
    2.718281828459045^(0.5*(x1^2 + x2^2))
 
Hermite[8, {x1_, x2_}, M_, \"phiH\"] = 
   (0.15915494309189535*(1 + x1*M[[1,1]] + x2*M[[1,2]] + ((-1 + x1^2)*(-1 + \
M[[2,1]]))/2 + 
      x1*x2*M[[2,2]] + ((-1 + x2^2)*(-1 + M[[2,3]]))/2 + 
      ((-3*x1 + x1^3)*(-3*M[[1,1]] + M[[3,1]]))/6 + ((-x2 + \
x1^2*x2)*(-M[[1,2]] + M[[3,2]]))/
       2 + ((-x1 + x1*x2^2)*(-M[[1,1]] + M[[3,3]]))/2 + 
      ((-3*x2 + x2^3)*(-3*M[[1,2]] + M[[3,4]]))/6 + 
      ((3 - 6*x1^2 + x1^4)*(3 - 6*M[[2,1]] + M[[4,1]]))/24 + 
      ((-3*x1*x2 + x1^3*x2)*(-3*M[[2,2]] + M[[4,2]]))/6 + 
      ((1 - x1^2 - x2^2 + x1^2*x2^2)*(1 - M[[2,1]] - M[[2,3]] + M[[4,3]]))/4 \
+ 
      ((-3*x1*x2 + x1*x2^3)*(-3*M[[2,2]] + M[[4,4]]))/6 + 
      ((3 - 6*x2^2 + x2^4)*(3 - 6*M[[2,3]] + M[[4,5]]))/24 + 
      ((15*x1 - 10*x1^3 + x1^5)*(15*M[[1,1]] - 10*M[[3,1]] + M[[5,1]]))/120 + \

      ((3*x2 - 6*x1^2*x2 + x1^4*x2)*(3*M[[1,2]] - 6*M[[3,2]] + M[[5,2]]))/24 \
+ 
      ((3*x1 - x1^3 - 3*x1*x2^2 + x1^3*x2^2)*(3*M[[1,1]] - M[[3,1]] - \
3*M[[3,3]] + 
         M[[5,3]]))/12 + ((3*x2 - 3*x1^2*x2 - x2^3 + x1^2*x2^3)*(3*M[[1,2]] - \
3*M[[3,2]] - 
         M[[3,4]] + M[[5,4]]))/12 + ((3*x1 - 6*x1*x2^2 + x1*x2^4)*
        (3*M[[1,1]] - 6*M[[3,3]] + M[[5,5]]))/24 + 
      ((15*x2 - 10*x2^3 + x2^5)*(15*M[[1,2]] - 10*M[[3,4]] + M[[5,6]]))/120 + \

      ((-15 + 45*x1^2 - 15*x1^4 + x1^6)*(-15 + 45*M[[2,1]] - 15*M[[4,1]] + \
M[[6,1]]))/720 + 
      ((15*x1*x2 - 10*x1^3*x2 + x1^5*x2)*(15*M[[2,2]] - 10*M[[4,2]] + \
M[[6,2]]))/120 + 
      ((-3 + 6*x1^2 - x1^4 + 3*x2^2 - 6*x1^2*x2^2 + x1^4*x2^2)*(-3 + \
6*M[[2,1]] + 
         3*M[[2,3]] - M[[4,1]] - 6*M[[4,3]] + M[[6,3]]))/48 + 
      ((9*x1*x2 - 3*x1^3*x2 - 3*x1*x2^3 + x1^3*x2^3)*(9*M[[2,2]] - 3*M[[4,2]] \
- 3*M[[4,4]] + 
         M[[6,4]]))/36 + ((-3 + 3*x1^2 + 6*x2^2 - 6*x1^2*x2^2 - x2^4 + \
x1^2*x2^4)*
        (-3 + 3*M[[2,1]] + 6*M[[2,3]] - 6*M[[4,3]] - M[[4,5]] + M[[6,5]]))/48 \
+ 
      ((15*x1*x2 - 10*x1*x2^3 + x1*x2^5)*(15*M[[2,2]] - 10*M[[4,4]] + \
M[[6,6]]))/120 + 
      ((-15 + 45*x2^2 - 15*x2^4 + x2^6)*(-15 + 45*M[[2,3]] - 15*M[[4,5]] + \
M[[6,7]]))/720 + 
      ((-105*x1 + 105*x1^3 - 21*x1^5 + x1^7)*(-105*M[[1,1]] + 105*M[[3,1]] - \
21*M[[5,1]] + 
         M[[7,1]]))/5040 + ((-15*x2 + 45*x1^2*x2 - 15*x1^4*x2 + x1^6*x2)*
        (-15*M[[1,2]] + 45*M[[3,2]] - 15*M[[5,2]] + M[[7,2]]))/720 + 
      ((-15*x1 + 10*x1^3 - x1^5 + 15*x1*x2^2 - 10*x1^3*x2^2 + x1^5*x2^2)*
        (-15*M[[1,1]] + 10*M[[3,1]] + 15*M[[3,3]] - M[[5,1]] - 10*M[[5,3]] + \
M[[7,3]]))/
       240 + ((-9*x2 + 18*x1^2*x2 - 3*x1^4*x2 + 3*x2^3 - 6*x1^2*x2^3 + \
x1^4*x2^3)*
        (-9*M[[1,2]] + 18*M[[3,2]] + 3*M[[3,4]] - 3*M[[5,2]] - 6*M[[5,4]] + \
M[[7,4]]))/144 + 
      ((-9*x1 + 3*x1^3 + 18*x1*x2^2 - 6*x1^3*x2^2 - 3*x1*x2^4 + x1^3*x2^4)*
        (-9*M[[1,1]] + 3*M[[3,1]] + 18*M[[3,3]] - 6*M[[5,3]] - 3*M[[5,5]] + \
M[[7,5]]))/144 + 
      ((-15*x2 + 15*x1^2*x2 + 10*x2^3 - 10*x1^2*x2^3 - x2^5 + x1^2*x2^5)*
        (-15*M[[1,2]] + 15*M[[3,2]] + 10*M[[3,4]] - 10*M[[5,4]] - M[[5,6]] + \
M[[7,6]]))/
       240 + ((-15*x1 + 45*x1*x2^2 - 15*x1*x2^4 + x1*x2^6)*(-15*M[[1,1]] + \
45*M[[3,3]] - 
         15*M[[5,5]] + M[[7,7]]))/720 + ((-105*x2 + 105*x2^3 - 21*x2^5 + \
x2^7)*
        (-105*M[[1,2]] + 105*M[[3,4]] - 21*M[[5,6]] + M[[7,8]]))/5040 + 
      ((105 - 420*x1^2 + 210*x1^4 - 28*x1^6 + x1^8)*(105 - 420*M[[2,1]] + \
210*M[[4,1]] - 
         28*M[[6,1]] + M[[8,1]]))/40320 + ((-105*x1*x2 + 105*x1^3*x2 - \
21*x1^5*x2 + x1^7*x2)*
        (-105*M[[2,2]] + 105*M[[4,2]] - 21*M[[6,2]] + M[[8,2]]))/5040 + 
      ((15 - 45*x1^2 + 15*x1^4 - x1^6 - 15*x2^2 + 45*x1^2*x2^2 - 15*x1^4*x2^2 \
+ x1^6*x2^2)*
        (15 - 45*M[[2,1]] - 15*M[[2,3]] + 15*M[[4,1]] + 45*M[[4,3]] - \
M[[6,1]] - 
         15*M[[6,3]] + M[[8,3]]))/1440 + ((-45*x1*x2 + 30*x1^3*x2 - 3*x1^5*x2 \
+ 15*x1*x2^3 - 
         10*x1^3*x2^3 + x1^5*x2^3)*(-45*M[[2,2]] + 30*M[[4,2]] + 15*M[[4,4]] \
- 3*M[[6,2]] - 
         10*M[[6,4]] + M[[8,4]]))/720 + ((9 - 18*x1^2 + 3*x1^4 - 18*x2^2 + \
36*x1^2*x2^2 - 
         6*x1^4*x2^2 + 3*x2^4 - 6*x1^2*x2^4 + x1^4*x2^4)*(9 - 18*M[[2,1]] - \
18*M[[2,3]] + 
         3*M[[4,1]] + 36*M[[4,3]] + 3*M[[4,5]] - 6*M[[6,3]] - 6*M[[6,5]] + \
M[[8,5]]))/576 + 
      ((-45*x1*x2 + 15*x1^3*x2 + 30*x1*x2^3 - 10*x1^3*x2^3 - 3*x1*x2^5 + \
x1^3*x2^5)*
        (-45*M[[2,2]] + 15*M[[4,2]] + 30*M[[4,4]] - 10*M[[6,4]] - 3*M[[6,6]] \
+ M[[8,6]]))/
       720 + ((15 - 15*x1^2 - 45*x2^2 + 45*x1^2*x2^2 + 15*x2^4 - 15*x1^2*x2^4 \
- x2^6 + 
         x1^2*x2^6)*(15 - 15*M[[2,1]] - 45*M[[2,3]] + 45*M[[4,3]] + \
15*M[[4,5]] - 
         15*M[[6,5]] - M[[6,7]] + M[[8,7]]))/1440 + 
      ((-105*x1*x2 + 105*x1*x2^3 - 21*x1*x2^5 + x1*x2^7)*(-105*M[[2,2]] + \
105*M[[4,4]] - 
         21*M[[6,6]] + M[[8,8]]))/5040 + ((105 - 420*x2^2 + 210*x2^4 - \
28*x2^6 + x2^8)*
        (105 - 420*M[[2,3]] + 210*M[[4,5]] - 28*M[[6,7]] + \
M[[8,9]]))/40320))/
    2.718281828459045^(0.5*(x1^2 + x2^2))\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultipStand[{x},{{mue},{m2},{m3}},\"H\"]//Simplify//\
Expand\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 1 + (m3*mue)/(2*m2^2) - (m3*mue^3)/(6*m2^3) - \
(m3*x)/(2*m2^2) + (m3*mue^2*x)/(2*m2^3) - 

   (m3*mue*x^2)/(2*m2^3) + (m3*x^3)/(6*m2^3)\
\>", "\<\
                   3  \
               2             2       3
    m3 mue   m3 mue    m3 x    m3 mue  x   m3 mue x    m3 x
1 + ------ - ------- - ----- + --------- - --------- + -----
        2         3        2         3           3         3
    2 m2      6 m2     2 m2      2 m2        2 m2      6 m2\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultipStandz[{(x-mue)/Sqrt[m2]},{{mue},{m2},{m3}},\"\
H\"]//Simplify//Expand\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 1 + (m3*mue)/(2*m2^2) - (m3*mue^3)/(6*m2^3) - \
(m3*x)/(2*m2^2) + (m3*mue^2*x)/(2*m2^3) - 

   (m3*mue*x^2)/(2*m2^3) + (m3*x^3)/(6*m2^3)\
\>", "\<\
                   3  \
               2             2       3
    m3 mue   m3 mue    m3 x    m3 mue  x   m3 mue x    m3 x
1 + ------ - ------- - ----- + --------- - --------- + -----
        2         3        2         3           3         3
    2 m2      6 m2     2 m2      2 m2        2 m2      6 m2\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultip[{(x-mue)/Sqrt[m2]},{{0},{1},{m3/m2^(3/2)}},\"\
H\"]//Simplify//Expand\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 1 + (m3*mue)/(2*m2^2) - (m3*mue^3)/(6*m2^3) - \
(m3*x)/(2*m2^2) + (m3*mue^2*x)/(2*m2^3) - 

   (m3*mue*x^2)/(2*m2^3) + (m3*x^3)/(6*m2^3)\
\>", "\<\
                   3  \
               2             2       3
    m3 mue   m3 mue    m3 x    m3 mue  x   m3 mue x    m3 x
1 + ------ - ------- - ----- + --------- - --------- + -----
        2         3        2         3           3         3
    2 m2      6 m2     2 m2      2 m2        2 m2      6 m2\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultipStand[{x1,x2},{{1,2},{1,.5,1},{1,0,0,1}},\"H\"\
]//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["{{0, 0}, {1., 0., 1.}, {1., -0.57735, 0.333333, 1.34715}}", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {0.03333333333284827*Second, 1 + 0.*(-1 + (1.*(-1 + \
x1) + 0.*(-2 + x2))^2) + 

    0.16666666666666666*(-3*(1.*(-1 + x1) + 0.*(-2 + x2)) + (1.*(-1 + x1) + \
0.*(-2 + x2))^

       3) + 1.1102230246251565*^-16*

     (-1 + (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2))^2) \
+ 

    0.22452510468485454*(-3*(-0.5773502691896258*(-1 + x1) + \
1.1547005383792517*(-2 + x2))\\
  + 
    (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2))^3) - 

    0.2886751345948129*(0.5773502691896258*(-1 + x1) + (1.*(-1 + x1) + 0.*(-2 \
+ x2))^2*

       (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2)) - 

      1.1547005383792517*(-2 + x2)) + 0.1666666666666667*

     (-1.*(-1 + x1) + (1.*(-1 + x1) + 0.*(-2 + x2))*

       (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2))^2 + \
0.*(-2 + x2)) + 

    0.*(1.*(-1 + x1) + 0.*(-2 + x2))*(-0.5773502691896258*(-1 + x1) + 

      1.1547005383792517*(-2 + x2))}\
\>", "\<\
                              \
                                2
 {0.0333333 Second, 1 + 0. (-1 + (1. (-1 + x1) + 0. (-2 + x2)) ) + 
                                                                            3
  0.166667 (-3 (1. (-1 + x1) + 0. (-2 + x2)) + (1. (-1 + x1) + 0. (-2 + x2)) \
) + 
            -16                                              2
  1.11022 10    (-1 + (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) ) + 
  0.224525 (-3 (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) + 
                                         3
  (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) ) - 
                                                             2
  0.288675 (0.57735 (-1 + x1) + (1. (-1 + x1) + 0. (-2 + x2))  
  (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) - 1.1547 (-2 + x2)) + 
  0.166667 (-1. (-1 + x1) + (1. (-1 + x1) + 0. (-2 + x2)) 
                                         2
  (-0.57735 (-1 + x1) + 1.1547 (-2 + x2))  + 0. (-2 + x2)) + 
  0. (1. (-1 + x1) + 0. (-2 + x2)) (-0.57735 (-1 + x1) + 1.1547 (-2 + x2))}\
\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultipStand[{x1,x2},{{1,2},{1,.5,1},{1,0,0,1}},\"H\"\
]//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["{{0, 0}, {1., 0., 1.}, {1., -0.57735, 0.333333, 1.34715}}", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {0.016666666666424135*Second, 1 + \
0.16666666666666666*(-3*(1.*(-1 + x1) + 0.*(-2 + x2)) + 

      (1.*(-1 + x1) + 0.*(-2 + x2))^3) + 0.22452510468485454*

     (-3*(-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2)) + 

      (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2))^3) - 

    0.2886751345948129*(0.5773502691896258*(-1 + x1) + (1.*(-1 + x1) + 0.*(-2 \
+ x2))^2*

       (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2)) - 

      1.1547005383792517*(-2 + x2)) + 0.1666666666666667*

     (-1.*(-1 + x1) + (1.*(-1 + x1) + 0.*(-2 + x2))*

       (-0.5773502691896258*(-1 + x1) + 1.1547005383792517*(-2 + x2))^2 + \
0.*(-2 + x2))}\
\>", "\<\
 {0.0166667 Second, 1 + 0.166667 (-3 (1. (-1 + x1) \
+ 0. (-2 + x2)) + 
                               3
  (1. (-1 + x1) + 0. (-2 + x2)) ) + 0.224525 
                                                                              \
         3
  (-3 (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) + (-0.57735 (-1 + x1) + 1.1547 \
(-2 + x2)) ) - 
                                                             2
  0.288675 (0.57735 (-1 + x1) + (1. (-1 + x1) + 0. (-2 + x2))  
  (-0.57735 (-1 + x1) + 1.1547 (-2 + x2)) - 1.1547 (-2 + x2)) + 
  0.166667 (-1. (-1 + x1) + (1. (-1 + x1) + 0. (-2 + x2)) 
                                         2
  (-0.57735 (-1 + x1) + 1.1547 (-2 + x2))  + 0. (-2 + x2))}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HermiteExpansionMultiStand[{x1,x2},{{1,2},{1,.5,1},{1,0,0,1}},\"{d,\
H}\"]//Simplify\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Part::pspec: Part specification 1 + k$ is neither an integer nor a \
list of integers.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 0.34567901234567894*x1^3 + \
x1^2*(-0.4444444444444444 - 0.2962962962962962*x2) - 

   0.29629629629629645*x1*(-4.732050807568875 + x2)*(-1.2679491924311228 + \
x2) + 

   0.34567901234567916*(0.34710759563233157 + x2)*(8.334179889054791 - 

     5.4899647384894745*x2 + x2^2)\
\>", "\<\
            3     2
 0.345679 x1  + x1  (-0.444444 - 0.296296 x2) - 
  0.296296 x1 (-4.73205 + x2) (-1.26795 + x2) + 
                                                     2
  0.345679 (0.347108 + x2) (8.33418 - 5.48996 x2 + x2 )\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Log-Reihe ", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Log[1+x+x^2] + O[x]^6", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
SeriesData[x, 0, {1, 1/2, -2/3, 1/4, 1/5}, 1, 6, \
1]\
\>", "\<\
     2      3    4    5
    x    2 x    x    x        6
x + -- - ---- + -- + -- + O[x]
    2     3     4    5\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
p=HermiteExpansion[6,z,mm]
p//Numerator
p//Denominator\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
(1 + (z*(-3 + z^2)*mm[3])/6 + ((3 - 6*z^2 + z^4)*(-3 \
+ mm[4]))/24 + (z*(15 - 10*z^2 + z^4)*(-10*mm[3] + mm[5]))/120 + ((-15 + \
45*z^2 - 15*z^4 + z^6)*(30 - 15*mm[4] + mm[6]))/720)/(E^(z^2/2)*Sqrt[2*Pi])\
\
\>", "\<\
             2                  2    4                             \
2    4                                   2       4    6
    z (-3 + z ) mm[3]   (3 - 6 z  + z ) (-3 + mm[4])   z (15 - 10 z  + z ) \
(-10 mm[3] + mm[5])   (-15 + 45 z  - 15 z  + z ) (30 - 15 mm[4] + mm[6])
1 + ----------------- + ---------------------------- + \
--------------------------------------- + \
--------------------------------------------------
            6                        24                                  120  \
                                          720
------------------------------------------------------------------------------\
---------------------------------------------------------------------
                                                                   2
                                                                  z /2
                                                                 E     Sqrt[2 \
Pi]\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
Sqrt[2]*(1 + (z*(-3 + z^2)*mm[3])/6 + ((3 - 6*z^2 + \
z^4)*(-3 + mm[4]))/24 + (z*(15 - 10*z^2 + z^4)*(-10*mm[3] + mm[5]))/120 + \
((-15 + 45*z^2 - 15*z^4 + z^6)*(30 - 15*mm[4] + mm[6]))/720)\
\>", "\<\
      \
                2                  2    4                             2    4  \
                                 2       4    6
             z (-3 + z ) mm[3]   (3 - 6 z  + z ) (-3 + mm[4])   z (15 - 10 z  \
+ z ) (-10 mm[3] + mm[5])   (-15 + 45 z  - 15 z  + z ) (30 - 15 mm[4] + \
mm[6])
Sqrt[2] (1 + ----------------- + ---------------------------- + \
--------------------------------------- + \
--------------------------------------------------)
                     6                        24                              \
    120                                            720\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
2*E^(z^2/2)*Sqrt[Pi]\
\>", "\<\
    2
   z /2
2 E     Sqrt[Pi]\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
logp= -Log[Denominator[p]] + Series[Log[p//Numerator],{z,0,6}] \
//Normal
explogp=Exp[logp]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 -Log[2*Sqrt[Pi]] + Log[Sqrt[2]*(1 + (-3 + mm[4])/8 \
+ (-30 + 15*mm[4] - mm[6])/48)] + (z*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

   (z^3*((3*(mm[3]/6 + (10*mm[3] - mm[5])/12))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) - (2*(-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 \
+ (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/

       (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/3 + z^2*(-1/2 + \
(-((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)^2) + (2*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48))/2) + 

   (z^4*((-3*(mm[3]/6 + (10*mm[3] - mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + \
mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + (4*((-3 + \
mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + (2*((3 - mm[4])/4 + (30 - 15*mm[4] + \
mm[6])/16)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

       (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*(-((mm[3]/6 + (10*mm[3] - mm[5])/12)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15*mm[4] - mm[6])/48)^2 - 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/4 + 

   (z^5*((-4*(-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-3 + mm[4])/24 + (-30 + \
15*mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + \
(-10*mm[3] + mm[5])/(24*(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + \
(3*(mm[3]/6 + (10*mm[3] - mm[5])/12)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - \
15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

       (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + (2*((3 - mm[4])/4 \
+ (30 - 15*mm[4] + mm[6])/16)*(-((mm[3]/6 + (10*mm[3] - mm[5])/12)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15*mm[4] - mm[6])/48)^2 - 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

      ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((mm[3]/6 + (10*mm[3] - \
mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

         (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2) + ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

             (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)))/5 + 

   (z^6*(-((-10*mm[3] + mm[5])*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(24*(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2) + (30 - 15*mm[4] + \
mm[6])/(120*(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + (4*((-3 + \
mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/

       (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + (3*(mm[3]/6 + \
(10*mm[3] - mm[5])/12)*(-((mm[3]/6 + (10*mm[3] - mm[5])/12)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15*mm[4] - mm[6])/48)^2 - 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

      (2*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(((mm[3]/6 + (10*mm[3] \
- mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

         (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2) + ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

             (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48))/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - (-10*mm[3] + mm[5])/(120*(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + 

         ((mm[3]/6 + (10*mm[3] - mm[5])/12)*(-((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2) + ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

         (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*((mm[3]/6 + (10*mm[3] \
- mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 \
+ (-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + 

            ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - 

         ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((mm[3]/6 + (10*mm[3] - \
mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

            (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2) + ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + 

            ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] -\\
  mm[6])/48)))/
              (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)))/6\
\>", "\<\
                                                    \
                                                                              \
                                                                              \
                                                               -mm[3]   -10 \
mm[3] + mm[5] 2             3 - mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                                                                              \
                                    (------ + -----------------)              \
--------- + ---------------------
                                                                              \
                                                                              \
                                                                              \
 -mm[3]   -10 mm[3] + mm[5]            2              8                       \
    4                16
                                                                              \
                                                                              \
                                                                              \
(------ + -----------------) (------------------------------------------ - \
---------------------------------------)
                                                                              \
                                                     mm[3]   10 mm[3] - mm[5] \
            -mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]    \
   2              8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2      \
 -3 + mm[4]   -30 + 15 mm[4] - mm[6]                         -mm[3]   -10 \
mm[3] + mm[5] 2               3 - mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                  3 (----- + \
----------------)         2 (------ + -----------------) (--------- + \
---------------------)                                 (1 + ---------- + \
----------------------)    1 + ---------- + ----------------------            \
            (------ + -----------------)             2 (--------- + \
---------------------)
                                                                              \
                                          3            6            12        \
              2              8               4                16              \
                                       8                  48                  \
     8                  48                                     2              \
8                             4                16
                                                                              \
                                         z  \
(--------------------------------------- - \
------------------------------------------------------------------ + \
------------------------------------------------------------------------------\
-------------------------------------)              \
-(------------------------------------------) + \
---------------------------------------
                                                                              \
      -mm[3]   -10 mm[3] + mm[5]                 -3 + mm[4]   -30 + 15 mm[4] \
- mm[6]                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2              \
                                           -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]                                                            -3 + mm[4]   \
-30 + 15 mm[4] - mm[6] 2        -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                                                              \
   z (------ + -----------------)            1 + ---------- + \
----------------------               (1 + ---------- + \
----------------------)                                                      \
1 + ---------- + ----------------------                                       \
                (1 + ---------- + ----------------------)     1 + ---------- \
+ ----------------------
                                     -3 + mm[4]   -30 + 15 mm[4] - mm[6]      \
        2              8                             8                  48    \
                              8                  48                           \
                                              8                  48           \
                                          2    1               8              \
    48                        8                  48
 -Log[2 Sqrt[Pi]] + Log[Sqrt[2] (1 + ---------- + ----------------------)] + \
--------------------------------------- + \
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
--------------------------------------------------------------------------- + \
z  (-(-) + \
------------------------------------------------------------------------------\
---------) + 
                                         8                  48                \
   -3 + mm[4]   -30 + 15 mm[4] - mm[6]                                        \
                                                                              \
3                                                                             \
                                               2                              \
                 2
                                                                             1\
 + ---------- + ----------------------
                                                                              \
       8                  48
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                         -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   \
30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                        (------ + -----------------)              --------- + \
---------------------
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                   -mm[3]   \
-10 mm[3] + mm[5]            2              8                           4     \
           16
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                  (------ + \
-----------------) (------------------------------------------ - \
---------------------------------------)
                                                                              \
                                                                             -\
mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 - 15 mm[4] + mm[6]     \
                                         mm[3]   10 mm[3] - mm[5]             \
-mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2        \
      8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4] \
  -30 + 15 mm[4] - mm[6]
                                                                              \
                                                                            (-\
----- + -----------------)              --------- + ---------------------     \
                                         ----- + ----------------            \
(------ + -----------------) (--------- + ---------------------)              \
                   (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
                                                                              \
                                  3 - mm[4]   30 - 15 mm[4] + mm[6]           \
 2              8                           4                16               \
   -mm[3]   -10 mm[3] + mm[5]              6            12                    \
  2              8               4                16                          \
                           8                  48                       8      \
            48
                                                                              \
                               2 (--------- + ---------------------) \
(------------------------------------------ - \
---------------------------------------)   (------ + -----------------) \
(-(---------------------------------------) + \
---------------------------------------------------------------- - \
------------------------------------------------------------------------------\
-------------------------------------)
          mm[3]   10 mm[3] - mm[5]   -mm[3]   -10 mm[3] + mm[5]       -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]           4                16                  \
-3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]       2              8                 -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                \
                                        -3 + mm[4]   -30 + 15 mm[4] - mm[6]
      -3 (----- + ----------------) (------ + -----------------)   4 \
(---------- + ----------------------)                                         \
 (1 + ---------- + ----------------------)    1 + ---------- + \
----------------------                                    1 + ---------- + \
----------------------               (1 + ---------- + \
----------------------)                                                     1 \
+ ---------- + ----------------------
   4        6            12            2              8                   24  \
               48                                                             \
 8                  48                       8                  48            \
                                          8                  48               \
                   8                  48                                      \
                                  8                  48
  z  (---------------------------------------------------------- + \
--------------------------------------- + \
------------------------------------------------------------------------------\
---------------------------------------------- + \
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------)
                   -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2               -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]                                                \
 -3 + mm[4]   -30 + 15 mm[4] - mm[6]                                          \
                                                                              \
                                       -3 + mm[4]   -30 + 15 mm[4] - mm[6]
              (1 + ---------- + ----------------------)            1 + \
---------- + ----------------------                                           \
  1 + ---------- + ----------------------                                     \
                                                                              \
                                        1 + ---------- + \
----------------------
                       8                  48                               8  \
                48                                                            \
   8                  48                                                      \
                                                                              \
                                         8                  48
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
--------------------------- + 
                                                                              \
                                                                              \
                                                                              \
              4
                                                                              \
                                                                              \
       -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 - 15 mm[4] + \
mm[6]
                                                                              \
                                                                              \
      (------ + -----------------)              --------- + \
---------------------
                                                                              \
                                                   mm[3]   10 mm[3] - mm[5]   \
         2              8                           4                16
                                                                              \
                                                3 (----- + ----------------) \
(------------------------------------------ - \
---------------------------------------)
           -mm[3]   -10 mm[3] + mm[5]   -3 + mm[4]   -30 + 15 mm[4] - mm[6]   \
                                                     6            12          \
     -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4]   -30 + 15 mm[4] \
- mm[6]
       -4 (------ + -----------------) (---------- + ----------------------)  \
                                                                              \
(1 + ---------- + ----------------------)    1 + ---------- + \
----------------------
    5        2              8               24                 48             \
              -10 mm[3] + mm[5]                                               \
         8                  48                       8                  48
  (z  (--------------------------------------------------------------------- \
+ -------------------------------------------- + \
------------------------------------------------------------------------------\
------------------------------------- + 
                         -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                \
         -3 + mm[4]   -30 + 15 mm[4] - mm[6]                                  \
            -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                    (1 + ---------- + ----------------------)                 \
 24 (1 + ---------- + ----------------------)                                 \
        1 + ---------- + ----------------------
                             8                  48                            \
             8                  48                                            \
                8                  48
                                                                              \
                                                                              \
                                  -mm[3]   -10 mm[3] + mm[5] 2             3 \
- mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                                 (------ + -----------------)              \
--------- + ---------------------
                                                                              \
                                                                            -\
mm[3]   -10 mm[3] + mm[5]            2              8                         \
  4                16
                                                                              \
                                                                           (--\
---- + -----------------) (------------------------------------------ - \
---------------------------------------)
                                                  mm[3]   10 mm[3] - mm[5]    \
         -mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       \
2              8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       \
-3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                                  ----- + ----------------    \
        (------ + -----------------) (--------- + ---------------------)      \
                           (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
     3 - mm[4]   30 - 15 mm[4] + mm[6]              6            12           \
           2              8               4                16                 \
                                    8                  48                     \
  8                  48
  2 (--------- + ---------------------) \
(-(---------------------------------------) + \
---------------------------------------------------------------- - \
------------------------------------------------------------------------------\
-------------------------------------)
         4                16                   -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                \
                                        -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                           1 + ---------- + \
----------------------               (1 + ---------- + \
----------------------)                                                     1 \
+ ---------- + ----------------------
                                                   8                  48      \
                            8                  48                             \
                                           8                  48
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
----------------------------------- + 
                                                                              \
                                          -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                                                              \
                                      1 + ---------- + ----------------------
                                                                              \
                                              8                  48
                                                                              \
                                                                              \
                       -mm[3]   -10 mm[3] + mm[5] 2              3 - mm[4]   \
30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                      (------ + -----------------)               --------- + \
---------------------
                                                                              \
                                                        3 - mm[4]   30 - 15 \
mm[4] + mm[6]              2              8                            4      \
          16
                                                                              \
                                                       (--------- + \
---------------------) (-(------------------------------------------) + \
---------------------------------------)
                                  mm[3]   10 mm[3] - mm[5]   -mm[3]   -10 \
mm[3] + mm[5]      -3 + mm[4]   -30 + 15 mm[4] - mm[6]          4             \
   16                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2        -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]
                                 (----- + ----------------) (------ + \
-----------------)     ---------- + ----------------------                    \
                        (1 + ---------- + ----------------------)     1 + \
---------- + ----------------------
    -mm[3]   -10 mm[3] + mm[5]      6            12            2              \
8                  24                 48                                      \
                         8                  48                        8       \
           48
  ((------ + -----------------) \
(------------------------------------------------------- - \
--------------------------------------- + \
------------------------------------------------------------------------------\
----------------------------------------------- + 
      2              8                      -3 + mm[4]   -30 + 15 mm[4] - \
mm[6] 2              -3 + mm[4]   -30 + 15 mm[4] - mm[6]                      \
                            -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                       (1 + ---------- + \
----------------------)           1 + ---------- + ----------------------     \
                                         1 + ---------- + \
----------------------
                                                8                  48         \
                     8                  48                                    \
                            8                  48
                                                                              \
                                                                              \
                      -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 \
- 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                     (------ + -----------------)              --------- + \
---------------------
                                                                              \
                                                                -mm[3]   -10 \
mm[3] + mm[5]            2              8                           4         \
       16
                                                                              \
                                                               (------ + \
-----------------) (------------------------------------------ - \
---------------------------------------)
                                       mm[3]   10 mm[3] - mm[5]            \
-mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2        \
      8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4] \
  -30 + 15 mm[4] - mm[6]
                                       ----- + ----------------           \
(------ + -----------------) (--------- + ---------------------)              \
                   (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
   -mm[3]   -10 mm[3] + mm[5]            6            12                     \
2              8               4                16                            \
                         8                  48                       8        \
          48
  (------ + -----------------) (--------------------------------------- - \
---------------------------------------------------------------- + \
------------------------------------------------------------------------------\
-------------------------------------)
     2              8               -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
            -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                             \
                           -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                1 + ---------- + ----------------------       \
       (1 + ---------- + ----------------------)                              \
                       1 + ---------- + ----------------------
                                        8                  48                 \
                8                  48                                         \
                               8                  48                          \
                                 -3 + mm[4]   -30 + 15 mm[4] - mm[6]
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
-----------------------)) / (1 + ---------- + ----------------------))) / 5 + \

                                                                              \
                                    -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
                                                                              \
                                     8                  48
                                                                              \
                                1 + ---------- + ----------------------
                                                                              \
                                        8                  48
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                           -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4] \
  30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                          (------ + -----------------)              --------- \
+ ---------------------
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                     -mm[3]   \
-10 mm[3] + mm[5]            2              8                           4     \
           16
                                                                              \
                                                                              \
                                                                              \
                                                                              \
                                                                    (------ + \
-----------------) (------------------------------------------ - \
---------------------------------------)
                                                                              \
                                                                              \
 -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 - 15 mm[4] + mm[6]   \
                                           mm[3]   10 mm[3] - mm[5]           \
  -mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2      \
        8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]
                                                                              \
                                                                              \
(------ + -----------------)              --------- + ---------------------   \
                                           ----- + ----------------           \
 (------ + -----------------) (--------- + ---------------------)             \
                    (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
                                                                              \
                                  -3 + mm[4]   -30 + 15 mm[4] - mm[6]         \
   2              8                           4                16             \
       mm[3]   10 mm[3] - mm[5]              6            12                  \
    2              8               4                16                        \
                             8                  48                       8    \
              48
                                                                              \
                               4 (---------- + ----------------------) \
(------------------------------------------ - \
---------------------------------------)   3 (----- + ----------------) \
(-(---------------------------------------) + \
---------------------------------------------------------------- - \
------------------------------------------------------------------------------\
-------------------------------------)
                              -mm[3]   -10 mm[3] + mm[5]                      \
                                      24                 48                  \
-3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]         6            12                -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                \
                                        -3 + mm[4]   -30 + 15 mm[4] - mm[6]
       -((-10 mm[3] + mm[5]) (------ + -----------------))                    \
                                                                        (1 + \
---------- + ----------------------)    1 + ---------- + \
----------------------                                    1 + ---------- + \
----------------------               (1 + ---------- + \
----------------------)                                                     1 \
+ ---------- + ----------------------
    6                           2              8                         30 - \
15 mm[4] + mm[6]                                                              \
   8                  48                       8                  48          \
                                            8                  48             \
                     8                  48                                    \
                                    8                  48
  (z  (--------------------------------------------------- + \
--------------------------------------------- + \
------------------------------------------------------------------------------\
------------------------------------------------ + \
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------ + 
                  -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2               -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]                                                \
   -3 + mm[4]   -30 + 15 mm[4] - mm[6]                                        \
                                                                              \
                                          -3 + mm[4]   -30 + 15 mm[4] - mm[6]
          24 (1 + ---------- + ----------------------)       120 (1 + \
---------- + ----------------------)                                          \
    1 + ---------- + ----------------------                                   \
                                                                              \
                                           1 + ---------- + \
----------------------
                      8                  48                               8   \
               48                                                             \
    8                  48                                                     \
                                                                              \
                                           8                  48
                                                                              \
                                                                              \
                                -mm[3]   -10 mm[3] + mm[5] 2              3 - \
mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                               (------ + -----------------)               \
--------- + ---------------------
                                                                              \
                                                                 3 - mm[4]   \
30 - 15 mm[4] + mm[6]              2              8                           \
 4                16
                                                                              \
                                                                (--------- + \
---------------------) (-(------------------------------------------) + \
---------------------------------------)
                                           mm[3]   10 mm[3] - mm[5]   -mm[3]  \
 -10 mm[3] + mm[5]      -3 + mm[4]   -30 + 15 mm[4] - mm[6]          4        \
        16                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2        -3 \
+ mm[4]   -30 + 15 mm[4] - mm[6]
                                          (----- + ----------------) (------ \
+ -----------------)     ---------- + ----------------------                  \
                          (1 + ---------- + ----------------------)     1 + \
---------- + ----------------------
      3 - mm[4]   30 - 15 mm[4] + mm[6]      6            12            2     \
         8                  24                 48                             \
                                  8                  48                       \
 8                  48
  (2 (--------- + ---------------------) \
(------------------------------------------------------- - \
--------------------------------------- + \
------------------------------------------------------------------------------\
----------------------------------------------- + 
          4                16                        -3 + mm[4]   -30 + 15 \
mm[4] - mm[6] 2              -3 + mm[4]   -30 + 15 mm[4] - mm[6]              \
                                    -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                                (1 + ---------- + \
----------------------)           1 + ---------- + ----------------------     \
                                         1 + ---------- + \
----------------------
                                                         8                  \
48                              8                  48                         \
                                       8                  48
                                                                              \
                                                                              \
                      -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 \
- 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                     (------ + -----------------)              --------- + \
---------------------
                                                                              \
                                                                -mm[3]   -10 \
mm[3] + mm[5]            2              8                           4         \
       16
                                                                              \
                                                               (------ + \
-----------------) (------------------------------------------ - \
---------------------------------------)
                                       mm[3]   10 mm[3] - mm[5]            \
-mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2        \
      8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4] \
  -30 + 15 mm[4] - mm[6]
                                       ----- + ----------------           \
(------ + -----------------) (--------- + ---------------------)              \
                   (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
   -mm[3]   -10 mm[3] + mm[5]            6            12                     \
2              8               4                16                            \
                         8                  48                       8        \
          48
  (------ + -----------------) (--------------------------------------- - \
---------------------------------------------------------------- + \
------------------------------------------------------------------------------\
-------------------------------------)
     2              8               -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
            -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                             \
                           -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                1 + ---------- + ----------------------       \
       (1 + ---------- + ----------------------)                              \
                       1 + ---------- + ----------------------
                                        8                  48                 \
                8                  48                                         \
                               8                  48                          \
                                 -3 + mm[4]   -30 + 15 mm[4] - mm[6]
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
-----------------------)) / (1 + ---------- + ----------------------) + 
                                                                              \
                                    -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
                                                                              \
                                     8                  48
                                                                              \
                                1 + ---------- + ----------------------
                                                                              \
                                        8                  48
                                                                              \
                                                                              \
                               -mm[3]   -10 mm[3] + mm[5] 2              3 - \
mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                              (------ + -----------------)               \
--------- + ---------------------
                                                                              \
                                                                         mm[3]\
   10 mm[3] - mm[5]              2              8                            \
4                16
                                                                              \
                                                                        (-----\
 + ----------------) (-(------------------------------------------) + \
---------------------------------------)
                                  -mm[3]   -10 mm[3] + mm[5]   -3 + mm[4]   \
-30 + 15 mm[4] - mm[6]                                                       \
6            12                 -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2        \
-3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                 (------ + -----------------) (---------- + \
----------------------)                                                       \
                          (1 + ---------- + ----------------------)     1 + \
---------- + ----------------------
    -mm[3]   -10 mm[3] + mm[5]      2              8               24         \
        48                            -10 mm[3] + mm[5]                       \
                                 8                  48                        \
8                  48
  ((------ + -----------------) \
(------------------------------------------------------------------ - \
--------------------------------------------- + \
------------------------------------------------------------------------------\
-------------------------------------- + 
      2              8                            -3 + mm[4]   -30 + 15 mm[4] \
- mm[6] 2                        -3 + mm[4]   -30 + 15 mm[4] - mm[6]          \
                                    -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                             (1 + ---------- + \
----------------------)                120 (1 + ---------- + \
----------------------)                                         1 + \
---------- + ----------------------
                                                      8                  48   \
                                     8                  48                    \
                                        8                  48
                                                                              \
                                                                              \
                             -mm[3]   -10 mm[3] + mm[5] 2             3 - \
mm[4]   30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                            (------ + -----------------)              \
--------- + ---------------------
                                                                              \
                                                                       -mm[3] \
  -10 mm[3] + mm[5]            2              8                           4   \
             16
                                                                              \
                                                                      (------ \
+ -----------------) (------------------------------------------ - \
---------------------------------------)
                                              mm[3]   10 mm[3] - mm[5]        \
    -mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2    \
          8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]
                                              ----- + ----------------        \
   (------ + -----------------) (--------- + ---------------------)           \
                      (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
   3 - mm[4]   30 - 15 mm[4] + mm[6]            6            12               \
      2              8               4                16                      \
                               8                  48                       8  \
                48
  (--------- + ---------------------) \
(--------------------------------------- - \
---------------------------------------------------------------- + \
------------------------------------------------------------------------------\
-------------------------------------)
       4                16                 -3 + mm[4]   -30 + 15 mm[4] - \
mm[6]                   -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                 \
                                       -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                       1 + ---------- + \
----------------------              (1 + ---------- + ----------------------) \
                                                    1 + ---------- + \
----------------------
                                               8                  48          \
                       8                  48                                  \
                                      8                  48
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------ - 
                                                                              \
                                       -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                                                              \
                                   1 + ---------- + ----------------------
                                                                              \
                                           8                  48
                                                                              \
                                                                              \
                       -mm[3]   -10 mm[3] + mm[5] 2              3 - mm[4]   \
30 - 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                      (------ + -----------------)               --------- + \
---------------------
                                                                              \
                                                        3 - mm[4]   30 - 15 \
mm[4] + mm[6]              2              8                            4      \
          16
                                                                              \
                                                       (--------- + \
---------------------) (-(------------------------------------------) + \
---------------------------------------)
                                  mm[3]   10 mm[3] - mm[5]   -mm[3]   -10 \
mm[3] + mm[5]      -3 + mm[4]   -30 + 15 mm[4] - mm[6]          4             \
   16                    -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2        -3 + \
mm[4]   -30 + 15 mm[4] - mm[6]
                                 (----- + ----------------) (------ + \
-----------------)     ---------- + ----------------------                    \
                        (1 + ---------- + ----------------------)     1 + \
---------- + ----------------------
    -mm[3]   -10 mm[3] + mm[5]      6            12            2              \
8                  24                 48                                      \
                         8                  48                        8       \
           48
  ((------ + -----------------) \
(------------------------------------------------------- - \
--------------------------------------- + \
------------------------------------------------------------------------------\
----------------------------------------------- + 
      2              8                      -3 + mm[4]   -30 + 15 mm[4] - \
mm[6] 2              -3 + mm[4]   -30 + 15 mm[4] - mm[6]                      \
                            -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                       (1 + ---------- + \
----------------------)           1 + ---------- + ----------------------     \
                                         1 + ---------- + \
----------------------
                                                8                  48         \
                     8                  48                                    \
                            8                  48
                                                                              \
                                                                              \
                      -mm[3]   -10 mm[3] + mm[5] 2             3 - mm[4]   30 \
- 15 mm[4] + mm[6]
                                                                              \
                                                                              \
                     (------ + -----------------)              --------- + \
---------------------
                                                                              \
                                                                -mm[3]   -10 \
mm[3] + mm[5]            2              8                           4         \
       16
                                                                              \
                                                               (------ + \
-----------------) (------------------------------------------ - \
---------------------------------------)
                                       mm[3]   10 mm[3] - mm[5]            \
-mm[3]   -10 mm[3] + mm[5]   3 - mm[4]   30 - 15 mm[4] + mm[6]       2        \
      8                -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2       -3 + mm[4] \
  -30 + 15 mm[4] - mm[6]
                                       ----- + ----------------           \
(------ + -----------------) (--------- + ---------------------)              \
                   (1 + ---------- + ----------------------)    1 + \
---------- + ----------------------
   -mm[3]   -10 mm[3] + mm[5]            6            12                     \
2              8               4                16                            \
                         8                  48                       8        \
          48
  (------ + -----------------) (--------------------------------------- - \
---------------------------------------------------------------- + \
------------------------------------------------------------------------------\
-------------------------------------)
     2              8               -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
            -3 + mm[4]   -30 + 15 mm[4] - mm[6] 2                             \
                           -3 + mm[4]   -30 + 15 mm[4] - mm[6]
                                1 + ---------- + ----------------------       \
       (1 + ---------- + ----------------------)                              \
                       1 + ---------- + ----------------------
                                        8                  48                 \
                8                  48                                         \
                               8                  48                          \
                                 -3 + mm[4]   -30 + 15 mm[4] - mm[6]          \
 -3 + mm[4]   -30 + 15 mm[4] - mm[6]
  ----------------------------------------------------------------------------\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
-----------------------)) / (1 + ---------- + ----------------------))) / (1 \
+ ---------- + ----------------------))) / 6
                                                                              \
                                    -3 + mm[4]   -30 + 15 mm[4] - mm[6]       \
                                                                              \
                                     8                  48                    \
     8                  48
                                                                              \
                                1 + ---------- + ----------------------
                                                                              \
                                        8                  48\
\>"], "Output",\

  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 E^(-Log[2*Sqrt[Pi]] + Log[Sqrt[2]*(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)] + (z*(-mm[3]/2 + (-10*mm[3] + \
mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

    (z^3*((3*(mm[3]/6 + (10*mm[3] - mm[5])/12))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) - (2*(-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 \
+ (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/

        (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/3 + z^2*(-1/2 + \
(-((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)^2) + (2*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48))/2) + 

    (z^4*((-3*(mm[3]/6 + (10*mm[3] - mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + \
mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + (4*((-3 + \
mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + (2*((3 - mm[4])/4 + (30 - 15*mm[4] + \
mm[6])/16)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

        (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*(-((mm[3]/6 + (10*mm[3] - mm[5])/12)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15*mm[4] - mm[6])/48)^2 - 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/4 + 

    (z^5*((-4*(-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-3 + mm[4])/24 + (-30 + \
15*mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + \
(-10*mm[3] + mm[5])/(24*(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + \
(3*(mm[3]/6 + (10*mm[3] - mm[5])/12)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - \
15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

        (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + (2*((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

       ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((mm[3]/6 + (10*mm[3] - \
mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

          (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2) + ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

              (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)))/5 + 

    (z^6*(-((-10*mm[3] + mm[5])*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(24*(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2) + (30 - 15*mm[4] + \
mm[6])/(120*(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + (4*((-3 + \
mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/

        (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + (3*(mm[3]/6 + \
(10*mm[3] - mm[5])/12)*(-((mm[3]/6 + (10*mm[3] - mm[5])/12)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15*mm[4] - mm[6])/48)^2 - 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

       (2*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(((mm[3]/6 + (10*mm[3] \
- mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

          (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)^2) + ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + (10*mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + ((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/

              (1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((-mm[3]/2 + \
(-10*mm[3] + mm[5])/8)*((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48))/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - (-10*mm[3] + mm[5])/(120*(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)) + 

          ((mm[3]/6 + (10*mm[3] - mm[5])/12)*(-((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2) + ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + 

          (((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)*((mm[3]/6 + (10*mm[3] \
- mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - ((-mm[3]/2 \
+ (-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16))/(1 + \
(-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + 

             ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - 

          ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*(((mm[3]/6 + (10*mm[3] - \
mm[5])/12)*(-mm[3]/2 + (-10*mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)^2 - ((-3 + mm[4])/24 + (-30 + 15*mm[4] - mm[6])/48)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) + (((3 - mm[4])/4 + (30 - \
15*mm[4] + mm[6])/16)*(-((-mm[3]/2 + (-10*mm[3] + mm[5])/8)^2/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2) + 

                ((3 - mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + \
mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48) + ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((mm[3]/6 + \
(10*mm[3] - mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48) - \
((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((3 - mm[4])/4 + (30 - 15*mm[4] + \
mm[6])/16))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 + 

                ((-mm[3]/2 + (-10*mm[3] + mm[5])/8)*((-mm[3]/2 + (-10*mm[3] + \
mm[5])/8)^2/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)^2 - ((3 - \
mm[4])/4 + (30 - 15*mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15*mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15*mm[4] - \
mm[6])/48)))/6)\
\>", "\<\
                                                   \
                                                                              \
                                                            3                 \
                                                                              \
                                                                              \
                                                      2
 Power[E, -Log[2 Sqrt[Pi]] + Log[Sqrt[2] (1 + (-3 + mm[4])/8 + (-30 + 15 \
mm[4] - mm[6])/48)] + (z (-mm[3]/2 + (-10 mm[3] + mm[5])/8))/(1 + (-3 + \
mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + (z  ((3 (mm[3]/6 + (10 mm[3] - \
mm[5])/12))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) - (2 (-mm[3]/2 \
+ (-10 mm[3] + mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  + 
                                                                         2    \
                                               2                              \
                                                                              \
                                                   2                          \
                      2                                                   2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/3 + z  (-(1/2) + (-((-mm[3]/2 \
+ (-10 mm[3] + mm[5])/8) /(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) \
) + (2 ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15 mm[4] - mm[6])/48))/2) + 
    4                                                                         \
                                                     2
  (z  ((-3 (mm[3]/6 + (10 mm[3] - mm[5])/12) (-mm[3]/2 + (-10 mm[3] + \
mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  + (4 ((-3 + \
mm[4])/24 + (-30 + 15 mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + 15 \
mm[4] - mm[6])/48) + 
                                                                              \
       2                                                   2
  (2 ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) ((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) /(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - \
mm[4])/4 + (30 - 15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                           2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) (-((mm[3]/6 + (10 mm[3] - mm[5])/12)/(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)) + ((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15 mm[4] - mm[6])/48)  - 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)))/4 + 
    5                                                                         \
                                                                   2
  (z  ((-4 (-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-3 + mm[4])/24 + (-30 + 15 \
mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  + \
(-10 mm[3] + mm[5])/(24 (1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)) + \

                                                                          2   \
                                                2
  (3 (mm[3]/6 + (10 mm[3] - mm[5])/12) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) \
/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - \
15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                                       2
  (2 ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) (-((mm[3]/6 + (10 mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)) + ((-mm[3]/2 + \
(-10 mm[3] + mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
    2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) (((mm[3]/6 + (10 mm[3] - mm[5])/12) \
(-mm[3]/2 + (-10 mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - \
mm[6])/48)  - ((-3 + mm[4])/24 + (-30 + 15 mm[4] - mm[6])/48)/(1 + (-3 + \
mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
       2                                                   2
  (((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) (-((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) /(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) ) + ((3 - \
mm[4])/4 + (30 - 15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                        2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((mm[3]/6 + (10 mm[3] - mm[5])/12)/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) - ((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15 mm[4] - mm[6])/48)  + 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - \
mm[6])/48)))/5 + 
    6                                                                         \
                                         2                                    \
                                                                              \
                                                           2                  \
                                 2
  (z  (-((-10 mm[3] + mm[5]) (-mm[3]/2 + (-10 mm[3] + mm[5])/8))/(24 (1 + (-3 \
+ mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) ) + (30 - 15 mm[4] + mm[6])/(120 (1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)) + (4 ((-3 + mm[4])/24 + (-30 \
+ 15 mm[4] - mm[6])/48) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 + (-3 + \
mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 mm[4] + \
mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + \
mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                            2
  (3 (mm[3]/6 + (10 mm[3] - mm[5])/12) (-((mm[3]/6 + (10 mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)) + ((-mm[3]/2 + \
(-10 mm[3] + mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                2
  (2 ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) (((mm[3]/6 + (10 mm[3] - \
mm[5])/12) (-mm[3]/2 + (-10 mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)  - ((-3 + mm[4])/24 + (-30 + 15 mm[4] - mm[6])/48)/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
       2                                                   2
  (((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) (-((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) /(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) ) + ((3 - \
mm[4])/4 + (30 - 15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                        2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((mm[3]/6 + (10 mm[3] - mm[5])/12)/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) - ((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15 mm[4] - mm[6])/48)  + 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                  2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) (((-mm[3]/2 + (-10 mm[3] + mm[5])/8) \
((-3 + mm[4])/24 + (-30 + 15 mm[4] - mm[6])/48))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)  - (-10 mm[3] + mm[5])/(120 (1 + (-3 + mm[4])/8 + (-30 \
+ 15 mm[4] - mm[6])/48)) + 
                                                                          2   \
                                                2
  ((mm[3]/6 + (10 mm[3] - mm[5])/12) (-((-mm[3]/2 + (-10 mm[3] + mm[5])/8) \
/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) ) + ((3 - mm[4])/4 + (30 \
- 15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - \
mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                                  2
  (((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) ((mm[3]/6 + (10 mm[3] - \
mm[5])/12)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) - ((-mm[3]/2 + \
(-10 mm[3] + mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 \
+ mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  + 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48) - 
                                                                              \
                                                                              \
    2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) (((mm[3]/6 + (10 mm[3] - mm[5])/12) \
(-mm[3]/2 + (-10 mm[3] + mm[5])/8))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - \
mm[6])/48)  - ((-3 + mm[4])/24 + (-30 + 15 mm[4] - mm[6])/48)/(1 + (-3 + \
mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
       2                                                   2
  (((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16) (-((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) /(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) ) + ((3 - \
mm[4])/4 + (30 - 15 mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] \
- mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) + 
                                                                              \
                                                                              \
                                                                              \
                        2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((mm[3]/6 + (10 mm[3] - mm[5])/12)/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48) - ((-mm[3]/2 + (-10 mm[3] + \
mm[5])/8) ((3 - mm[4])/4 + (30 - 15 mm[4] + mm[6])/16))/(1 + (-3 + mm[4])/8 + \
(-30 + 15 mm[4] - mm[6])/48)  + 
                                                                         2    \
                                               2
  ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) ((-mm[3]/2 + (-10 mm[3] + mm[5])/8) /(1 \
+ (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)  - ((3 - mm[4])/4 + (30 - 15 \
mm[4] + mm[6])/16)/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + \
(-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + \
15 mm[4] - mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - \
mm[6])/48)))/(1 + (-3 + mm[4])/8 + (-30 + 15 mm[4] - mm[6])/48)))/6]\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
rule={mm[3]->-1,mm[4]->4,mm[5]->1,mm[6]->19}
Plot[{p,explogp}/.rule//Evaluate,{z,-3,3}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{mm[3] -> -1, mm[4] -> 4, mm[5] -> 1, mm[6] -> 19}\
\
\>", "\<\
{mm[3] -> -1, mm[4] -> 4, mm[5] -> 1, mm[6] -> 19}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[GraphicsData["PICT", "\<\
=;h0100Y0;81@`0A0_l<0?ooool0:@0000@000530000/P000000000N00402P04
02T0/P5309X0003oQ6P000000:h16P0000@0000004P0E@1804@0400P00<02000
000JD9_D000000000000[P4J00@0:@2b0D<0900>POn1oh7oPOn1oh7o/ol06^_o
P@210?h0j_n10840oP3Zoh40P@3n003o0JSno`400?Woo03mo`00o?l00?[o003i
o`00n_l00?[o003jo`00n_l00?Wo003jo`00n_l00?[o003jo`00n_l00?Wo003j
o`00n_l00?[o003jo`00nOl00?[o003jo`00n_l00?[o003io`00n_l00?[o003j
o`00n_l00?Wo003jo`00n_l00?co003mo`400?Woo03mo`00o?l00?[o003io`00
n_l00?[o003jo`00n_l00?Wo003jo`00n_l00?[o003jo`00n_l00?Wo003jo`00
n_l00?[o003jo`00nOl00?[o003jo`00n_l00?[o003io`00n_l00?[o003jo`00
n_l00?Wo003jo`00n_l00?co003mo`400?Woo03mo`00o?l00?[o003io`00n_l0
0?[o003jo`00n_l00?Wo003jo`00n_l00?[o003jo`00n_l00?Wo003jo`00n_l0
0?[o003jo`00nOl00?[o003jo`00n_l00?[o003io`00n_l00?[o003jo`00n_l0
0?Wo003jo`00n_l00?co0@3o09X5ool0ool0n_l00?ko003mo`00o?l00=Wo003I
o`00fOl00=Wo003Io`00fOl00?co003no`<0ool0n_l00?ko003mo`00o?l00=Wo
003Io`00fOl00=Wo003Io`00fOl00?co003no`<0ool0n_l00?ko003mo`00o?l0
0=Wo003Io`00fOl00=Wo003Io`00fOl00?co0@3o04T5ool0ool0m_l00?go0021
oh7o0Ol0o_l30?oo0?Ko003mo`00POodoobIT_l00?ko0`3oo`3fo`00oOl0087o
m?ol09;o0@3o04T5ool0ool0mol00?cooP21ohCooP3no`<0ool0mol00?cooP21
ooOonYVEooh0o_l30?oo0?Oo003looh0POogooX0UOon003o05<5ool0ool0mol0
0?co0021oh7o0Ol0o_l30?oo0?Oo003lo`00POoeoojI0?omV@00UOl00?ko0`3o
o`3go`00o?l0087omOon003oo02Eo`40o`1C1Ooo0?oo0?So003ko`00POn1o`7o
0?ko0`3oo`3ho`00nol0087omoomVOgooYT009Ko003no`<0ool0n?l00?_o0021
ooOoo@3mood0U_l10?l0FOko0@00oOl00?co003ko`00POn1o`7o0?go0@00oOl0
0?co003ko`00POohoofInoonV@00Uol00?go0@00oOl00?co003ko`00POohood0
noom09Oo0@3o03O[o`40087oP_l1003Zo`40087onOl1VIWhoojIV?l1003Zo`40
087onOl1003hooh0V?l2003o03;[o`00POn1o`7o0>[o0021ooWooYWgo`:IV@2H
o`00j_l0087onOon0?OooP2Ho`40o`0bjol0087oPOl1o`3Zo`00POoio`6IVOKo
oYVHo`00j_l0087onOl1003fooh0V?l10?l0<^_o0021oh7o0Ol0j_l0087on_on
VOGo0YVI09Wo003Zo`00POojooh0mOon09Wo0@3o03W[o`40087oP_l1003Zo`40
087onol1VIWdo`:IV@2Jo`400>[o0@00POoko`400?CooP2Jo`800?l0<^_o0021
oh7o0Ol0j_l0087onoonVOCooYT009[o003Zo`00POokooh0m?om09[o0@3o03G[
o`00POn1o`7o0>[o0021oo_o0IVIl_l3VIT009_o003Zo`00POoko`400?;oo@2K
o`40o`0cjol0087oPOl1o`3Zo`00POoloojIl_l3VIT009_o003Zo`00POolooh0
l_om09_o0@3o03W[o`40087oP_l1003Zo`40087ooOl1VIWaoojI002Lo`400>[o
0@00POomo`400?7oo@2Lo`800?l0<n_o0021oh7o0Ol0j_l0087ooOonVO3o0iVI
002Lo`00j_l0087ooOon0?3oo@2Lo`40o`0ejol0087oPOl1o`3Zo`00POomo`6I
VNoo0iVI002Lo`00j_l0087ooOl1003_ood0W?l10?l0=>_o0021oh7o0Ol0j_l0
087ooOl1VIW_oojI002Lo`00j_l0087ooOl1003_ood0W?l10?l0>^_o0@00POn2
o`400>[o0@00POl1ooonVNko0iVI002No`400>[o0@00POl1ooon0>koo@2No`80
0?l0Doko0@00mol1003lo`00POn1o`7o0?go0@00mol1003lo`00POono`6IVNgo
0iVI002Mo`00oOl1003go`400?co0021ooko0@00kOom09go0@3o05H5ool0ool0
nOl00?[o0021oh7o0Ol0o_l30?oo0?Wo003jo`00POono`6IVNgo0iVI002Mo`00
o_l30?oo0?Wo003jo`00POono`400>goo@2Mo`40o`1F1Ooo0?oo0?[o003io`00
POn1o`7o0?ko0`3oo`3jo`00nOl0087o0OoooYW]o`6IVOh0W_l00?ko0`3oo`3j
o`00nOl0087o0OoooP3]oo`0W_l10?l0DPGoo`3oo`3jood0o?on087oQ?on0?ko
0`3oo`3jood0o?on087o0YVI0>gooYT1002Pooh0o_l30?oo0?[oo@3looh0POon
0>goo02Pooh00?l0HPGoo`3oo`3jo`00o_l00?go0021oh7o0Ol0o_l30?oo0?[o
003no`00oOl0087o0oooVIW[o`>IV@00W_l00?ko0`3oo`3jo`00o_l00?go0021
o`?oo`00joom09ko0@3o0605ool0ool0n_l00?ko003mo`00POn1o`7o0?ko0`3o
o`3jo`00o_l00?go0021o`3ooYW[o`6IVOh0Wol00?ko0`3oo`3jo`00o_l00?go
0021o`3ooP3[oo`0Wol10?l0H?ko0@00oOl00?gooP3lo`00POn1o`7o0?go0@00
oOl00?gooP3lo`00POl3oiVI0>_o19VIo`00Wol00?go0@00oOl00?gooP3lo`00
POl0ooh0jol4003o002Oo`40o`0fjol10021oh;o0@00j_l10021o`:IV@3[oojI
0@00X?l1003Zo`40087ooP3[oo`0X?l2003o02o[o`00POn1o`7o0>[o0021oojI
jOl1VIWn0:3o003Zo`00POon0>Woo02Po`40o`0fjol0087oPOl1o`3Zo`00POl2
VIT0jOl4VIWo002Po`00j_l0087ooP3Yo`@00?l00:3o0@3o03K[o`00POn1o`7o
0>[o0021o`:IV@3Yo`BIVOl00:3o003Zo`00POon0>Wo1000o`00X?l10?l0=^_o
0@00POn2o`400>[o0@00P_l1VIWXoojI0@00XOl1003Zo`4008;o0@00j?ol0:7o
0P00o`0_jol0087oPOl1o`3Zo`00P_onVNOo0IVIoP2Qo`00j_l008;ooP3Woo`0
XOl10?l0=^_o0021oh7o0Ol0j_l008;o0YVI0>Oo19VIo`00XOl00>[o0022ooh0
iol4003o002Qo`40o`0fjol0087oPOl1o`3Zo`00P_l1VIWVo`BIVOl00:7o003Z
o`00P_l1003Vo`@00?l00:7o0@3o03G[o`40087oP_l1003Zo`4008?o0IVIi_on
VOh0Xol1003Zo`4008?o0@00i_ok0:?o0P00o`0djol0087oPOl1o`3Zo`00Poon
VNGo19VIo`00X_l00>[o0023ooh0iOl4003o002Ro`40o`0fjol0087oPOl1o`3Z
o`00Pol1VIWTo`BIVOl00:;o003Zo`00Pol1003To`@00?l00:;o0@3o03K[o`00
POn1o`7o0>[o0023o`6IVNCo19VIo`00X_l00>[o0023o`400>Co1000o`00X_l1
0?l0>N_o0@00POn2o`400>[o0@00QOonVNCo0YVIooh0Y?l1003Zo`4008GooP3T
o`800?on0:Co0P00o`1Ao_l1003ioo`0oOl0087oPOl1o`3mo`400?Woo03mo`00
Q?l2VIT0i?onV@;o002So`00oOl1003ioo`0oOl008CooP3Tooh00_l00:?o0@3o
05L5ool0ool0n_l00?Wo0021oh7o0Ol0o_l30?oo0?[o003io`00Q?l1VIWRo`BI
VOl00:?o003no`<0ool0n_l00?Wo0024o`400>;o1000o`00Xol10?l0E`Goo`3o
o`3jood0o?l0087oPOl1o`3no`<0ool0n_om0?co0024o`6IVN;o0YVIooh0Y?l0
0?ko0`3oo`3jood0o?l008Co0@00h_l2003ooP2To`40o`1G1Ooo0?oo0?Ko003m
ooh0POn4ooh0o_l30?oo0?Ko003mooh0QoonVN;o1IVIool00:KooP3no`<0ool0
m_l00?gooP27ooh0h_l5003oo`00Y_on003o05T5ool0ool0m_l00?go0021oh7o
0Ol0o_l30?oo0?Ko003mo`00QOl1VIWQo`FIVOoo002To`00o_l30?oo0?Ko003m
o`00QOl1003Qo`D00?oo002To`40o`1U1Ooo0?oo0?[o003no`00oOl0087oPOl1
o`3no`<0ool0n_l00?ko003mo`00QOl1VIWQo`FIVOoo002To`00o_l30?oo0?[o
003no`00oOl008Go0@00hOl5003oo`00Y?l10?l0GOko0@00oOl00?gooP3lo`00
POn1o`7o0?go0@00oOl00?gooP3lo`00QOl1VIWQoojI0?on0:Go003mo`400?go
003mooh0o?l008Go0@00hOon003ooP2Uo`40o`0kjol10021oh;o0@00j_l10027
oojIh?l5VIWoo`00Y_l1003Zo`4008OooP3Po`D00?oo002Vo`800?l0>>_o0021
oh7o0Ol0j_l008Ko0IVIgol5VIWoo`00YOl00>[o0026o`400=oo1@00ool00:Go
0@3o03S[o`00POn1o`7o0>[o0026o`6IVMoo1IVIool00:Go003Zo`00Q_l1003O
o`D00?oo002Uo`40o`0hjol0087oPOl1o`3Zo`00Q_l1VIWOo`>IVOoooP2Vo`00
j_l008Ko0@00gol3003oooh0Y_l10?l0?n_o0@00POn2o`400>[o0@00R?l209VI
gol1VIWno`400:Oo0@00j_l10028ooh0gol1003no`400:Oo0P00o`0hjol0087o
POl1o`3Zo`00QoonVMoo0IVIo_l1002Vo`00j_l008OooP3Oo`400?ko0@00Y_l1
0?l0>>_o0021oh7o0Ol0j_l008Oo0IVIg_onV@7oooh0Yol00>[o0027o`400=ko
oP01ooon0:Oo0@3o03[[o`00POn1o`7o0>[o0028o`80VIWMo`6IVOko0@00Yol0
0>[o0028ooh0gOl1003no`400:Oo0@3o03o[o`40087oP_l1003Zo`4008Wo0P2I
VMgo0IVIo_l1002Xo`400>[o0@00ROon0=go0@00o_l1002Xo`800?l0>>_o0021
oh7o0Ol0j_l008SooYWMo`6IVOko0@00Yol00>[o0028ooh0gOl1003no`400:Oo
0@3o03S[o`00POn1o`7o0>[o0028o`6IVMco0IVIo_on0:So003Zo`00R?l1003L
o`400?kooP2Xo`40o`0jjol0087oPOl1o`3Zo`00ROl209VIg?l1VIWmo`400:So
003Zo`00ROon0=co0@00oOl1002Xo`40o`0mjol10021oh;o0@00j_l1002:o`80
VIWLoojIo_l1002Yo`400>[o0@00R_on0=cooP3no`400:Wo0P00o`1Ao_l1003f
o`00o?l0087oPOl1o`3mo`400?Ko003lo`00ROonVM_o0IVIo_on0:Wo003mo`40
0?Ko003lo`00ROon0=_o0@00o_on0:Wo0@3o05h5ool0ool0n?l1003lo`00POn1
o`7o0?ko0`3oo`3ho`400?co0029o`6IVM[o0IVIoOl1002Yo`00o_l30?oo0?So
0@00o?l008Wo0@00f_l1003mo`400:Wo0@3o0645ool0ool0nOl20?l0o?l0087o
POl1o`3no`<0ool0nOl20?l0o?l008Wo0IVIf_l1VIWmo`400:Wo003no`<0ool0
nOl20?l0o?l008Wo0@00f_l1003mo`400:Wo0@3o06@5ool0ool0n_l30?oo0?co
oP21ohCooP3no`<0ool0n_l30?oo0?cooP2<o`80VIWJo`6IVOgo0@00Zoon0?ko
0`3oo`3jo`<0ool0o?on08cooP3Jo`400?go0@00Zoon003o05L5ool0ool0n_ol
0?go0021oh7o0Ol0o_l30?oo0?[oo03mo`00R_onVM[o0IVIoOon0:[o003no`<0
ool0n_ol0?go002:ooh0f_l1003mooh0Z_l10?l0F@Goo`3oo`3go`00o?l0087o
POl1o`3no`<0ool0mol00?co002:o`6IVMWooYWmo`400:[o003no`<0ool0mol0
0?co002:o`400=WooP3mo`400:[o0@3o067no`400?go003looh0oOl0087oPOl1
o`3mo`400?go003looh0oOl008[o0IVIf?l1VIWmo`400:[o003mo`400?go003l
ooh0oOl008[o0@00f?l1003mo`400:[o0@3o03g[o`40087oP_l1003Zo`4008co
0P2IVMSo0IVIoOon0:co0@00j_l1002<ooh0f?l1003mooh0[?l2003o03S[o`00
POn1o`7o0>[o002;oojIf?l1VIWlo`400:_o003Zo`00Roon0=So0@00o?l1002[
o`40o`0jjol0087oPOl1o`3Zo`00Rol1VIWGo`6IVOco0@00Zol00>[o002;o`40
0=Oo0@00o?l1002[o`40o`0jjol0087oPOl1o`3Zo`00Rol1VIWGo`6IVOco0@00
Zol00>[o002;o`400=Oo0@00o?l1002[o`40o`0kjol10021oh;o0@00j_l1002=
o`80VIWGoojIoOon0:go0@00j_l1002=ooh0eoon0?gooP2]o`800?l0>^_o0021
oh7o0Ol0j_l008co0P2IVMKo0IVIo?l1002/o`00j_l008cooP3Fo`400?co0@00
[?l10?l0>>_o0021oh7o0Ol0j_l008cooYWFo`6IVOco0@00[?l00>[o002<ooh0
e_l1003lo`400:co0@3o03[[o`00POn1o`7o0>[o002<o`6IVMGo0IVIo?l1002/
o`00j_l008co0@00eOl1003lo`400:co0@3o03g[o`40087oP_l1003Zo`4008go
0IVIeOl1VIWlooh0[_l1003Zo`4008go0@00eOl1003looh0[_l2003o03[[o`00
POn1o`7o0>[o002=o`80VIWEo`6IVO_o0@00[Ol00>[o002=ooh0eOl1003ko`40
0:go0@3o03S[o`00POn1o`7o0>[o002=oojIeOl1VIWko`400:go003Zo`00SOon
0=Go0@00nol1002]o`40o`0hjol0087oPOl1o`3Zo`00SOl1VIWDoojIo?l1002]
o`00j_l008go0@00e?on0?co0@00[Ol10?l0?n_o0@00POn2o`400>[o0@00S_l1
VIWCo`6IVOco0@00[_l1003Zo`4008ko0@00dol1003lo`400:ko0P00o`1Co_l1
003hooh0o?l0087oPOl1o`3mo`400?SooP3lo`00S_l209VIdol1VIWlooh0[_l0
0?go0@00n?on0?co002>ooh0dol1003looh0[_l10?l0I@Goo`3oo`3jo`00o_l0
0?go0021oh7o0Ol0o_l30?oo0?[o003no`00oOl008kooYWCo`6IVO_o0@00[_l0
0?ko0`3oo`3jo`00o_l00?go002>ooh0dol1003ko`400:ko0@3o05/5ool0ool0
m_l00?go0021oh7o0Ol0o_l30?oo0?Ko003mo`00S_l1VIWBo`6IVO_o0@00[_l0
0?ko0`3oo`3fo`00oOl008ko0@00d_l1003ko`400:ko0@3o05h5ool0ool0n?l1
003looh0POn4ooh0o_l30?oo0?So0@00o?on093o0IVId_l1VIWko`400;3ooP3n
o`<0ool0n?l1003looh0T?l1003Bo`400?_o0@00/?on003o05L5ool0ool0m_l0
0?go0021oh7o0Ol0o_l30?oo0?Ko003mo`00S_l1VIWBoojIo?on0:oo003no`<0
ool0m_l00?go002>o`400=;ooP3looh0[ol10?l0I@Goo`3oo`3jo`00o_l00?go
0021oh7o0Ol0o_l30?oo0?[o003no`00oOl008oooYWAo`6IVO_o0@00[ol00?ko
0`3oo`3jo`00o_l00?go002?ooh0dOl1003ko`400:oo0@3o067no`400?go003m
ooh0o?l0087oPOl1o`3mo`400?go003mooh0o?l008oo0IVId?l1VIWko`400:oo
003mo`400?go003mooh0o?l008oo0@00d?l1003ko`400:oo0@3o03o[o`40087o
P_l1003Zo`40093o0IVId?l1VIWko`400;3o0@00j_l1002@o`400=3o0@00nol1
002`o`800?l0>>_o0021oh7o0Ol0j_l008oo0IVId?l1VIWkooh0/?l00>[o002?
o`400=3o0@00noon0;3o0@3o03[[o`00POn1o`7o0>[o002@o`80VIW@o`6IVO[o
0@00/?l00>[o002@ooh0d?l1003jo`400;3o0@3o03K[o`00POn1o`7o0>[o002@
oojId?onVO_o0@00/?l00>[o002@ooh0d?on0?_o0@00/?l10?l0?n_o0@00POn2
o`400>[o0@00TOl1VIW>o`6IVO_o0@00/Ol1003Zo`40097o0@00c_l1003ko`40
0;7o0P00o`0hjol0087oPOl1o`3Zo`00T?l1VIW>o`6IVO_ooP2ao`00j_l0093o
0@00c_l1003kooh0/Ol10?l0>^_o0021oh7o0Ol0j_l0093o0IVIc_l1VIWjo`40
0;7o003Zo`00T?l1003>o`400?[o0@00/Ol10?l0>^_o0021oh7o0Ol0j_l0097o
0P2IVLko0IVIn_l1002ao`00j_l0097ooP3>o`400?[o0@00/Ol10?l0?N_o0@00
POn2o`400>[o0@00T_onVLko0IVIn_l1002bo`400>[o0@00T_on0<ko0@00n_l1
002bo`800?l0>>_o0021oh7o0Ol0j_l0097o0IVIcOl1VIWjooh0/_l00>[o002A
o`400<go0@00n_on0;;o0@3o03S[o`00POn1o`7o0>[o002Ao`6IVLgooYWjo`40
0;;o003Zo`00TOl1003=ooh0n_l1002bo`40o`0jjol0087oPOl1o`3Zo`00TOl1
VIW<o`6IVO[o0@00/_l00>[o002Ao`400<co0@00n_l1002bo`40o`0mjol10021
oh;o0@00j_l1002CoojIc?l1VIWjo`400;?o0@00j_l1002Cooh0c?l1003jo`40
0;?o0P00o`1Eo_l1003hooh0o?l0087oPOl1o`3mo`400?SooP3lo`00T_l1VIW;
o`6IVO[o0@00/_l00?go0@00n?on0?co002Bo`400<_o0@00n_l1002bo`40o`1U
1Ooo0?oo0?[o003no`00oOl0087oPOl1o`3no`<0ool0n_l00?ko003mo`00T_l1
VIW;o`6IVO[ooP2co`00o_l30?oo0?[o003no`00oOl009;o0@00bol1003jooh0
/ol10?l0I`Goo`3oo`3jo`00o_l00?go0021oh7o0Ol0o_l30?oo0?[o003no`00
oOl009;o0IVIbol1VIWio`400;?o003no`<0ool0n_l00?ko003mo`00T_l1003;
o`400?Wo0@00/ol10?l0F@Goo`3oo`3go`00o?on087oQ?on0?ko0`3oo`3go`00
o?on09Go0P2IVL_ooYWjo`400;GooP3no`<0ool0mol00?cooP2Eooh0boon0?[o
0@00]Oon003o05T5ool0ool0n?l00?_o0021oh7o0Ol0o_l30?oo0?So003ko`00
ToonVL[o0IVIn_l1002co`00o_l30?oo0?So003ko`00Toon0<[o0@00n_l1002c
o`40o`1R1Ooo0?oo0?Wo0`3oo`3mo`00POn1o`7o0?ko0`3oo`3io`<0ool0oOl0
09?o0IVIbOl1VIWjooh0]?l00?ko0`3oo`3io`<0ool0oOl009?o0@00bOl1003j
ooh0]?l10?l0HOko0@00oOl00?koo03mo`00POn1o`7o0?go0@00oOl00?koo03m
o`00Tol1VIW9o`6IVOWo0@00]?l00?go0@00oOl00?koo03mo`00Tol10039o`40
0?Wo0@00]?l10?l0?n_o0@00POn2o`400>[o0@00U?l1VIW9o`6IVOWo0@00]Ol1
003Zo`4009Co0@00bOl1003io`400;Go0P00o`0hjol0087oPOl1o`3Zo`00U?on
VLWo0IVInOl1002do`00j_l009CooP39o`400?Wo0@00]?l10?l0>>_o0021oh7o
0Ol0j_l009Co0IVIb?l1VIWiooh0]Ol00>[o002Do`400<So0@00nOon0;Go0@3o
03S[o`00POn1o`7o0>[o002Do`6IVLSooYWio`400;Go003Zo`00U?l10038ooh0
nOl1002eo`40o`15jol10021oh;o0@00j_l1003IooL0b?onVLOo0IVInOl1002f
o`400>[o0@00fOog0<SooP37o`400?Wo0@00]_l2003o043[o`00POn1o`7o0>[o
003Ioo@0b_l2VIT0aol1VIWiooh0]_l00>[o003Ioo@0b_on0<Oo0@00nOon0;Ko
0@3o04[[o`00POn1o`7o0>[o003Kood0nOol0<co0IVIa_l1VIWho`400;Ko003Z
o`00foom0?Woo03<o`400<Ko0@00n?l1002fo`40o`1:jol0087oPOl1o`3Zo`00
g_ok0?Koo03>o`6IVLKo0IVIn?l1002fo`00j_l00=kon`3foo`0c_l10036o`40
0?So0@00]_l10?l0A^_o0021oh7o0Ol0j_l00=ooo03bood0d?onVLKo0IVIn?on
0;Oo003Zo`00gool0?;oo@3@ooh0a_l1003hooh0]ol10?l0Cn_o0@00POn2o`40
0>[o0@00hOon0>gooP3Ao`:IV@36o`6IVOOo0@00^?l1003Zo`400>7ooP3]ooh0
dOon0<Ko0@00mol1002ho`800?l0B^_o0021oh7o0Ol0j_l00>7ooP3[o`400=7o
0YVI0<KooYWho`400;Oo003Zo`00hOon0>_o0@00dOon0<KooP3ho`400;Oo0@3o
04S[o`00POn1o`7o0>[o003Sood0j_on0=;o0IVIa?l1VIWhooh0^?l00>[o003S
ood0j_on0=;o0@00a?l1003hooh0^?l10?l0B>_o0021oh7o0Ol0j_l00>Coo@3X
ooh0e?onVLCo0IVImol1002ho`00j_l00>Coo@3Xooh0e?on0<Co0@00mol1002h
o`40o`1?jol10021oh;o0@00j_l1003Vooh0iOon0=Go0YVI0<Co0IVImol1002i
o`400>[o0@00i_on0>GooP3Eooh0a?l1003go`400;Wo0P00o`1So_l1003go`00
nol0087oPOl1o`3mo`400?Oo003ko`00i_on0>?ooP3Fo`:IV@34o`6IVOOooP2i
o`00oOl1003go`00nol00>KooP3Sooh0e_on0<Co0@00moon0;Wo0@3o06X5ool0
ool0nOl1003ko`00POn1o`7o0?ko0`3oo`3io`400?_o003Wooh0hOon0=SooYW3
oojImol1002io`00o_l30?oo0?Wo0@00nol00>OooP3Qooh0f?on0<?ooP3go`40
0;Wo0@3o06/5ool0ool0n?l00?_o0021oh7o0Ol0o_l30?oo0?So003ko`00j?on
0=oo0@00f?l2VIT0`_l1VIWgooh0^_l00?ko0`3oo`3ho`00nol00>SooP3Oo`40
0=SooP32o`400?OooP2jo`40o`1[1Ooo0?oo0?So003kooh0POn4ooh0o_l30?oo
0?So003kooh0joon0=kooP3Io`:IV@32o`6IVOKo0@00_?on0?ko0`3oo`3ho`00
noon0>_ooP3Nooh0fOon0<;o0@00m_l1002looh00?l0I`Goo`3oo`3ho`00nol0
087oPOl1o`3no`<0ool0n?l00?_o003Zooh0g?on0=_ooYW1oojImol1002jo`00
o_l30?oo0?So003ko`00j_on0=cooP3Kooh0`Oon0?Oo0@00^_l10?l0J@Goo`3o
o`3ho`00nol0087oPOl1o`3no`<0ool0n?l00?_o003[ooh0f_on0=co0YVI0<3o
0IVImoon0;_o003no`<0ool0n?l00?_o003[ooh0f_on0=cooP30o`400?OooP2k
o`40o`1co_l1003mo`00oOon0?co0021oh7o0Ol0oOl1003mo`00oOon0?co003/
ooh0f?l1003MoojI0030o`6IVOKo0@00^ol00?go0@00oOl00?gooP3lo`00k?on
0=So0@00gOom0<3o0@00m_l1002ko`40o`1=jol10021oh;o0@00j_l1003_ood0
eoon0=ko0YVI0;oo0IVIm_on0;go0@00j_l1003_ood0eoon0=kooP2oo`400?Ko
oP2mo`800?l0B^_o0021oh7o0Ol0j_l00>ooo@3Eooh0h?onV@00_ol1VIWeo`40
0;co003Zo`00koom0=GooP3Pood0_ol1003eo`400;co0@3o04W[o`00POn1o`7o
0>[o003`ooh0d_l1003Po`>IV@00_oonVOKooP2mo`00j_l00?3ooP3Bo`400>3o
o@2oooh0m_on0;go0@3o04[[o`00POn1o`7o0>[o003aooh0dOon0>;ooYT00;go
0IVImOl1002mo`00j_l00?7ooP3Aooh0h_om0;go0@00mOl1002mo`40o`1@jol1
0021oh;o0@00j_l1003dood0coon0>?o0iVI002mo`6IVOGo0@00__l1003Zo`40
0?Coo@3?ooh0hoom0;go0@00mOl1002no`800?l0Bn_o0021oh7o0Ol0j_l00?Co
o@3=o`400>?o0iVI002mo`6IVOGooP2no`00j_l00?Coo@3=o`400>?oo@2mo`40
0?GooP2no`40o`18jol0087oPOl1o`3Zo`00m_om0<_ooP3UoojI002loojImOl1
002no`00j_l00?Koo@3;ooh0iOom0;cooP3eo`400;ko0@3o04W[o`00POn1o`7o
0>[o003hoo`0bOon0>Ko0iVI002ko`6IVOGooP2oo`00j_l00?Soo039ooh0i_om
0;_o0@00mOon0;oo0@3o05;[o`40087oP_l1003Zo`400?[oo@36o`400>OooYT1
002ko`6IVOCo0@00`?l1003Zo`400?[oo@36o`400>Ooo02ko`400?Co0@00`?l2
003o04O[o`00POn1o`7o0>[o003kood0a?on0>So0iVI002joojImOon0<3o003Z
o`00noom0<CooP3Xood0^_on0?GooP30o`40o`1;jol0087oPOl1o`3Zo`00oOol
0<;ooP3ZoojI0@00^Ol1VIWdo`400<3o003Zo`00oOol0<;ooP3Zoo`0^Ol1003d
o`400<3o0@3o04W[o`00POn1o`7o0>[o003mooh0_ol1003Zo`>IV@00^?onVOGo
oP31o`00j_l00?gooP2oo`400>[oo@2hooh0mOon0<7o0@3o04C[o`40087oP_l1
003Zo`400;WooP3]oofI0@00]oonVOGooP33o`400>[o0@00^Oon0>gon`2gooh0
mOon0<?o0P00o`1Hl_l1003lo`00POn1o`7o0?7o0@00o?l00;OooP3`oobI0@00
]OonVOGo0@00c_oj0?co003ao`400?co002gooh0l?oj0;GooP3eo`400<konP3l
o`40o`1Qlol30?oo0?go0021oh7o0Ol0l_l30?oo0?go002fooh0m?okV@3ooP2e
oo^In?on0=?omP3lo`00l_l30?oo0?go002fooh0m?ok003ooP2eoo/0n?on0=?o
mP3lo`40o`1;lol30?oo0?go0021oh7o0Ol0l_l30?oo0?go003mojJIo_l1002b
okRIo?l00?;o0`3oo`3mo`00oOnV0?ko0@00/_nh0?co0@3o04_co`<0ool0oOon
087oQ?on0?;o0`3oo`3mooh00OooZIWlooh0/?njVOkooP3bo`<0ool0oOon007o
ojT0o?on0;3o^P3nooh00?l0Do?o0`3oo`3mo`00POn1o`7o0?;o0`3oo`3mo`00
]?on0?7ooP2Ro`400=gonP3_o`00l_l30?oo0?go002dooh0lOon0:;o0@00gOoj
0>oo0@3o05?co`<0ool0oOl0087oPOl1o`3bo`<0ool0oOl00;?ooP3bo`400:7o
oP3Poo/0k?l00?;o0`3oo`3mo`00/oon0?;o0@00XOon0>3on`3/o`40o`1;l_l1
003lo`00POn1o`7o0?7o0@00o?l00;;ooP3dooh0X?on0>?oo03Yo`00lOl1003l
o`00/_on0?CooP2Pooh0hool0>Wo0@3o04?[o`40087oP_l1003Zo`400;;ooP3e
o`4009kooP3Voo`0j?l1003Zo`400;;ooP3eo`4009kooP3Voo`0j?l2003o043[
o`00POn1o`7o0>[o002`o`400?KooP2Mo`400>Soo03Uo`00j_l00;3o0@00m_on
09go0@00j?ol0>Go0@3o03k[o`00POn1o`7o0>[o002`ooh0mol1002Looh0jool
0>?o003Zo`00/?on0?Oo0@00W?on0>_oo03So`40o`0ljol0087oPOl1o`3Zo`00
[oon0?WooP2Kooh0k_ol0>7o003Zo`00[oon0?WooP2Kooh0k_ol0>7o0@3o047[
o`40087oP_l1003Zo`400:oooP3lood0VOol0?Con`3Po`400>[o0@00[oon0?co
o@2Ioo`0m?ok0>3o0P00o`0djol0087oPOl1o`3Zo`00[_of09Oon`3kooP0gOl0
0>[o002^ooH0Uook0?_on03Mo`40o`0/jol0087oPOl1o`3Zo`00[?oi09?olP3J
o`00j_l00:con@2Coo80f_l10?l0:>_o0021oh7o0Ol0j_l0087o]?oi0=Go003Z
o`00POndooT0eOl10?l09N_o0@00POn2o`400>[o0@00POn2o`400>[o0@00POn2
o`800?l0KN_o003lo`00fOl00=Wo003Io`00fOl00=Wo003Io`00o?l00>[o003l
o`00fOl00=Wo003Io`00fOl00=Wo003Io`00o?l00>[o003lo`00fOl00=Wo003I
o`00fOl00=Wo003Io`00o?l10?l1SN_o003lo`00n_l00?Wo003jo`00n_l00?[o
003jo`00nOl00?[o003jo`00n_l00?[o003jo`00nOl00?[o003jo`00n_l00?[o
003io`00n_l00?[o003jo`00n_l00?Wo003jo`00n_l00?[o003jo`00nOl00?[o
003jo`00o?l00>[o003lo`00n_l00?Wo003jo`00n_l00?[o003jo`00nOl00?[o
003jo`00n_l00?[o003jo`00nOl00?[o003jo`00n_l00?[o003io`00n_l00?[o
003jo`00n_l00?Wo003jo`00n_l00?[o003jo`00nOl00?[o003jo`00o?l00>[o
003lo`00n_l00?Wo003jo`00n_l00?[o003jo`00nOl00?[o003jo`00n_l00?[o
003jo`00nOl00?[o003jo`00n_l00?[o003io`00n_l00?[o003jo`00n_l00?Wo
003jo`00n_l00?[o003jo`00nOl00?[o003jo`00o?l10?l06^_oP@210?h0j_n1
0840oP3Zoh40P@3n003o00j1oh7oPOn1oh7oPOnco`0>POn1oh7oPOn1oh7o/ol0
3X7oPOn1oh7oPOn1ok?o00j1oh7oPOn1oh7oPOnco`1Ii?on0=_ooP3Jo`00g?l1
003Jo`00f_on0=_ooP3Mooh0foon0=[o003Lo`400=[o003Jooh0foon0=gooP3K
ooh0f_l00=co0@00f_l00=[ooP3Kooh0n_l0UNGo003no`00gOl00?ko003Lo`40
0=go0`3oo`3Lo`400=_o003no`00gOl00?ko003Oo`00o_l00=go003no`00g?l1
003Mo`<0ool0g?l1003Ko`00o_l00=go003no`00gol00?ko003Mo`00o_l00=co
0@00gOl30?oo0=co0@00fol00?ko003Mo`00o_l00?_o07OQo`00gOl00?ko003K
o`00gOl30?oo0=_o003Ko`00o_l00=Wo003Ko`00gOl00?ko003Ko`00gOl30?oo
0=_o003Ko`00o_l00=Wo003Ko`00gOl00?ko003Ko`00gOl30?oo0=_o003Ko`00
o_l00=Wo003ko`1Uhol1003Io`00f_l00=go0`3oo`3Ko`00f?l00=[o0@00g?l1
003Io`00f_l00=go0`3oo`3Ko`00f?l00=[o0@00g?l1003Io`00f_l00=go0`3o
o`3Ko`00f?l00=[o0@00n_l0Pn_oo03lo`00hool0?ko003Qoo`0o_l00=go0`3o
o`3Ko`00fOl00=Oo003Uoo`0o?l00>?oo03no`00hOol0?ko003Mo`<0ool0fol0
0=Wo003Go`00iOol0?co003Soo`0o_l00>7oo03no`00gOl30?oo0=_o003Io`00
eol00?_o08WUo`00o_l00=co0`3oo`3Ko`00gOl30?oo0=_o003Jo`<0ool0gOl0
0?ko003Oo`00o_l00=co0`3oo`3Ko`00gOl30?oo0=_o003Jo`<0ool0gOl00?ko
003Oo`00o_l00=co0`3oo`3Ko`00gOl30?oo0=_o003Jo`<0ool0gOl00?ko003k
o`1Ii?on0=coo03Looh0gOl1003Kooh0g?ol0=cooP3Mooh0g?ol0=cooP3Mo`40
0=_ooP3Loo`0g?on0=gooP3Loo`0g?on0=go0@00foon0=coo03Looh0n_l03X7o
POn1oh7oPOn1ok?o0?l\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
p/.rule
explogp/.rule\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
(1 - (z*(-3 + z^2))/6 + (11*z*(15 - 10*z^2 + \
z^4))/120 + (-15 + 45*z^2 - 15*z^4 + z^6)/180)/(E^(z^2/2)*Sqrt[2*Pi])\
\>", "\
\<\
             2                   2    4              2       4    6
    z (-3 + z )   11 z (15 - 10 z  + z )   -15 + 45 z  - 15 z  + z
1 - ----------- + ---------------------- + ------------------------
         6                 120                       180
-------------------------------------------------------------------
                           2
                          z /2
                         E     Sqrt[2 Pi]\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
E^((45*z)/22 - (2245*z^2)/968 + (11851*z^3)/10648 - \
(886337*z^4)/937024 + (16566881*z^5)/25768160 - (1188424517*z^6)/3401397120 + \
Log[11/(6*Sqrt[2])] - Log[2*Sqrt[Pi]])\
\>", "\<\
                    2       \
         3                   4                      5                         \
 6
 (45 z)/22 - (2245 z )/968 + (11851 z )/10648 - (886337 z )/937024 + \
(16566881 z )/25768160 - (1188424517 z )/3401397120 + Log[11/(6 Sqrt[2])] - \
Log[2 Sqrt[Pi]]
E\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{42, 1440}, {0, 878}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{730, 799},
WindowMargins->{{Automatic, 33}, {Automatic, 10}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3406902286-9666275"->{
    Cell[73836, 2655, 103, 2, 21, "Print",
      CellTags->"Info3406902286-9666275"],
    Cell[73942, 2659, 1270, 26, 152, "Print",
      CellTags->"Info3406902286-9666275"]},
  "Info3406902320-6947369"->{
    Cell[202304, 5368, 90, 2, 22, "Print",
      CellTags->"Info3406902320-6947369"],
    Cell[202397, 5372, 415927, 6890, 24570, "Print",
      CellTags->"Info3406902320-6947369"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3406902286-9666275", 775567, 15206},
  {"Info3406902320-6947369", 775773, 15211}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 90, 2, 36, "Subsection",
  InitializationCell->True],
Cell[1869, 57, 120, 5, 40, "Input"],
Cell[1992, 64, 146, 3, 26, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2163, 71, 165, 6, 40, "Input",
  InitializationCell->True],
Cell[2331, 79, 102, 2, 59, "Output"],
Cell[2436, 83, 85, 2, 26, "Output"]
}, Open  ]],
Cell[2536, 88, 117, 3, 26, "Input",
  InitializationCell->True],
Cell[2656, 93, 336, 9, 124, "Input",
  InitializationCell->True],
Cell[2995, 104, 272, 8, 40, "Input",
  InitializationCell->True],
Cell[3270, 114, 247, 7, 40, "Input",
  InitializationCell->True],
Cell[3520, 123, 277, 8, 40, "Input",
  InitializationCell->True],
Cell[3800, 133, 242, 7, 26, "Input",
  InitializationCell->True],
Cell[4045, 142, 496, 11, 264, "Input",
  InitializationCell->True],
Cell[4544, 155, 499, 11, 264, "Input",
  InitializationCell->True],
Cell[5046, 168, 468, 11, 222, "Input",
  InitializationCell->True],
Cell[5517, 181, 541, 12, 264, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[6083, 197, 102, 2, 26, "Input"],
Cell[6188, 201, 74, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6299, 208, 100, 2, 26, "Input"],
Cell[6402, 212, 74, 2, 26, "Output"]
}, Open  ]],
Cell[6491, 217, 283, 8, 54, "Input",
  InitializationCell->True],
Cell[6777, 227, 492, 11, 264, "Input",
  InitializationCell->True],
Cell[7272, 240, 82, 2, 30, "Text"],
Cell[7357, 244, 312, 9, 124, "Input",
  InitializationCell->True],
Cell[7672, 255, 270, 8, 40, "Input",
  InitializationCell->True],
Cell[7945, 265, 429, 10, 208, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8399, 279, 107, 2, 26, "Subsubsection"],
Cell[8509, 283, 309, 9, 110, "Input",
  InitializationCell->True],
Cell[8821, 294, 510, 12, 194, "Input",
  InitializationCell->True],
Cell[9334, 308, 566, 12, 222, "Input",
  InitializationCell->True],
Cell[9903, 322, 311, 9, 110, "Input",
  InitializationCell->True],
Cell[10217, 333, 547, 12, 208, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[10801, 350, 109, 2, 26, "Subsubsection"],

Cell[CellGroupData[{
Cell[10935, 356, 80, 2, 70, "Input"],
Cell[11018, 360, 70, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11125, 367, 104, 2, 70, "Input"],
Cell[11232, 371, 65, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11334, 378, 143, 5, 70, "Input"],
Cell[11480, 385, 76, 2, 70, "Output"]
}, Open  ]],
Cell[11571, 390, 106, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[11702, 396, 75, 2, 70, "Input"],
Cell[11780, 400, 99, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11916, 407, 111, 2, 70, "Input"],
Cell[12030, 411, 348, 6, 70, "Message"],
Cell[12381, 419, 348, 6, 70, "Message"],
Cell[12732, 427, 348, 6, 70, "Message"],
Cell[13083, 435, 348, 6, 70, "Message"],
Cell[13434, 443, 51, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13522, 450, 118, 2, 70, "Input"],
Cell[13643, 454, 348, 6, 70, "Message"],
Cell[13994, 462, 348, 6, 70, "Message"],
Cell[14345, 470, 348, 6, 70, "Message"],
Cell[14696, 478, 348, 6, 70, "Message"],
Cell[15047, 486, 51, 2, 70, "Output"]
}, Open  ]],
Cell[15113, 491, 286, 9, 70, "Input",
  InitializationCell->True],
Cell[15402, 502, 489, 12, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15928, 519, 79, 2, 20, "Subsubsection"],
Cell[16010, 523, 295, 9, 70, "Input",
  InitializationCell->True],
Cell[16308, 534, 504, 12, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16861, 552, 95, 2, 28, "Subsection",
  InitializationCell->True],
Cell[16959, 556, 183, 7, 42, "Input",
  InitializationCell->True],
Cell[17145, 565, 246, 8, 72, "Input",
  InitializationCell->True],
Cell[17394, 575, 536, 12, 252, "Input",
  InitializationCell->True],
Cell[17933, 589, 798, 17, 402, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[18756, 610, 102, 5, 42, "Input"],
Cell[18861, 617, 768, 17, 188, "Print"]
}, Open  ]],
Cell[19644, 637, 84, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[19753, 646, 124, 5, 42, "Input"],
Cell[19880, 653, 675, 20, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20592, 678, 111, 5, 42, "Input"],
Cell[20706, 685, 1252, 34, 148, "Output"]
}, Open  ]],
Cell[21973, 722, 254, 8, 57, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[22252, 734, 96, 2, 27, "Input"],
Cell[22351, 738, 199, 8, 25, "Output"]
}, Open  ]],
Cell[22565, 749, 398, 10, 117, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[22988, 763, 217, 6, 57, "Input"],
Cell[23208, 771, 163, 5, 21, "Message"],
Cell[23374, 778, 500, 13, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23911, 796, 208, 6, 57, "Input"],
Cell[24122, 804, 163, 5, 21, "Message"],
Cell[24288, 811, 845, 22, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25170, 838, 151, 5, 42, "Input"],
Cell[25324, 845, 163, 5, 21, "Message"],
Cell[25490, 852, 324, 12, 60, "Output"]
}, Open  ]],
Cell[25829, 867, 1358, 24, 717, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[27212, 895, 144, 5, 27, "Input"],
Cell[27359, 902, 264, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27660, 915, 95, 2, 27, "Input"],
Cell[27758, 919, 176, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27971, 931, 68, 2, 27, "Input"],
Cell[28042, 935, 938, 30, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29017, 970, 114, 2, 27, "Input"],
Cell[29134, 974, 68, 2, 23, "Print"],
Cell[29205, 978, 163, 5, 21, "Message"],
Cell[29371, 985, 1890, 49, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31298, 1039, 106, 2, 27, "Input"],
Cell[31407, 1043, 206, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31650, 1055, 116, 5, 42, "Input"],
Cell[31769, 1062, 78, 5, 38, "Print"],
Cell[31850, 1069, 163, 5, 21, "Message"],
Cell[32016, 1076, 366, 12, 77, "Output"]
}, Open  ]],
Cell[32397, 1091, 1218, 24, 657, "Input",
  InitializationCell->True],
Cell[33618, 1117, 287, 8, 87, "Input",
  InitializationCell->True],
Cell[33908, 1127, 411, 11, 102, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[34344, 1142, 152, 9, 102, "Input"],
Cell[34499, 1153, 145, 7, 25, "Output"],
Cell[34647, 1162, 145, 7, 25, "Output"],
Cell[34795, 1171, 139, 8, 38, "Output"],
Cell[34937, 1181, 139, 8, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35113, 1194, 98, 2, 27, "Input"],
Cell[35214, 1198, 118, 6, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35369, 1209, 71, 2, 27, "Input"],
Cell[35443, 1213, 200, 7, 68, "Print"]
}, Open  ]],
Cell[35658, 1223, 127, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[35810, 1230, 99, 2, 27, "Input"],
Cell[35912, 1234, 116, 6, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36065, 1245, 87, 2, 27, "Input"],
Cell[36155, 1249, 116, 6, 25, "Output"]
}, Open  ]],
Cell[36286, 1258, 278, 12, 132, "Input",
  InitializationCell->True],
Cell[36567, 1272, 229, 7, 42, "Input",
  InitializationCell->True],
Cell[36799, 1281, 436, 11, 162, "Input",
  InitializationCell->True],
Cell[37238, 1294, 372, 10, 132, "Input",
  InitializationCell->True],
Cell[37613, 1306, 429, 13, 57, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[38067, 1323, 100, 5, 42, "Input"],
Cell[38170, 1330, 120, 6, 25, "Output"],
Cell[38293, 1338, 106, 6, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38436, 1349, 103, 5, 42, "Input"],
Cell[38542, 1356, 353, 10, 25, "Output"],
Cell[38898, 1368, 353, 10, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39288, 1383, 110, 5, 42, "Input"],
Cell[39401, 1390, 353, 10, 25, "Output"],
Cell[39757, 1402, 353, 10, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40147, 1417, 117, 5, 42, "Input"],
Cell[40267, 1424, 243, 9, 25, "Output"],
Cell[40513, 1435, 243, 9, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40793, 1449, 113, 5, 42, "Input"],
Cell[40909, 1456, 106, 6, 25, "Output"],
Cell[41018, 1464, 106, 6, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41161, 1475, 109, 5, 42, "Input"],
Cell[41273, 1482, 240, 8, 25, "Output"],
Cell[41516, 1492, 204, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41757, 1505, 109, 5, 42, "Input"],
Cell[41869, 1512, 361, 12, 38, "Output"],
Cell[42233, 1526, 361, 12, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42631, 1543, 134, 6, 57, "Input"],
Cell[42768, 1551, 361, 12, 38, "Output"],
Cell[43132, 1565, 361, 12, 38, "Output"],
Cell[43496, 1579, 191, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43724, 1592, 103, 2, 27, "Input"],
Cell[43830, 1596, 136, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44003, 1608, 104, 2, 27, "Input"],
Cell[44110, 1612, 161, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44308, 1624, 104, 2, 27, "Input"],
Cell[44415, 1628, 160, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44612, 1640, 90, 2, 27, "Input"],
Cell[44705, 1644, 106, 6, 25, "Output"]
}, Open  ]],
Cell[44826, 1653, 219, 7, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[45070, 1664, 82, 2, 27, "Input"],
Cell[45155, 1668, 63, 2, 39, "Output"]
}, Open  ]],
Cell[45233, 1673, 240, 8, 42, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[45498, 1685, 102, 2, 27, "Input"],
Cell[45603, 1689, 122, 6, 25, "Output"]
}, Open  ]],
Cell[45740, 1698, 398, 10, 162, "Input",
  InitializationCell->True],
Cell[46141, 1710, 296, 9, 87, "Input",
  InitializationCell->True],
Cell[46440, 1721, 505, 14, 132, "Input",
  InitializationCell->True],
Cell[46948, 1737, 456, 13, 117, "Input",
  InitializationCell->True],
Cell[47407, 1752, 447, 12, 117, "Input",
  InitializationCell->True],
Cell[47857, 1766, 510, 13, 162, "Input",
  InitializationCell->True],
Cell[48370, 1781, 399, 11, 57, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[48794, 1796, 122, 5, 42, "Input"],
Cell[48919, 1803, 142, 7, 25, "Output"],
Cell[49064, 1812, 248, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49349, 1825, 104, 5, 42, "Input"],
Cell[49456, 1832, 122, 6, 25, "Output"],
Cell[49581, 1840, 106, 6, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49724, 1851, 119, 5, 42, "Input"],
Cell[49846, 1858, 136, 7, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50019, 1870, 255, 8, 87, "Input"],
Cell[50277, 1880, 159, 8, 25, "Output"],
Cell[50439, 1890, 177, 8, 25, "Output"],
Cell[50619, 1900, 251, 9, 25, "Output"],
Cell[50873, 1911, 271, 9, 25, "Output"]
}, Open  ]],
Cell[51159, 1923, 259, 9, 87, "Input",
  InitializationCell->True],
Cell[51421, 1934, 268, 9, 87, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[51714, 1947, 216, 7, 72, "Input"],
Cell[51933, 1956, 252, 12, 77, "Output"],
Cell[52188, 1970, 218, 11, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52443, 1986, 182, 6, 57, "Input"],
Cell[52628, 1994, 197, 11, 64, "Output"]
}, Open  ]],
Cell[52840, 2008, 259, 10, 102, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[53124, 2022, 101, 2, 27, "Input"],
Cell[53228, 2026, 153, 5, 21, "Message"],
Cell[53384, 2033, 153, 5, 21, "Message"],
Cell[53540, 2040, 153, 5, 21, "Message"],
Cell[53696, 2047, 167, 5, 21, "Message"],
Cell[53866, 2054, 306, 11, 64, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[54221, 2071, 68, 1, 28, "Subsection"],
Cell[54292, 2074, 587, 15, 236, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[54904, 2093, 110, 5, 44, "Input"],
Cell[55017, 2100, 312, 6, 68, "Output"]
}, Open  ]],
Cell[55344, 2109, 554, 14, 204, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[55923, 2127, 143, 5, 44, "Input"],
Cell[56069, 2134, 525, 15, 68, "Output"]
}, Open  ]],
Cell[56609, 2152, 1048, 25, 476, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[57682, 2181, 76, 2, 26, "Input"],
Cell[57761, 2185, 475, 14, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58273, 2204, 106, 5, 40, "Input"],
Cell[58382, 2211, 2278, 56, 240, "Output"]
}, Open  ]],
Cell[60675, 2270, 118, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[60818, 2276, 80, 2, 26, "Input"],
Cell[60901, 2280, 74, 2, 22, "Print"]
}, Open  ]],
Cell[60990, 2285, 968, 23, 404, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[61983, 2312, 197, 4, 40, "Input"],
Cell[62183, 2318, 1993, 38, 108, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64213, 2361, 174, 4, 26, "Input"],
Cell[64390, 2367, 1410, 39, 240, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65837, 2411, 118, 5, 40, "Input"],
Cell[65958, 2418, 656, 18, 84, "Output"],
Cell[66617, 2438, 740, 18, 84, "Output"]
}, Open  ]],
Cell[67372, 2459, 1000, 24, 432, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[68397, 2487, 78, 2, 26, "Input"],
Cell[68478, 2491, 2011, 48, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[70526, 2544, 107, 5, 37, "Input"],
Cell[70636, 2551, 953, 26, 108, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71626, 2582, 133, 5, 39, "Input"],
Cell[71762, 2589, 872, 22, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72671, 2616, 133, 5, 39, "Input"],
Cell[72807, 2623, 895, 23, 108, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73739, 2651, 94, 2, 25, "Input"],
Cell[73836, 2655, 103, 2, 21, "Print",
  CellTags->"Info3406902286-9666275"],
Cell[73942, 2659, 1270, 26, 152, "Print",
  CellTags->"Info3406902286-9666275"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75249, 2690, 129, 5, 40, "Input"],
Cell[75381, 2697, 106, 6, 24, "Output"]
}, Open  ]],
Cell[75502, 2706, 876, 18, 362, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[76403, 2728, 76, 2, 26, "Input"],
Cell[76482, 2732, 124737, 2608, 70, "Print"]
}, Closed]],
Cell[201234, 5343, 961, 17, 409, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[202220, 5364, 81, 2, 28, "Input"],
Cell[202304, 5368, 90, 2, 22, "Print",
  CellTags->"Info3406902320-6947369"],
Cell[202397, 5372, 415927, 6890, 24570, "Print",
  CellTags->"Info3406902320-6947369"]
}, Closed]],

Cell[CellGroupData[{
Cell[618361, 12267, 115, 2, 25, "Input"],
Cell[618479, 12271, 81, 2, 28, "Output"]
}, Open  ]],
Cell[618575, 12276, 98, 2, 28, "Input"],
Cell[618676, 12280, 93, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[618794, 12286, 140, 5, 44, "Input"],
Cell[618937, 12293, 336, 6, 75, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[619310, 12304, 152, 6, 44, "Input"],
Cell[619465, 12312, 335, 6, 75, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[619837, 12323, 220, 6, 60, "Input"],
Cell[620060, 12331, 291, 5, 69, "Output"]
}, Open  ]],
Cell[620366, 12339, 75, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[620466, 12345, 164, 5, 44, "Input"],
Cell[620633, 12352, 702, 20, 124, "Output"],
Cell[621338, 12374, 762, 20, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622137, 12399, 284, 8, 82, "Input"],
Cell[622424, 12409, 163, 5, 21, "Message"],
Cell[622590, 12416, 342, 12, 57, "Output"],
Cell[622935, 12430, 342, 12, 57, "Output"]
}, Open  ]],
Cell[623292, 12445, 1378, 27, 637, "Input",
  InitializationCell->True],
Cell[624673, 12474, 1332, 27, 672, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[626030, 12505, 76, 2, 27, "Input"],
Cell[626109, 12509, 30214, 635, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[656360, 13149, 151, 5, 24, "Input"],
Cell[656514, 13156, 545, 14, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[657096, 13175, 167, 5, 44, "Input"],
Cell[657266, 13182, 545, 14, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[657848, 13201, 167, 5, 44, "Input"],
Cell[658018, 13208, 545, 14, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[658600, 13227, 154, 5, 28, "Input"],
Cell[658757, 13234, 124, 2, 24, "Print"],
Cell[658884, 13238, 2085, 55, 236, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[661006, 13298, 154, 5, 28, "Input"],
Cell[661163, 13305, 124, 2, 24, "Print"],
Cell[661290, 13309, 1495, 39, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[662822, 13353, 159, 5, 44, "Input"],
Cell[662984, 13360, 163, 5, 40, "Message"],
Cell[663150, 13367, 632, 19, 82, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[663831, 13392, 66, 1, 36, "Subsection"],

Cell[CellGroupData[{
Cell[663922, 13397, 88, 2, 70, "Input"],
Cell[664013, 13401, 266, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[664316, 13416, 129, 6, 70, "Input"],
Cell[664448, 13424, 1237, 23, 70, "Output"],
Cell[665688, 13449, 887, 18, 70, "Output"],
Cell[666578, 13469, 154, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[666769, 13482, 166, 6, 70, "Input"],
Cell[666938, 13490, 62650, 948, 70, "Output"],
Cell[729591, 14440, 24839, 387, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[754467, 14832, 163, 5, 70, "Input"],
Cell[754633, 14839, 206, 7, 70, "Output"],
Cell[754842, 14848, 18466, 286, 70, 18332, 282, "GraphicsData", "PICT", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[773345, 15139, 96, 5, 70, "Input"],
Cell[773444, 15146, 651, 15, 70, "Output"],
Cell[774098, 15163, 555, 14, 70, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

