(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53437,       1711]*)
(*NotebookOutlinePosition[     54518,       1745]*)
(*  CellTagsIndexPosition[     54474,       1741]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Unprotect[\"code`PARTest`*\"];
Clear[    \"code`PARTest`*\"];
Remove   [\"code`PARTest`Private`*\"];

\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
BeginPackage[\"code`PARTest`\",
\t\t\t\t{\"code`Kronecker`\", 
\t\t\t\t \"code`LSD`\",
\t\t\t\t \"Statistics`DataManipulation`\",
      \t\t\t \"Statistics`NormalDistribution`\",(*
                 \"Statistics`InverseStatisticalFunctions`\",*)
                 \"Statistics`Common`DistributionsCommon`\", 
                 \"Statistics`DescriptiveStatistics`\",                       \
                
                 \"Global`\"
                 }]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Symbole", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
     
DMS::usage =\"DMS, McDonald-Swaminathan-Ableitungen\"

NEWTON::usage =\"NEWTON, Scoring-Algorithmus\"

MOMENT1::usage =\"MOMENT1, Momentenmatrizen\"

STERN01::usage =\"STERN01\"

STERN01R::usage =\"STERN01R; reelle Arithm.\"


MatrixE1::usage = \"MatrixE1[Lambda,Elt,dt], Returns E1 and DL1 =
\t(lambdai - lambdaj)^-1\"
                             
MatrixE2::usage = \"MatrixE2[Lambda,Elt], Returns {E2,Lplus1,Eltplus}\"

MatrixE3::usage = \"MatrixE3[dt,DL1,E2,Eltplus,Lplus1], Returns E3\"

PStern::usage = \"PStern[Omega,A,B,dt], Stern-Matrizen \"

Stern::usage = \"Stern[Omega,A,B,dt], Stern-Matrizen\"

ABL::usage = \"ABL[THETA,dt], Returns 
\t{DOSDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,Ostern,Astern,Bstern,SIGMA,MUE}\"

VDACH::usage = \" \"
ABLIN::usage = \" \"
ABL01::usage = \" \"
LIKSTERN::usage = \" \"
SH::usage = \" \"
MOMENT1::usage = \" \"
SHIFT::usage = \" \"
STERNR::usage = \" \"
LINSTERN::usage = \" \"
STERN01::usage = \" \"
LIK2::usage = \" \"
DoUntil::usage = \" \"
DoWhile::usage = \" \"
SIGNI::usage = \" \"
VecPrint::usage = \" \"
LKOMP::usage = \" \"
OUTPUT::usage = \" \"
STANDARD::usage = \" \"
DELTA::usage = \" \"
DELTASTERN::usage = \" \"
NUMABL::usage = \" \"
ALIASING::usage = \" \"
MatrixLog::usage = \"MatrixLog[A_]\"
Indirekt::usage = \"Indirekt[{Ostern_,Astern_,Bstern_}]\"
L::usage = \"L[A_,B_]: AxB+BxA\"
SigmaStat::usage = \"SigmaStat[A_,Omega_]: A.Sigma+Sigma.A'+Omega==0\"
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementierung", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

Begin[\"`Private`\"]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

(***************************************************************)
DMS[Y_,X_] := Outer[D,Y//Flatten,X//Flatten]//Transpose;\t
(***************************************************************)
 \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
 
DMS[{a^4,b},{a,b,c}]
DMS[{a^4, b}, {a, b, c}]
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{4*a^3, 0}, {0, 1}, {0, 0}}\
\>", "\<\
     3
{{4 a , 0}, {0, 1}, {0, 0}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{4*a^3, 0}, {0, 1}, {0, 0}}\
\>", "\<\
     3
{{4 a , 0}, {0, 1}, {0, 0}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
MatrixE1[Lambda_,Elt_,dt_]:=
(***************************************************************)
\tModule[{p,d1,DL1},
\t\tp = Length[Lambda];
\t\td1 = Outer[Plus,Elt,-Elt] ;
\t\tDL1 = Outer[Plus,Lambda,-Lambda] ;
\t\tDo[ d1[[i,i]] = Elt[[i]]dt; DL1[[i,i]] = 1,{i,p} ];
\t\tDL1 = 1/DL1;
\t\t{d1 DL1,DL1}
\t]
\t\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
MatrixE2[Lambda_,Elt_]:=
(***************************************************************)
\tModule[{E2,Lplus1,Eltplus,p},
\t\tp = Length[Lambda];
\t\tLplus1 = 1/Outer[Plus,Lambda,Lambda];
\t\tEltplus = Outer[Times,Elt,Elt];
\t\tE2 = Lplus1 (Eltplus - Array[1&,{p,p}]);
\t\t{E2,Lplus1,Eltplus}
\t](*End E2*)
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
MatrixE3[dt_,DL1_,E2_,Eltplus_,Lplus1_]:=
(***************************************************************)
\tModule[{E3,p,AD},
\tp = Length[E2];
\tE3 = Array[0&,{p,p,p}];
\tDo[ E3[[f]] = DL1 Outer[Plus, E2[[p//Range,f]], -E2[[p//Range,f]]]
\t\t,{f,1,p} ];

\tAD = (dt Eltplus - E2) Lplus1;
\t
\tDo[ E3[[f,a,a]] = AD[[f,a]], {a,1,p},{f,1,p} ];

\tE3 = Transpose[E3,{2,1,3}];
\t(*E3 = Shape[E3,{p^2,p}]*)
\tPartition[E3//Flatten,p]
\t]
\t\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
PStern[Omega_,A_,B_,dt_]:= 
(***************************************************************)
\tModule[{Ostern,Astern,Bstern,A1,S,SS,S1,S1S,Lambda,Elt,E2,Lplus1,SOS,B1,p},
\t\tp = Dimensions[A][[1]];
\t\t{Lambda,S} = Eigensystem[A//N];  
\t\t
\t\t(* Print[\"EW von A\",Lambda]; *)
\t\t
\t\tSS = S;
    \tS = S//Transpose;
\t\tElt = Exp[Lambda dt];
\t\tS1 = Inverse[S];
\t\tS1S = Transpose[S1];
\t\tSOS = S1.Omega.S1S;
\t\tAstern = Re[S.DiagonalMatrix[Elt].S1];
\t\tA1 = Re[S.DiagonalMatrix[1/Lambda].S1];
\t\tB1 = A1.(Astern - IdentityMatrix[p]);
\t\tBstern = B1.B;
\t\t{E2,Lplus1,Eltplus} = MatrixE2[Lambda,Elt];
\t\tOstern = Re[S.(E2 SOS).SS];
\t\t{Ostern,Astern,Bstern,A1,S,S1,S1S,Lambda,Elt,E2,Lplus1,Eltplus,SOS,B1}
\t\t
\t](*End PStern*)\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
\t
(***************************************************************)
Stern[Omega_,A_,B_,dt_]:=
(***************************************************************)
\t\tTake[PStern[Omega,A,B,dt],3]
\t\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
ABL[THETA_,dt_] :=
(***************************************************************)
\tModule[{OMEGA,A,B,SIGMA,MUE,OU,AU,BU,DSIGDTH,DMUEDTH,
\t\t\tp,q,NULL,p2,Zweip,u,pq,pu,Ostern,Astern,Bstern,
\t\t\tA1,S,S1,S1S,Lambda,Elt,E2,Lplus1,Eltplus,SOS,B1,
\t\t\tE1,DL1,E3,SS,dia,jj,SSE,AUI,OUI,BUI,AST,S1AUIS,
\t\t\tDOSDTH,DASDTH,DBSDTH},

\t{OMEGA,A,B,SIGMA,MUE} = PAR[THETA];
\t{OU,AU,BU,DSIGDTH,DMUEDTH} = PARD[THETA];  

\t{p,q} = Dimensions[B];
\tNULL = J[0,p,p];
\tp2 = p^2;

\tZweip = 2p;
\tu = Length[THETA];              (* DIM(THETA) *)
\tpq = p*q;
\tpu = p*u;
\t
\t
\t{Ostern,Astern,Bstern,A1,S,S1,S1S,
 \t\tLambda,Elt,E2,Lplus1,Eltplus,SOS,B1} = PStern[OMEGA,A,B,dt];
 \t
  
\t{E1,DL1} = MatrixE1[Lambda,Elt,dt]; 

\tE3 = MatrixE3[dt,DL1,E2,Eltplus,Lplus1];
\tSS = KroneckerProduct[S,S];

\tLplus1 = .;

\tdia = Range[1,p2+1,p+1];
\tjj = J[1,p2,1];
\tE2 = Partition[E2//Flatten,p2];
\tSSE = SS KroneckerProduct[jj,E2];

\tDASDTH = {};
\tDBSDTH = {};
\tDOSDTH = {};
\t
\tDo[ 
\t\t(*
\t\tAUI = Shape[AU[[i]],{p,p}];  (* SUBMATRIX AU(I)  *)
   \t \tOUI = Shape[OU[[i]],{p,p}];  (* SUBMATRIX OU(I)  *)
    \tBUI = Shape[BU[[i]],{p,q}];  (* SUBMATRIX BU(I)  *)
\t\t*)
\t\tAUI = Partition[AU[[i]],p];  (* SUBMATRIX AU(I)  *)
   \t \tOUI = Partition[OU[[i]],p];  (* SUBMATRIX OU(I)  *)
    \tBUI = Partition[BU[[i]],q]; 
    \t
    \tIf[ all[AUI ~eq~ 0],
         \t(* alle A fix*)
         
              FLAG1 = False;
              AST = NULL;
         
         \t\t(*ELSE*),
         
              S1AUIS = S1.AUI.S;
              AST = S.(S1AUIS E1).S1;
              AST = Re[AST];
              FLAG1 = True;
     \t];
     \t
\t\tDASDTH = Append[DASDTH, AST//Flatten] ;
           
    \tdv = NULL;
    
    \tIf[ FLAG1,
    \t\t
        \thilf =  SS.Apply[Plus,
        \t\t\tKroneckerProduct[S1AUIS,SOS][[p2//Range ,dia]] E3,1];
        \thilf = Shape[Re[hilf],{p,p}];
        \tdv = dv + hilf + Transpose[hilf];
        
    \t];

     \tIf[ any[OUI ~ne~ 0], 
       
        \tdv = dv + Shape[Re[SSE.Flatten[S1.OUI.S1S] ],{p,p}];
        
    \t];

     \tDOSDTH = Append[DOSDTH,Flatten[dv]];
     \tFLAG3 = Not[all[BUI ~eq~ 0]]; 
        
     \tIf[FLAG1 == False, 
   
         \tIf[FLAG3 == False,
         \t\tDBSDTH = Append[DBSDTH,Array[0&,{pq}]];
            \t,(*ELSE*) 
            \tDBSDTH = Append[DBSDTH,Flatten[B1.BUI]]; 
         \t];
        
       \t,(*ELSE*)
       
         If[FLAG3 == False,
            DBSDTH = Append[DBSDTH,
                          Flatten[A1.(-AUI.Bstern + AST.B)]]
         ,(*ELSE*)
            DBSDTH = Append[DBSDTH,
                          Flatten[A1.(-AUI.Bstern + AST.B) + B1.BUI]]
        ];
      ];


 \t,{i,1,u} ];
           
\t{DOSDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,Ostern,Astern,Bstern,SIGMA,MUE}

\t] (*End ABL*)
\t\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
VDACH[ASTERN_,BSTERN_,{M11_,M12_,M13_,M22_,M23_,M33_}]:= 
(***************************************************************)

\tModule[{vdach,H1,H2,H3},
\t\tH1 = M11-ASTERN.Transpose[M12]-BSTERN.Transpose[M13];
\t\tH2 = M12-ASTERN.M22 -          BSTERN.Transpose[M23];
\t\tH3 = M13-ASTERN.M23 -          BSTERN.M33 ;
\t\tvdach = H1-H2.Transpose[ASTERN]-H3.Transpose[BSTERN];
\t\t{vdach,H1,H2,H3}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
ABLIN[THETA_,DT_] := Module[
(***************************************************************)
{OU,AU,BU,DSIGDTH,DMUEDTH,OMEGA,A,B,SIGMA,MUE,P,DVDTH,DASDTH,
DBSDTH,V,ASTERN,BSTERN},

{OU,AU,BU,DSIGDTH,DMUEDTH} = PARD[THETA];
{OMEGA,A,B,SIGMA,MUE} = PAR[THETA];
{V,ASTERN,BSTERN} = LINSTERN[OMEGA,A,B,DT];

DASDTH=AU*DT;
DBSDTH=BU*DT;
DVDTH=OU*DT;

{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,
\t\t\t\tASTERN,BSTERN,SIGMA,MUE}
]
\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
ABL01[THETA_,DT_,NONLIN_] := Module[
(***************************************************************)
{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,ASTERN,BSTERN,SIGMA,MUE},

{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,ASTERN,BSTERN,
\tSIGMA,MUE} = If[NONLIN == 1,ABL[THETA,DT],ABLIN[THETA,DT] ]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LIKSTERN[ASTERN_,BSTERN_,V_,MUE_,SIGMA_,M0_,M00_,M_,n_,T_] := 
\tModule[
(***************************************************************)
(* LOG-LIKELIHOOD ALS FKT. DER *-PARAMETER *)
{LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM,DV,DS},

{vdach,H1,H2,H3} = VDACH[ASTERN,BSTERN,M];
V1= Inverse[V];
SIGMA1=Inverse[SIGMA];
DM=M0-MUE;
S0=M00-Outer[Times,M0,M0]+Outer[Times,DM,DM];
DV=Det[V];
DS=Det[SIGMA];
LIKELI=-.5*(   n*T*(Log[DV] + MatrixTrace[V1.vdach])
              +n*  (Log[DS] + MatrixTrace[SIGMA1.S0])  );
              
{LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["??LIKSTERN", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
 

LIKSTERN[Hermann`PARTest`Private`ASTERN_, Hermann`PARTest`Private`BSTERN_, \
Hermann`PARTest`Private`V_, MUE_, SIGMA_, M0_, M00_, M_, n_, T_] := 
  Module[{Hermann`PARTest`Private`LIKELI, Hermann`PARTest`Private`vdach, \
Hermann`PARTest`Private`H1, Hermann`PARTest`Private`H2, \
Hermann`PARTest`Private`H3, Hermann`PARTest`Private`V1, \
Hermann`PARTest`Private`SIGMA1, Hermann`PARTest`Private`S0, \
Hermann`PARTest`Private`DM, 
    Hermann`PARTest`Private`DV, Hermann`PARTest`Private`DS}, \
{Hermann`PARTest`Private`vdach, Hermann`PARTest`Private`H1, \
Hermann`PARTest`Private`H2, Hermann`PARTest`Private`H3} = \
VDACH[Hermann`PARTest`Private`ASTERN, Hermann`PARTest`Private`BSTERN, M]; 
    Hermann`PARTest`Private`V1 = Inverse[Hermann`PARTest`Private`V]; \
Hermann`PARTest`Private`SIGMA1 = Inverse[SIGMA]; Hermann`PARTest`Private`DM = \
M0 - MUE; Hermann`PARTest`Private`S0 = M00 - Outer[Times, M0, M0] + \
Outer[Times, Hermann`PARTest`Private`DM, Hermann`PARTest`Private`DM]; 
    Hermann`PARTest`Private`DV = Det[Hermann`PARTest`Private`V]; \
Hermann`PARTest`Private`DS = Det[SIGMA]; Hermann`PARTest`Private`LIKELI = 
     -0.5*(n*T*(Log[Hermann`PARTest`Private`DV] + \
MatrixTrace[Hermann`PARTest`Private`V1 . Hermann`PARTest`Private`vdach]) + \
n*(Log[Hermann`PARTest`Private`DS] + \
MatrixTrace[Hermann`PARTest`Private`SIGMA1 . Hermann`PARTest`Private`S0])); 
    {Hermann`PARTest`Private`LIKELI, Hermann`PARTest`Private`vdach, \
Hermann`PARTest`Private`H1, Hermann`PARTest`Private`H2, \
Hermann`PARTest`Private`H3, Hermann`PARTest`Private`V1, \
Hermann`PARTest`Private`SIGMA1, Hermann`PARTest`Private`S0, \
Hermann`PARTest`Private`DM}]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
SH[THETA_,DT_,M0_,M00_,M_,n_,T_,NONLIN_] := Module[
(***************************************************************)
(* SCORE UND FISHER-INFORMATIONS-MATRIX *)

{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,ASTERN,BSTERN,SIGMA,
 MUE,P,Q,P2,NT,LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM,S,H,
 M11,M12,M13,M22,M23,M33},
\t
\t
{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,
\t\t\t\tASTERN,BSTERN,SIGMA,MUE} = ABL01[THETA,DT,NONLIN];

(*
{DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,V,
\t\t\t\tASTERN,BSTERN,SIGMA,MUE}//Print; *)


{P,Q} = Dimensions[BSTERN];
P2=P*P;
NT=n*T;

{LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM} = 
\t\tLIKSTERN[ASTERN,BSTERN,V,MUE,SIGMA,M0,M00,M,n,T];
\t\t
(*{LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM}//Print;*)


S=NT*(-.5*DVDTH  .Flatten[V1.(V-vdach).V1]
         +DASDTH .Flatten[V1.H2]
         +DBSDTH .Flatten[V1.H3] )
  +n*(-.5*DSIGDTH.Flatten[SIGMA1.(SIGMA-S0).SIGMA1]
         +DMUEDTH.SIGMA1.DM );
         
(*S//Print;*)

{M11,M12,M13,M22,M23,M33} = M;

H=DASDTH.(V1~KroneckerProduct~M23).Transpose[DBSDTH];
H=H+Transpose[H];
H=H+DBSDTH.(V1~KroneckerProduct~M33).Transpose[DBSDTH] ;
H=H+DASDTH.(V1~KroneckerProduct~M22).Transpose[DASDTH] ;
H=H+.5*DVDTH.(V1~KroneckerProduct~V1).Transpose[DVDTH];
H=H*NT;
H=H+n*(.5*DSIGDTH.(SIGMA1~KroneckerProduct~SIGMA1).Transpose[DSIGDTH]
 \t\t\t\t + DMUEDTH.SIGMA1.Transpose[DMUEDTH]);

(*H = IdentityMatrix[Length[THETA]];*)

(*
H//Print; 
S//Print;
*)

{S,H,LIKELI,vdach,DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,
 V,ASTERN,BSTERN,SIGMA,MUE}
]        \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["??SH", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
 
Attributes[SH] = {Protected}
 
SH[THETA_, DT_, M0_, M00_, M_, n_, T_, NONLIN_] := Module[{DVDTH, DASDTH, \
DBSDTH, DSIGDTH, DMUEDTH, V, ASTERN, BSTERN, SIGMA, MUE, P, Q, P2, NT, \
LIKELI, vdach, H1, H2, H3, V1, SIGMA1, S0, DM, S, H, 
     M11, M12, M13, M22, M23, M33}, Print[\"Vor ABL01\"]; {DVDTH, DASDTH, \
DBSDTH, DSIGDTH, DMUEDTH, V, ASTERN, BSTERN, SIGMA, MUE} = ABL01[THETA, DT, \
NONLIN]; Print[\"Nach ABL01\"]; 
     {P, Q} = Dimensions[BSTERN]; P2 = P*P; NT = n*T; {LIKELI, vdach, H1, H2, \
H3, V1, SIGMA1, S0, DM} = LIKSTERN[ASTERN, BSTERN, V, MUE, SIGMA, M0, M00, M, \
n, T]; 
     S = NT*(-0.5*DVDTH . Flatten[V1 . (V - vdach) . V1] + DASDTH . \
Flatten[V1 . H2] + DBSDTH . Flatten[V1 . H3]) + n*(-0.5*DSIGDTH . \
Flatten[SIGMA1 . (SIGMA - S0) . SIGMA1] + DMUEDTH . SIGMA1 . DM); 
     {M11, M12, M13, M22, M23, M33} = M; H = DASDTH . KroneckerProduct[V1, \
M23] . Transpose[DBSDTH]; H = H + Transpose[H]; H = H + DBSDTH . \
KroneckerProduct[V1, M33] . Transpose[DBSDTH]; 
     H = H + DASDTH . KroneckerProduct[V1, M22] . Transpose[DASDTH]; H = H + \
0.5*DVDTH . KroneckerProduct[V1, V1] . Transpose[DVDTH]; H = H*NT; 
     H = H + n*(0.5*DSIGDTH . KroneckerProduct[SIGMA1, SIGMA1] . \
Transpose[DSIGDTH] + DMUEDTH . SIGMA1 . Transpose[DMUEDTH]); Print[H]; \
Print[S]; 
     {S, H, LIKELI, vdach, DVDTH, DASDTH, DBSDTH, DSIGDTH, DMUEDTH, V, \
ASTERN, BSTERN, SIGMA, MUE}]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
MOMENT1[YY_,XX_,P_,Q_,N_,T_,PRINT_] := Module[
(***************************************************************)
(* DATENMATRIZEN (T+1)xPxN *)
(* DATENMATRIZEN (T+1)xQxN *)
{M0,M00,M11,M12,M13,M22,M23,M33,NT,Y,Y0,YPLUS,X},

NT=N*T;

Y0=First[YY];
M0=Apply[Plus,Y0,1]/N;
M00=(Y0.Transpose[Y0])/N;
YPLUS=Shape[Drop[YY,1]//Transpose,{P,NT}];
Y=Shape[Drop[YY,-1]//Transpose,{P,NT}];
X=Shape[Drop[XX,-1]//Transpose,{Q,NT}];

NT=1./(NT);
M11=NT*(YPLUS.(YPLUS// Transpose));
M12=NT*(YPLUS.(Y\t// Transpose));
M13=NT*(YPLUS.(X\t// Transpose));
M22=NT*(Y.    (Y\t// Transpose));    
M23=NT*(Y.    (X\t// Transpose));
M33=NT*(X.    (X\t// Transpose));
If[PRINT,
Print[M0//Spalte//MatrixForm,\"   \",M00//MatrixForm];
Print[\"\"];
Print[ \t( M11            ~ii~ M12            ~ii~M13 )~vv~ 
 \t\t((M12//Transpose)~ii~ M22            ~ii~M23 )~vv~
 \t\t((M13//Transpose)~ii~(M23//Transpose)~ii~M33 )  //MatrixForm] 
 ];

{M0,M00,{M11,M12,M13,M22,M23,M33}}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["??MOMENT1", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
MOMENT1, Momentenmatrizen

MOMENT1[YY_, XX_, P_, Q_, N_, T_, PRINT_] := 
  Module[{M0, M00, M11, M12, M13, M22, M23, M33, NT, Y, Y0, YPLUS, X}, 
   NT = N*T; Y0 = First[YY]; M0 = Apply[Plus, Y0, 1]/N; 
    M00 = Y0 . Transpose[Y0]/N; 
    YPLUS = Shape[Transpose[Drop[YY, 1]], {P, NT}]; 
    Y = Shape[Transpose[Drop[YY, -1]], {P, NT}]; 
    X = Shape[Transpose[Drop[XX, -1]], {Q, NT}]; NT = 1./NT; 
    M11 = NT*YPLUS . Transpose[YPLUS]; M12 = NT*YPLUS . Transpose[Y]; 
    M13 = NT*YPLUS . Transpose[X]; M22 = NT*Y . Transpose[Y]; 
    M23 = NT*Y . Transpose[X]; M33 = NT*X . Transpose[X]; 
    If[PRINT, Print[MatrixForm[Spalte[M0]], \"   \", MatrixForm[M00]]; 
      Print[\"\"]; Print[MatrixForm[vv[vv[ii[ii[M11, M12], M13], 
          ii[ii[Transpose[M12], M22], M23]], 
         ii[ii[Transpose[M13], Transpose[M23]], M33]]]]]; 
    {M0, M00, {M11, M12, M13, M22, M23, M33}}]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
SHIFT[H_,BOUND_] := Module[{H1,EIGEN,MINI,COND},
(***************************************************************)
EIGEN=Eigenvalues[H];
MINI=Min[EIGEN];
COND=Max[Abs[EIGEN]]/Min[Abs[EIGEN]];
If[MINI<BOUND, 
H1=H+DiagonalMatrix[Array[(BOUND-MINI)&,{Length[H]}]], H1 = H ];
Print[\"EIGENWERTE DER HESSE-MATRIX: \", EIGEN];
Print[\"{MINI,COND,BOUND} = \", {MINI,COND,BOUND }];
Return[H1]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
STERNR[OMEGA_,A_,B_,DT_] := Module[{V,ASTERN,BSTERN,P,P2,IP,IP2},
(***************************************************************)

ASTERN =  MatrixExp[A DT//N];
P=Length[A];
P2=P*P;
IP = IdentityMatrix[P]//N;
IP2 = IdentityMatrix[P2]//N;
BSTERN=LinearSolve[A,(ASTERN-IP).B//N];
V=Shape[
\tLinearSolve[
\t\tIP~KroneckerProduct~A + A~KroneckerProduct~IP,
\t\t(ASTERN~KroneckerProduct~ASTERN - IP2).Flatten[OMEGA]],
  {P,P}];
{V,ASTERN,BSTERN}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
STERNR[IdentityMatrix[5],IdentityMatrix[5],Shape[1,{5,1}],2];\
\>", \
"Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Stern[IdentityMatrix[5],IdentityMatrix[5],Shape[1,{5,1}],2];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LINSTERN[OMEGA_,A_,B_,DT_] := Module[{V,ASTERN,BSTERN,P},
(***************************************************************)
P=Dimensions[A][[1]];
ASTERN=IdentityMatrix[P]+A*DT;
BSTERN=B*DT;
V=OMEGA*DT;
{V,ASTERN,BSTERN}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
STERN01[OMEGA_,A_,B_,DT_,NONLIN_] := Module[{},
(***************************************************************)
If[NONLIN == 1, Stern[OMEGA,A,B,DT], LINSTERN[OMEGA,A,B,DT] ]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
STERN01R[OMEGA_,A_,B_,DT_,NONLIN_] := Module[{},
(***************************************************************)
If[NONLIN == 1, STERNR[OMEGA,A,B,DT], LINSTERN[OMEGA,A,B,DT] ]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LIK2[THETA_,DT_,M0_,M00_,M_,N_,T_,NONLIN_] := Module[
(***************************************************************)
(* LOG-LIKELIHOOD MIT REELLER ARITHMETIK*)
{OMEGA,A,B,SIGMA,MUE,V,ASTERN,BSTERN},

{OMEGA,A,B,SIGMA,MUE} = PAR[THETA];
{V,ASTERN,BSTERN} = STERN01[OMEGA,A,B,DT,NONLIN];   

{LIKELI,vdach,H1,H2,H3,V1,SIGMA1,S0,DM} = 
   LIKSTERN[ASTERN,BSTERN,V,MUE,SIGMA,M0,M00,M,N,T];
LIKELI
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

(***************************************************************)
DoUntil[range_,cond_,body_]:= 
(***************************************************************)
\tModule[{}, Do[ body; If[cond,Break[] ] ,range]]
\t\t
Attributes[DoUntil] = HoldAll;\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

(***************************************************************)
DoWhile[range_,cond_,body_]:= 
(***************************************************************)
\tModule[{}, Do[ If[!cond,Break[] ]; body ,range]]
\t\t
Attributes[DoWhile] = HoldAll;

\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "(***************************************************************)\t\t\t \n\
LikTest[LIKNEU_]:=\n\
(***************************************************************)\n\t\
If[(LIKNEU//NumberQ//Not)||(Im[LIKNEU]=!=0)||(LIKNEU>10.^10),\n\t \t\
Print[\"LIKNEU = \",LIKNEU,\" reset to -10.^10\"]; -10.^10,\n\t \t\tLIKNEU]\t\
",
  StyleBox["",
    FontWeight->"Plain"]
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[{
  "(***************************************************************)\n\
NEWTON[THETA0_,KMAX_,EPS_,M0_,M00_,M_,DT_,n_,T_,OPTION_,NONLIN_,PRINT_] := \n\
(***************************************************************)\nModule[\n\
{THETA,MAXSTEP,MINSTEP,BOUND,U,K,S,H,LIKELI,vdach,DVDTH,DASDTH,\n \
DBSDTH,DSIGDTH,DMUEDTH,V,ASTERN,BSTERN,SIGMA,MUE,liktheta,LIKALT,\n \
ALPHA,THETA1,LIKNEU,STEP,STEPL,t,m},\n\n(*MAXSTEP=10.^3;*)\nMAXSTEP=1;\n\
MINSTEP=10.^-10;\nBOUND=10.^-4;\nALPHA=10^-4;\nU=Length[THETA0];\n\n\
If[PRINT[[1]] == 1,\n\
Print[\"***********************LSDE1**********************************\"];\n\
Print[\"***********************MODUL: NEWTON**************************\"];\n\
Print[\"**************************************************************\"];\n\
Print[\"Technical Output\"];\n\
VecPrint[{KMAX,EPS,DT,n,T,OPTION,NONLIN,MAXSTEP,MINSTEP,BOUND}//Spalte,\n     \
    {\"KMAX\",\"EPS\",\"DT\",\"n\",\"T\",\"OPTION\",\"NONLIN\",\"MAXSTEP\",\n \
         \"MINSTEP\",\"BOUND\"}];\nPrint[ \"\"];\nPrint[ \"STARTWERT THETA0 = \
\", THETA0];\n];\n\nTHETA=THETA0;\nliktheta = {}; \n\
NUMABL[THETA0,DT,$MachineEpsilon^.5,M0,M00,M,n,T,NONLIN];\n\n\n\
DoUntil[{K,KMAX}, Max[Abs[S]]<EPS && Max[Abs[STEP]]<EPS, \n  \t\n  \t\
If[PRINT[[2]] == 1,\n   \t\
Print[\"-----------------------------------------------------------------\"];\
\n    Print[\"NEWTON: Iteration = \",K];\n    ];\n   \n    \
{S,H,LIKALT,vdach,DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,\n     \
V,ASTERN,BSTERN,SIGMA,MUE} = SH[THETA,DT,M0,M00,M,n,T,NONLIN];\n   \n    \
liktheta = Append[liktheta, Join[{LIKALT},THETA]];\n    \n\t   If[OPTION == \
1, H = SHIFT[H,BOUND] ];\n\t\n    STEP=LinearSolve[H,S];\n\n    (*BEGRENZUNG \
DER SCHRITTL\[CapitalADoubleDot]NGE*)\n    STEPL=Max[Abs[STEP]];\n    \
STEP=STEP*Min[1,MAXSTEP/STEPL];\n    \n\n    (*STEP-HALVING*)\n   \n    \
THETA1=THETA+STEP;   (*VOLLER NEWTON-STEP*)\n    LIKNEU = \
LIK2[THETA1,DT,M0,M00,M,n,T,NONLIN];\n    ",
  StyleBox["LIKNEU = LikTest[LIKNEU];\n    ",
    FontWeight->"Plain"],
  "\n    DoWhile[{Z,100},\n         \t(LIKNEU<LIKALT+ALPHA*(S.STEP) &&\n      \
    \t\tMax[Abs[STEP]]>MINSTEP),\n         STEP=STEP*.5;\n         \n         \
If[PRINT[[3]] == 1,\n         Print[\"STEP-HALVING:  \",Z,\"  LIKNEU  \", \
LIKNEU,\"  LIKALT  \", LIKALT];\n         ];\n         \n         \
THETA1=THETA+STEP;\n         LIKNEU = LIK2[THETA1,DT,M0,M00,M,n,T,NONLIN];\n  \
       ",
  StyleBox["LIKNEU = LikTest[LIKNEU];",
    FontWeight->"Plain"],
  "\n\n    ]; (*End DoWhile*)\n    \n    If[PRINT[[4]] == 1,\n    \
Print[\"\"];\n    Print[\"LIKNEU \", PaddedForm[LIKNEU,{20,15}],\n    \t     \
\" LIKALT \", PaddedForm[LIKALT,{20,15}],\n    \t     \" LIKNEU-LIKALT \", \
PaddedForm[LIKNEU-LIKALT,{20,15}] ];\n    Print[\"\"];\n    ];\n    \
If[PRINT[[5]] == 1, \n    Print[MatrixForm[{THETA1,THETA, STEP, \
S}//Transpose,\n    TableHeadings->{Automatic,{\"THETA1\",\"THETA\",\"STEP\",\
\"SCORE\"}}]];\n    Print[\"\"];\n    ];\n    \n    If[PRINT[[6]] == 1,\n    \
Print[H//MatrixForm]]; \n    \n    THETA=THETA1;\n    k = K;\n   \n]; (*End \
DoUntil*)\n\nIf[PRINT[[7]] == 1,\nPrint[ \"NEWTON: ENDE DER ITERATION  \
\",k,\"  \",KMAX]];\n\n\n\
{S,H,LIKELI,vdach,DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,\n \t\
V,ASTERN,BSTERN,SIGMA,MUE} = SH[THETA,DT,M0,M00,M,n,T,NONLIN];\n\nliktheta = \
Append[liktheta,Join[{LIKELI},THETA]];\n\nIf[PRINT[[8]] == 1,\n\
Print[MatrixForm[liktheta,\n\t\
TableHeadings->{Automatic,{\"Likelihood\",\"Theta\"}}]]];\n\t\nCOV = \
OUTPUT[THETA,H,.05,S,LIKELI];\nLKOMP[LIKELI,U,n*(T+1)];\nDELTA[COV,THETA];\n\
DELTASTERN[COV,THETA,DT,NONLIN];\n\nt = Transpose;\nm = \
PaddedForm[MatrixForm[#,TableHeadings->None],{10,4}]&;\n\nIf[NONLIN==0,\n\t\
{M11,M12,M13,M22,M23,M33} = M;\n    AB=Inverse[( M22    ~ii~M23)~vv~\n        \
       ((M23//t)~ii~M33)]   .(((M12//t)- M22)~vv~\n                           \
          ( (M13//t)-(M23//t)));\n    AB=(AB//t)/DT;\n    \
ODACH=(M11-M12-(M12//t)+M22)/DT;\n    \
Print[\"----------------------------------------------------------\"];  \n    \
Print[\"ITO-SCH\[CapitalADoubleDot]TZER A B\" ,AB//m];\n    Print[\"\"];\n    \
Print[\"OMEGADACH       \", ODACH//m];\n];\n\n{THETA,COV,liktheta}\n]\n\n"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SetDelayed::write: Tag NEWTON in NEWTON[THETA0_, KMAX_, EPS_, M0_, \
M00_, M_, DT_, n_, T_, OPTION_, NONLIN_, PRINT_] is Protected.\
\>", "Message",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
$Failed\
\>", "\<\
$Failed\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
SIGNI[THETA_,F_,ALPHA_]:= 
(***************************************************************)
(*APPROXIMATIVER CHI-QUADRAT-TEST*)
Module[{U,CHI,PROB,Z,COV,AU2,DCOV,STD,STD1,CORR,GRENZE},

U=Length[THETA];
CHI=THETA.F.THETA//N;
If[CHI>=0,
\tPROB = 1 - CDF[ChiSquareDistribution[U], CHI];
\tPrint[\"------------------------------------------------------\"];
\tPrint[\"WALD-TEST:\"];
\tPrint[\"------------------------------------------------------\"];
\tVecPrint[{CHI,U,PROB//Chop,ALPHA}//Spalte,
\t         {\"CHI \",\"U \",\"PROB \",\"ALPHA \"}];
\tIf[PROB<ALPHA, Print[ \"NULLHYPOTHESE THETA = 0 ABLEHNEN\"]];
,(*ELSE*) 
\tPrint[ \"F NICHT POSITIV DEFINIT\"];
];

(*BONFERRONI-KONFIDENZINTERVALLE*)
COV=PseudoInverse[F];
AU2=ALPHA/(2 U);
Z=Quantile[NormalDistribution[0,1],(1-AU2)];
DCOV=Transpose[COV,{1,1}];

If[ all[DCOV ~gr~0],

    STD=Sqrt[DCOV];
    STD1=1/STD;
    CORR=DiagonalMatrix[STD1].COV.DiagonalMatrix[STD1];
    GRENZE=Z*STD;
    Print[\"------------------------------------------------------\"];
    Print[\"BONFERRONI-KONFIDENZINTERVALLE:\"];
    Print[\"------------------------------------------------------\"];
    Print[\"P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA\"];
    Print[\"QUANTIL Z(1-ALPHA/2U) = \", Z//N];
    VecPrint[{THETA,GRENZE,STD}//N,{\"THETA\",\"GRENZE\",\"STD\"}];  
    Print[\"-------------------------------------------------------\"];
    Print[\"Korrelation der ML-Sch\[ADoubleDot]tzer\"];
    Print[\"-------------------------------------------------------\"];
    Print[N[CORR,2]//Chop//MatrixForm];
,(*else*)
\tPrint[\"Warnung: Negative Diagonalelemente der Kovarianzmatrix\"];
];

Return[COV];
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["SIGNI[{1,2,3},IdentityMatrix[3],.05]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
------------------------------------------------------
WALD-TEST:
------------------------------------------------------
    CHI  U  PROB       ALPHA 
1   14.  3  0.00290515 0.05
NULLHYPOTHESE THETA = 0 ABLEHNEN
------------------------------------------------------
BONFERRONI-KONFIDENZINTERVALLE:
------------------------------------------------------
P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA
QUANTIL Z(1-ALPHA/2U) = 2.39398
    THETA GRENZE  STD
1   1.    2.39398 1.
2   2.    2.39398 1.
3   3.    2.39398 1.
-------------------------------------------------------
Korrelation der ML-Sch\.8atzer
-------------------------------------------------------
    1  2  3

1   1. 0  0
2   0  1. 0
3   0  0  1.\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\
\>", "\<\
{{1, 0, \
0}, {0, 1, 0}, {0, 0, 1}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 
(***************************************************************)
VecPrint[veclist_, label_] := 
(***************************************************************)
  Print[MatrixForm[Transpose[veclist], 
  \tTableHeadings -> {Automatic, label}]]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SetDelayed::write: Tag VecPrint in VecPrint[veclist_, label_] is \
Protected.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
$Failed\
\>", "\<\
$Failed\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["VecPrint[{1,2.8888888,6.99999}//Spalte,{\"Score\",\"Theta\"}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
    Score   Theta
1   1       2.88889 6.99999\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 
(***************************************************************)
VecPrint[veclist_, label_] := 
(***************************************************************)
  Print[TableForm[Transpose[veclist], 
  \tTableHeadings -> {Automatic, label},
  \tTableDirections->{Column,Row},
  \tTableSpacing->{0,2}]]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SetDelayed::write: Tag VecPrint in VecPrint[veclist_, label_] is \
Protected.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
$Failed\
\>", "\<\
$Failed\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
VecPrint[{{1.11,2,3},{4,5,6}},{\"x\",\"y\"}]
VecPrint1[{{1.11,2,3},{4,5,6}},{\"x\",\"y\"}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
    x    y
1   1.11 4
2   2    5
3   3    6
    x    y
1   1.11 4
2   2    5
3   3    6\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
LKOMP[LIK_,U_,Nue_] := Module[{EPS,LN,KOMP1,KOMP2,KOMP3},
(***************************************************************)
(*KOMPENSIERTE LIKELIHOOD*)
EPS=10^-3;
LN=Log[Nue//N];
KOMP1=U;
KOMP2=.5*U*LN;
KOMP3=.5*U*(U+1)*(1+EPS)*Log[LN];
Print[\"--------------------------------------------------------\"];
Print[\"KOMPENSIERTE LIKELIHOOD\"];
Print[\"--------------------------------------------------------\"];

Print[\"U =  \",U,\"  Nue = \" ,Nue];
Print[\"AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)\"];
ket={{  0,     KOMP1,    KOMP2,    KOMP3},
     {LIK, LIK-KOMP1,LIK-KOMP2,LIK-KOMP3}};
Print[ TableForm[ket,
\t\tTableHeadings -> {{\"Kompensator\",\"komp. Lik.\"},
\t\t                  {\"LIK\",\"AIC\",\"SIC/RISS\",\"A/D\"}},
\t\tTableDirections->{Column,Row},
\t\tTableSpacing->{0,1}]];
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["LKOMP[100.99,5,10]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
--------------------------------------------------------
KOMPENSIERTE LIKELIHOOD
--------------------------------------------------------
U =  5  Nue = 10
AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE (A/D)
              LIK    AIC   SIC/RISS A/D
Kompensator   0      5     5.75646  12.523
komp. Lik.    100.99 95.99 95.2335  88.467\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
OUTPUT[THETA_,F_,ALPHA_,SCORE_,LIKELI_]:= Module[{COV,EIGF,EIGCOV},
(***************************************************************)
Print[\"--------------------------------------------------------\"];
Print[\"ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD\"];
Print[\"--------------------------------------------------------\"];
Print[{THETA,SCORE}//Transpose//TableForm[#,
\t  TableHeadings->{Automatic,{\"THETA\",\"SCORE\"}},
\t  TableDirections->{Column,Row},
\t  TableSpacing->{0,1}]&
      ,\"   Likelihood = \",N[LIKELI,25] ];
COV = SIGNI[THETA, F, ALPHA];
EIGF=Eigenvalues[F];
EIGCOV=1/EIGF;
Print[\"--------------------------------------------------------\"];
Print[\"GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE\"];
Print[\"--------------------------------------------------------\"];
Print[N[COV,5]//Chop//MatrixForm];
Print[\"\"];
Print[N[EIGCOV,5]];
Print[\"--------------------------------------------------------\"];
Print[\"GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE\"];
Print[\"--------------------------------------------------------\"];
Print[N[F,5]//Chop//MatrixForm];
Print[\"\"];
Print[N[EIGF,5]];
COV
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
OUTPUT[Table[Random[],{i,3}],.0077777788888 IdentityMatrix[3],
.05,Table[Random[],{i,3}],100.399999999999]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[GridBox[{
              {"\<\"\"\>", "\<\"THETA\"\>", "\<\"SCORE\"\>"},
              {"1", "0.32379940293451626`", "0.43932814890884253`"},
              {"2", "0.43790834496231723`", "0.8109742725325659`"},
              {"3", "0.8702426000397391`", "0.4203527356390895`"}
              },
            RowSpacings->0,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
              TableDirections -> {Column, Row}, TableSpacing -> {0, 1}]]], 
        "\[InvisibleSpace]", "\<\"   Likelihood = \"\>", "\[InvisibleSpace]", 
        "100.399999999999`"}],
      SequenceForm[ 
        TableForm[ {{0.32379940293451626, 0.43932814890884253}, {
          0.43790834496231723, 0.81097427253256593}, {0.87024260003973908, 
          0.42035273563908948}}, TableHeadings -> {Automatic, {"THETA", 
          "SCORE"}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          1}], "   Likelihood = ", 100.399999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("WALD-TEST:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"CHI \"\>", "\<\"U \"\>", "\<\"PROB \"\>", \
"\<\"ALPHA \"\>"},
          {"1", "0.008197249708682014`", "3", "0.9998030965623732`", "0.05`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"CHI ", "U ", "PROB ", 
          "ALPHA "}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("BONFERRONI-KONFIDENZINTERVALLE:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("QUANTIL Z(1-ALPHA/2U) = \
"\[InvisibleSpace]2.3939797998185104`\),
      SequenceForm[ "QUANTIL Z(1-ALPHA/2U) = ", 2.3939797998185104],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA\"\>", "\<\"GRENZE\"\>", "\<\"STD\"\>"},
          {"1", "0.32379940293451626`", "27.145177464208096`", 
            "11.338933380417828`"},
          {"2", "0.43790834496231723`", "27.145177464208096`", 
            "11.338933380417828`"},
          {"3", "0.8702426000397391`", "27.145177464208096`", 
            "11.338933380417828`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "GRENZE", "STD"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Korrelation der ML-Sch\[ADoubleDot]tzer"\)], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9999999999999998`", "0", "0"},
            {"0", "0.9999999999999998`", "0"},
            {"0", "0", "0.9999999999999998`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE"\)], \
"Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"128.57141020555366`", "0", "0"},
            {"0", "128.57141020555366`", "0"},
            {"0", "0", "128.57141020555366`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({128.57141020555366`, 128.57141020555366`, 
      128.57141020555366`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.0077777788888`", "0", "0"},
            {"0", "0.0077777788888`", "0"},
            {"0", "0", "0.0077777788888`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({0.0077777788888`, 0.0077777788888`, 0.0077777788888`}\)], "Print"],

Cell[BoxData[
    \({{128.57141020555366`, 0.`, 0.`}, {0.`, 128.57141020555366`, 
        0.`}, {0.`, 0.`, 128.57141020555366`}}\)], "Output"]
}, Open  ]],

Cell["\<\
(***************************************************************)
STANDARD[DADTH_,COV_,D1_,D2_]:= Module[{C,Cdiag,STD},
(***************************************************************)
(* COV: u x u*)
If[DADTH === {} || COV === {}, Return[Shape[0.,{D1,D2}]] ];
C=Transpose[DADTH].COV.DADTH;
Cdiag = Transpose[C,{1,1}];
STD=Sqrt[Cdiag ((Cdiag ~ge~ 0 )/.{True->1,False->0})];
STD=Shape[STD,{D1,D2}]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["STANDARD[Shape[9,{2,5}],Shape[9,{2,2}],2,2]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
STANDARD[{{9, 9, 9, 9, 9}, {9, 9, 9, 9, 9}}, {{9, \
9}, {9, 9}}, 2, 2]\
\>", "\<\
STANDARD[{{9, 9, 9, 9, 9}, {9, 9, 9, 9, 9}}, \
{{9, 9}, {9, 9}}, 2, 2]\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(***************************************************************)
DELTA[COV_,TH_] := Module[
(***************************************************************)
(*DELTA-THEOREM*)
{m,OMEGA,A,B,SIGMA,MUE,DODTH,DADTH,DBDTH,DSIGDTH,DMUEDTH,
 STDA,STDB,STDO,STDMUE,STDSIG},

{OMEGA,A,B,SIGMA,MUE} = PAR[TH];
{DODTH,DADTH,DBDTH,DSIGDTH,DMUEDTH} = PARD[TH];
{P,Q}=Dimensions[B];
STDA=STANDARD[DADTH,COV,P,P];
STDB=STANDARD[DBDTH,COV,P,Q];
STDO=STANDARD[DODTH,COV,P,P];
STDMUE=STANDARD[DMUEDTH,COV,P,1];
STDSIG=STANDARD[DSIGDTH,COV,P,P];
m = PaddedForm[MatrixForm[#,TableHeadings->None],{10,4}]&;
Print[\"----------------------------------------------------------\"];
Print[\"DELTA-THEOREM\"];
Print[\"----------------------------------------------------------\"];
Print[\"GESCH\[CapitalADoubleDot]TZTE STANDARDABWEICHUNGEN DER \
SYSTEM-MATRIZEN\"];
Print[\"A, B, OMEGA, SIGMA UND MUE\"];
Print[\"----------------------------------------------------------\"];
Print[\" A      \",A//m];
Print[\"\"];
Print[\" STDA   \",STDA//m];
Print[\"----------------------------------------------------------\"];
Print[\" B      \",B//m];
Print[\"\"];
Print[\" STDB   \",STDB//m];
Print[\"----------------------------------------------------------\"];
Print[\" OMEGA  \",OMEGA//m];
Print[\"\"];
Print[\" STDO   \",STDO//m];
Print[\"----------------------------------------------------------\"];
Print[\" MUE    \",MUE//m];
Print[\"\"];
Print[\" STDMUE \",STDMUE//m];
Print[\"----------------------------------------------------------\"];
Print[\" SIGMA  \",SIGMA//m];
Print[\"\"];
Print[\" STDSIG \",STDSIG//m];
]

\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SetDelayed::write: Tag DELTA in DELTA[COV_, TH_] is \
Protected.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
$Failed\
\>", "\<\
$Failed\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(***************************************************************)
DELTASTERN[COV_,TH_,DT_,NONLIN_] := Module[
(***************************************************************)
(*DELTA-THEOREM f\[UDoubleDot]r Stern-Matrizen*)
{m,Ostern,Astern,Bstern,SIGMA,MUE,DOSDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,
 STDA,STDB,STDO,STDMUE,STDSIG},

{DOSDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,
\tOstern,Astern,Bstern,SIGMA,MUE} = ABL01[TH,DT,NONLIN];
\t
{P,Q}=Dimensions[Bstern];
STDA=STANDARD[DASDTH,COV,P,P];
STDB=STANDARD[DBSDTH,COV,P,Q];
STDO=STANDARD[DOSDTH,COV,P,P];
STDMUE=STANDARD[DMUEDTH,COV,P,1];
STDSIG=STANDARD[DSIGDTH,COV,P,P];
m = PaddedForm[MatrixForm[#,TableHeadings->None],{10,4}]&;
Print[\"----------------------------------------------------------\"];
Print[\"DELTA-THEOREM\"];
Print[\"----------------------------------------------------------\"];
Print[\"GESCH\[CapitalADoubleDot]TZTE STANDARDABWEICHUNGEN DER \
SYSTEM-MATRIZEN\"];
Print[\"A*, B*, OMEGA*, SIGMA UND MUE\"];
Print[\"----------------------------------------------------------\"];
Print[\" A*     \",Astern//m];
Print[\"\"];
Print[\" STDA   \",STDA//m];
Print[\"----------------------------------------------------------\"];
Print[\" B*     \",Bstern//m]; 
Print[\"\"];   
Print[\" STDB   \",STDB//m];
Print[\"----------------------------------------------------------\"];
Print[\" OMEGA* \",Ostern//m];
Print[\"\"];
Print[\" STDO   \",STDO//m];
Print[\"----------------------------------------------------------\"];
Print[\" MUE    \",MUE//m]; 
Print[\"\"];
Print[\" STDMUE \",STDMUE//m];
Print[\"----------------------------------------------------------\"];
Print[\" SIGMA  \",SIGMA//m];
Print[\"\"];
Print[\" STDSIG \",STDSIG//m];
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
NUMABL[THETA_,DT_,DIFF_,M0_,M00_,M_,N_,T_,NONLIN_] :=             
(***************************************************************)
(*NUMERISCHE ABLEITUNGEN*)

Module[{OMEGA,A,B,SIGMA,MUE,V,ASTERN,BSTERN,P,Q,PQ,P2,
\t\tVDach,H1,H2,H3,V1,SIGMA1,S0,DM,U,DIFF1,THI,
\t\tSCORE,LIKELI,LIKELII,DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,
\t\tVI,ASTERNI,BSTERNI,OMEGAI,AI,BI},


{OMEGA,A,B,SIGMA,MUE} = PAR[THETA];
{V,ASTERN,BSTERN} = STERN01[OMEGA,A,B,DT,NONLIN];
{P,Q}=A//Dimensions;

PQ=P*Q;
P2=P*P;
{LIKELI,VDach,H1,H2,H3,V1,SIGMA1,S0,DM} = 
\tLIKSTERN[ASTERN,BSTERN,V,MUE,SIGMA,M0,M00,M,N,T];


U=Length[THETA];
DIFF1=1/DIFF; (*INKREMENT*)
SCORE = {}; DVDTH = {}; DASDTH = {}; 
DBSDTH = {};  DSIGDTH = {};  DMUEDTH = {};
Do[ 
    THI=THETA;
    THI[[I]]=THI[[I]]+DIFF;
    {OMEGAI,AI,BI,SIGMAI,MUEI} = PAR[THI];
\t{VI,ASTERNI,BSTERNI} = STERN01[OMEGAI,AI,BI,DT,NONLIN];
\t{LIKELII,VDACHI,H1I,H2I,H3I,V1I,SIGMA1I,S0I,DMI} = 
\t\tLIKSTERN[ASTERNI,BSTERNI,VI,MUEI,SIGMAI,M0,M00,M,N,T];
    SCORE=Append[SCORE, DIFF1*(LIKELII-LIKELI)];
    DVDTH=Append[DVDTH,DIFF1*Flatten[VI-V]];
    DASDTH=Append[DASDTH,DIFF1*Flatten[ASTERNI-ASTERN]];
    DBSDTH=Append[DBSDTH,DIFF1*Flatten[BSTERNI-BSTERN]];
    DSIGDTH=Append[DSIGDTH,DIFF1*Flatten[SIGMAI-SIGMA]];
    DMUEDTH=Append[DMUEDTH,DIFF1*Flatten[MUEI-MUE]];
,{I,1,U}];

S=N*T*( -.5*DVDTH.Flatten[V1.(V-VDach).V1] +
          +DASDTH.Flatten[V1.H2] +
          +DBSDTH.Flatten[V1.H3]) +
  +N*(-.5*DSIGDTH.Flatten[SIGMA1.(SIGMA-S0).SIGMA1]
         + DMUEDTH.SIGMA1.DM );
Print[ \"NUMABL: SCORE MIT ANALYTISCHER FORMEL, NUMERISCHE KOEFFIZIENTEN\"];
Print[ \"NUMABL: REIN NUMERISCHER SCORE\"];
Print[MatrixForm[{S,SCORE,S-SCORE}//Transpose,
\t\tTableHeadings->{Automatic,{\"S1\",\"S2\",\"S1-S2\"}}]];

{SCORE,LIKELI,DVDTH,DASDTH,DBSDTH,DSIGDTH,DMUEDTH,
             V,ASTERN,BSTERN,SIGMA,MUE}

]

(************************************************************************)
ExpandK//Clear;
ExpandK[S_,KK_]:=
(************************************************************************)
\tModule[{j},
\tj=0;
\tTable[If[S[[i]] == 0, 0,
\t  \t\tIf[S[[i]] == 1,
\t  \t\tj+=1;KK[[j]],
\t  \t        -KK[[j]] ]],
\t{i,1,Length[S]}]
];

(************************************************************************)
ALIASING//Clear
ALIASING[A_,B_,OMEGA_,K_,DT_]:=
(************************************************************************)
Module[{P,P2,LAMBDA,EV,EV1,DL,AA,ELT0,EXPO,ASTERN,IP,IP2,
        BSTERN,L,V,m,S,NC,ANZ,K1,NN,AN,ASTERNN,BSTERNN,
        OMEGAN,EIGEN,VN,KL},
        
Print[\"***********************LSDE1******************************************\
\"];
Print[\"***********************MODUL: \
ALIASING********************************\"];
Print[\"**********************************************************************\
\"];
P=Length[A];
If[Im[A],Print[\"ALIASING: KOMPLEXE DRIFT\"];Return];
{LAMBDA,EV} = Eigensystem[A];
EV  = EV//Transpose;
EV1 = EV//Inverse//Chop;
DL = DiagonalMatrix[LAMBDA];
AA = EV.DL.EV1//Chop;
ELT0 = Exp[LAMBDA*DT];
EXP0 = DiagonalMatrix[ELT0];
ASTERN = EV.EXP0.EV1;
ASTERN= ASTERN//Chop;
IP  = IdentityMatrix[P];
IP2 = IdentityMatrix[P P];
BSTERN=Inverse[A].(ASTERN-IP).B;

L = A~KroneckerProduct~IP + IP~KroneckerProduct~A;
V=Shape[ Inverse[L].
\t\t((ASTERN~KroneckerProduct~ASTERN) -IP2).
\t\tFlatten[OMEGA],{P,P}];
         
Print[ \"--------------------ALIASING------------------------\"];
m = PaddedForm[MatrixForm[#]]&;
Print[\"A \",A//m,\"AA \",AA//m,\"LAMBDA \",LAMBDA//m];
Print[\"\"];
Print[\"EV \",EV//m];
Print[\"\"];
Print[\"EV1 \",EV1//m];
Print[\"\"];
Print[\"ASTERN \",ASTERN//m,\"BSTERN \",BSTERN//m,\"V \",V//m,\"DT \",DT];

S = Map[Sign[Im[#]]&,LAMBDA];
NC=Apply[Plus,S//Abs]/2;  
If[NC==0 ,Print[\"KEINE C.C. EW\"; Return]];
ANZ=Length[K];

K1 = Map[ExpandK[S,#]&,K];
Print[\"Expandierte Integer-Vektoren  \",K1//m];

Table[ 

NN=DiagonalMatrix[K1[[L]] ];
AN=A + EV.NN.EV1*(2 Pi I /DT)//N//Chop;
ASTERNN = MatrixExp[AN*DT];
BN=Inverse[ASTERN-IP].AN.BSTERN//N//Chop;
BSTERNN=Inverse[AN].(ASTERN-IP).BN;
LN = (AN~KroneckerProduct~IP)+(IP~KroneckerProduct~AN);
OMEGAN=Shape[Inverse[ASTERN~KroneckerProduct~ASTERN-IP2].LN.Flatten[V],{P,P}]/\
/N//Chop;
EIGEN=Eigenvalues[OMEGAN];
VN=Shape[Inverse[LN].(ASTERN~KroneckerProduct~ASTERN-IP2).Flatten[OMEGAN],{P,\
P}]//N//Chop;


KL=K[[L]];
Print[\"\"];
Print[\"--------------------ALIASING------------------- L \",L,\"  KL  \
\",KL];
Print[\"\"];
Print[\"  A\",A//m,\"  AN\",AN//m,\"  ASTERNN\",ASTERNN//m];
Print[\"\"];
Print[\"  B\",B//m,\"  BN\",BN//m,\"  BSTERNN\",BSTERNN//m];
Print[\"\"];
Print[\"  OMEGA\",OMEGA//m,\"  OMEGAN\",OMEGAN//m];
Print[\"\"];
Print[\"  EIGEN\",EIGEN//m,\"  VN\",VN//m];
{AN,BN,OMEGAN}
,{L,1,ANZ}]

]

(************************************************************************)
MatrixLog[A_]:= 
(************************************************************************)
Module[{EW,EV,logEW},
{EW,EV} = Eigensystem[A];
EV = EV//Transpose;
logEW = Log[EW];
{EV.DiagonalMatrix[logEW].Inverse[EV],EW,EV}//Chop
]


(************************************************************************)
Indirekt[{Ostern_,Astern_,Bstern_}]:=
(************************************************************************)
Module[{A,lambda,P,p = Length[Astern],Ip,B,L,Omega},

{A,lambda,P} = MatrixLog[Astern];
Ip = IdentityMatrix[p]; 
B = A.Inverse[Astern-Ip].Bstern;
L = A~KroneckerProduct~Ip + Ip~KroneckerProduct~A ;
Omega = L.Inverse[Astern~KroneckerProduct~Astern-
                  IdentityMatrix[p^2]].Flatten[Ostern];
Omega = Shape[Omega,{p,p}];
{Omega,A,B}]



(************************************************************************)
L[A_,B_]:= A~KroneckerProduct~B + B~KroneckerProduct~A;
(************************************************************************)

(************************************************************************)
SigmaStat[A_,Omega_]:= Module[{Id,p,LL},
(************************************************************************)
p=A//Length;
Id=IdentityMatrix[p];
LL=L[A,Id];
Shape[-Inverse[LL].Flatten[Omega],{p,p}]
]

\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
End[]

Protect[Names[\"code`PARTest`*\"]//Evaluate];

EndPackage[ ]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{641, 679},
WindowMargins->{{Automatic, 38}, {Automatic, 10}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
0000001804P000000bd2=_oaoo43?095o`85N@?NW0002008ool000001@050001
0000I24A4R060`410@000BL?0040000000000000000004E3<34100;o00000001
000A0S<R<3`00Q3400018NOWinOWia4A\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 189, 8, 87, "Input",
  InitializationCell->True],
Cell[1946, 61, 539, 14, 162, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2510, 79, 60, 1, 56, "Section"],
Cell[2573, 82, 1503, 56, 837, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[4113, 143, 96, 2, 56, "Section",
  InitializationCell->True],
Cell[4212, 147, 109, 6, 57, "Input",
  InitializationCell->True],
Cell[4324, 155, 280, 8, 87, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4629, 167, 107, 6, 72, "Input"],
Cell[4739, 175, 150, 6, 33, "Output"],
Cell[4892, 183, 150, 6, 33, "Output"]
}, Open  ]],
Cell[5057, 192, 462, 15, 192, "Input",
  InitializationCell->True],
Cell[5522, 209, 461, 14, 177, "Input",
  InitializationCell->True],
Cell[5986, 225, 592, 21, 297, "Input",
  InitializationCell->True],
Cell[6581, 248, 896, 27, 432, "Input",
  InitializationCell->True],
Cell[7480, 277, 285, 9, 102, "Input",
  InitializationCell->True],
Cell[7768, 288, 2943, 117, 1752, "Input",
  InitializationCell->True],
Cell[10714, 407, 549, 14, 70, "Input",
  InitializationCell->True],
Cell[11266, 423, 578, 21, 70, "Input",
  InitializationCell->True],
Cell[11847, 446, 439, 11, 70, "Input",
  InitializationCell->True],
Cell[12289, 459, 718, 22, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[13032, 485, 61, 1, 70, "Input"],
Cell[13096, 488, 1705, 30, 70, "Print"]
}, Open  ]],
Cell[14816, 521, 1636, 60, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[16477, 585, 55, 1, 70, "Input"],
Cell[16535, 588, 1446, 27, 70, "Print"]
}, Open  ]],
Cell[17996, 618, 1099, 36, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[19120, 658, 60, 1, 70, "Input"],
Cell[19183, 661, 941, 19, 70, "Print"]
}, Open  ]],
Cell[20139, 683, 540, 15, 70, "Input",
  InitializationCell->True],
Cell[20682, 700, 597, 20, 267, "Input",
  InitializationCell->True],
Cell[21282, 722, 122, 4, 27, "Input"],
Cell[21407, 728, 111, 1, 27, "Input"],
Cell[21521, 731, 374, 12, 147, "Input",
  InitializationCell->True],
Cell[21898, 745, 330, 8, 87, "Input",
  InitializationCell->True],
Cell[22231, 755, 332, 8, 87, "Input",
  InitializationCell->True],
Cell[22566, 765, 550, 16, 207, "Input",
  InitializationCell->True],
Cell[23119, 783, 336, 10, 117, "Input",
  InitializationCell->True],
Cell[23458, 795, 339, 12, 147, "Input",
  InitializationCell->True],
Cell[23800, 809, 454, 11, 117, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[24279, 824, 4278, 67, 2156, "Input",
  InitializationCell->True],
Cell[28560, 893, 194, 5, 34, "Message"],
Cell[28757, 900, 102, 5, 24, "Output"]
}, Open  ]],
Cell[28874, 908, 1811, 51, 732, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[30710, 963, 87, 1, 70, "Input"],
Cell[30800, 966, 777, 25, 330, "Print"],
Cell[31580, 993, 156, 6, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31773, 1004, 333, 9, 102, "Input",
  InitializationCell->True],
Cell[32109, 1015, 138, 4, 21, "Message"],
Cell[32250, 1021, 102, 5, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32389, 1031, 112, 1, 27, "Input"],
Cell[32504, 1034, 104, 4, 36, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32645, 1043, 392, 11, 132, "Input",
  InitializationCell->True],
Cell[33040, 1056, 138, 4, 21, "Message"],
Cell[33181, 1062, 102, 5, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33320, 1072, 149, 4, 42, "Input"],
Cell[33472, 1078, 146, 10, 120, "Print"]
}, Open  ]],
Cell[33633, 1091, 981, 27, 372, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[34639, 1122, 69, 1, 27, "Input"],
Cell[34711, 1125, 412, 10, 120, "Print"]
}, Open  ]],
Cell[35138, 1138, 1325, 32, 432, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[36488, 1174, 165, 4, 54, "Input"],
Cell[36656, 1180, 91, 1, 22, "Print"],
Cell[36750, 1183, 80, 1, 22, "Print"],
Cell[36833, 1186, 91, 1, 22, "Print"],
Cell[36927, 1189, 1211, 25, 51, "Print"],
Cell[38141, 1216, 89, 1, 22, "Print"],
Cell[38233, 1219, 45, 1, 22, "Print"],
Cell[38281, 1222, 89, 1, 22, "Print"],
Cell[38373, 1225, 562, 14, 31, "Print"],
Cell[38938, 1241, 89, 1, 22, "Print"],
Cell[39030, 1244, 66, 1, 22, "Print"],
Cell[39099, 1247, 89, 1, 22, "Print"],
Cell[39191, 1250, 89, 1, 22, "Print"],
Cell[39283, 1253, 208, 4, 22, "Print"],
Cell[39494, 1259, 758, 18, 51, "Print"],
Cell[40255, 1279, 90, 1, 22, "Print"],
Cell[40348, 1282, 74, 1, 22, "Print"],
Cell[40425, 1285, 90, 1, 22, "Print"],
Cell[40518, 1288, 319, 8, 53, "Print"],
Cell[40840, 1298, 91, 1, 22, "Print"],
Cell[40934, 1301, 97, 2, 22, "Print"],
Cell[41034, 1305, 91, 1, 22, "Print"],
Cell[41128, 1308, 319, 8, 53, "Print"],
Cell[41450, 1318, 45, 1, 22, "Print"],
Cell[41498, 1321, 103, 2, 22, "Print"],
Cell[41604, 1325, 91, 1, 22, "Print"],
Cell[41698, 1328, 108, 2, 22, "Print"],
Cell[41809, 1332, 91, 1, 22, "Print"],
Cell[41903, 1335, 310, 8, 53, "Print"],
Cell[42216, 1345, 45, 1, 22, "Print"],
Cell[42264, 1348, 87, 1, 22, "Print"],
Cell[42354, 1351, 142, 2, 38, "Output"]
}, Open  ]],
Cell[42511, 1356, 486, 13, 162, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[43022, 1373, 94, 1, 27, "Input"],
Cell[43119, 1376, 251, 8, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43407, 1389, 1678, 48, 672, "Input",
  InitializationCell->True],
Cell[45088, 1439, 125, 4, 21, "Message"],
Cell[45216, 1445, 102, 5, 70, "Output"]
}, Open  ]],
Cell[45333, 1453, 1783, 47, 672, "Input",
  InitializationCell->True],
Cell[47119, 1502, 6145, 196, 3102, "Input",
  InitializationCell->True],
Cell[53267, 1700, 154, 8, 87, "Input",
  InitializationCell->True]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

